module FHIR
  module STU3
    class NutritionOrder < FHIR::STU3::Model
      include FHIR::STU3::Hashable
      include FHIR::STU3::Json
      include FHIR::STU3::Xml

      SEARCH_PARAMS = ['identifier', 'patient', 'encounter', 'additive', 'datetime', 'formula', 'oraldiet', 'provider', 'status', 'supplement']
      METADATA = {
        'id' => {'type'=>'id', 'path'=>'NutritionOrder.id', 'min'=>0, 'max'=>1},
        'meta' => {'type'=>'Meta', 'path'=>'NutritionOrder.meta', 'min'=>0, 'max'=>1},
        'implicitRules' => {'type'=>'uri', 'path'=>'NutritionOrder.implicitRules', 'min'=>0, 'max'=>1},
        'language' => {'valid_codes'=>{'urn:ietf:bcp:47'=>['ar', 'bn', 'cs', 'da', 'de', 'de-AT', 'de-CH', 'de-DE', 'el', 'en', 'en-AU', 'en-CA', 'en-GB', 'en-IN', 'en-NZ', 'en-SG', 'en-US', 'es', 'es-AR', 'es-ES', 'es-UY', 'fi', 'fr', 'fr-BE', 'fr-CH', 'fr-FR', 'fy', 'fy-NL', 'hi', 'hr', 'it', 'it-CH', 'it-IT', 'ja', 'ko', 'nl', 'nl-BE', 'nl-NL', 'no', 'no-NO', 'pa', 'pt', 'pt-BR', 'ru', 'ru-RU', 'sr', 'sr-SP', 'sv', 'sv-SE', 'te', 'zh', 'zh-CN', 'zh-HK', 'zh-SG', 'zh-TW']}, 'type'=>'code', 'path'=>'NutritionOrder.language', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'extensible', 'uri'=>'http://hl7.org/fhir/ValueSet/languages'}},
        'text' => {'type'=>'Narrative', 'path'=>'NutritionOrder.text', 'min'=>0, 'max'=>1},
        'contained' => {'type'=>'Resource', 'path'=>'NutritionOrder.contained', 'min'=>0, 'max'=>Float::INFINITY},
        'extension' => {'type'=>'Extension', 'path'=>'NutritionOrder.extension', 'min'=>0, 'max'=>Float::INFINITY},
        'modifierExtension' => {'type'=>'Extension', 'path'=>'NutritionOrder.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
        'identifier' => {'type'=>'Identifier', 'path'=>'NutritionOrder.identifier', 'min'=>0, 'max'=>Float::INFINITY},
        'status' => {'valid_codes'=>{'http://hl7.org/fhir/nutrition-request-status'=>['proposed', 'draft', 'planned', 'requested', 'active', 'on-hold', 'completed', 'cancelled', 'entered-in-error']}, 'type'=>'code', 'path'=>'NutritionOrder.status', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'required', 'uri'=>'http://hl7.org/fhir/ValueSet/nutrition-request-status'}},
        'patient' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Patient'], 'type'=>'Reference', 'path'=>'NutritionOrder.patient', 'min'=>1, 'max'=>1},
        'encounter' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Encounter'], 'type'=>'Reference', 'path'=>'NutritionOrder.encounter', 'min'=>0, 'max'=>1},
        'dateTime' => {'type'=>'dateTime', 'path'=>'NutritionOrder.dateTime', 'min'=>1, 'max'=>1},
        'orderer' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Practitioner'], 'type'=>'Reference', 'path'=>'NutritionOrder.orderer', 'min'=>0, 'max'=>1},
        'allergyIntolerance' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/AllergyIntolerance'], 'type'=>'Reference', 'path'=>'NutritionOrder.allergyIntolerance', 'min'=>0, 'max'=>Float::INFINITY},
        'foodPreferenceModifier' => {'valid_codes'=>{'http://hl7.org/fhir/diet'=>['vegetarian', 'dairy-free', 'nut-free', 'gluten-free', 'vegan', 'halal', 'kosher']}, 'type'=>'CodeableConcept', 'path'=>'NutritionOrder.foodPreferenceModifier', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/encounter-diet'}},
        'excludeFoodModifier' => {'valid_codes'=>{'http://snomed.info/sct'=>['3718001', '4700006', '7661006', '7791007', '10249006', '10827009', '13577000', '14263006', '22836000', '23182003', '24515005', '25743006', '28230009', '28647000', '28942008', '39102003', '41834005', '43708003', '44027008', '44632005', '46329000', '50479000', '50593009', '51905005', '53875002', '54041009', '63045006', '63766005', '67324005', '70813002', '72511004', '74242007', '75476008', '77722008', '80743002', '82450006', '82566005', '83235009', '83595008', '85668006', '89707004', '89811004', '90677004', '91606004', '96364008', '102259006', '102260001', '102261002', '102262009', '102263004', '102264005', '102270004', '102271000', '102697003', '102698008', '102699000', '108743002', '109010000', '116957009', '117633004', '126076005', '126077001', '126078006', '126079003', '126080000', '126081001', '126082008', '127384006', '226017009', '226021002', '226022009', '226023004', '226024005', '226037008', '226041007', '226046002', '226061001', '226062008', '226358006', '226359003', '226367006', '226368001', '226491003', '226492005', '226493000', '226495007', '226496008', '226497004', '226498009', '226529007', '226530002', '226531003', '226532005', '226533000', '226534006', '226535007', '226536008', '226537004', '226538009', '226539001', '226540004', '226541000', '226542007', '226543002', '226544008', '226546005', '226547001', '226548006', '226549003', '226550003', '226551004', '226552006', '226553001', '226554007', '226555008', '226556009', '226557000', '226558005', '226559002', '226560007', '226561006', '226562004', '226563009', '226564003', '226565002', '226566001', '226567005', '226568000', '226569008', '226570009', '226571008', '226572001', '226574000', '226575004', '226576003', '226577007', '226578002', '226579005', '226580008', '226581007', '226582000', '226583005', '226584004', '226585003', '226587006', '226589009', '226590000', '226592008', '226593003', '226595005', '226596006', '226597002', '226598007', '226601002', '226604005', '226605006', '226611009', '226612002', '226613007', '226614001', '226616004', '226617008', '226618003', '226619006', '226620000', '226621001', '226622008', '226639005', '226640007', '226641006', '226642004', '226643009', '226644003', '226645002', '226647005', '226648000', '226649008', '226650008', '226651007', '226652000', '226653005', '226654004', '226655003', '226656002', '226657006', '226658001', '226659009', '226660004', '226661000', '226662007', '226663002', '226664008', '226665009', '226666005', '226667001', '226668006', '226669003', '226670002', '226671003', '226672005', '226673000', '226674006', '226675007', '226676008', '226677004', '226678009', '226679001', '226680003', '226681004', '226682006', '226683001', '226684007', '226685008', '226686009', '226687000', '226688005', '226689002', '226690006', '226691005', '226692003', '226693008', '226694002', '226695001', '226697009', '226698004', '226699007', '226700008', '226701007', '226702000', '226703005', '226704004', '226705003', '226706002', '226707006', '226708001', '226709009', '226710004', '226711000', '226712007', '226713002', '226714008', '226715009', '226716005', '226717001', '226718006', '226719003', '226720009', '226721008', '226722001', '226723006', '226724000', '226725004', '226726003', '226727007', '226728002', '226729005', '226730000', '226731001', '226732008', '226733003', '226734009', '226735005', '226736006', '226737002', '226738007', '226739004', '226740002', '226741003', '226742005', '226743000', '226744006', '226745007', '226746008', '226747004', '226748009', '226749001', '226750001', '226751002', '226752009', '226753004', '226754005', '226755006', '226756007', '226757003', '226758008', '226759000', '226760005', '226761009', '226762002', '226763007', '226764001', '226765000', '226766004', '226767008', '226768003', '226769006', '226770007', '226771006', '226774003', '226775002', '226776001', '226777005', '226778000', '226779008', '226780006', '226781005', '226782003', '226783008', '226784002', '226785001', '226786000', '226787009', '226788004', '226789007', '226790003', '226791004', '226793001', '226795008', '226796009', '226797000', '226798005', '226799002', '226800003', '226801004', '226802006', '226803001', '226804007', '226805008', '226806009', '226807000', '226808005', '226809002', '226810007', '226811006', '226812004', '226813009', '226814003', '226815002', '226816001', '226817005', '226818000', '226819008', '226820002', '226821003', '226822005', '226823000', '226824006', '226825007', '226826008', '226827004', '226828009', '226829001', '226830006', '226831005', '226832003', '226834002', '226835001', '226836000', '226837009', '226838004', '226839007', '226840009', '226841008', '226842001', '226843006', '226844000', '226845004', '226846003', '226847007', '226848002', '226849005', '226850005', '226851009', '226852002', '226853007', '226854001', '226855000', '226856004', '226857008', '226858003', '226859006', '226860001', '226861002', '226862009', '226863004', '226864005', '226865006', '226866007', '226867003', '226868008', '226869000', '226870004', '226871000', '226872007', '226873002', '226874008', '226875009', '226876005', '226877001', '226878006', '226879003', '226880000', '226881001', '226882008', '226883003', '226884009', '226885005', '226886006', '226887002', '226888007', '226889004', '226890008', '226891007', '226892000', '226894004', '226895003', '226896002', '226897006', '226898001', '226899009', '226900004', '226901000', '226902007', '226903002', '226904008', '226905009', '226906005', '226907001', '226908006', '226909003', '226910008', '226911007', '226912000', '226913005', '226914004', '226915003', '226916002', '226917006', '226918001', '226919009', '226920003', '226921004', '226922006', '226923001', '226924007', '226925008', '226926009', '226927000', '226928005', '226929002', '226930007', '226931006', '226932004', '226933009', '226934003', '226935002', '226936001', '226937005', '226938000', '226939008', '226940005', '226941009', '226942002', '226943007', '226944001', '226945000', '226946004', '226947008', '226948003', '226949006', '226950006', '226951005', '226952003', '226953008', '226954002', '226955001', '226956000', '226957009', '226958004', '226959007', '226960002', '226961003', '226962005', '226963000', '226964006', '226965007', '226966008', '226967004', '226968009', '226969001', '226970000', '226971001', '226972008', '226973003', '226974009', '226975005', '226976006', '226977002', '226978007', '226979004', '226980001', '226981002', '226982009', '226983004', '226984005', '226985006', '226987003', '226988008', '226989000', '226990009', '226991008', '226992001', '226993006', '226994000', '226995004', '226996003', '226997007', '226998002', '226999005', '227000008', '227001007', '227002000', '227003005', '227004004', '227005003', '227006002', '227007006', '227008001', '227009009', '227010004', '227011000', '227012007', '227013002', '227014008', '227015009', '227016005', '227017001', '227018006', '227019003', '227020009', '227021008', '227022001', '227023006', '227024000', '227025004', '227026003', '227027007', '227028002', '227029005', '227030000', '227031001', '227032008', '227033003', '227034009', '227036006', '227037002', '227038007', '227040002', '227041003', '227042005', '227043000', '227044006', '227045007', '227046008', '227047004', '227048009', '227049001', '227050001', '227051002', '227052009', '227053004', '227054005', '227055006', '227056007', '227057003', '227058008', '227059000', '227060005', '227061009', '227062002', '227063007', '227064001', '227065000', '227066004', '227067008', '227068003', '227069006', '227070007', '227071006', '227072004', '227073009', '227074003', '227075002', '227076001', '227078000', '227079008', '227080006', '227081005', '227082003', '227083008', '227084002', '227085001', '227086000', '227087009', '227088004', '227089007', '227091004', '227092006', '227093001', '227094007', '227095008', '227096009', '227097000', '227098005', '227099002', '227100005', '227101009', '227102002', '227103007', '227104001', '227105000', '227106004', '227107008', '227108003', '227109006', '227110001', '227111002', '227112009', '227113004', '227114005', '227115006', '227116007', '227117003', '227118008', '227119000', '227120006', '227121005', '227122003', '227123008', '227124002', '227125001', '227126000', '227127009', '227128004', '227129007', '227130002', '227131003', '227132005', '227133000', '227134006', '227135007', '227136008', '227137004', '227138009', '227139001', '227140004', '227141000', '227142007', '227143002', '227144008', '227145009', '227146005', '227147001', '227148006', '227149003', '227150003', '227151004', '227152006', '227153001', '227154007', '227155008', '227156009', '227157000', '227158005', '227159002', '227160007', '227161006', '227162004', '227163009', '227164003', '227165002', '227167005', '227168000', '227169008', '227170009', '227171008', '227172001', '227173006', '227174000', '227175004', '227176003', '227177007', '227178002', '227179005', '227180008', '227181007', '227182000', '227183005', '227184004', '227185003', '227186002', '227187006', '227188001', '227189009', '227190000', '227191001', '227193003', '227194009', '227195005', '227196006', '227197002', '227198007', '227199004', '227200001', '227201002', '227202009', '227203004', '227204005', '227205006', '227206007', '227207003', '227208008', '227209000', '227210005', '227212002', '227213007', '227214001', '227215000', '227216004', '227217008', '227218003', '227219006', '227220000', '227221001', '227222008', '227223003', '227224009', '227225005', '227226006', '227227002', '227228007', '227229004', '227230009', '227231008', '227232001', '227233006', '227234000', '227235004', '227236003', '227237007', '227238002', '227239005', '227240007', '227241006', '227242004', '227243009', '227244003', '227245002', '227246001', '227247005', '227248000', '227249008', '227250008', '227251007', '227252000', '227253005', '227254004', '227255003', '227256002', '227257006', '227258001', '227259009', '227260004', '227261000', '227262007', '227263002', '227264008', '227265009', '227266005', '227267001', '227268006', '227269003', '227270002', '227271003', '227272005', '227273000', '227274006', '227275007', '227276008', '227277004', '227278009', '227279001', '227280003', '227281004', '227282006', '227283001', '227284007', '227285008', '227286009', '227287000', '227288005', '227289002', '227290006', '227291005', '227292003', '227294002', '227295001', '227296000', '227297009', '227298004', '227299007', '227300004', '227301000', '227302007', '227303002', '227304008', '227305009', '227306005', '227307001', '227308006', '227309003', '227310008', '227311007', '227312000', '227313005', '227314004', '227315003', '227316002', '227317006', '227318001', '227319009', '227320003', '227321004', '227322006', '227323001', '227324007', '227325008', '227326009', '227327000', '227328005', '227329002', '227330007', '227331006', '227332004', '227333009', '227334003', '227335002', '227336001', '227337005', '227338000', '227339008', '227340005', '227341009', '227342002', '227343007', '227344001', '227345000', '227346004', '227347008', '227348003', '227349006', '227350006', '227351005', '227352003', '227353008', '227354002', '227355001', '227356000', '227357009', '227358004', '227359007', '227360002', '227361003', '227362005', '227363000', '227364006', '227365007', '227366008', '227367004', '227368009', '227369001', '227370000', '227371001', '227372008', '227373003', '227374009', '227375005', '227376006', '227377002', '227378007', '227379004', '227380001', '227381002', '227382009', '227383004', '227384005', '227385006', '227386007', '227387003', '227388008', '227389000', '227390009', '227391008', '227392001', '227393006', '227395004', '227396003', '227397007', '227398002', '227399005', '227400003', '227401004', '227402006', '227403001', '227404007', '227405008', '227406009', '227407000', '227408005', '227409002', '227410007', '227411006', '227412004', '227413009', '227414003', '227415002', '227416001', '227417005', '227418000', '227419008', '227420002', '227421003', '227422005', '227423000', '227424006', '227425007', '227426008', '227427004', '227428009', '227429001', '227430006', '227431005', '227432003', '227433008', '227434002', '227435001', '227436000', '227437009', '227438004', '227439007', '227440009', '227441008', '227442001', '227443006', '227444000', '227445004', '227446003', '227447007', '227448002', '227449005', '227450005', '227451009', '227452002', '227453007', '227454001', '227455000', '227456004', '227457008', '227458003', '227459006', '227460001', '227461002', '227462009', '227463004', '227464005', '227465006', '227466007', '227467003', '227468008', '227469000', '227470004', '227471000', '227472007', '227473002', '227474008', '227475009', '227476005', '227477001', '227478006', '227479003', '227480000', '227481001', '227482008', '227483003', '227484009', '227485005', '227486006', '227487002', '227488007', '227489004']}, 'type'=>'CodeableConcept', 'path'=>'NutritionOrder.excludeFoodModifier', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/food-type'}},
        'oralDiet' => {'type'=>'NutritionOrder::OralDiet', 'path'=>'NutritionOrder.oralDiet', 'min'=>0, 'max'=>1},
        'supplement' => {'type'=>'NutritionOrder::Supplement', 'path'=>'NutritionOrder.supplement', 'min'=>0, 'max'=>Float::INFINITY},
        'enteralFormula' => {'type'=>'NutritionOrder::EnteralFormula', 'path'=>'NutritionOrder.enteralFormula', 'min'=>0, 'max'=>1}
      }

      class OralDiet < FHIR::STU3::Model
        include FHIR::STU3::Hashable
        include FHIR::STU3::Json
        include FHIR::STU3::Xml

        METADATA = {
          'id' => {'type'=>'string', 'path'=>'OralDiet.id', 'min'=>0, 'max'=>1},
          'extension' => {'type'=>'Extension', 'path'=>'OralDiet.extension', 'min'=>0, 'max'=>Float::INFINITY},
          'modifierExtension' => {'type'=>'Extension', 'path'=>'OralDiet.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
          'type' => {'valid_codes'=>{'http://snomed.info/sct'=>['38903004', '50712000', '56948003', '61420007', '182954008', '182955009', '182956005', '182957001', '182958006', '182959003', '182960008', '183028005', '223456000', '225373002', '225374008', '229912004', '229913009', '229914003', '229915002', '229916001', '229917005', '284071006', '289133003', '310244003', '361231003', '386261001', '404919001', '422972009', '425458000', '1151000175103']}, 'type'=>'CodeableConcept', 'path'=>'OralDiet.type', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/diet-type'}},
          'schedule' => {'type'=>'Timing', 'path'=>'OralDiet.schedule', 'min'=>0, 'max'=>Float::INFINITY},
          'nutrient' => {'type'=>'NutritionOrder::OralDiet::Nutrient', 'path'=>'OralDiet.nutrient', 'min'=>0, 'max'=>Float::INFINITY},
          'texture' => {'type'=>'NutritionOrder::OralDiet::Texture', 'path'=>'OralDiet.texture', 'min'=>0, 'max'=>Float::INFINITY},
          'fluidConsistencyType' => {'valid_codes'=>{'http://snomed.info/sct'=>['439031000124108', '439021000124105', '439041000124103', '439081000124109']}, 'type'=>'CodeableConcept', 'path'=>'OralDiet.fluidConsistencyType', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/consistency-type'}},
          'instruction' => {'type'=>'string', 'path'=>'OralDiet.instruction', 'min'=>0, 'max'=>1}
        }

        class Nutrient < FHIR::STU3::Model
          include FHIR::STU3::Hashable
          include FHIR::STU3::Json
          include FHIR::STU3::Xml

          METADATA = {
            'id' => {'type'=>'string', 'path'=>'Nutrient.id', 'min'=>0, 'max'=>1},
            'extension' => {'type'=>'Extension', 'path'=>'Nutrient.extension', 'min'=>0, 'max'=>Float::INFINITY},
            'modifierExtension' => {'type'=>'Extension', 'path'=>'Nutrient.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
            'modifier' => {'valid_codes'=>{'http://snomed.info/sct'=>['33463005', '39972003', '88480006', '925002', '1025008', '1057009', '1368003', '1381005', '1603001', '2264001', '2331003', '2942001', '3161008', '3212004', '3325005', '3342004', '3617004', '3829006', '3932008', '3945007', '5167005', '5312000', '5405008', '6083003', '6881002', '6910009', '6927001', '6952004', '7156005', '7774008', '7791007', '8143001', '8534003', '8919000', '9396007', '9797000', '9992001', '10466005', '10644005', '10767000', '10790005', '10796004', '11121002', '11202003', '11320009', '11331001', '11984007', '12597001', '12689001', '12930006', '12970004', '13235001', '13342004', '13863008', '14125007', '14139007', '14312008', '14399003', '14564001', '14645000', '14971004', '15331006', '15472007', '16850006', '18039003', '18414002', '19160003', '19427006', '19622008', '19839007', '21075006', '21239003', '21559000', '21572004', '21706000', '22038003', '22362000', '22555008', '22559002', '22606007', '23433006', '23459009', '23692005', '25128000', '25183006', '25205007', '25710007', '25761002', '26327007', '26645004', '26766001', '27054007', '27122000', '27378009', '29011006', '29531004', '30094001', '30178006', '30179003', '30324001', '30589007', '30820000', '31731008', '32505007', '32714004', '32741009', '33396006', '33922005', '34274009', '34471003', '35321007', '35344005', '35733004', '35883004', '36397007', '36434002', '36816009', '36998008', '37123002', '37225000', '37237003', '38182007', '38595007', '38623000', '38794009', '38839009', '39292004', '39360003', '39546001', '40479008', '40924008', '40937006', '41441005', '41464007', '41503000', '42146005', '42180008', '42193003', '42730005', '42841002', '43239002', '43289005', '43431002', '43613009', '43706004', '43728004', '43835003', '43897008', '43909000', '44044007', '44262008', '44588005', '44970006', '45158004', '45962009', '46075000', '46257009', '47192000', '47703008', '48736006', '48861002', '49506005', '50233008', '50374006', '50479000', '51224002', '51774004', '52130006', '52625008', '52717004', '52736009', '52745005', '52860004', '53499005', '53560004', '53646005', '53700003', '53834009', '54045000', '54083004', '54517000', '54808007', '54821000', '55328009', '55495002', '55946005', '56158000', '56383006', '56740002', '57272005', '57273000', '57279001', '58202007', '58279004', '58292001', '58753009', '60244003', '60260004', '60764009', '60908004', '61025005', '61045002', '61244006', '62174006', '62442005', '62754006', '62763008', '63004003', '63089006', '63330006', '63349005', '63383003', '63718003', '63793008', '64179000', '64538009', '65054007', '65183007', '65586005', '66656000', '66781008', '66925006', '66945003', '66956003', '67060008', '67079006', '67154005', '67266008', '67377000', '67517005', '67535001', '67690002', '67719005', '68024001', '68077006', '68334004', '68580003', '68630002', '68992005', '69089000', '69169004', '69324000', '69750003', '69770009', '69783005', '70203000', '70288006', '70319005', '70496003', '70587000', '70706009', '70726008', '71128006', '71425003', '71544008', '72164009', '72309009', '72717003', '72835003', '72840006', '73131003', '73353008', '73722009', '73916008', '74718007', '74801000', '75665004', '75799006', '75815006', '75871008', '75876003', '75951003', '77004003', '77404006', '77454000', '77923008', '78481003', '78527003', '78529000', '78671009', '78686003', '78870008', '80393001', '80582002', '80916004', '81100008', '82224005', '82481002', '82622003', '83797003', '83873000', '83912003', '84553006', '84987009', '85214009', '85369009', '85668006', '85958004', '86399009', '86431009', '86739005', '86865003', '86953001', '87116002', '87136001', '87371008', '87437000', '87445005', '87708000', '87802005', '87869004', '88166005', '88236008', '88262004', '88546006', '88617009', '88954003', '89272005', '89351005', '89702005', '89867007', '90150007', '90544008', '90567005', '90664008', '90733003', '91166002', '91255004', '95970003', '96277001', '96335004', '102258003', '102658006', '102661007', '102663005', '102747008', '102750006', '103067001', '103068006', '103069003', '103070002', '103072005', '103074006', '105824007', '108946001', '109064002', '109224005', '109240008', '111039007', '111065006', '111066007', '111069000', '111070004', '111071000', '111078006', '112000000', '112121003', '115599005', '116094003', '116119005', '116120004', '116123002', '116124008', '116128006', '116256008', '116257004', '116258009', '116259001', '116260006', '116261005', '116262003', '116263008', '116264002', '116265001', '116266000', '116267009', '116268004', '116269007', '116271007', '116272000', '116776001', '116777005', '116778000', '116934003', '117634005', '126076005', '126077001', '126078006', '126079003', '126080000', '126081001', '126082008', '126224002', '126225001', '126226000', '126227009', '126228004', '126229007', '126230002', '126231003', '126235007', '126237004', '126238009', '126239001', '129497004', '173196005', '226356005', '226358006', '226369009', '226370005', '226371009', '226372002', '226373007', '226374001', '226375000', '226781005', '226793001', '226842001', '226880000', '226911007', '227365007', '227366008', '227367004', '227368009', '227537006', '227948007', '227991002', '227992009', '227993004', '227994005', '227995006', '227996007', '229941008', '229949005', '255673007', '255954005', '256227006', '256579008', '259333003', '259336006', '259337002', '259382003', '259403006', '259406003', '259411001', '259509008', '259512006', '259651009', '259655000', '259656004', '259659006', '259660001', '259661002', '259662009', '259663004', '259665006', '259666007', '261353004', '273943001', '277951002', '277953004', '277954005', '284460001', '290131005', '301862003', '304051003', '311719002', '312184007', '312276003', '372601001', '372639009', '386927006', '386932007', '386989006', '387021003', '387030006', '387082008', '387131008', '387206004', '387367007', '387415009', '391734004', '395750001', '395751002', '395752009', '395753004', '395754005', '395756007', '395757003', '395758008', '395759000', '395760005', '395766004', '395769006', '395775002', '395782003', '395787009', '395789007', '395791004', '395792006', '395815002', '395830006', '395838004', '395839007', '395840009', '395875009', '395877001', '395878006', '395879003', '395894004', '395925008', '395941009', '395951005', '395952003', '395981002', '395982009', '396003009', '396020008', '396056006', '396065004', '398939009', '409093004', '409094005', '409257009', '409258004', '409871008', '411332009', '412135003', '412203006', '412227008', '412228003', '412230001', '412244007', '412250002', '412410003', '412415008', '412512009', '412595005', '413483001', '414506003', '415543009', '415562007', '417955006', '418346004', '418407000', '418692007', '418929008', '418990001', '419297002', '419382002', '419432008', '419508004', '419679002', '420075002', '421289007', '421526004', '421621000', '421881000', '422073002', '422160004', '422934004', '423061008', '423071005', '423249007', '423373002', '423388007', '423432002', '423725005', '423795001', '423809007', '425329004', '425364008', '425702007', '425867009', '425874004', '426722004', '427638006', '428732003', '429592005', '429990006', '430469009', '430632000', '430633005', '430634004', '430926008', '432165000', '432219009', '432884004', '433468002', '438901003', '442247006', '442330008', '442340006', '442346000', '443148002', '446531006', '447134003', '449236003', '456992002', '456995000', '456997008', '456999006', '457000009', '699182008', '702796008', '703391005', '703394002', '703395001', '703399007', '703402008', '704384003', '704430002', '706927001', '706929003', '706930008', '706936002', '706938001', '706941005', '706942003', '706943008', '706978008', '706980002', '707019004', '707020005', '707053000', '707070008', '707071007', '707184000', '707244004', '707614005', '707661006', '707677007', '708047003', '708053003', '708259008', '708264007', '708267000', '708272009', '708276007', '708280002', '708290005', '708296004', '708303001', '708310007', '708316001', '708348002', '708351009', '708354001', '708356004', '708562005', '708565007', '708600008', '708658008', '708665000', '708703004', '708704005', '708715000', '708748000', '708846006', '708850004', '708864004', '709050009', '709131007', '709610005', '709844000', '710051007', '710208001', '710238007', '711264008', '712565006', '712587002', '712590008', '712594004', '712681009', '712684001', '712686004', '712698009', '712713006', '712736002', '712800005', '712801009', '712808003', '712847001', '713311003', '713332006', '713337000', '713357001', '713365003', '713366002', '713393004', '713664008', '715884006', '715885007', '716119001', '5811000122108', '669361000168106', '737661000168109']}, 'type'=>'CodeableConcept', 'path'=>'Nutrient.modifier', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/nutrient-code'}},
            'amount' => {'type'=>'Quantity', 'path'=>'Nutrient.amount', 'min'=>0, 'max'=>1}
          }

          attr_accessor :id                # 0-1 string
          attr_accessor :extension         # 0-* [ Extension ]
          attr_accessor :modifierExtension # 0-* [ Extension ]
          attr_accessor :modifier          # 0-1 CodeableConcept
          attr_accessor :amount            # 0-1 Quantity
        end

        class Texture < FHIR::STU3::Model
          include FHIR::STU3::Hashable
          include FHIR::STU3::Json
          include FHIR::STU3::Xml

          METADATA = {
            'id' => {'type'=>'string', 'path'=>'Texture.id', 'min'=>0, 'max'=>1},
            'extension' => {'type'=>'Extension', 'path'=>'Texture.extension', 'min'=>0, 'max'=>Float::INFINITY},
            'modifierExtension' => {'type'=>'Extension', 'path'=>'Texture.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
            'modifier' => {'valid_codes'=>{'http://snomed.info/sct'=>['228053002', '439091000124107', '228049004', '441881000124103', '441761000124103', '441751000124100', '228059003', '441791000124106', '228055009', '228056005', '441771000124105', '228057001', '228058006', '228060008']}, 'type'=>'CodeableConcept', 'path'=>'Texture.modifier', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/texture-code'}},
            'foodType' => {'valid_codes'=>{'http://snomed.info/sct'=>['255620007', '28647000', '22836000', '72511004', '226760005', '226887002', '102263004', '74242007', '227415002', '264331002', '227518002', '44027008', '226529007', '227210005']}, 'type'=>'CodeableConcept', 'path'=>'Texture.foodType', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/modified-foodtype'}}
          }

          attr_accessor :id                # 0-1 string
          attr_accessor :extension         # 0-* [ Extension ]
          attr_accessor :modifierExtension # 0-* [ Extension ]
          attr_accessor :modifier          # 0-1 CodeableConcept
          attr_accessor :foodType          # 0-1 CodeableConcept
        end

        attr_accessor :id                   # 0-1 string
        attr_accessor :extension            # 0-* [ Extension ]
        attr_accessor :modifierExtension    # 0-* [ Extension ]
        attr_accessor :type                 # 0-* [ CodeableConcept ]
        attr_accessor :schedule             # 0-* [ Timing ]
        attr_accessor :nutrient             # 0-* [ NutritionOrder::OralDiet::Nutrient ]
        attr_accessor :texture              # 0-* [ NutritionOrder::OralDiet::Texture ]
        attr_accessor :fluidConsistencyType # 0-* [ CodeableConcept ]
        attr_accessor :instruction          # 0-1 string
      end

      class Supplement < FHIR::STU3::Model
        include FHIR::STU3::Hashable
        include FHIR::STU3::Json
        include FHIR::STU3::Xml

        METADATA = {
          'id' => {'type'=>'string', 'path'=>'Supplement.id', 'min'=>0, 'max'=>1},
          'extension' => {'type'=>'Extension', 'path'=>'Supplement.extension', 'min'=>0, 'max'=>Float::INFINITY},
          'modifierExtension' => {'type'=>'Extension', 'path'=>'Supplement.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
          'type' => {'valid_codes'=>{'http://snomed.info/sct'=>['442901000124106', '443031000124106', '443051000124104', '442911000124109', '443021000124108', '442971000124100', '442981000124102', '442991000124104', '443011000124100', '442961000124107', '442951000124105', '442941000124108', '442921000124101', '442931000124103', '444331000124106', '443361000124100', '443391000124108', '443401000124105', '443491000124103', '443501000124106', '443421000124100', '443471000124104', '444431000124104', '443451000124109', '444321000124108', '441561000124106', '443461000124106', '441531000124102', '443561000124107', '443481000124101', '441571000124104', '441591000124103', '441601000124106', '443351000124102', '443771000124106', '441671000124100', '443111000124101', '443431000124102', '443411000124108', '444361000124102', '444401000124107', '444381000124107', '444371000124109', '443441000124107', '442651000124102']}, 'type'=>'CodeableConcept', 'path'=>'Supplement.type', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/supplement-type'}},
          'productName' => {'type'=>'string', 'path'=>'Supplement.productName', 'min'=>0, 'max'=>1},
          'schedule' => {'type'=>'Timing', 'path'=>'Supplement.schedule', 'min'=>0, 'max'=>Float::INFINITY},
          'quantity' => {'type'=>'Quantity', 'path'=>'Supplement.quantity', 'min'=>0, 'max'=>1},
          'instruction' => {'type'=>'string', 'path'=>'Supplement.instruction', 'min'=>0, 'max'=>1}
        }

        attr_accessor :id                # 0-1 string
        attr_accessor :extension         # 0-* [ Extension ]
        attr_accessor :modifierExtension # 0-* [ Extension ]
        attr_accessor :type              # 0-1 CodeableConcept
        attr_accessor :productName       # 0-1 string
        attr_accessor :schedule          # 0-* [ Timing ]
        attr_accessor :quantity          # 0-1 Quantity
        attr_accessor :instruction       # 0-1 string
      end

      class EnteralFormula < FHIR::STU3::Model
        include FHIR::STU3::Hashable
        include FHIR::STU3::Json
        include FHIR::STU3::Xml

        METADATA = {
          'id' => {'type'=>'string', 'path'=>'EnteralFormula.id', 'min'=>0, 'max'=>1},
          'extension' => {'type'=>'Extension', 'path'=>'EnteralFormula.extension', 'min'=>0, 'max'=>Float::INFINITY},
          'modifierExtension' => {'type'=>'Extension', 'path'=>'EnteralFormula.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
          'baseFormulaType' => {'valid_codes'=>{'http://snomed.info/sct'=>['443031000124106', '443051000124104', '442911000124109', '443021000124108', '442971000124100', '442981000124102', '442991000124104', '443011000124100', '442961000124107', '442951000124105', '442941000124108', '442921000124101', '442931000124103', '443361000124100', '443401000124105', '443491000124103', '443501000124106', '443421000124100', '443471000124104', '444431000124104', '443451000124109', '441561000124106', '443461000124106', '441531000124102', '443561000124107', '443481000124101', '441571000124104', '441591000124103', '441601000124106', '443351000124102', '443771000124106', '441671000124100', '443111000124101', '443431000124102', '443411000124108', '442651000124102']}, 'type'=>'CodeableConcept', 'path'=>'EnteralFormula.baseFormulaType', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/entformula-type'}},
          'baseFormulaProductName' => {'type'=>'string', 'path'=>'EnteralFormula.baseFormulaProductName', 'min'=>0, 'max'=>1},
          'additiveType' => {'valid_codes'=>{'http://hl7.org/fhir/entformula-additive'=>['lipid', 'protein', 'carbohydrate', 'fiber', 'water']}, 'type'=>'CodeableConcept', 'path'=>'EnteralFormula.additiveType', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/entformula-additive'}},
          'additiveProductName' => {'type'=>'string', 'path'=>'EnteralFormula.additiveProductName', 'min'=>0, 'max'=>1},
          'caloricDensity' => {'type'=>'Quantity', 'path'=>'EnteralFormula.caloricDensity', 'min'=>0, 'max'=>1},
          'routeofAdministration' => {'valid_codes'=>{'http://hl7.org/fhir/v3/RouteOfAdministration'=>['PO', 'EFT', 'ENTINSTL', 'GT', 'NGT', 'OGT', 'GJT', 'JJTINSTL', 'OJJ']}, 'type'=>'CodeableConcept', 'path'=>'EnteralFormula.routeofAdministration', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'extensible', 'uri'=>'http://hl7.org/fhir/ValueSet/enteral-route'}},
          'administration' => {'type'=>'NutritionOrder::EnteralFormula::Administration', 'path'=>'EnteralFormula.administration', 'min'=>0, 'max'=>Float::INFINITY},
          'maxVolumeToDeliver' => {'type'=>'Quantity', 'path'=>'EnteralFormula.maxVolumeToDeliver', 'min'=>0, 'max'=>1},
          'administrationInstruction' => {'type'=>'string', 'path'=>'EnteralFormula.administrationInstruction', 'min'=>0, 'max'=>1}
        }

        class Administration < FHIR::STU3::Model
          include FHIR::STU3::Hashable
          include FHIR::STU3::Json
          include FHIR::STU3::Xml

          MULTIPLE_TYPES = {
            'rate' => ['Quantity', 'Ratio']
          }
          METADATA = {
            'id' => {'type'=>'string', 'path'=>'Administration.id', 'min'=>0, 'max'=>1},
            'extension' => {'type'=>'Extension', 'path'=>'Administration.extension', 'min'=>0, 'max'=>Float::INFINITY},
            'modifierExtension' => {'type'=>'Extension', 'path'=>'Administration.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
            'schedule' => {'type'=>'Timing', 'path'=>'Administration.schedule', 'min'=>0, 'max'=>1},
            'quantity' => {'type'=>'Quantity', 'path'=>'Administration.quantity', 'min'=>0, 'max'=>1},
            'rateQuantity' => {'type'=>'Quantity', 'path'=>'Administration.rate[x]', 'min'=>0, 'max'=>1},
            'rateRatio' => {'type'=>'Ratio', 'path'=>'Administration.rate[x]', 'min'=>0, 'max'=>1}
          }

          attr_accessor :id                # 0-1 string
          attr_accessor :extension         # 0-* [ Extension ]
          attr_accessor :modifierExtension # 0-* [ Extension ]
          attr_accessor :schedule          # 0-1 Timing
          attr_accessor :quantity          # 0-1 Quantity
          attr_accessor :rateQuantity      # 0-1 Quantity
          attr_accessor :rateRatio         # 0-1 Ratio
        end

        attr_accessor :id                        # 0-1 string
        attr_accessor :extension                 # 0-* [ Extension ]
        attr_accessor :modifierExtension         # 0-* [ Extension ]
        attr_accessor :baseFormulaType           # 0-1 CodeableConcept
        attr_accessor :baseFormulaProductName    # 0-1 string
        attr_accessor :additiveType              # 0-1 CodeableConcept
        attr_accessor :additiveProductName       # 0-1 string
        attr_accessor :caloricDensity            # 0-1 Quantity
        attr_accessor :routeofAdministration     # 0-1 CodeableConcept
        attr_accessor :administration            # 0-* [ NutritionOrder::EnteralFormula::Administration ]
        attr_accessor :maxVolumeToDeliver        # 0-1 Quantity
        attr_accessor :administrationInstruction # 0-1 string
      end

      attr_accessor :id                     # 0-1 id
      attr_accessor :meta                   # 0-1 Meta
      attr_accessor :implicitRules          # 0-1 uri
      attr_accessor :language               # 0-1 code
      attr_accessor :text                   # 0-1 Narrative
      attr_accessor :contained              # 0-* [ Resource ]
      attr_accessor :extension              # 0-* [ Extension ]
      attr_accessor :modifierExtension      # 0-* [ Extension ]
      attr_accessor :identifier             # 0-* [ Identifier ]
      attr_accessor :status                 # 0-1 code
      attr_accessor :patient                # 1-1 Reference(Patient)
      attr_accessor :encounter              # 0-1 Reference(Encounter)
      attr_accessor :dateTime               # 1-1 dateTime
      attr_accessor :orderer                # 0-1 Reference(Practitioner)
      attr_accessor :allergyIntolerance     # 0-* [ Reference(AllergyIntolerance) ]
      attr_accessor :foodPreferenceModifier # 0-* [ CodeableConcept ]
      attr_accessor :excludeFoodModifier    # 0-* [ CodeableConcept ]
      attr_accessor :oralDiet               # 0-1 NutritionOrder::OralDiet
      attr_accessor :supplement             # 0-* [ NutritionOrder::Supplement ]
      attr_accessor :enteralFormula         # 0-1 NutritionOrder::EnteralFormula

      def resourceType
        'NutritionOrder'
      end
    end
  end
end