module FHIR
  module STU3
    class ActivityDefinition < FHIR::STU3::Model
      include FHIR::STU3::Hashable
      include FHIR::STU3::Json
      include FHIR::STU3::Xml

      MULTIPLE_TYPES = {
        'timing' => ['Timing', 'dateTime', 'Period', 'Range'],
        'product' => ['Reference', 'CodeableConcept']
      }
      SEARCH_PARAMS = ['composed-of', 'date', 'depends-on', 'derived-from', 'description', 'effective', 'identifier', 'jurisdiction', 'name', 'predecessor', 'publisher', 'status', 'successor', 'title', 'topic', 'url', 'version']
      METADATA = {
        'id' => {'type'=>'id', 'path'=>'ActivityDefinition.id', 'min'=>0, 'max'=>1},
        'meta' => {'type'=>'Meta', 'path'=>'ActivityDefinition.meta', 'min'=>0, 'max'=>1},
        'implicitRules' => {'type'=>'uri', 'path'=>'ActivityDefinition.implicitRules', 'min'=>0, 'max'=>1},
        'language' => {'valid_codes'=>{'urn:ietf:bcp:47'=>['ar', 'bn', 'cs', 'da', 'de', 'de-AT', 'de-CH', 'de-DE', 'el', 'en', 'en-AU', 'en-CA', 'en-GB', 'en-IN', 'en-NZ', 'en-SG', 'en-US', 'es', 'es-AR', 'es-ES', 'es-UY', 'fi', 'fr', 'fr-BE', 'fr-CH', 'fr-FR', 'fy', 'fy-NL', 'hi', 'hr', 'it', 'it-CH', 'it-IT', 'ja', 'ko', 'nl', 'nl-BE', 'nl-NL', 'no', 'no-NO', 'pa', 'pt', 'pt-BR', 'ru', 'ru-RU', 'sr', 'sr-SP', 'sv', 'sv-SE', 'te', 'zh', 'zh-CN', 'zh-HK', 'zh-SG', 'zh-TW']}, 'type'=>'code', 'path'=>'ActivityDefinition.language', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'extensible', 'uri'=>'http://hl7.org/fhir/ValueSet/languages'}},
        'text' => {'type'=>'Narrative', 'path'=>'ActivityDefinition.text', 'min'=>0, 'max'=>1},
        'contained' => {'type'=>'Resource', 'path'=>'ActivityDefinition.contained', 'min'=>0, 'max'=>Float::INFINITY},
        'extension' => {'type'=>'Extension', 'path'=>'ActivityDefinition.extension', 'min'=>0, 'max'=>Float::INFINITY},
        'modifierExtension' => {'type'=>'Extension', 'path'=>'ActivityDefinition.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
        'url' => {'type'=>'uri', 'path'=>'ActivityDefinition.url', 'min'=>0, 'max'=>1},
        'identifier' => {'type'=>'Identifier', 'path'=>'ActivityDefinition.identifier', 'min'=>0, 'max'=>Float::INFINITY},
        'version' => {'type'=>'string', 'path'=>'ActivityDefinition.version', 'min'=>0, 'max'=>1},
        'name' => {'type'=>'string', 'path'=>'ActivityDefinition.name', 'min'=>0, 'max'=>1},
        'title' => {'type'=>'string', 'path'=>'ActivityDefinition.title', 'min'=>0, 'max'=>1},
        'status' => {'valid_codes'=>{'http://hl7.org/fhir/publication-status'=>['draft', 'active', 'retired', 'unknown']}, 'type'=>'code', 'path'=>'ActivityDefinition.status', 'min'=>1, 'max'=>1, 'binding'=>{'strength'=>'required', 'uri'=>'http://hl7.org/fhir/ValueSet/publication-status'}},
        'experimental' => {'type'=>'boolean', 'path'=>'ActivityDefinition.experimental', 'min'=>0, 'max'=>1},
        'date' => {'type'=>'dateTime', 'path'=>'ActivityDefinition.date', 'min'=>0, 'max'=>1},
        'publisher' => {'type'=>'string', 'path'=>'ActivityDefinition.publisher', 'min'=>0, 'max'=>1},
        'description' => {'type'=>'markdown', 'path'=>'ActivityDefinition.description', 'min'=>0, 'max'=>1},
        'purpose' => {'type'=>'markdown', 'path'=>'ActivityDefinition.purpose', 'min'=>0, 'max'=>1},
        'usage' => {'type'=>'string', 'path'=>'ActivityDefinition.usage', 'min'=>0, 'max'=>1},
        'approvalDate' => {'type'=>'date', 'path'=>'ActivityDefinition.approvalDate', 'min'=>0, 'max'=>1},
        'lastReviewDate' => {'type'=>'date', 'path'=>'ActivityDefinition.lastReviewDate', 'min'=>0, 'max'=>1},
        'effectivePeriod' => {'type'=>'Period', 'path'=>'ActivityDefinition.effectivePeriod', 'min'=>0, 'max'=>1},
        'useContext' => {'type'=>'UsageContext', 'path'=>'ActivityDefinition.useContext', 'min'=>0, 'max'=>Float::INFINITY},
        'jurisdiction' => {'valid_codes'=>{'urn:iso:std:iso:3166'=>['AD', 'AE', 'AF', 'AG', 'AI', 'AL', 'AM', 'AN', 'AO', 'AQ', 'AR', 'AS', 'AT', 'AU', 'AW', 'AX', 'AZ', 'BA', 'BB', 'BD', 'BE', 'BF', 'BG', 'BH', 'BI', 'BJ', 'BL', 'BM', 'BN', 'BO', 'BQ', 'BR', 'BS', 'BT', 'BU', 'BV', 'BW', 'BY', 'BZ', 'CA', 'CC', 'CD', 'CF', 'CG', 'CH', 'CI', 'CK', 'CL', 'CM', 'CN', 'CO', 'CR', 'CS', 'CT', 'CU', 'CV', 'CW', 'CX', 'CY', 'CZ', 'DD', 'DE', 'DJ', 'DK', 'DM', 'DO', 'DY', 'DZ', 'EC', 'EE', 'EG', 'EH', 'ER', 'ES', 'ET', 'FI', 'FJ', 'FK', 'FM', 'FO', 'FQ', 'FR', 'GA', 'GB', 'GD', 'GE', 'GF', 'GG', 'GH', 'GI', 'GL', 'GM', 'GN', 'GP', 'GQ', 'GR', 'GS', 'GT', 'GU', 'GW', 'GY', 'HK', 'HM', 'HN', 'HR', 'HT', 'HU', 'HV', 'ID', 'IE', 'IL', 'IM', 'IN', 'IO', 'IQ', 'IR', 'IS', 'IT', 'JE', 'JM', 'JO', 'JP', 'JT', 'KE', 'KG', 'KH', 'KI', 'KM', 'KN', 'KP', 'KR', 'KW', 'KY', 'KZ', 'LA', 'LB', 'LC', 'LI', 'LK', 'LR', 'LS', 'LT', 'LU', 'LV', 'LY', 'MA', 'MC', 'MD', 'ME', 'MF', 'MG', 'MH', 'MI', 'MK', 'ML', 'MM', 'MN', 'MO', 'MP', 'MQ', 'MR', 'MS', 'MT', 'MU', 'MV', 'MW', 'MX', 'MY', 'MZ', 'NA', 'NC', 'NE', 'NF', 'NG', 'NH', 'NI', 'NL', 'NO', 'NP', 'NQ', 'NR', 'NT', 'NU', 'NZ', 'OM', 'PA', 'PC', 'PE', 'PF', 'PG', 'PH', 'PK', 'PL', 'PM', 'PN', 'PR', 'PS', 'PT', 'PU', 'PW', 'PY', 'PZ', 'QA', 'RE', 'RH', 'RO', 'RS', 'RU', 'RW', 'SA', 'SB', 'SC', 'SD', 'SE', 'SG', 'SH', 'SI', 'SJ', 'SK', 'SL', 'SM', 'SN', 'SO', 'SR', 'SS', 'ST', 'SU', 'SV', 'SX', 'SY', 'SZ', 'TC', 'TD', 'TF', 'TG', 'TH', 'TJ', 'TK', 'TL', 'TM', 'TN', 'TO', 'TP', 'TR', 'TT', 'TV', 'TW', 'TZ', 'UA', 'UG', 'UM', 'US', 'UY', 'UZ', 'VA', 'VC', 'VD', 'VE', 'VG', 'VI', 'VN', 'VU', 'WF', 'WK', 'WS', 'YD', 'YE', 'YT', 'YU', 'ZA', 'ZM', 'ZR', 'ZW'], 'http://unstats.un.org/unsd/methods/m49/m49.htm'=>['001', '002', '014', '017', '015', '018', '011', '019', '419', '029', '013', '005', '021', '142', '143', '030', '034', '035', '145', '150', '151', '154', '039', '155', '009', '053', '054', '057', '061'], 'https://www.usps.com/'=>['AK', 'AL', 'AR', 'AS', 'AZ', 'CA', 'CO', 'CT', 'DC', 'DE', 'FL', 'FM', 'GA', 'GU', 'HI', 'IA', 'ID', 'IL', 'IN', 'KS', 'KY', 'LA', 'MA', 'MD', 'ME', 'MH', 'MI', 'MN', 'MO', 'MP', 'MS', 'MT', 'NC', 'ND', 'NE', 'NH', 'NJ', 'NM', 'NV', 'NY', 'OH', 'OK', 'OR', 'PA', 'PR', 'PW', 'RI', 'SC', 'SD', 'TN', 'TX', 'UM', 'UT', 'VA', 'VI', 'VT', 'WA', 'WI', 'WV', 'WY'], nil=>[]}, 'type'=>'CodeableConcept', 'path'=>'ActivityDefinition.jurisdiction', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'extensible', 'uri'=>'http://hl7.org/fhir/ValueSet/jurisdiction'}},
        'topic' => {'valid_codes'=>{'http://hl7.org/fhir/definition-topic'=>['treatment', 'education', 'assessment']}, 'type'=>'CodeableConcept', 'path'=>'ActivityDefinition.topic', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/definition-topic'}},
        'contributor' => {'type'=>'Contributor', 'path'=>'ActivityDefinition.contributor', 'min'=>0, 'max'=>Float::INFINITY},
        'contact' => {'type'=>'ContactDetail', 'path'=>'ActivityDefinition.contact', 'min'=>0, 'max'=>Float::INFINITY},
        'copyright' => {'type'=>'markdown', 'path'=>'ActivityDefinition.copyright', 'min'=>0, 'max'=>1},
        'relatedArtifact' => {'type'=>'RelatedArtifact', 'path'=>'ActivityDefinition.relatedArtifact', 'min'=>0, 'max'=>Float::INFINITY},
        'library' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Library'], 'type'=>'Reference', 'path'=>'ActivityDefinition.library', 'min'=>0, 'max'=>Float::INFINITY},
        'kind' => {'valid_codes'=>{'http://hl7.org/fhir/resource-types'=>['Account', 'ActivityDefinition', 'AdverseEvent', 'AllergyIntolerance', 'Appointment', 'AppointmentResponse', 'AuditEvent', 'Basic', 'Binary', 'BodySite', 'Bundle', 'CapabilityStatement', 'CarePlan', 'CareTeam', 'ChargeItem', 'Claim', 'ClaimResponse', 'ClinicalImpression', 'CodeSystem', 'Communication', 'CommunicationRequest', 'CompartmentDefinition', 'Composition', 'ConceptMap', 'Condition', 'Consent', 'Contract', 'Coverage', 'DataElement', 'DetectedIssue', 'Device', 'DeviceComponent', 'DeviceMetric', 'DeviceRequest', 'DeviceUseStatement', 'DiagnosticReport', 'DocumentManifest', 'DocumentReference', 'DomainResource', 'EligibilityRequest', 'EligibilityResponse', 'Encounter', 'Endpoint', 'EnrollmentRequest', 'EnrollmentResponse', 'EpisodeOfCare', 'ExpansionProfile', 'ExplanationOfBenefit', 'FamilyMemberHistory', 'Flag', 'Goal', 'GraphDefinition', 'Group', 'GuidanceResponse', 'HealthcareService', 'ImagingManifest', 'ImagingStudy', 'Immunization', 'ImmunizationRecommendation', 'ImplementationGuide', 'Library', 'Linkage', 'List', 'Location', 'Measure', 'MeasureReport', 'Media', 'Medication', 'MedicationAdministration', 'MedicationDispense', 'MedicationRequest', 'MedicationStatement', 'MessageDefinition', 'MessageHeader', 'NamingSystem', 'NutritionOrder', 'Observation', 'OperationDefinition', 'OperationOutcome', 'Organization', 'Parameters', 'Patient', 'PaymentNotice', 'PaymentReconciliation', 'Person', 'PlanDefinition', 'Practitioner', 'PractitionerRole', 'Procedure', 'ProcedureRequest', 'ProcessRequest', 'ProcessResponse', 'Provenance', 'Questionnaire', 'QuestionnaireResponse', 'ReferralRequest', 'RelatedPerson', 'RequestGroup', 'ResearchStudy', 'ResearchSubject', 'Resource', 'RiskAssessment', 'Schedule', 'SearchParameter', 'Sequence', 'ServiceDefinition', 'Slot', 'Specimen', 'StructureDefinition', 'StructureMap', 'Subscription', 'Substance', 'SupplyDelivery', 'SupplyRequest', 'Task', 'TestReport', 'TestScript', 'ValueSet', 'VisionPrescription']}, 'type'=>'code', 'path'=>'ActivityDefinition.kind', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'required', 'uri'=>'http://hl7.org/fhir/ValueSet/resource-types'}},
        'code' => {'valid_codes'=>{'http://snomed.info/sct'=>['104001', '115006', '119000', '121005', '128004', '133000', '135007', '142007', '146005', '153001', '160007', '166001', '170009', '174000', '176003', '189009', '197002', '230009', '243009', '245002', '262007', '267001', '285008', '294002', '295001', '306005', '316002', '334003', '342002', '346004', '348003', '351005', '352003', '353008', '374009', '388008', '389000', '401004', '406009', '417005', '435001', '445004', '456004', '459006', '463004', '468008', '474008', '489004', '493005', '494004', '497006', '503003', '531007', '533005', '535003', '540006', '543008', '545001', '549007', '550007', '559008', '570001', '574005', '603006', '617002', '618007', '625000', '628003', '629006', '633004', '637003', '642006', '645008', '647000', '657004', '665001', '670008', '671007', '673005', '674004', '676002', '680007', '687005', '695009', '697001', '710006', '712003', '721002', '722009', '726007', '730005', '741007', '746002', '753006', '754000', '759005', '762008', '764009', '767002', '789003', '791006', '807005', '814007', '817000', '831000', '851001', '853003', '867007', '870006', '879007', '881009', '893000', '897004', '910002', '911003', '913000', '926001', '935008', '941001', '945005', '948007', '951000', '956005', '967006', '969009', '971009', '1001000', '1008006', '1019009', '1021004', '1029002', '1032004', '1035002', '1036001', '1041009', '1042002', '1043007', '1044001', '1048003', '1054002', '1071001', '1084005', '1093006', '1103000', '1104006', '1115001', '1119007', '1121002', '1127003', '1133007', '1163003', '1176009', '1181000', '1186005', '1198000', '1209007', '1225002', '1227005', '1235008', '1237000', '1238005', '1251000', '1253002', '1258006', '1266002', '1267006', '1278003', '1279006', '1292009', '1299000', '1315009', '1316005', '1324000', '1327007', '1328002', '1329005', '1337002', '1339004', '1347004', '1352009', '1358008', '1366004', '1385001', '1390003', '1398005', '1399002', '1407007', '1410000', '1411001', '1413003', '1414009', '1417002', '1431002', '1440003', '1449002', '1453000', '1455007', '1457004', '1494008', '1500007', '1501006', '1505002', '1529009', '1533002', '1550000', '1555005', '1559004', '1576000', '1577009', '1578004', '1583007', '1585000', '1596008', '1597004', '1602006', '1614003', '1615002', '1616001', '1636000', '1638004', '1640009', '1645004', '1651009', '1653007', '1669000', '1677001', '1678006', '1680000', '1683003', '1689004', '1691007', '1699009', '1702002', '1704001', '1709006', '1712009', '1713004', '1730002', '1746005', '1747001', '1753001', '1757000', '1759002', '1770009', '1774000', '1775004', '1784004', '1787006', '1788001', '1801001', '1805005', '1811008', '1813006', '1820004', '1830008', '1836002', '1844002', '1854003', '1859008', '1861004', '1862006', '1866009', '1868005', '1870001', '1871002', '1872009', '1876007', '1879000', '1889001', '1906007', '1907003', '1917008', '1924009', '1950008', '1958001', '1966005', '1983001', '1995001', '1999007', '2002009', '2021001', '2051007', '2054004', '2067001', '2069003', '2078009', '2079001', '2080003', '2098004', '2115003', '2119009', '2127000', '2137005', '2153008', '2161003', '2164006', '2166008', '2171001', '2178007', '2181002', '2188008', '2193006', '2196003', '2199005', '2214008', '2220009', '2225004', '2234009', '2238007', '2242005', '2244006', '2250001', '2252009', '2266004', '2267008', '2270007', '2276001', '2278000', '2279008', '2290003', '2315006', '2318008', '2321005', '2322003', '2337004', '2344008', '2347001', '2364003', '2371008', '2373006', '2382000', '2386002', '2393003', '2406000', '2407009', '2408004', '2409007', '2425002', '2442008', '2448007', '2455009', '2457001', '2458006', '2459003', '2461007', '2474001', '2475000', '2480009', '2486003', '2488002', '2494005', '2498008', '2507007', '2508002', '2514009', '2517002', '2530001', '2531002', '2535006', '2536007', '2547000', '2552005', '2564002', '2566000', '2567009', '2580007', '2598006', '2601001', '2607002', '2613006', '2614000', '2616003', '2619005', '2629003', '2632000', '2642003', '2643008', '2644002', '2645001', '2646000', '2658000', '2659008', '2668005', '2670001', '2673004', '2677003', '2690005', '2693007', '2696004', '2697008', '2716009', '2722000', '2731000', '2732007', '2737001', '2742009', '2743004', '2745006', '2752008', '2780005', '2794006', '2802005', '2811005', '2813008', '2837008', '2842000', '2843005', '2847006', '2851008', '2854000', '2857007', '2866006', '2875008', '2876009', '2885009', '2891006', '2898000', '2903001', '2908005', '2914003', '2915002', '2933008', '2945004', '2947007', '2960001', '2968008', '2970004', '2971000', '2977001', '3001009', '3010001', '3016007', '3025001', '3026000', '3029007', '3041000', '3047001', '3060007', '3061006', '3063009', '3075004', '3078002', '3083005', '3088001', '3090000', '3112006', '3116009', '3130004', '3133002', '3137001', '3143004', '3162001', '3164000', '3165004', '3166003', '3177009', '3183007', '3186004', '3190002', '3204007', '3241008', '3249005', '3251009', '3256004', '3257008', '3258003', '3268008', '3270004', '3278006', '3287002', '3320000', '3324009', '3326006', '3328007', '3333006', '3338002', '3352000', '3357006', '3360004', '3390006', '3399007', '3407002', '3413006', '3418002', '3432000', '3443008', '3448004', '3450007', '3457005', '3479000', '3498003', '3499006', '3509001', '3512003', '3515001', '3517009', '3518004', '3527003', '3546002', '3559005', '3562008', '3564009', '3575008', '3580004', '3605001', '3607009', '3620007', '3625002', '3651000', '3654008', '3659003', '3664004', '3666002', '3669009', '3673007', '3683006', '3686003', '3688002', '3690001', '3691002', '3697003', '3700004', '3701000', '3713005', '3717006', '3734003', '3735002', '3740005', '3748003', '3749006', '3758004', '3770000', '3778007', '3780001', '3784005', '3786007', '3787003', '3794000', '3796003', '3799005', '3802001', '3819004', '3826004', '3828003', '3831002', '3843001', '3858009', '3861005', '3862003', '3864002', '3880007', '3881006', '3887005', '3889008', '3891000', '3895009', '3907006', '3911000', '3915009', '3917001', '3918006', '3926003', '3929005', '3936006', '3938007', '3942005', '3955006', '3957003', '3963007', '3967008', '3968003', '3969006', '3971006', '3980006', '3981005', '3985001', '3991004', '3998005', '4007002', '4008007', '4010009', '4027001', '4034004', '4035003', '4036002', '4037006', '4044002', '4045001', '4052004', '4064007', '4068005', '4083000', '4084006', '4090005', '4094001', '4101004', '4102006', '4114003', '4116001', '4119008', '4131005', '4134002', '4139007', '4143006', '4149005', '4154001', '4165006', '4176005', '4192000', '4213001', '4214007', '4226002', '4252008', '4263006', '4266003', '4285000', '4293000', '4304000', '4319004', '4321009', '4323007', '4331002', '4333004', '4336007', '4337003', '4339000', '4341004', '4344007', '4348005', '4350002', '4363008', '4365001', '4380007', '4387005', '4388000', '4407008', '4411002', '4420006', '4424002', '4436008', '4438009', '4443002', '4447001', '4449003', '4450003', '4455008', '4457000', '4466001', '4467005', '4475004', '4487006', '4489009', '4496006', '4503005', '4504004', '4505003', '4507006', '4511000', '4516005', '4520009', '4525004', '4533003', '4535005', '4539004', '4542005', '4544006', '4558008', '4563007', '4570007', '4579008', '4581005', '4585001', '4587009', '4589007', '4593001', '4594007', '4613005', '4625008', '4626009', '4636001', '4640005', '4642002', '4660002', '4670000', '4671001', '4672008', '4691008', '4692001', '4694000', '4699005', '4701005', '4707009', '4712005', '4713000', '4719001', '4727005', '4734007', '4737000', '4756005', '4758006', '4764004', '4765003', '4770005', '4772002', '4784000', '4804005', '4811009', '4815000', '4820000', '4827002', '4829004', '4847005', '4849008', '4862007', '4877004', '4891005', '4895001', '4902005', '4903000', '4904006', '4914002', '4929000', '4930005', '4934001', '4957007', '4966006', '4970003', '4974007', '4976009', '4987001', '4992004', '4993009', '5016005', '5019003', '5021008', '5022001', '5025004', '5032008', '5034009', '5048009', '5055006', '5057003', '5065000', '5091004', '5105000', '5110001', '5113004', '5119000', '5121005', '5123008', '5130002', '5131003', '5135007', '5147001', '5151004', '5154007', '5161006', '5162004', '5165002', '5176003', '5182000', '5184004', '5186002', '5190000', '5191001', '5212002', '5216004', '5233006', '5243009', '5245002', '5246001', '5264008', '5267001', '5270002', '5273000', '5282006', '5290006', '5298004', '5304008', '5316002', '5317006', '5326009', '5328005', '5337005', '5338000', '5342002', '5348003', '5357009', '5373003', '5384005', '5391008', '5393006', '5402006', '5407000', '5415002', '5419008', '5422005', '5429001', '5431005', '5433008', '5446003', '5447007', '5452002', '5456004', '5457008', '5460001', '5479003', '5482008', '5486006', '5489004', '5506006', '5517007', '5521000', '5536002', '5545001', '5551006', '5556001', '5570001', '5571002', '5572009', '5586008', '5608002', '5616006', '5621009', '5632009', '5636007', '5638008', '5648005', '5651003', '5663008', '5669007', '5671007', '5687005', '5690004', '5694008', '5721002', '5722009', '5726007', '5728008', '5731009', '5733007', '5738003', '5745003', '5760000', '5771004', '5777000', '5781000', '5785009', '5787001', '5789003', '5796001', '5806001', '5807005', '5809008', '5812006', '5818005', '5821007', '5823005', '5832007', '5845006', '5846007', '5857002', '5865004', '5870006', '5880005', '5892005', '5894006', '5897004', '5902003', '5925002', '5930003', '5947002', '5961007', '5966002', '5971009', '5983006', '5986003', '5992009', '5995006', '5997003', '5998008', '6005008', '6007000', '6019008', '6025007', '6026008', '6029001', '6035001', '6063004', '6069000', '6082008', '6092000', '6100001', '6108008', '6119006', '6125005', '6126006', '6127002', '6130009', '6133006', '6143009', '6146001', '6148000', '6157006', '6159009', '6161000', '6164008', '6166005', '6177004', '6187000', '6188005', '6189002', '6190006', '6195001', '6198004', '6200005', '6205000', '6213004', '6221005', '6225001', '6226000', '6227009', '6231003', '6238009', '6240004', '6255008', '6271008', '6274000', '6286002', '6289009', '6295005', '6307005', '6309008', '6319002', '6337001', '6339003', '6343004', '6353003', '6354009', '6355005', '6358007', '6361008', '6363006', '6370006', '6384001', '6385000', '6388003', '6396008', '6397004', '6399001', '6402000', '6403005', '6419003', '6429005', '6433003', '6434009', '6438007', '6439004', '6443000', '6444006', '6465000', '6466004', '6470007', '6473009', '6480006', '6486000', '6487009', '6491004', '6499002', '6502003', '6506000', '6519001', '6521006', '6527005', '6535008', '6536009', '6543003', '6547002', '6555009', '6556005', '6562000', '6563005', '6567006', '6568001', '6585004', '6589005', '6601003', '6614002', '6615001', '6622009', '6634001', '6639006', '6650009', '6656003', '6657007', '6658002', '6661001', '6665005', '6668007', '6670003']}, 'type'=>'CodeableConcept', 'path'=>'ActivityDefinition.code', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/procedure-code'}},
        'timingTiming' => {'type'=>'Timing', 'path'=>'ActivityDefinition.timing[x]', 'min'=>0, 'max'=>1},
        'timingDateTime' => {'type'=>'dateTime', 'path'=>'ActivityDefinition.timing[x]', 'min'=>0, 'max'=>1},
        'timingPeriod' => {'type'=>'Period', 'path'=>'ActivityDefinition.timing[x]', 'min'=>0, 'max'=>1},
        'timingRange' => {'type'=>'Range', 'path'=>'ActivityDefinition.timing[x]', 'min'=>0, 'max'=>1},
        'location' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Location'], 'type'=>'Reference', 'path'=>'ActivityDefinition.location', 'min'=>0, 'max'=>1},
        'participant' => {'type'=>'ActivityDefinition::Participant', 'path'=>'ActivityDefinition.participant', 'min'=>0, 'max'=>Float::INFINITY},
        'productReference' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Medication', 'http://hl7.org/fhir/StructureDefinition/Substance'], 'type'=>'Reference', 'path'=>'ActivityDefinition.product[x]', 'min'=>0, 'max'=>1},
        'productCodeableConcept' => {'valid_codes'=>{'http://snomed.info/sct'=>['261000', '336001', '363000', '519005', '585007', '693002', '698006', '699003', '747006', '873008', '925002', '1018001', '1025008', '1057009', '1091008', '1171004', '1190007', '1244009', '1269009', '1325004', '1336006', '1355006', '1368003', '1381005', '1450002', '1476002', '1536005', '1575001', '1603001', '1668008', '1914001', '1944003', '1956002', '1971003', '2029004', '2125008', '2195004', '2197007', '2201007', '2212007', '2215009', '2249001', '2264001', '2346005', '2537003', '2660003', '2680002', '2796008', '2799001', '2869004', '2878005', '2927004', '2958003', '2964005', '2991007', '2995003', '3031003', '3066001', '3087006', '3136005', '3142009', '3145006', '3209002', '3212004', '3225007', '3342004', '3378009', '3379001', '3501003', '3592004', '3597005', '3617004', '3672002', '3693004', '3793006', '3823007', '3829006', '3874004', '3906002', '3932008', '3941003', '3945007', '3983008', '4014000', '4025009', '4043008', '4076007', '4188007', '4203009', '4334005', '4353000', '4355007', '4413004', '4423008', '4480008', '4518006', '4616002', '4681002', '4700006', '4780009', '4814001', '4844003', '5007006', '5142007', '5167005', '5172001', '5220000', '5312000', '5405008', '5477001', '5641004', '5647000', '5657004', '5681006', '5691000', '5699003', '5739006', '5767002', '5774007', '5907009', '5955009', '6054001', '6088007', '6162007', '6237004', '6260007', '6333002', '6394006', '6495008', '6513000', '6524003', '6602005', '6612003', '6710000', '6717002', '6790004', '6809003', '6826009', '6837005', '6865007', '6873003', '6881002', '6910009', '6927001', '6952004', '6992002', '7034005', '7084003', '7156005', '7179006', '7302008', '7318002', '7328006', '7348004', '7451005', '7509000', '7515000', '7549008', '7608003', '7737009', '7770004', '7774008', '7816005', '7834009', '7904003', '7975001', '8030004', '8143001', '8202008', '8203003', '8222007', '8252004', '8397006', '8450009', '8534003', '8631001', '8689007', '8701002', '8767001', '8886003', '8919000', '8987006', '9174005', '9234005', '9271007', '9396007', '9457002', '9471005', '9530002', '9532005', '9539001', '9643009', '9663002', '9676008', '9680003', '9721008', '9765000', '9797000', '9817005', '9910008', '9974009', '9992001', '10016008', '10020007', '10109009', '10133003', '10174003', '10192006', '10202007', '10240005', '10270000', '10282009', '10324005', '10329000', '10333007', '10342000', '10354000', '10377000', '10424009', '10466005', '10471003', '10500003', '10534002', '10595003', '10644005', '10660009', '10682002', '10730008', '10750007', '10751006', '10767000', '10782005', '10790005', '10843002', '10955007', '11036001', '11038000', '11115001', '11121002', '11137008', '11170003', '11202003', '11331001', '11345007', '11420005', '11473005', '11496005', '11504003', '11633008', '11644000', '11652002', '11714005', '11943009', '11984007', '11986009', '12009000', '12034000', '12177002', '12208001', '12218006', '12290003', '12315006', '12391001', '12525000', '12568004', '12578001', '12597001', '12689001', '12716009', '12801003', '12821002', '12870003', '12930006', '12970004', '13030002', '13150000', '13188003', '13235001', '13342004', '13502005', '13585009', '13668001', '13708006', '13787003', '13789000', '14013006', '14071002', '14146003', '14172007', '14193005', '14285000', '14312008', '14321009', '14340003', '14349002', '14399003', '14409006', '14438009', '14443002', '14461006', '14507006', '14638000', '14645000', '14715007', '14743003', '14767006', '14796007', '14819006', '14903000', '14905007', '15009009', '15017001', '15098005', '15129007', '15322006', '15331006', '15352003', '15505005', '15571002', '15660006', '15698006', '15730005', '15785009', '15810003', '15895007', '15901005', '16106007', '16125005', '16130009', '16214005', '16257000', '16276003', '16318005', '16355005', '16359004', '16392005', '16395007', '16462002', '16477005', '16492006', '16613008', '16624005', '16628008', '16670003', '16683002', '16717002', '16744007', '16745008', '16748005', '16808006', '16826009', '16915004', '16923002', '16946000', '17008002', '17062003', '17072000', '17117004', '17147002', '17212003', '17240008', '17243005', '17244004', '17356001', '17614005', '17731005', '17777001', '17798001', '17836006', '17916009', '17932007', '17942009', '17990002', '17991003', '18017000', '18039003', '18143001', '18220004', '18288009', '18321003', '18394004', '18414002', '18449009', '18462008', '18535002', '18550006', '18600008', '18616005', '18712002', '18815007', '18832006', '18852007', '18959002', '18970009', '19012003', '19041007', '19046002', '19114000', '19126005', '19163001', '19205004', '19421007', '19427006', '19462001', '19499001', '19510001', '19524002', '19595005', '19622008', '19839007', '19893005', '19918001', '19967004', '19978007', '20056006', '20170008', '20217007', '20229003', '20231007', '20238001', '20327004', '20340009', '20368008', '20378006', '20379003', '20413008', '20450009', '20468007', '20495002', '20686000', '20752000', '20771003', '20844009', '20847002', '20887007', '21028006', '21066009', '21075006', '21094001', '21168008', '21175009', '21235009', '21246007', '21289006', '21303006', '21373005', '21394008', '21518006', '21556007', '21559000', '21566004', '21568003', '21572004', '21611007', '21614004', '21706000', '21891005', '21903000', '21919007', '22038003', '22086005', '22165008', '22236007', '22242006', '22250002', '22362000', '22424004', '22453003', '22496008', '22606007', '22635004', '22654004', '22769006', '22779008', '22790003', '22792006', '22827004', '22840009', '22882008', '22941009', '22976006', '23053002', '23068001', '23077008', '23176001', '23295004', '23375008', '23433006', '23459009', '23564005', '23692005', '23701001', '23814005', '23816007', '23861006', '23862004', '23866001', '23883005', '23959001', '23969007', '24022008', '24202000', '24237002', '24261009', '24336008', '24357000', '24434007', '24435008', '24556008', '24570008', '24583009', '24650007', '24686008', '24721007', '24751001', '24809001', '24823004', '24838003', '24869004', '25002001', '25013003', '25027008', '25128000', '25141001', '25183006', '25204006', '25205007', '25213008', '25217009', '25254000', '25305005', '25307002', '25401000', '25500001', '25525005', '25538002', '25571003', '25607008', '25620006', '25710007', '25747007', '25796002', '25886000', '25911004', '26120001', '26191006', '26277008', '26288002', '26327007', '26346008', '26351002', '26371006', '26379008', '26437003', '26469007', '26518005', '26656004', '26817007', '26945002', '26992003', '27054007', '27079005', '27081007', '27082000', '27122000', '27184001', '27192005', '27244000', '27248002', '27345002', '27361000', '27499006', '27586005', '27594003', '27656005', '27730007', '27736001', '27766008', '27822002', '27928002', '27931001', '27989007', '28021008', '28029005', '28069006', '28121005', '28223003', '28268006', '28344001', '28421003', '28464005', '28521000', '28580002', '28588009', '28662003', '28702005', '28825003', '28829009', '28927005', '28942008', '28983006', '28999000', '29011006', '29184007', '29190006', '29301006', '29327006', '29406002', '29522004', '29527005', '29531004', '29584000', '29588002', '29666006', '29671004', '29725000', '29765001', '29783009', '29876006', '30034004', '30053009', '30094001', '30145004', '30178006', '30179003', '30203009', '30205002', '30236005', '30324001', '30325000', '30326004', '30329006', '30333004', '30424002', '30589007', '30658004', '30676006', '30745005', '30804005', '30820000', '30827002', '30848000', '30863002', '30990007', '31011004', '31055005', '31147000', '31178001', '31422009', '31522006', '31617001', '31622001', '31662002', '31706007', '31707003', '31731008', '31780003', '31787000', '31799007', '31801005', '31815007', '31818009', '31827005', '31895006', '31936008', '31990000', '32050003', '32083005', '32120008', '32133002', '32154009', '32157002', '32281001', '32370002', '32436002', '32437006', '32498003', '32505007', '32519007', '32707001', '32714004', '32757009', '32789000', '32800009', '32824001', '32836007', '32852005', '32898006', '32901007', '33280006', '33307008', '33396006', '33435008', '33440000', '33447002', '33535006', '33619005', '33635003', '33642003', '33667000', '33752008', '33837008', '33922005', '33963004', '34007009', '34070005', '34074001', '34086003', '34113002', '34120009', '34198005', '34211007', '34239008', '34274009', '34332002', '34425005', '34471003', '34654009', '34657002', '34658007', '34737006', '34915005', '34919004', '34953000', '34983009', '35060001', '35135004', '35150008', '35236008', '35257000', '35281007', '35318005', '35321007', '35343004', '35431001', '35466004', '35473009', '35605007', '35733004', '35748005', '35765001', '35864006', '35883004', '35903003', '35946000', '35954003', '35966009', '35976007', '36020009', '36021008', '36022001', '36136008', '36167005', '36173006', '36176003', '36235004', '36378007', '36380001', '36516003', '36541005', '36651003', '36661005', '36712003', '36872003', '36887008', '36953002', '37006008', '37013008', '37077000', '37078005', '37123002', '37225000', '37237003', '37262003', '37276002', '37352007', '37365003', '37411004', '37433002', '37451001', '37527009', '37648000', '37656002', '37691005', '37716005', '37751002', '37756007', '37758008', '37765000', '37951005', '37957009', '37978007', '37986007', '37994000', '38044001', '38122009', '38218009', '38245005', '38344006', '38399002', '38408002', '38543004', '38595007', '38622005', '38623000', '38648002', '38686006', '38714005', '38794009', '38909000', '38914001', '38937007', '39012008', '39044007', '39123009', '39152007', '39263003', '39292004', '39294003', '39428005', '39514001', '39546001', '39552000', '39808001', '39815009', '39933002', '39962001', '39972003', '39973008', '39979007', '40036000', '40115000', '40342009', '40404004', '40438007', '40534007', '40545005', '40601003', '40699008', '40710000', '40789008', '40924008', '40937006', '40940006', '41062004', '41067005', '41091001', '41143004', '41153003', '41199001', '41261002', '41332001', '41395001', '41410009', '41433005', '41464007', '41485007', '41492002', '41503000', '41509001', '41573001', '41592004', '41598000', '41722006', '41793006', '41834005', '41903005', '41945007', '41989007', '42033003', '42056007', '42145009', '42146005', '42159002', '42163009', '42180008', '42193003', '42212002', '42230009', '42319009', '42382009', '42464005', '42520004', '42549007', '42605004', '42671007', '42692007', '42710006', '42730005', '42761001', '42841002', '42877009', '43004008', '43032004', '43048003', '43136004', '43171004', '43239002', '43289005', '43332008', '43356007', '43440003', '43462003', '43538006', '43541002', '43585000', '43592005', '43597004', '43613009', '43621003', '43688007', '43698001', '43706004', '43784004', '43835003', '43848004', '43880002', '43897008', '43909000', '43989002', '44044007', '44068004', '44159003', '44234001', '44262008', '44293009', '44330008', '44347009', '44469001', '44508008', '44520000', '44555003', '44588005', '44603007', '44609006', '44624002', '44644008', '44681007', '44711006', '44776005', '44908000', '45084007', '45119009', '45158004', '45159007', '45207006', '45266004', '45483006', '45524001', '45555007', '45604009', '45754009', '45807004', '45940009', '45946003', '45960001', '46015007', '46021006', '46058006', '46097003', '46122001', '46134009', '46146008', '46191004', '46201000', '46225008', '46250006', '46257009', '46293006', '46492003', '46514003', '46558003', '46572007', '46654009', '46668002', '46711008', '46749007', '46861006', '46887006', '46921009', '46943001', '46950002', '47026005', '47176005', '47180000', '47192000', '47218005', '47247003', '47280005', '47336007', '47349002', '47350002', '47355007', '47383009', '47389008', '47408003', '47413004', '47414005', '47500008', '47663000']}, 'type'=>'CodeableConcept', 'path'=>'ActivityDefinition.product[x]', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/medication-codes'}},
        'quantity' => {'type'=>'Quantity', 'path'=>'ActivityDefinition.quantity', 'min'=>0, 'max'=>1},
        'dosage' => {'type'=>'Dosage', 'path'=>'ActivityDefinition.dosage', 'min'=>0, 'max'=>Float::INFINITY},
        'bodySite' => {'valid_codes'=>{'http://snomed.info/sct'=>['106004', '107008', '108003', '110001', '111002', '116007', '124002', '149003', '155008', '167005', '202009', '205006', '206007', '221001', '227002', '233006', '235004', '246001', '247005', '251007', '256002', '263002', '266005', '272005', '273000', '283001', '284007', '289002', '301000', '311007', '315003', '318001', '344001', '345000', '356000', '393006', '402006', '405008', '414003', '420002', '422005', '446003', '457008', '461002', '464005', '465006', '471000', '480000', '485005', '528006', '552004', '565008', '582005', '587004', '589001', '595000', '608002', '621009', '635006', '650002', '660006', '661005', '667009', '688000', '691000', '692007', '723004', '774007', '790007', '798000', '808000', '809008', '823005', '830004', '836005', '885000', '895007', '917004', '921006', '947002', '955009', '976004', '996007', '1005009', '1012000', '1015003', '1028005', '1030007', '1063000', '1075005', '1076006', '1086007', '1087003', '1092001', '1099005', '1101003', '1106008', '1110006', '1122009', '1136004', '1159005', '1172006', '1173001', '1174007', '1193009', '1216008', '1231004', '1236009', '1243003', '1246006', '1263005', '1277008', '1307006', '1311000', '1350001', '1353004', '1403006', '1425000', '1439000', '1441004', '1456008', '1467009', '1484003', '1490004', '1502004', '1511004', '1516009', '1527006', '1537001', '1541002', '1562001', '1569005', '1580005', '1581009', '1584001', '1600003', '1605008', '1610007', '1611006', '1617005', '1620002', '1626008', '1627004', '1630006', '1631005', '1650005', '1655000', '1659006', '1684009', '1706004', '1707008', '1711002', '1716007', '1721005', '1729007', '1732005', '1765002', '1780008', '1781007', '1797002', '1818002', '1825009', '1832000', '1840006', '1849007', '1853009', '1874005', '1893007', '1895000', '1902009', '1910005', '1918003', '1927002', '1992003', '1997009', '2010005', '2020000', '2031008', '2033006', '2044003', '2048000', '2049008', '2059009', '2071003', '2076008', '2083001', '2095001', '2123001', '2150006', '2156000', '2160002', '2175005', '2182009', '2192001', '2205003', '2209009', '2236006', '2246008', '2255006', '2285001', '2292006', '2302002', '2305000', '2306004', '2327009', '2330002', '2332005', '2334006', '2349003', '2372001', '2383005', '2389009', '2395005', '2397002', '2400006', '2402003', '2421006', '2433001', '2436009', '2453002', '2454008', '2484000', '2489005', '2499000', '2502001', '2504000', '2510000', '2539000', '2543001', '2550002', '2577006', '2579009', '2592007', '2600000', '2620004', '2639009', '2653009', '2666009', '2672009', '2675006', '2681003', '2682005', '2686008', '2687004', '2695000', '2703009', '2712006', '2718005', '2726002', '2730004', '2739003', '2741002', '2746007', '2748008', '2759004', '2771005', '2789006', '2792005', '2803000', '2810006', '2812003', '2824005', '2826007', '2830005', '2839006', '2841007', '2845003', '2848001', '2855004', '2861001', '2894003', '2905008', '2909002', '2920002', '2922005', '2923000', '2954001', '2969000', '2979003', '2986006', '2998001', '3003007', '3008003', '3028004', '3039001', '3042007', '3054007', '3055008', '3056009', '3057000', '3058005', '3062004', '3068000', '3081007', '3093003', '3100007', '3113001', '3117000', '3118005', '3120008', '3134008', '3138006', '3153003', '3156006', '3159004', '3169005', '3178004', '3194006', '3198009', '3215002', '3222005', '3227004', '3236000', '3243006', '3255000', '3262009', '3279003', '3295003', '3301002', '3302009', '3315000', '3332001', '3336003', '3341006', '3350008', '3362007', '3366005', '3370002', '3374006', '3377004', '3382006', '3383001', '3394002', '3395001', '3396000', '3400000', '3409004', '3417007', '3438001', '3444002', '3447009', '3460003', '3462006', '3471002', '3478008', '3481003', '3488009', '3490005', '3524005', '3538003', '3541007', '3553006', '3556003', '3563003', '3572006', '3578005', '3582007', '3584008', '3594003', '3608004', '3609007', '3646006', '3663005', '3665003', '3670005', '3711007', '3743007', '3761003', '3766008', '3785006', '3788008', '3789000', '3810000', '3838008', '3860006', '3865001', '3867009', '3876002', '3877006', '3910004', '3916005', '3924000', '3931001', '3935005', '3937002', '3954005', '3956007', '3959000', '3960005', '3964001', '3966004', '3977005', '3984002', '3989007', '4015004', '4019005', '4029003', '4061004', '4066009', '4072009', '4081003', '4093007', '4111006', '4117005', '4121003', '4146003', '4148002', '4150005', '4158003', '4159006', '4180000', '4193005', '4205002', '4212006', '4215008', '4247003', '4258007', '4268002', '4276000', '4281009', '4295007', '4303006', '4312008', '4317002', '4328003', '4335006', '4352005', '4358009', '4360006', '4369007', '4371007', '4375003', '4377006', '4394008', '4402002', '4419000', '4421005', '4430002', '4432005', '4442007', '4486002', '4524000', '4527007', '4537002', '4548009', '4549001', '4566004', '4573009', '4578000', '4583008', '4588004', '4596009', '4603002', '4606005', '4621004', '4624007', '4647008', '4651005', '4658004', '4677002', '4703008', '4717004', '4718009', '4743003', '4755009', '4759003', '4766002', '4768001', '4774001', '4775000', '4799000', '4810005', '4812002', '4828007', '4840007', '4843009', '4861000', '4866005', '4870002', '4871003', '4881004', '4888005', '4897009', '4905007', '4906008', '4924005', '4942000', '4954000', '4956003', '4958002', '5001007', '5023006', '5026003', '5046008', '5068003', '5069006', '5076001', '5115006', '5122003', '5128004', '5140004', '5192008', '5194009', '5195005', '5204005', '5213007', '5225005', '5228007', '5229004', '5261000', '5272005', '5279001', '5296000', '5324007', '5329002', '5336001', '5347008', '5362005', '5366008', '5379004', '5382009', '5394000', '5398002', '5403001', '5421003', '5427004', '5458003', '5459006', '5491007', '5493005', '5498001', '5501001', '5520004', '5538001', '5542003', '5544002', '5560003', '5564007', '5574005', '5580002', '5597008', '5611001', '5625000', '5627008', '5633004', '5643001', '5644007', '5653000', '5665001', '5668004', '5677006', '5682004', '5696005', '5697001', '5709001', '5713008', '5717009', '5718004', '5727003', '5742000', '5751008', '5769004', '5780004', '5798000', '5802004', '5814007', '5815008', '5816009', '5825003', '5828001', '5847003', '5854009', '5868002', '5872003', '5881009', '5882002', '5889006', '5890002', '5893000', '5898009', '5923009', '5926001', '5928000', '5942008', '5943003', '5944009', '5948007', '5951000', '5953002', '5976004', '5979006', '5996007', '6001004', '6004007', '6006009', '6009002', '6013009', '6014003', '6023000', '6032003', '6046003', '6050005', '6059006', '6062009', '6073002', '6074008', '6076005', '6104005', '6105006', '6110005', '6194002', '6216007', '6217003', '6229007', '6253001', '6268000', '6269008', '6279005', '6317000', '6325003', '6326002', '6335009', '6359004', '6371005', '6375001', '6392005', '6404004', '6413002', '6417001', '6423006', '6424000', '6445007', '6448009', '6450001', '6472004', '6504002', '6511003', '6530003', '6533001', '6538005', '6541001', '6544009', '6550004', '6551000', '6553002', '6564004', '6566002', '6572002', '6598008', '6606008', '6608009', '6620001', '6623004', '6633007', '6643005', '6646002', '6649009', '6651008', '6684008', '6685009', '6711001', '6720005', '6731002', '6739000', '6742006', '6750002', '6757004', '6787005', '6789008', '6799003', '6805009', '6820003', '6828005', '6829002', '6834003', '6841009', '6844001', '6850006', '6864006', '6866008', '6871001', '6894000', '6902008', '6905005', '6912001', '6914000', '6921000', '6930008', '6944002', '6969002', '6975006', '6981003', '6987004', '6989001', '6991009', '7035006', '7050002', '7067009', '7076002', '7083009', '7090004', '7091000', '7099003', '7117004', '7121006', '7148007', '7149004', '7154008', '7160008', '7167006', '7173007', '7188002', '7192009', '7227003', '7234001', '7242000', '7275008', '7295002', '7296001', '7311008', '7344002', '7345001', '7347009', '7362006', '7376007', '7378008', '7384006', '7404008', '7435002', '7471001', '7477002', '7480001', '7494000', '7498002', '7507003', '7524009', '7532001', '7554004', '7566005', '7569003', '7591005', '7597009', '7605000', '7610001', '7629007', '7651004', '7652006', '7657000', '7658005', '7697002', '7712004', '7726008', '7736000', '7742001', '7748002', '7755000', '7756004', '7764005', '7769000', '7783003', '7820009', '7829005', '7832008', '7835005', '7840002', '7841003', '7844006', '7851002', '7854005', '7872004', '7874003', '7880006', '7884002', '7885001', '7892006', '7896009', '7911004', '7925003', '7936005', '7944005', '7954009', '7967007', '7986004', '7991003', '7999001', '8001006', '8012006', '8017000', '8024004', '8039003', '8040001', '8045006', '8057002', '8059004', '8067007', '8068002', '8079007', '8091003', '8100009', '8111001', '8112008', '8119004', '8128003', '8133004', '8157004', '8158009', '8159001', '8160006', '8161005', '8165001', '8205005', '8225009', '8242003', '8251006', '8264007', '8265008', '8266009', '8279000', '8289001', '8292002', '8314003', '8334002', '8356004', '8361002', '8369000', '8373002', '8387002', '8389004', '8412003', '8415001', '8454000', '8464009', '8482007', '8483002', '8496001', '8523001', '8546004', '8556000', '8559007', '8560002', '8568009', '8580001', '8595004', '8598002', '8600008', '8603005', '8604004', '8608001', '8617001', '8623006', '8629005', '8640002', '8668003', '8671006', '8677005', '8688004', '8695008', '8710005', '8711009', '8714001', '8752000', '8770002', '8775007', '8784007', '8810002', '8814006', '8815007', '8820007', '8821006', '8827005', '8839002', '8845005', '8850004', '8854008', '8862000', '8873007', '8887007', '8892009', '8894005', '8897003', '8907008', '8910001', '8911002', '8928004', '8931003', '8935007', '8942007', '8965002', '8966001', '8983005', '8988001', '8993003', '9000002', '9003000', '9018004', '9040008', '9055004', '9073001', '9081000', '9086005', '9089003', '9108007', '9127001', '9156001', '9181003', '9185007', '9186008', '9188009', '9208002', '9212008', '9229006', '9231002', '9240003', '9242006', '9258009', '9261005', '9262003', '9284003', '9290004', '9305001', '9317004', '9320007', '9321006', '9325002', '9332006', '9348007', '9379006', '9380009', '9384000', '9390001', '9432007', '9438006', '9454009', '9455005', '9475001', '9481009', '9490002', '9498009', '9502002', '9512009', '9535007', '9558005', '9566001', '9568000', '9596006', '9609000', '9625005', '9642004', '9646001', '9654004', '9659009', '9662007', '9668006', '9677004', '9683001', '9684007', '9708001', '9732008', '9736006', '9743000', '9758008', '9770007', '9775002', '9779008', '9783008', '9791004', '9796009', '9813009', '9825007', '9837009', '9840009', '9841008', '9846003', '9847007', '9849005', '9870004', '9875009', '9878006', '9880000', '9881001', '9891007', '9898001', '9951005', '9968009', '9970000', '9976006', '9994000', '9999005', '10013000', '10024003', '10025002', '10026001', '10036009', '10042008', '10047002', '10052007', '10056005', '10062000', '10119003', '10124000']}, 'type'=>'CodeableConcept', 'path'=>'ActivityDefinition.bodySite', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/body-site'}},
        'transform' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/StructureMap'], 'type'=>'Reference', 'path'=>'ActivityDefinition.transform', 'min'=>0, 'max'=>1},
        'dynamicValue' => {'type'=>'ActivityDefinition::DynamicValue', 'path'=>'ActivityDefinition.dynamicValue', 'min'=>0, 'max'=>Float::INFINITY}
      }

      class Participant < FHIR::STU3::Model
        include FHIR::STU3::Hashable
        include FHIR::STU3::Json
        include FHIR::STU3::Xml

        METADATA = {
          'id' => {'type'=>'string', 'path'=>'Participant.id', 'min'=>0, 'max'=>1},
          'extension' => {'type'=>'Extension', 'path'=>'Participant.extension', 'min'=>0, 'max'=>Float::INFINITY},
          'modifierExtension' => {'type'=>'Extension', 'path'=>'Participant.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
          'type' => {'valid_codes'=>{'http://hl7.org/fhir/action-participant-type'=>['patient', 'practitioner', 'related-person']}, 'type'=>'code', 'path'=>'Participant.type', 'min'=>1, 'max'=>1, 'binding'=>{'strength'=>'required', 'uri'=>'http://hl7.org/fhir/ValueSet/action-participant-type'}},
          'role' => {'valid_codes'=>{nil=>[]}, 'type'=>'CodeableConcept', 'path'=>'Participant.role', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/action-participant-role'}}
        }

        attr_accessor :id                # 0-1 string
        attr_accessor :extension         # 0-* [ Extension ]
        attr_accessor :modifierExtension # 0-* [ Extension ]
        attr_accessor :type              # 1-1 code
        attr_accessor :role              # 0-1 CodeableConcept
      end

      class DynamicValue < FHIR::STU3::Model
        include FHIR::STU3::Hashable
        include FHIR::STU3::Json
        include FHIR::STU3::Xml

        METADATA = {
          'id' => {'type'=>'string', 'path'=>'DynamicValue.id', 'min'=>0, 'max'=>1},
          'extension' => {'type'=>'Extension', 'path'=>'DynamicValue.extension', 'min'=>0, 'max'=>Float::INFINITY},
          'modifierExtension' => {'type'=>'Extension', 'path'=>'DynamicValue.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
          'description' => {'type'=>'string', 'path'=>'DynamicValue.description', 'min'=>0, 'max'=>1},
          'path' => {'type'=>'string', 'path'=>'DynamicValue.path', 'min'=>0, 'max'=>1},
          'language' => {'type'=>'string', 'path'=>'DynamicValue.language', 'min'=>0, 'max'=>1},
          'expression' => {'type'=>'string', 'path'=>'DynamicValue.expression', 'min'=>0, 'max'=>1}
        }

        attr_accessor :id                # 0-1 string
        attr_accessor :extension         # 0-* [ Extension ]
        attr_accessor :modifierExtension # 0-* [ Extension ]
        attr_accessor :description       # 0-1 string
        attr_accessor :path              # 0-1 string
        attr_accessor :language          # 0-1 string
        attr_accessor :expression        # 0-1 string
      end

      attr_accessor :id                     # 0-1 id
      attr_accessor :meta                   # 0-1 Meta
      attr_accessor :implicitRules          # 0-1 uri
      attr_accessor :language               # 0-1 code
      attr_accessor :text                   # 0-1 Narrative
      attr_accessor :contained              # 0-* [ Resource ]
      attr_accessor :extension              # 0-* [ Extension ]
      attr_accessor :modifierExtension      # 0-* [ Extension ]
      attr_accessor :url                    # 0-1 uri
      attr_accessor :identifier             # 0-* [ Identifier ]
      attr_accessor :version                # 0-1 string
      attr_accessor :name                   # 0-1 string
      attr_accessor :title                  # 0-1 string
      attr_accessor :status                 # 1-1 code
      attr_accessor :experimental           # 0-1 boolean
      attr_accessor :date                   # 0-1 dateTime
      attr_accessor :publisher              # 0-1 string
      attr_accessor :description            # 0-1 markdown
      attr_accessor :purpose                # 0-1 markdown
      attr_accessor :usage                  # 0-1 string
      attr_accessor :approvalDate           # 0-1 date
      attr_accessor :lastReviewDate         # 0-1 date
      attr_accessor :effectivePeriod        # 0-1 Period
      attr_accessor :useContext             # 0-* [ UsageContext ]
      attr_accessor :jurisdiction           # 0-* [ CodeableConcept ]
      attr_accessor :topic                  # 0-* [ CodeableConcept ]
      attr_accessor :contributor            # 0-* [ Contributor ]
      attr_accessor :contact                # 0-* [ ContactDetail ]
      attr_accessor :copyright              # 0-1 markdown
      attr_accessor :relatedArtifact        # 0-* [ RelatedArtifact ]
      attr_accessor :library                # 0-* [ Reference(Library) ]
      attr_accessor :kind                   # 0-1 code
      attr_accessor :code                   # 0-1 CodeableConcept
      attr_accessor :timingTiming           # 0-1 Timing
      attr_accessor :timingDateTime         # 0-1 dateTime
      attr_accessor :timingPeriod           # 0-1 Period
      attr_accessor :timingRange            # 0-1 Range
      attr_accessor :location               # 0-1 Reference(Location)
      attr_accessor :participant            # 0-* [ ActivityDefinition::Participant ]
      attr_accessor :productReference       # 0-1 Reference(Medication|Substance)
      attr_accessor :productCodeableConcept # 0-1 CodeableConcept
      attr_accessor :quantity               # 0-1 Quantity
      attr_accessor :dosage                 # 0-* [ Dosage ]
      attr_accessor :bodySite               # 0-* [ CodeableConcept ]
      attr_accessor :transform              # 0-1 Reference(StructureMap)
      attr_accessor :dynamicValue           # 0-* [ ActivityDefinition::DynamicValue ]

      def resourceType
        'ActivityDefinition'
      end
    end
  end
end