module FHIR
  module STU3
    class DocumentReference < FHIR::STU3::Model
      include FHIR::STU3::Hashable
      include FHIR::STU3::Json
      include FHIR::STU3::Xml

      SEARCH_PARAMS = ['identifier', 'patient', 'type', 'encounter', 'authenticator', 'author', 'class', 'created', 'custodian', 'description', 'event', 'facility', 'format', 'indexed', 'language', 'location', 'period', 'related-id', 'related-ref', 'relatesto', 'relation', 'securitylabel', 'setting', 'status', 'subject']
      METADATA = {
        'id' => {'type'=>'id', 'path'=>'DocumentReference.id', 'min'=>0, 'max'=>1},
        'meta' => {'type'=>'Meta', 'path'=>'DocumentReference.meta', 'min'=>0, 'max'=>1},
        'implicitRules' => {'type'=>'uri', 'path'=>'DocumentReference.implicitRules', 'min'=>0, 'max'=>1},
        'language' => {'valid_codes'=>{'urn:ietf:bcp:47'=>['ar', 'bn', 'cs', 'da', 'de', 'de-AT', 'de-CH', 'de-DE', 'el', 'en', 'en-AU', 'en-CA', 'en-GB', 'en-IN', 'en-NZ', 'en-SG', 'en-US', 'es', 'es-AR', 'es-ES', 'es-UY', 'fi', 'fr', 'fr-BE', 'fr-CH', 'fr-FR', 'fy', 'fy-NL', 'hi', 'hr', 'it', 'it-CH', 'it-IT', 'ja', 'ko', 'nl', 'nl-BE', 'nl-NL', 'no', 'no-NO', 'pa', 'pt', 'pt-BR', 'ru', 'ru-RU', 'sr', 'sr-SP', 'sv', 'sv-SE', 'te', 'zh', 'zh-CN', 'zh-HK', 'zh-SG', 'zh-TW']}, 'type'=>'code', 'path'=>'DocumentReference.language', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'extensible', 'uri'=>'http://hl7.org/fhir/ValueSet/languages'}},
        'text' => {'type'=>'Narrative', 'path'=>'DocumentReference.text', 'min'=>0, 'max'=>1},
        'contained' => {'type'=>'Resource', 'path'=>'DocumentReference.contained', 'min'=>0, 'max'=>Float::INFINITY},
        'extension' => {'type'=>'Extension', 'path'=>'DocumentReference.extension', 'min'=>0, 'max'=>Float::INFINITY},
        'modifierExtension' => {'type'=>'Extension', 'path'=>'DocumentReference.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
        'masterIdentifier' => {'type'=>'Identifier', 'path'=>'DocumentReference.masterIdentifier', 'min'=>0, 'max'=>1},
        'identifier' => {'type'=>'Identifier', 'path'=>'DocumentReference.identifier', 'min'=>0, 'max'=>Float::INFINITY},
        'status' => {'valid_codes'=>{'http://hl7.org/fhir/document-reference-status'=>['current', 'superseded', 'entered-in-error']}, 'type'=>'code', 'path'=>'DocumentReference.status', 'min'=>1, 'max'=>1, 'binding'=>{'strength'=>'required', 'uri'=>'http://hl7.org/fhir/ValueSet/document-reference-status'}},
        'docStatus' => {'valid_codes'=>{'http://hl7.org/fhir/composition-status'=>['preliminary', 'final', 'amended', 'entered-in-error']}, 'type'=>'code', 'path'=>'DocumentReference.docStatus', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'required', 'uri'=>'http://hl7.org/fhir/ValueSet/composition-status'}},
        'type' => {'valid_codes'=>{'http://loinc.org'=>['55107-7', '74155-3', '51851-4', '67851-6', '34744-3', '34873-0', '68552-9', '67852-4', '68471-2', '68483-7', '64058-1', '64070-6', '64053-2', '64054-0', '34862-3', '64062-3', '64078-9', '64066-4', '64060-7', '64074-8', '51849-8', '34763-3', '47039-3', '34094-3', '57830-2', '48765-2', '74152-0', '61359-6', '57055-6', '56446-8', '51848-0', '68814-3', '64064-9', '51847-2', '69981-9', '74154-6', '71230-7', '72134-0', '55108-5', '73568-8', '74144-7', '55109-3', '34095-0', '34096-8', '63485-7', '55110-1', '34098-4', '34097-6', '47040-1', '47041-9', '59284-0', '11488-4', '34099-2', '34756-7', '34758-3', '34760-9', '34879-7', '34761-7', '34764-1', '34776-5', '34779-9', '34781-5', '72555-6', '34783-1', '34785-6', '34795-5', '34798-9', '34797-1', '34800-3', '34777-3', '34803-7', '34855-7', '34805-2', '34807-8', '34810-2', '34812-8', '34814-4', '34816-9', '34820-1', '34822-7', '34824-3', '34826-8', '34828-4', '34788-0', '34791-4', '34103-2', '34831-8', '73575-3', '34833-4', '34837-5', '34839-1', '34841-7', '34845-8', '34847-4', '34849-0', '34851-6', '34853-2', '51846-4', '34104-0', '68619-6', '68633-7', '68639-4', '68486-0', '68648-5', '68651-9', '68661-8', '64072-2', '68551-1', '68670-9', '64056-5', '68681-6', '68685-7', '68694-9', '68705-3', '68566-9', '68570-1', '68575-0', '68716-0', '68469-6', '68727-7', '68892-9', '68897-8', '68746-7', '68757-4', '68765-7', '68869-7', '68874-7', '68787-1', '68879-6', '68802-8', '68864-8', '68812-7', '68821-8', '68586-7', '68590-9', '68597-4', '68837-4', '34102-4', '64080-5', '68846-5', '64068-0', '64076-3', '68852-3', '34100-8', '51854-8', '51845-6', '34749-2', '34101-6', '47042-7', '34864-9', '34869-8', '34865-6', '34866-4', '34872-2', '55111-9', '74148-8', '64297-5', '74208-0', '51899-3', '74150-4', '74151-2', '47048-4', '70004-7', '68611-3', '68625-3', '68635-2', '68641-0', '68652-7', '68673-3', '68687-3', '68556-0', '68696-4', '68557-8', '68577-6', '68708-7', '68718-6', '68748-3', '68767-3', '68778-0', '68794-7', '68855-6', '68804-4', '68604-8', '68640-2', '68706-1', '68788-9', '68822-6', '74213-0', '60280-5', '8653-8', '18842-5', '68612-1', '68626-1', '68642-8', '68653-5', '68663-4', '68674-1', '68688-1', '68697-2', '34745-0', '68558-6', '68572-7', '68578-4', '68709-5', '68719-4', '68733-5', '68738-4', '68749-1', '68768-1', '68773-1', '68779-8', '68795-4', '68856-4', '68805-1', '68815-0', '68591-7', '68831-7', '59259-2', '68841-6', '59258-4', '34105-7', '68823-4', '34106-5', '55112-7', '34895-3', '34897-9', '67854-0', '68477-9', '68605-5', '67855-7', '34902-7', '34107-3', '34856-5', '34859-9', '34860-7', '70005-4', '64142-3', '34857-3', '72267-8', '47420-5', '47043-5', '34787-2', '34790-6', '34793-0', '34843-3', '34114-9', '64290-0', '64291-8', '57024-2', '64289-2', '51897-7', '56444-3', '74146-2', '34117-2', '68614-7', '68622-0', '68628-7', '68637-8', '68644-4', '68655-0', '68665-9', '68676-6', '68683-2', '68690-7', '68699-8', '68560-2', '68573-5', '68580-0', '68711-1', '68721-0', '68731-9', '68735-0', '68740-0', '68751-7', '68760-8', '68770-7', '68775-6', '68781-4', '68791-3', '68797-0', '68858-0', '68807-7', '68817-6', '28626-0', '68592-5', '68833-3', '68599-0', '68843-2', '34774-0', '68849-9', '11492-6', '34115-6', '68825-9', '67856-5', '34116-4', '74264-3', '74149-6', '28636-9', '28581-7', '68553-7', '18740-1', '47044-3', '64065-6', '68470-4', '34119-8', '34120-6', '34118-0', '74209-8', '74188-4', '74194-2', '74191-8', '74190-0', '74193-4', '74192-6', '74197-5', '74187-6', '74196-7', '74195-9', '74189-2', '34121-4', '34896-1', '34899-5', '55113-5', '57056-4', '57057-2', '64299-1', '51852-2', '68684-0', '68866-3', '68593-3', '68609-7', '68620-4', '68624-6', '68634-5', '68649-3', '68662-6', '68671-7', '68555-2', '68682-4', '68686-5', '68695-6', '68707-9', '68567-7', '68571-9', '68576-8', '68585-9', '68717-8', '68728-5', '68893-7', '68898-6', '68747-5', '68758-2', '68766-5', '68870-5', '68875-4', '68789-7', '68880-4', '68803-6', '68865-5', '68813-5', '68826-7', '68598-2', '68838-2', '68847-3', '68853-1', '57058-0', '64285-0', '60590-7', '60593-1', '70006-2', '68587-5', '61357-0', '61356-2', '56445-0', '74145-4', '74147-0', '59268-3', '34109-9', '68615-4', '68621-2', '68629-5', '34750-0', '68636-0', '34752-6', '68645-1', '68650-1', '68656-8', '34754-2', '28618-7', '34759-1', '68666-7', '34861-5', '34878-9', '34898-7', '34762-5', '34765-8', '34767-4', '34768-2', '34769-0', '34780-7', '34782-3', '34794-8', '34784-9', '34786-4', '68677-4', '34796-3', '34799-7', '34905-0', '68700-4', '34746-8', '34801-1', '34778-1', '34802-9', '28578-3', '34806-0', '34808-6', '34811-0', '34813-6', '34815-1', '34817-7', '34858-1', '34906-8', '51855-5', '68722-8', '68889-5', '68894-5', '68741-8', '68752-5', '68761-6', '68867-1', '68871-3', '68782-2', '68854-9', '68876-2', '68881-2', '68859-8', '68882-0', '68818-4', '34821-9', '34823-5', '28579-1', '34827-6', '34829-2', '68834-1', '28628-6', '34792-2', '34830-0', '34832-6', '34834-2', '68839-0', '34838-3', '34840-9', '28653-4', '28571-8', '34846-6', '34848-2', '34773-2', '68848-1', '34852-4', '34111-5', '57053-1', '34112-3', '64069-8', '68827-5', '64077-1', '64073-0', '34113-1', '34108-1', '34753-4', '34110-7', '34766-6', '68601-4', '34850-8', '34854-0', '68672-5', '34748-4', '34139-6', '34844-1', '74166-0', '74156-1', '64300-7', '60591-5', '60592-3', '57834-4', '48768-6', '53576-5', '64296-7', '72170-4', '56447-6', '64295-9', '51900-9', '67860-7', '67861-5', '34875-5', '34880-5', '68610-5', '68606-3', '34867-2', '64298-3', '74207-2', '67862-3', '68616-2', '68623-8', '34751-8', '68638-6', '68657-6', '68550-3', '68678-2', '68691-5', '68701-2', '34747-6', '68562-8', '34809-4', '68581-8', '68713-7', '68723-6', '68732-7', '68736-8', '68742-6', '68753-3', '68762-4', '68771-5', '68776-4', '68783-0', '68792-1', '68798-8', '68860-6', '68808-5', '68819-2', '68594-1', '68835-8', '68844-0', '34876-3', '34881-3', '68850-7', '34123-0', '68828-3', '57832-8', '64288-4', '57829-4', '57833-6', '57831-0', '57828-6', '73709-8', '55114-3', '57017-6', '57016-8', '64293-4', '68630-3', '68658-4', '68667-5', '68692-3', '68702-0', '68563-6', '68714-5', '68724-4', '68890-3', '68895-2', '68743-4', '68754-1', '68868-9', '68872-1', '68784-8', '68877-0', '68799-6', '68861-4', '68809-3', '68820-0', '68836-6', '68851-5', '68729-3', '68829-1', '68607-1', '11506-3', '68617-0', '68631-1', '68646-9', '28580-9', '68659-2', '28617-9', '68668-3', '34900-1', '68554-5', '72556-4', '34904-3', '68679-0', '68693-1', '68703-8', '28623-7', '28575-9', '68564-4', '11507-1', '68574-3', '68582-6', '68725-1', '68891-1', '68896-0', '68744-2', '68755-8', '68763-2', '68873-9', '68785-5', '68878-8', '68800-2', '68862-2', '68810-1', '11508-9', '18733-6', '28569-2', '68595-8', '11509-7', '28627-8', '11510-5', '68840-8', '28656-7', '11512-1', '15507-7', '34130-5', '68472-0', '68485-2', '68484-5', '64059-9', '64071-4', '68473-8', '64055-7', '68475-3', '68830-9', '64063-1', '64079-7', '68478-7', '68479-5', '64057-3', '64067-2', '68480-3', '64061-5', '64075-5', '68481-1', '70238-1', '34126-3', '34131-3', '34124-8', '34128-9', '34127-1', '34901-9', '34132-1', '34129-7', '34125-5', '74468-0', '74465-6', '73569-6', '64294-2', '64284-3', '57133-1', '57170-3', '57178-6', '57134-9', '57135-6', '57136-4', '57137-2', '69438-0', '57138-0', '57139-8', '57171-1', '57172-9', '57141-4', '57142-2', '57143-0', '57144-8', '57146-3', '57145-5', '57173-7', '57179-4', '57147-1', '57148-9', '57149-7', '57150-5', '57151-3', '57174-5', '57175-2', '57176-0', '57152-1', '57153-9', '57154-7', '57155-4', '57156-2', '57157-0', '57158-8', '57177-8', '57159-6', '57160-4', '57162-0', '57163-8', '57164-6', '57165-3', '57166-1', '57167-9', '57168-7', '57169-5', '64292-6', '55115-0', '70007-0', '68476-1', '68474-6', '71482-4', '51898-5', '74153-8', '59282-4', '47045-0', '68608-9', '61143-4', '68602-2', '68603-0', '47046-8', '34133-9', '74211-4', '48764-5', '47047-6', '67865-6', '34135-4', '34136-2', '34134-7', '61358-8', '11504-8', '34868-0', '34818-5', '34870-6', '28624-5', '34874-8', '34877-1', '34137-0', '34138-8', '18761-7', '68618-8', '68632-9', '68647-7', '68660-0', '34755-9', '68669-1', '34770-8', '68680-8', '68704-6', '68565-1', '68569-3', '68887-9', '68583-4', '68715-2', '68726-9', '68737-6', '68745-9', '68756-6', '68764-0', '68772-3', '68777-2', '68786-3', '68793-9', '68801-0', '68863-0', '68811-9', '68883-8', '68596-6', '68482-9', '68884-6', '59281-6', '74198-3', '54094-8', '57054-9', '38932-0', '38933-8', '38934-6', '38936-1', '38937-9', '38938-7', '38939-5', '38940-3', '38941-1', '38942-9', '38943-7', '38944-5', '38956-9', '38946-0', '38949-4', '38950-2', '38966-8', '38951-0', '38952-8', '38953-6', '38954-4', '38969-2', '38955-1', '38957-7', '38958-5', '38959-3', '38960-1', '38961-9', '38962-7', '38963-5', '38964-3', '38965-0', '38967-6', '38968-4', '38947-8', '38935-3', '38945-2', '38948-6', '38972-6', '38980-9', '38970-0', '38971-8', '38973-4', '38979-1', '38974-2', '38975-9', '38976-7', '38977-5', '38978-3', '38981-7', '38982-5', '38983-3', '38984-1', '38985-8', '38986-6', '38987-4', '38988-2', '59283-2', '52027-0', '24754-4', '26376-4', '26377-2', '26378-0', '53243-2', '11485-0', '30649-8', '30641-5', '36760-7', '36762-3', '69067-7', '24543-1', '24580-3', '26368-1', '26369-9', '24614-0', '24615-7', '35881-2', '24698-3', '36763-1', '24766-8', '26370-7', '26371-5', '26372-3', '24832-8', '30648-0', '25081-1', '25012-6', '26373-1', '26374-9', '26375-6', '43793-9', '43794-7', '43795-4', '43792-1', '25064-7', '30836-1', '37426-4', '30640-7', '35882-0', '52032-0', '36764-9', '69135-2', '69253-3', '36765-6', '35883-8', '36766-4', '24568-8', '28615-3', '52065-0', '18743-5', '36761-5', '33720-4', '52041-1', '38268-9', '43562-8', '43563-6', '48807-2', '24631-4', '53242-4', '54095-5', '11486-8', '71428-7', '71421-2', '71388-3', '71406-3', '25062-1', '24611-6', '60570-9', '60571-7', '52042-9', '25038-1', '29751-5', '50007-4', '47523-6', '47530-1', '47521-0', '50971-1', '47528-5', '47527-7', '47522-8', '47520-2', '47524-4', '47529-3', '33718-8', '47525-1', '47526-9', '52040-3', '29749-9', '28622-9', '28574-2', '29761-4', '11490-0', '28655-9', '53245-7', '53247-3', '24684-3', '24887-2', '24553-0', '24554-8', '52071-8', '67796-3', '52043-7', '30600-1', '24923-5', '52030-4', '52031-2', '52044-5', '29272-2', '52064-3', '57129-9', '52045-2', '52033-8', '51969-4', '46365-3', '44228-5', '44156-8', '44101-4', '44155-0', '58747-7', '58743-6', '35884-6', '42280-8', '42705-4', '42281-6', '42285-7', '44167-5', '42282-4', '42133-9', '39361-1', '69120-4', '69122-0', '42286-5', '44168-3', '44169-1', '42284-0', '69123-8', '43502-4', '44166-7', '30578-9', '39451-0', '35885-3', '39620-0', '39623-4', '39622-6', '39621-8', '72533-3', '72532-5', '24623-1', '42688-2', '35886-1', '24598-5', '43756-6', '69278-0', '69292-1', '69296-2', '35888-7', '24771-8', '48434-5', '24811-2', '24822-9', '69287-1', '24837-7', '39452-8', '24856-7', '24863-3', '30703-3', '37491-8', '24662-9', '37887-7', '24973-0', '42134-7', '25043-1', '30878-3', '36926-4', '37210-2', '69306-9', '24594-4', '69192-3', '30653-0', '26343-4', '38012-1', '26344-2', '42450-7', '26345-9', '42458-0', '38126-9', '69121-2', '38133-5', '42447-3', '35887-9', '30698-5', '24671-0', '25042-3', '25041-5', '46281-2', '46282-0', '30602-7', '44107-1', '44108-9', '46387-7', '44160-0', '46284-6', '38026-1', '46283-8', '38033-7', '38135-0', '44221-0', '43757-4', '44159-2', '44217-8', '30608-4', '30603-5', '44158-4', '44220-2', '30595-3', '44103-0', '44219-4', '44104-8', '44105-5', '30605-0', '44157-6', '44218-6', '30606-8', '44106-3', '38017-0', '30610-0', '38136-8', '69124-6', '38019-6', '44216-0', '30580-5', '38018-8', '44215-2', '24755-1', '26298-0', '26299-8', '26300-4', '30601-9', '37913-1', '35890-3', '44117-0', '44162-6', '36767-2', '35891-1', '69076-8', '37211-0', '35893-7', '24602-5', '37914-9', '26337-6', '69169-1', '37912-3', '26338-4', '69203-8', '42449-9', '26339-2', '69213-7', '42457-2', '35895-2', '37915-6', '35894-5', '37492-6', '42333-5', '43567-7', '43565-1', '44109-7', '42463-0', '37212-8', '69387-9', '36927-2', '35892-9', '42136-2', '42279-0', '24772-6', '35899-4', '38766-2', '30607-6', '26340-0', '26341-8', '26342-6', '24812-0', '24816-1', '35900-0', '38765-4', '35896-0', '24823-7', '44161-8', '30634-0', '35901-8', '39522-8', '37213-6', '42137-0', '36768-0', '37917-2', '24838-5', '37918-0', '30604-3', '37919-8', '35902-6', '24864-1', '69074-3', '35903-4', '24883-1', '41802-0', '35898-6', '37920-6', '69075-0', '38132-7', '69396-0', '24986-2', '35904-2', '35905-9', '35906-7', '30609-2', '35907-5', '42265-9', '42135-4', '38154-1', '43797-0', '43564-4', '37214-4', '35908-3', '25009-2', '35897-8', '25044-9', '25059-7', '25069-6', '24670-2', '30651-4', '24813-8', '69279-8', '46285-3', '38024-6', '69073-5', '42448-1', '30652-2', '42288-1', '69224-4', '46367-9', '46368-7', '46286-1', '38028-7', '41803-8', '43462-1', '43447-2', '69290-5', '38029-5', '69225-1', '69099-0', '44171-7', '69127-9', '43568-5', '42289-9', '38027-9', '69097-4', '69197-2', '44170-9', '69125-3', '42267-5', '37916-4', '69098-2', '69198-0', '69288-9', '69226-9', '46369-5', '42290-7', '69199-8', '69289-7', '69126-1', '46370-3', '69200-4', '69227-7', '46288-7', '69228-5', '69100-6', '69201-2', '69291-3', '69128-7', '43571-9', '69401-8', '38030-3', '42266-7', '69101-4', '69202-0', '38031-1', '69129-5', '46287-9', '30700-9', '44225-1', '24718-9', '35910-9', '46289-5', '35909-1', '69093-3', '42260-0', '46366-1', '46384-4', '69083-4', '35911-7', '69092-5', '69094-1', '46290-3', '35889-5', '64998-8', '64999-6', '30818-9', '30892-4', '24624-9', '26331-9', '26332-7', '26333-5', '43558-6', '36769-8', '24781-7', '46371-1', '30646-4', '69400-0', '69391-1', '38127-7', '70915-4', '70916-2', '70917-0', '24680-1', '35913-3', '42287-3', '41809-5', '35914-1', '35915-8', '36770-6', '35916-6', '69078-4', '24692-6', '26325-1', '26326-9', '26327-7', '35917-4', '69133-7', '35918-2', '24896-3', '26328-5', '26329-3', '26330-1', '35919-0', '35920-8', '42283-2', '44172-5', '35921-6', '24868-2', '41800-4', '41798-0', '35922-4', '30699-3', '43537-0', '42478-8', '46291-1', '35923-2', '46292-9', '35924-0', '46293-7', '35925-7', '43478-7', '43474-6', '43477-9', '43473-8', '43475-3', '43476-1', '72248-8', '44214-5', '30815-5', '44213-7', '58740-2', '72541-6', '72542-4', '72540-8', '35926-5', '30638-1', '24769-2', '42334-3', '42706-2', '24901-1', '35927-3', '26319-4', '26320-2', '26321-0', '48435-2', '46392-7', '37427-2', '30579-7', '24931-8', '26322-8', '26323-6', '26324-4', '70918-8', '30812-2', '37493-4', '70919-6', '30817-1', '70920-4', '30814-8', '30702-5', '72530-9', '36771-4', '37494-2', '72537-4', '72645-5', '72644-8', '72536-6', '72643-0', '72642-2', '72543-2', '72552-3', '72553-1', '72535-8', '72534-1', '48735-5', '43759-0', '35928-1', '42296-4', '43758-2', '35929-9', '42297-2', '43760-8', '37608-7', '42701-3', '39760-4', '39759-6', '39761-2', '39953-5', '39763-8', '39762-0', '39758-8', '44110-5', '24600-9', '69068-5', '26313-7', '26314-5', '26318-6', '37921-4', '42021-6', '42020-8', '39026-0', '39028-6', '38032-9', '39027-8', '24595-1', '26315-2', '26316-0', '26317-8', '44118-8', '35930-7', '35931-5', '70921-2', '35932-3', '70922-0', '69240-0', '42139-6', '24609-0', '26334-3', '26335-0', '38023-8', '26336-8', '38025-3', '44121-2', '69245-9', '69246-7', '44204-6', '69247-5', '46372-9', '62494-0', '24621-5', '69241-8', '69242-6', '42422-6', '43444-9', '42423-4', '69243-4', '44223-6', '69244-2', '42421-8', '35933-1', '35936-4', '70923-8', '35934-9', '70924-6', '35935-6', '70925-3', '72539-0', '30643-1', '35912-5', '25028-2', '25029-0', '24613-2', '30644-9', '25077-9', '24625-6', '26310-3', '26311-1', '26312-9', '41801-2', '24716-3', '62491-6', '62492-4', '25072-0', '62450-2', '25026-6', '25027-4', '26307-9', '26308-7', '26309-5', '25024-1', '26304-6', '26305-3', '26306-1', '64993-9', '42456-4', '36772-2', '24779-1', '24782-5', '35937-2', '43487-8', '65797-3', '65798-1', '69134-5', '25078-7', '24756-9', '26301-2', '26302-0', '26303-8', '24555-5', '51391-1', '35938-0', '42140-4', '39362-9', '30637-3', '41799-8', '24995-3', '44224-4', '46373-7', '44102-2', '44222-8', '30629-0', '30581-3', '30664-7', '30582-1', '30665-4', '25053-0', '25054-8', '24537-3', '42141-2', '72549-9', '72548-1', '72547-3', '72546-5', '41810-3', '24559-7', '38142-6', '30628-2', '72538-2', '72544-0', '24885-6', '72550-7', '72551-5', '42017-4', '52790-3', '72545-7', '52791-1', '46294-5', '24996-1', '24626-4', '26295-6', '26296-4', '26297-2', '48740-5', '48736-3', '48739-7', '24570-4', '43763-2', '43761-6', '43762-4', '43764-0', '72554-9', '39138-3', '39139-1', '36936-3', '24603-3', '26292-3', '26293-1', '26294-9', '36928-0', '46296-0', '46295-2', '42433-3', '69160-0', '24585-2', '36929-8', '44122-0', '30656-3', '30800-7', '28632-8', '46264-8', '47519-4', '47245-6', '52035-3', '52036-1', '52046-0', '18841-7', '52028-8', '24655-3', '52047-8', '65806-2', '11500-6', '11495-9', '11494-2', '11496-7', '11497-5', '11498-3', '28572-6', '28621-1', '29753-1', '18734-4', '18735-1', '18736-9', '28654-2', '18763-3', '18737-7', '28635-1', '18738-5', '18739-3', '46214-3', '15508-5', '11502-2', '24717-1', '52048-6', '52049-4', '55186-1', '55185-3', '11503-0', '52037-9', '24672-8', '30632-4', '52050-2', '35990-1', '41806-1', '24556-3', '24558-9', '30762-9', '24566-2', '24531-6', '24532-4', '44115-4', '36781-3', '30864-3', '36791-2', '24534-0', '39494-0', '36930-6', '36931-4', '69277-2', '36792-0', '35940-6', '24538-1', '35939-8', '35941-4', '26208-9', '35942-2', '26209-7', '35943-0', '35944-8', '26210-5', '37674-9', '37222-7', '24542-3', '35945-5', '35947-1', '35946-3', '24547-2', '46388-5', '35948-9', '35949-7', '69276-4', '37216-9', '24544-9', '35950-5', '24660-3', '30863-5', '35951-3', '30861-9', '35952-1', '24548-0', '39040-1', '43508-1', '72529-1', '43510-7', '72528-3', '37219-3', '38021-2', '37220-1', '39039-3', '24590-2', '58748-5', '44138-6', '37217-7', '37218-5', '43772-3', '42385-5', '30794-2', '24601-7', '69165-9', '38057-6', '38058-4', '24596-9', '69397-8', '30795-9', '26214-7', '35954-7', '26215-4', '35955-4', '26216-2', '46299-4', '36010-7', '36011-5', '24616-5', '42146-1', '26217-0', '43765-7', '26218-8', '39427-0', '26219-6', '39437-9', '43552-9', '36793-8', '30859-3', '30865-0', '46374-5', '24627-2', '24629-8', '24630-6', '24657-9', '30862-7', '38016-2', '37235-9', '35960-4', '35961-2', '35959-6', '44120-4', '24757-7', '35962-0', '24674-4', '35963-8', '35965-3', '26220-4', '35964-6', '35966-1', '26221-2', '35967-9', '35968-7', '26222-0', '37688-9', '35969-5', '57823-7', '24690-0', '69193-1', '24693-4', '35970-3', '39042-7', '39031-0', '69293-9', '39428-8', '69297-0', '39439-5', '39449-4', '39418-9', '42145-3', '39429-6', '42144-6', '39440-3', '30876-7', '69283-0', '41835-0', '41816-0', '36794-6', '43771-5', '39495-7', '69398-6', '39503-8', '26224-6', '26223-8', '26226-1', '26225-3', '26231-1', '26230-3', '24853-4', '35953-9', '41808-7', '24696-7', '69389-5', '69399-4', '30871-8', '38134-3', '38128-5', '39498-1', '39504-6', '35984-4', '35985-1', '35986-9', '35987-7', '38037-8', '35988-5', '35989-3', '38048-5', '38768-8', '24705-6', '26238-6', '26239-4', '26240-2', '37221-9', '35991-9', '24707-2', '35992-7', '30872-6', '46362-0', '35993-5', '26241-0', '35994-3', '26242-8', '35995-0', '35996-8', '26243-6', '37706-9', '35997-6', '24710-6', '30873-4', '35998-4', '26244-4', '35999-2', '26245-1', '36000-8', '26246-9', '24711-4', '36001-6', '39415-5', '39416-3', '37236-7', '24719-7', '36002-4', '24720-5', '36003-2', '46382-8', '36004-0', '26247-7', '36005-7', '26248-5', '36006-5', '36007-3', '26249-3', '37717-6', '24725-4', '24728-8', '24731-2', '58741-0', '30858-5', '30856-9', '24733-8', '42304-6', '30880-9', '30655-5', '24746-0', '58742-8', '44164-2', '58744-4', '24748-6', '36009-9', '44137-8', '42148-7', '36014-9', '36013-1', '24760-1', '36012-3', '36016-4', '36017-2', '26250-1', '36015-6', '36018-0', '36020-6', '26251-9', '36019-8', '36021-4', '36022-2', '26252-7', '37735-8', '43566-9', '36024-8', '39425-4', '42147-9', '39497-3', '38129-3', '38137-6', '38141-8', '35958-8', '35956-2', '24767-6', '26253-5', '35957-0', '26254-3', '38767-0', '26255-0', '24735-3', '36033-9', '38036-0', '36032-1', '39032-8', '42477-0', '43767-3', '36034-7', '43774-9', '24789-0', '69402-6', '36035-4', '38038-6', '69113-9', '36036-2', '38049-3', '36037-0', '24802-1', '36038-8', '36799-5', '36800-1', '36801-9', '36040-4', '26256-8', '36039-6', '36041-2', '26257-6', '36042-0', '36043-8', '26258-4', '37760-6', '36045-3', '36044-6', '24814-6', '36046-1', '28614-6', '39454-4', '24818-7', '35971-1', '30692-8', '30709-0', '35972-9', '48693-6', '39434-6', '38130-1', '39421-3', '41834-3', '39499-9', '41815-2', '39505-3', '46363-8', '30881-7', '46364-6', '39420-5', '48692-8', '39432-0', '48691-0', '39443-7', '36079-2', '69385-3', '36784-7', '69392-9', '36785-4', '42461-4', '42462-2', '30874-2', '44174-1', '35974-5', '39422-1', '36795-3', '39431-2', '36796-1', '39442-9', '35973-7', '35975-2', '38013-9', '24687-6', '26227-9', '26228-7', '26229-5', '35976-0', '35978-6', '38040-2', '35977-8', '35979-4', '35980-2', '38051-9', '37766-3', '36074-3', '24821-1', '43513-1', '43556-0', '42696-5', '36075-0', '36076-8', '30866-8', '57822-9', '36047-9', '36048-7', '38043-6', '36776-3', '46298-6', '36050-3', '36049-5', '37234-2', '38044-4', '37233-4', '69394-5', '69211-1', '37606-1', '30860-1', '24835-1', '36051-1', '24839-3', '24842-7', '36788-8', '36085-9', '44175-8', '30857-7', '41807-9', '36777-1', '36802-7', '24848-4', '37611-1', '38836-3', '36778-9', '42303-8', '43530-5', '43455-5', '39502-0', '36779-7', '69390-3', '43506-5', '24857-5', '36052-9', '24859-1', '39509-5', '36053-7', '38045-1', '37223-5', '37224-3', '38138-4', '24865-8', '24867-4', '24869-0', '37632-7', '36789-6', '30867-6', '24870-8', '24872-4', '26259-2', '26260-0', '26261-8', '38140-0', '38139-2', '24877-3', '36932-2', '24880-7', '24881-5', '26262-6', '26263-4', '26264-2', '36077-6', '69284-8', '36055-2', '36056-0', '36057-8', '30675-3', '24884-9', '43445-6', '43454-8', '36803-5', '24892-2', '69294-7', '39435-3', '36078-4', '30868-4', '69295-4', '39426-2', '36804-3', '39419-7', '30619-1', '36031-3', '36058-6', '36059-4', '38053-5', '37653-3', '69116-2', '36060-2', '36933-0', '69298-8', '69117-0', '36061-0', '36073-5', '25002-7', '48742-1', '26271-7', '26272-5', '26273-3', '42437-4', '36062-8', '24905-2', '24907-8', '37850-5', '36805-0', '36806-8', '36807-6', '36063-6', '26266-7', '26265-9', '36064-4', '26268-3', '26267-5', '36065-1', '36066-9', '26270-9', '26269-1', '37811-7', '30588-8', '24914-4', '37866-1', '37874-5', '37495-9', '28566-8', '36067-7', '24926-8', '37497-5', '24932-6', '24935-9', '70926-1', '36068-5', '43457-1', '42698-1', '24963-1', '24968-0', '69393-7', '36069-3', '37232-6', '24978-9', '24980-5', '70927-9', '37911-5', '49565-5', '24988-8', '36070-1', '24990-4', '37225-0', '36071-9', '36072-7', '37885-1', '36782-1', '38131-9', '46359-6', '44235-0', '42468-9', '38059-2', '36773-0', '37226-8', '24999-5', '30719-9', '37228-4', '37227-6', '37230-0', '37229-2', '37231-8', '37819-0', '39446-0', '24702-3', '26235-2', '26236-0', '26237-8', '36054-5', '24582-9', '44163-4', '26211-3', '26212-1', '26213-9', '43507-3', '42300-4', '25010-0', '37898-4', '30888-2', '36780-5', '69285-5', '39508-7', '36023-0', '36025-5', '36026-3', '69180-8', '36027-1', '36028-9', '36029-7', '36030-5', '35981-0', '24688-4', '30710-8', '37923-0', '48448-5', '39447-8', '38014-7', '39423-9', '41833-5', '39500-4', '41814-5', '39506-1', '30882-5', '48690-2', '39496-5', '48689-4', '39501-2', '48688-6', '39507-9', '36080-0', '69395-2', '36786-2', '36787-0', '46385-1', '44236-8', '42475-4', '42476-2', '36084-2', '39448-6', '46379-4', '36797-9', '39433-8', '36798-7', '39444-5', '26232-9', '30875-9', '36774-8', '36775-5', '35982-8', '26233-7', '38041-0', '35983-6', '26234-5', '38052-7', '25019-1', '42301-2', '30705-8', '39036-9', '39525-1', '39030-2', '36783-9', '69222-8', '36081-8', '36083-4', '36082-6', '36790-4', '39445-2', '38054-3', '37428-0', '25033-2', '25036-5', '37932-1', '37430-6', '26277-4', '26278-2', '37429-8', '37431-4', '26279-0', '26280-8', '37432-2', '69209-5', '37433-0', '26281-6', '26282-4', '37644-2', '69219-4', '36008-1', '25045-6', '25040-7', '25056-3', '44136-0', '25061-3', '25071-2', '46375-2', '39523-6', '44229-3', '28576-7', '39453-6', '36957-9', '37294-6', '41804-6', '39043-5', '44165-9', '58745-1', '59255-0', '69082-6', '37295-3', '72830-3', '72832-9', '39879-2', '39881-8', '30760-3', '25055-5', '39408-0', '39862-8', '47378-5', '37435-5', '42693-2', '39140-9', '44126-1', '42386-3', '42387-1', '37434-8', '46300-0', '72139-9', '72138-1', '72137-3', '37436-3', '43555-2', '43449-8', '37437-1', '36114-7', '43450-6', '43451-4', '46394-3', '43452-2', '43453-0', '37438-9', '43527-1', '39637-4', '43655-0', '43652-7', '69235-0', '43670-9', '43673-3', '43662-6', '39684-6', '39811-5', '39141-7', '39656-4', '39654-9', '39655-6', '39675-4', '11525-3', '72251-2', '24889-8', '36934-8', '36935-5', '43446-4', '69237-6', '39678-8', '39748-9', '42292-3', '46395-0', '39913-9', '39918-8', '46396-8', '39916-2', '39930-3', '37439-7', '37440-5', '37441-3', '39409-8', '36086-7', '30704-1', '38047-7', '43572-7', '38011-3', '69280-6', '24599-3', '26286-5', '26288-1', '26290-7', '38015-4', '42149-5', '42151-1', '36089-1', '69281-4', '36090-9', '39526-9', '46301-8', '39424-7', '62451-0', '62452-8', '69286-3', '36937-1', '38020-4', '36087-5', '38034-5', '36808-4', '39044-3', '36091-7', '42707-0', '36092-5', '43776-4', '42150-3', '36088-3', '38035-2', '69300-2', '41812-9', '38042-8', '39430-4', '39441-1', '36093-3', '38039-4', '38050-1', '44116-2', '48461-8', '69212-9', '38046-9', '42152-9', '44173-3', '39436-1', '69299-6', '24913-6', '41813-7', '38143-4', '46302-6', '44237-6', '46303-4', '36094-1', '39045-0', '39524-4', '25039-9', '48460-0', '69282-2', '72831-1', '44127-9', '39046-8', '36102-2', '36095-8', '36096-6', '69096-6', '36098-2', '36099-0', '36100-6', '36101-4', '36097-4', '39681-2', '39813-1', '39821-4', '36103-0', '36105-5', '47366-0', '36938-9', '36104-8', '36106-3', '36107-1', '38769-6', '36108-9', '46304-2', '36109-7', '36110-5', '36111-3', '36112-1', '39905-5', '39906-3', '39527-7', '49569-7', '43659-2', '39725-7', '39718-2', '39724-0', '39723-2', '49568-9', '39729-9', '39700-0', '49567-1', '39142-5', '39712-5', '39734-9', '39736-4', '39710-9', '39711-7', '38060-0', '25052-2', '25050-6', '42132-1', '72142-3', '72141-5', '72140-7', '37442-1', '37443-9', '36939-7', '70929-5', '70928-7', '70930-3', '36940-5', '42455-6', '24677-7', '42390-5', '39838-8', '39898-2', '39872-7', '46305-9', '46358-8', '44139-4', '46306-7', '39680-4', '39816-4', '39825-5', '41837-6', '39658-0', '39662-2', '49566-3', '30711-6', '24732-0', '30706-6', '30701-7', '69388-7', '69086-7', '69108-9', '69085-9', '69207-9', '69217-8', '69208-7', '69218-6', '48442-8', '48450-1', '44114-7', '48452-7', '44113-9', '48441-0', '36267-3', '24557-1', '48743-9', '42274-1', '36846-4', '30805-6', '36855-5', '36950-4', '36951-2', '36268-1', '24539-9', '26187-5', '36269-9', '26188-3', '36270-7', '26189-1', '44131-1', '36271-5', '36273-1', '36272-3', '36274-9', '30806-4', '46360-4', '43509-9', '43511-5', '36944-7', '24587-8', '48694-4', '43769-9', '42392-1', '36276-4', '69189-9', '69166-7', '38870-2', '38062-6', '36277-2', '36278-0', '36279-8', '43528-9', '36358-0', '36280-6', '36281-4', '36856-3', '30598-7', '36283-0', '36848-0', '30804-9', '36420-8', '42277-4', '36284-8', '72252-0', '69161-8', '42299-8', '48455-0', '48454-3', '36285-5', '24675-1', '26193-3', '36286-3', '26194-1', '36287-1', '26195-8', '42268-3', '24694-2', '30803-1', '36338-2', '36339-0', '36340-8', '69194-9', '69204-6', '69214-5', '36341-6', '30682-9', '36342-4', '36343-2', '36344-0', '36345-7', '36346-5', '36347-3', '30684-5', '69174-1', '36348-1', '36349-9', '36350-7', '36351-5', '36352-3', '30686-0', '69177-4', '36353-1', '36354-9', '36355-6', '36356-4', '24726-2', '24729-6', '36847-2', '30593-8', '36857-1', '36357-2', '36359-8', '30688-6', '36360-6', '36361-4', '36362-2', '36363-0', '36364-8', '36365-5', '36282-2', '30659-7', '24740-3', '43768-1', '43775-6', '36377-0', '36378-8', '24784-1', '36379-6', '24803-9', '38837-1', '36862-1', '26199-0', '36380-4', '26200-6', '36381-2', '26201-4', '36382-0', '30612-6', '30670-4', '36288-9', '39291-0', '36416-6', '36849-8', '36850-6', '30807-2', '44128-7', '46308-3', '36858-9', '46307-5', '36859-7', '36289-7', '36371-3', '36372-1', '36373-9', '36290-5', '36291-3', '36292-1', '36333-3', '36408-3', '30870-0', '42697-3', '36409-1', '36410-9', '36411-7', '36412-5', '36383-8', '37272-2', '48443-6', '36384-6', '30586-2', '24840-1', '36853-0', '30594-6', '36423-2', '48451-9', '36842-3', '43458-9', '24849-2', '24851-8', '36843-1', '36844-9', '39029-4', '46310-9', '36845-6', '30614-2', '36385-3', '46311-7', '37265-6', '30616-7', '30674-6', '36854-8', '30623-3', '36863-9', '30672-0', '36835-7', '24904-5', '24879-9', '36414-1', '36387-9', '36388-7', '36389-5', '36275-6', '36415-8', '44134-5', '36375-4', '36376-2', '36390-3', '36391-1', '36392-9', '36393-7', '36394-5', '36406-7', '36395-2', '24906-0', '36864-7', '36865-4', '26202-2', '36396-0', '26203-0', '36397-8', '26204-8', '36398-6', '30663-9', '44111-3', '69220-2', '37277-1', '36399-4', '36400-0', '37505-5', '36401-8', '24937-5', '37506-3', '43456-3', '30855-1', '36402-6', '24967-2', '37507-1', '36403-4', '24981-3', '37508-9', '24989-6', '36404-2', '37266-4', '36405-9', '44231-9', '36837-3', '37267-2', '37268-0', '37269-8', '37270-6', '37271-4', '24703-1', '26196-6', '26197-4', '26198-2', '24583-7', '26190-9', '26191-7', '26192-5', '36407-5', '72241-3', '72238-9', '36366-3', '30690-2', '69181-6', '36367-1', '36368-9', '36369-7', '36370-5', '36334-1', '39034-4', '36417-4', '36851-4', '36852-2', '36421-6', '36422-4', '46312-5', '36860-5', '46309-1', '36861-3', '69186-5', '36374-7', '36840-7', '36841-5', '36335-8', '38831-4', '36336-6', '36337-4', '36413-3', '36418-2', '36419-0', '37457-9', '25035-7', '26205-5', '37458-7', '26206-3', '38802-5', '26207-1', '42298-0', '24588-6', '72244-7', '43448-0', '46318-2', '46317-4', '46315-8', '46316-6', '46314-1', '46313-3', '60515-4', '24586-0', '24936-7', '24977-1', '25046-4', '38022-0', '25047-2', '25057-1', '30599-5', '24567-0', '38055-0', '36809-2', '69162-6', '69238-4', '30853-6', '36941-3', '37237-5', '36115-4', '69102-2', '36116-2', '69109-7', '36117-0', '46319-0', '69103-0', '36118-8', '69110-5', '36119-6', '36120-4', '69105-5', '36121-2', '69112-1', '36122-0', '36124-6', '36125-3', '69106-3', '36126-1', '69114-7', '36127-9', '37238-3', '69210-3', '36123-8', '36128-7', '36129-5', '38828-0', '36130-3', '36131-1', '36132-9', '36810-0', '37444-7', '69107-1', '37445-4', '69115-4', '37446-2', '36811-8', '36812-6', '39322-3', '37496-7', '37509-7', '70931-1', '24734-6', '47985-7', '24934-2', '48447-7', '24965-6', '48436-0', '30596-1', '48439-4', '36134-5', '36813-4', '36828-2', '24533-2', '69908-2', '36943-9', '44124-6', '36135-2', '36136-0', '69163-4', '36137-8', '36138-6', '36139-4', '36140-2', '36142-8', '36141-0', '36143-6', '24545-6', '72255-3', '43503-2', '36144-4', '37499-1', '36145-1', '43504-0', '43505-7', '44125-3', '69095-8', '24589-4', '48444-4', '37239-1', '37215-1', '42391-3', '36149-3', '69190-7', '69167-5', '36150-1', '36151-9', '36152-7', '46323-2', '36198-0', '36153-5', '36154-3', '36146-9', '36829-0', '24628-0', '36156-8', '36266-5', '24659-5', '42275-8', '36942-1', '72254-6', '37254-0', '42694-0', '48457-6', '48456-8', '36157-6', '36158-4', '69170-9', '36159-2', '36160-0', '36161-8', '36162-6', '24691-8', '26184-2', '26185-9', '26186-7', '36148-5', '30801-5', '24697-5', '36172-5', '69172-5', '36174-1', '36176-6', '69195-6', '69205-3', '69215-2', '36178-2', '36179-0', '36180-8', '36181-6', '36182-4', '36183-2', '36184-0', '36185-7', '36186-5', '69175-8', '36187-3', '36188-1', '36189-9', '36190-7', '36191-5', '36192-3', '69178-2', '36193-1', '36194-9', '36195-6', '36196-4', '24727-0', '36814-2', '36826-6', '36830-8', '24593-6', '37498-3', '24747-8', '36197-2', '36200-4', '36199-8', '36201-2', '36202-0', '36203-8', '36204-6', '36205-3', '36206-1', '30583-9', '36155-0', '46322-4', '36113-9', '43766-5', '36219-4', '24790-8', '36220-2', '36221-0', '36222-8', '36223-6', '69088-3', '36224-4', '36225-1', '36226-9', '36227-7', '36228-5', '36229-3', '36230-1', '24815-3', '36231-9', '30624-1', '39293-6', '36824-1', '36825-8', '36831-6', '46324-0', '44135-2', '50755-8', '36163-4', '36213-7', '36214-5', '36215-2', '36164-2', '36165-9', '36166-7', '36167-5', '36258-2', '36259-0', '24820-3', '43512-3', '42695-7', '36260-8', '36261-6', '36262-4', '36263-2', '36232-7', '48446-9', '36233-5', '24836-9', '36235-0', '24841-9', '36827-4', '36234-3', '24844-3', '48449-3', '36820-9', '36832-4', '24850-0', '24852-6', '36821-7', '36822-5', '46320-8', '39038-5', '46321-6', '36823-3', '24858-3', '36236-8', '37240-9', '37241-7', '24866-6', '36237-6', '42294-9', '24873-2', '24878-1', '30590-4', '36238-4', '36242-6', '36243-4', '36244-2', '36147-7', '36833-2', '30887-4', '36217-8', '36218-6', '36245-9', '36246-7', '36247-5', '36248-3', '36249-1', '69221-0', '36250-9', '36251-7', '69184-0', '36252-5', '38830-6', '36253-3', '36254-1', '36255-8', '24915-1', '48440-2', '37253-2', '24987-0', '36256-6', '37500-6', '24933-4', '24938-3', '37501-4', '38061-8', '24964-9', '30678-7', '37502-2', '24979-7', '24982-1', '37503-0', '30622-5', '37242-5', '36257-4', '36815-9', '38835-5', '36816-7', '37243-3', '37244-1', '37245-8', '37246-6', '37247-4', '37248-2', '37249-0', '36173-3', '25003-5', '36175-8', '36177-4', '36239-2', '24584-5', '26181-8', '26182-6', '26183-4', '36240-0', '36241-8', '72243-9', '72240-5', '36207-9', '36208-7', '69182-4', '36209-5', '36210-3', '36211-1', '36212-9', '30626-6', '39037-7', '42295-6', '24549-8', '36168-3', '69187-3', '36216-0', '36817-5', '36818-3', '36819-1', '36169-1', '38829-8', '36170-9', '36171-7', '36264-0', '36265-7', '36834-0', '37447-0', '37448-8', '69091-7', '37449-6', '37450-4', '37451-2', '37452-0', '37453-8', '24753-6', '49507-7', '25058-9', '72531-7', '39450-2', '72246-2', '72250-4', '72247-0', '72245-4', '39648-1', '44154-3', '42389-7', '42388-9', '42270-9', '39682-0', '39638-2', '39755-4', '39839-6', '39844-6', '41838-4', '41772-5', '46297-8', '39823-0', '24578-7', '39632-5', '39644-0', '39770-3', '39649-9', '42310-3', '39852-9', '39692-9', '39876-8', '39628-3', '39740-6', '43526-3', '39938-6', '46330-7', '46327-3', '46326-5', '46328-1', '46325-7', '46329-9', '42143-8', '58750-1', '58749-3', '39668-9', '44152-7', '39743-0', '39640-8', '39641-6', '44153-5', '39631-7', '24817-9', '39851-1', '69229-3', '44151-9', '39691-1', '69234-3', '39647-3', '39639-0', '42377-2', '46393-5', '42394-7', '36424-0', '30668-8', '42291-5', '36952-0', '36878-7', '36496-8', '36953-8', '36954-6', '36425-7', '30680-3', '36879-5', '69087-5', '69164-2', '36426-5', '36427-3', '36428-1', '36429-9', '36430-7', '44132-9', '36431-5', '36432-3', '69119-6', '36433-1', '44130-3', '36434-9', '44123-8', '30657-1', '48453-5', '37278-9', '37279-7', '42393-9', '36436-4', '69191-5', '69168-3', '38064-2', '38817-3', '44119-6', '36437-2', '36438-0', '36439-8', '46333-1', '36483-6', '36440-6', '36441-4', '36880-3', '29252-4', '36442-2', '69084-2', '36547-8', '42276-6', '72253-8', '42302-0', '48459-2', '48458-4', '36443-0', '30796-7', '36444-8', '69171-7', '36445-5', '36446-3', '36447-1', '36448-9', '42278-2', '69104-8', '69111-3', '36435-6', '30802-3', '72249-6', '36460-4', '69173-3', '36462-0', '36464-6', '69196-4', '69206-1', '69216-0', '36466-1', '30681-1', '36467-9', '36468-7', '36469-5', '36470-3', '36471-1', '36472-9', '30683-7', '69176-6', '36473-7', '36474-5', '36475-2', '36476-0', '36477-8', '30685-2', '69179-0', '36478-6', '36479-4', '36480-2', '36481-0', '30799-1', '36876-1', '42293-1', '36881-1', '36482-8', '36484-4', '30687-8', '36485-1', '36486-9', '36487-7', '36488-5', '36489-3', '36490-1', '30584-7', '30658-9', '43770-7', '43773-1', '36503-1', '36504-9', '39359-5', '36505-6', '30691-0', '69089-1', '36506-4', '36507-2', '36508-0', '36509-8', '36510-6', '36511-4', '48445-1', '30611-8', '30669-6', '30625-8', '39292-8', '44129-5', '36450-5', '36882-9', '38773-8', '36449-7', '36451-3', '36497-6', '36498-4', '36499-2', '36452-1', '36453-9', '36454-7', '36455-4', '36537-9', '30869-2', '69185-7', '36538-7', '36539-5', '36540-3', '36541-1', '36512-2', '36513-0', '30585-4', '36514-8', '30660-5', '36877-9', '36549-4', '46331-5', '36872-0', '30587-0', '30661-3', '36873-8', '36874-6', '36956-1', '46332-3', '36875-3', '30613-4', '36515-5', '37280-5', '37281-3', '30615-9', '30673-8', '36883-7', '30671-2', '30589-6', '30591-2', '30666-2', '36543-7', '36517-1', '36518-9', '36519-7', '36544-5', '44133-7', '36501-5', '36502-3', '36520-5', '36521-3', '36522-1', '69118-8', '36523-9', '38770-4', '36535-3', '36524-7', '30693-6', '69090-9', '36525-4', '36526-2', '38834-8', '36527-0', '36528-8', '36529-6', '30662-1', '44112-1', '48687-8', '37293-8', '36530-4', '36531-2', '37510-5', '30592-0', '30667-0', '37511-3', '30854-4', '30620-9', '30679-5', '37994-1', '37288-8', '30597-9', '36532-0', '37512-1', '30621-7', '36533-8', '37282-1', '36534-6', '44230-1', '36866-2', '36867-0', '36868-8', '37283-9', '37284-7', '37285-4', '37286-2', '37287-0', '36461-2', '43514-9', '43515-6', '36463-8', '36465-3', '30654-8', '38833-0', '36516-3', '36955-3', '36536-1', '72242-1', '72239-7', '36491-9', '30689-4', '69183-2', '36492-7', '36493-5', '36494-3', '36495-0', '30627-4', '39033-6', '36548-6', '36456-2', '69188-1', '36500-7', '36869-6', '36870-4', '36457-0', '38832-2', '36458-8', '36459-6', '36542-9', '36545-2', '36546-0', '37459-5', '37460-3', '43516-4', '43517-2', '37461-1', '37462-9', '37463-7', '37464-5', '37465-2', '37466-0', '43525-5', '69223-6', '36871-2', '24787-4', '30712-4', '25051-4', '29750-7', '25060-5', '52072-6', '53246-5', '46210-1', '34819-3', '46215-0', '28568-4', '11536-0', '52066-8', '53244-0', '11543-6', '46208-5', '52051-0', '52052-8', '52053-6', '52054-4', '52067-6', '24620-7', '33721-2', '34122-2', '55188-7', '55750-4', '52034-6', '24882-3', '69252-5', '69248-3', '42018-2', '69301-0', '28629-4', '74030-8', '29752-3', '24875-7', '51965-2', '51850-6', '24998-7', '52055-1', '52063-5', '18836-7', '28570-0', '28577-5', '11505-5', '28625-2', '52068-4', '46209-3', '55751-2', '52075-9', '55184-6', '55182-0', '55183-8', '62385-0', '11514-7', '11521-2', '11515-4', '11516-2', '11517-0', '11518-8', '11519-6', '11520-4', '44226-9', '30636-5', '18823-5', '18824-3', '18825-0', '18826-8', '19002-5', '18594-2', '52184-9', '19003-3', '19004-1', '29206-0', '25073-8', '52056-9', '25015-9', '60569-1', '55187-9', '52057-7', '52058-5', '52039-5', '52059-3', '52060-1', '52029-6', '55228-1', '18752-6', '29755-6', '11526-1', '28633-6', '11527-9', '58477-1', '11529-5', '55230-7', '11523-8', '11541-0', '29757-2', '33717-0', '18745-0', '11524-6', '18750-0', '18754-2', '18746-8', '18753-4', '29756-4', '18744-3', '18759-1', '38269-7', '18756-7', '17787-3', '55229-9', '18751-8', '18742-7', '33716-2', '18748-4', '18749-2', '33719-6', '29754-9', '52038-7', '52061-9', '28583-3', '28573-4', '60568-3', '52069-2', '11534-5', '46213-5', '28630-2', '52062-7', '28651-8', '28616-1', '69409-1', '24783-3', '25065-4', '25068-8', '43471-2', '25066-2', '25067-0', '43472-0', '42702-1', '42703-9', '36550-2', '36551-0', '69307-7', '69314-3', '46335-6', '46336-4', '46337-2', '46338-0', '36564-3', '69311-9', '69319-2', '36554-4', '42699-9', '36555-1', '36556-9', '69308-5', '69315-0', '42153-7', '36559-3', '36560-1', '37689-7', '36561-9', '69309-3', '69316-8', '36563-5', '69310-1', '69318-4', '24761-9', '26400-2', '26401-0', '26402-8', '36565-0', '69312-7', '69320-0', '36566-8', '36567-6', '37741-6', '36557-7', '36558-5', '37764-8', '37614-5', '69152-7', '69260-8', '37616-0', '69317-6', '42313-7', '42314-5', '37654-1', '30748-8', '36568-4', '36569-2', '37792-9', '37851-3', '24917-7', '48695-1', '37875-2', '24940-9', '30773-6', '37904-0', '38121-0', '69313-5', '69321-8', '37894-3', '37924-8', '42419-2', '36570-0', '37825-7', '30642-3', '30787-6', '44176-6', '41775-8', '30749-6', '30722-3', '30724-9', '30774-4', '70932-9', '25063-9', '69268-1', '49510-1', '49509-3', '24715-5', '37513-9', '37514-7', '38806-6', '37467-8', '37468-6', '42431-7', '69079-2', '37469-4', '37470-2', '38803-3', '24799-9', '36583-3', '37662-4', '36571-8', '36572-6', '36573-4', '36575-9', '36576-7', '36577-5', '36578-3', '36579-1', '36580-9', '36581-7', '36582-5', '37726-7', '36584-1', '36585-8', '48462-6', '48463-4', '36574-2', '42439-0', '37622-8', '39050-0', '36958-7', '36959-5', '37783-8', '39048-4', '37842-2', '36586-6', '36587-4', '37798-6', '69269-9', '37877-8', '30725-6', '24948-2', '30777-7', '30752-0', '39049-2', '37880-2', '37890-1', '37897-6', '39402-3', '37634-3', '30734-8', '30735-5', '24561-3', '24637-1', '24560-5', '24636-3', '36588-2', '36589-0', '30727-2', '30729-8', '30755-3', '24563-9', '43466-2', '24652-0', '43778-0', '24564-7', '36960-3', '24807-0', '26358-2', '26359-0', '26360-8', '44177-4', '38849-6', '37733-3', '42420-0', '42378-0', '39410-6', '42379-8', '39411-4', '24723-9', '26355-8', '26356-6', '26357-4', '42395-4', '42396-2', '36962-9', '37849-7', '36963-7', '36964-5', '37800-0', '36965-2', '37471-0', '37472-8', '38804-1', '36966-0', '36967-8', '38775-3', '37928-9', '37857-0', '69132-9', '69141-0', '39514-5', '37625-1', '37650-9', '65799-9', '65800-5', '65801-3', '37297-9', '39149-0', '36973-6', '37843-0', '36974-4', '37801-8', '37844-8', '37035-3', '37473-6', '38805-8', '36975-1', '36977-7', '38776-1', '36976-9', '36978-5', '37628-5', '36979-3', '36980-1', '38777-9', '36981-9', '36982-7', '36983-5', '37732-5', '36620-3', '36591-6', '36592-4', '39051-8', '36593-2', '36594-0', '36595-7', '36596-5', '36597-3', '36598-1', '37703-6', '36599-9', '36600-5', '36601-3', '37712-7', '36602-1', '36603-9', '37730-9', '36604-7', '36605-4', '36606-2', '37751-5', '24843-5', '37629-3', '39053-4', '38857-9', '37784-6', '37858-8', '24920-1', '39052-6', '24943-3', '24969-8', '30756-1', '37891-9', '37893-5', '37930-5', '36984-3', '36985-0', '36986-8', '36987-6', '37727-5', '36988-4', '37872-9', '37878-6', '36989-2', '36990-0', '37903-2', '36991-8', '36992-6', '30786-8', '36993-4', '36994-2', '37729-1', '37626-9', '36999-1', '37000-7', '37750-7', '37909-9', '41774-1', '30757-9', '37515-4', '37516-2', '38066-7', '38819-9', '37001-5', '37002-3', '37754-9', '42442-4', '37003-1', '37910-7', '36997-5', '36971-0', '37833-1', '36998-3', '36972-8', '37834-9', '37004-9', '36995-9', '30737-1', '30738-9', '24639-7', '24638-9', '37008-0', '37009-8', '24641-3', '24640-5', '38069-1', '37005-6', '37773-9', '42441-6', '24801-3', '26283-2', '26284-0', '26285-7', '37006-4', '37007-2', '37475-1', '37671-5', '38067-5', '36607-0', '36609-6', '36610-4', '36611-2', '36612-0', '36613-8', '36614-6', '36615-3', '37704-4', '36616-1', '36617-9', '36618-7', '42689-0', '30778-5', '30758-7', '37892-7', '44178-2', '37545-1', '37728-3', '30759-5', '37631-9', '37845-5', '37012-2', '37013-0', '37802-6', '36621-1', '36622-9', '36623-7', '37714-3', '69270-7', '37931-3', '36624-5', '37015-5', '24648-8', '37014-8', '37755-6', '37477-7', '37476-9', '39324-9', '69263-2', '24828-6', '24871-6', '37998-2', '37999-0', '38000-6', '38006-3', '38068-3', '36996-7', '37010-6', '37011-4', '37018-9', '37020-5', '37019-7', '37752-3', '39323-1', '49511-9', '24699-1', '26178-4', '26179-2', '26180-0', '42812-8', '42813-6', '42814-4', '42811-0', '44206-1', '30714-0', '42426-7', '37659-0', '42428-3', '42429-1', '42427-5', '37660-8', '37846-3', '37298-7', '37299-5', '37808-3', '43671-7', '42471-3', '42474-7', '39516-0', '37024-7', '37025-4', '37791-1', '39517-8', '37861-2', '37026-2', '43780-6', '37027-0', '43779-8', '69256-6', '69239-2', '69069-3', '69064-4', '69149-3', '42432-5', '24944-1', '37028-8', '37029-6', '37030-4', '37770-5', '37870-3', '24668-6', '37031-2', '37032-0', '37033-8', '38007-1', '37034-6', '38779-5', '37300-1', '37037-9', '37038-7', '38855-3', '37771-3', '37039-5', '37040-3', '38772-0', '30790-0', '37041-1', '37042-9', '37761-4', '38842-1', '37677-2', '37043-7', '37756-4', '37044-5', '37645-9', '37045-2', '37046-0', '37047-8', '37048-6', '38780-3', '37049-4', '37613-7', '37863-8', '24921-9', '42473-9', '38117-8', '30751-2', '37050-2', '37051-0', '37809-1', '42680-9', '37052-8', '37053-6', '37772-1', '37656-6', '37055-1', '37054-4', '37790-3', '37847-1', '38858-7', '37805-9', '37848-9', '37056-9', '37057-7', '37810-9', '41793-1', '41790-7', '24656-1', '39047-6', '38065-9', '38818-1', '42008-3', '24893-0', '37058-5', '37059-3', '37207-8', '37731-7', '44205-3', '38850-4', '37734-1', '37633-5', '39144-1', '41795-6', '69302-8', '36968-6', '30639-9', '42470-5', '30809-8', '42469-7', '38001-4', '38002-2', '37060-1', '37636-8', '46341-4', '24535-7', '26133-9', '26134-7', '26135-4', '24536-5', '26136-2', '26137-0', '26138-8', '24541-5', '26097-6', '26098-4', '51395-2', '26099-2', '51394-5', '36625-2', '46342-2', '38070-9', '38071-7', '38072-5', '38820-7', '46380-2', '24597-7', '38079-0', '38080-8', '38821-5', '36626-0', '36627-8', '37774-7', '46339-8', '24612-4', '26100-8', '26101-6', '26102-4', '30745-4', '30631-6', '42269-1', '24664-5', '26106-5', '26107-3', '26108-1', '30883-3', '24676-9', '26109-9', '26110-7', '26111-5', '46381-0', '37637-6', '24695-9', '37303-5', '24704-9', '26118-0', '26120-6', '26122-2', '24706-4', '26124-8', '30783-5', '37517-0', '37518-8', '38147-5', '30782-7', '37519-6', '37520-4', '38146-7', '26125-5', '26126-3', '30780-1', '37521-2', '37522-0', '38144-2', '30781-9', '37523-8', '37524-6', '38145-9', '24709-8', '26127-1', '26128-9', '26129-7', '42399-6', '42400-2', '43641-0', '42434-1', '37532-9', '37533-7', '38152-5', '28582-5', '36629-4', '36630-2', '37716-8', '24752-8', '24762-7', '26130-5', '26131-3', '26132-1', '28567-6', '37319-1', '37321-7', '37320-9', '38797-7', '37062-7', '36632-8', '37738-2', '36628-6', '28565-0', '36635-1', '36636-9', '37758-0', '48465-9', '24686-8', '26112-3', '26113-1', '26114-9', '24829-4', '48745-4', '43533-9', '24830-2', '26139-6', '26140-4', '26141-2', '36637-7', '24834-4', '37639-2', '37332-4', '38798-5', '24846-8', '26142-0', '26143-8', '26144-6', '36886-0', '24854-2', '36887-8', '38774-6', '43529-7', '24855-9', '30791-8', '36638-5', '36639-3', '37777-0', '28561-9', '30885-8', '30767-8', '30768-6', '36631-0', '38771-2', '47984-0', '24745-2', '26146-1', '26148-7', '26150-3', '24891-4', '24899-7', '37937-0', '38073-3', '38074-1', '37963-6', '38868-6', '37962-8', '26151-1', '69071-9', '26152-9', '39326-4', '38866-0', '39489-0', '42381-4', '39493-2', '37960-2', '37938-8', '39352-0', '38869-4', '37964-4', '26153-7', '39351-2', '39491-6', '38867-8', '39353-8', '39492-4', '37961-0', '24900-3', '36633-6', '36634-4', '37786-1', '30884-1', '24665-2', '39058-3', '24903-7', '26154-5', '26155-2', '26156-0', '42159-4', '24909-4', '26157-8', '26158-6', '26159-4', '42160-2', '24911-0', '24916-9', '28564-3', '48697-7', '37338-1', '28613-8', '24946-6', '36640-1', '43538-8', '37481-9', '38008-9', '43781-4', '24972-2', '43536-2', '24975-5', '37340-7', '37341-5', '37342-3', '46340-6', '24983-9', '42692-4', '37975-0', '37323-3', '37324-1', '37965-1', '24993-8', '24994-6', '72876-6', '25000-1', '37325-8', '30889-0', '30890-8', '25006-8', '26160-2', '26161-0', '26162-8', '26163-6', '26164-4', '26165-1', '25011-8', '37530-3', '38151-7', '37531-1', '38150-9', '37534-5', '38148-3', '37535-2', '38149-1', '25013-4', '26166-9', '26167-7', '26168-5', '44238-4', '48464-2', '24689-2', '26115-6', '26116-4', '26117-2', '24619-9', '26169-3', '26170-1', '51392-9', '26171-9', '51388-7', '43468-8', '49512-7', '25074-6', '26172-7', '26173-5', '26174-3', '51387-9', '39370-2', '30635-7', '42162-8', '39400-7', '69131-1', '69140-2', '39513-7', '39360-3', '69059-4', '69139-4', '39377-7', '37583-2', '39372-8', '39373-6', '39390-0', '39511-1', '39376-9', '42164-4', '42163-6', '39414-8', '39398-3', '69056-0', '41811-1', '41832-7', '42010-9', '42165-1', '46389-3', '39391-8', '39412-2', '69148-5', '39389-2', '30694-4', '42271-7', '60527-9', '25008-4', '69236-8', '43672-5', '44147-7', '42405-1', '42401-0', '42411-9', '39392-6', '44199-8', '44198-0', '47373-6', '47375-1', '43521-4', '47983-2', '48489-9', '48488-1', '43522-2', '48467-5', '43523-0', '44202-0', '44201-2', '36641-9', '37064-3', '37664-0', '36665-8', '37661-6', '24540-7', '26385-5', '26386-3', '26387-1', '36642-7', '37768-9', '36661-7', '48433-7', '36662-5', '37718-4', '36643-5', '36644-3', '36645-0', '36646-8', '37679-8', '36647-6', '36648-4', '36649-2', '36650-0', '37681-4', '36652-6', '36653-4', '36654-2', '37690-5', '36655-9', '36656-7', '37694-7', '30784-3', '36657-5', '38846-2', '37697-0', '24721-3', '26388-9', '26389-7', '26390-5', '36663-3', '69058-6', '36664-1', '37721-8', '24765-0', '26391-3', '26392-1', '26393-9', '24806-2', '26394-7', '26395-4', '26396-2', '36651-8', '69257-4', '24861-7', '26397-0', '26398-8', '26399-6', '37617-8', '42685-8', '42686-6', '36659-1', '36660-9', '37707-7', '36658-3', '39060-9', '42687-4', '37066-8', '37780-4', '37651-7', '44179-0', '37655-8', '36666-6', '37787-9', '42435-8', '37840-6', '36667-4', '36668-2', '37793-7', '37853-9', '37867-9', '37879-4', '36669-0', '43784-8', '36670-8', '37905-7', '24984-7', '69273-1', '37883-6', '36671-6', '36672-4', '37815-8', '37895-0', '37902-4', '37348-0', '36673-2', '37821-6', '37922-2', '37925-5', '37482-7', '37483-5', '37826-5', '69305-1', '42430-9', '42009-1', '39378-5', '48468-3', '43467-0', '69060-2', '69142-8', '39379-3', '39380-1', '69061-0', '41819-4', '39381-9', '69143-6', '39382-7', '38118-6', '38844-7', '37686-3', '38871-0', '38108-7', '38874-4', '38114-5', '44181-6', '43539-6', '48469-1', '39880-0', '44184-0', '44182-4', '44183-2', '36674-0', '37658-2', '38843-9', '37678-0', '42166-9', '38841-3', '37675-6', '37068-4', '37069-2', '37698-8', '36945-4', '38851-2', '37762-2', '36946-2', '69274-9', '38840-5', '37672-3', '37067-6', '36293-9', '37635-0', '36294-7', '36295-4', '36296-2', '37665-7', '36298-8', '36299-6', '36300-2', '36301-0', '37682-2', '36297-0', '36302-8', '36303-6', '36304-4', '37695-4', '36305-1', '36306-9', '36307-7', '37699-6', '24722-1', '26379-8', '26380-6', '26381-4', '36308-5', '36309-3', '37722-6', '30788-4', '36310-1', '36311-9', '37742-4', '36312-7', '36838-1', '48470-9', '48471-7', '37604-6', '69261-6', '30766-0', '37256-5', '39062-5', '36313-5', '36314-3', '37781-2', '37648-3', '39061-7', '24908-6', '26382-2', '26383-0', '26384-8', '37854-7', '24918-5', '24941-7', '30775-1', '37257-3', '37259-9', '37260-7', '37261-5', '37906-5', '37881-0', '37888-5', '36315-0', '37812-5', '36316-8', '37820-8', '37926-3', '37454-6', '48738-9', '37455-3', '37827-3', '48737-1', '37933-9', '69154-3', '39393-4', '39399-1', '39364-5', '39404-9', '39383-5', '48472-5', '39365-2', '69155-0', '39394-2', '43499-3', '43483-7', '39901-4', '39902-2', '39882-6', '39883-4', '30776-9', '69151-9', '24778-3', '69138-6', '69254-1', '36947-0', '36948-8', '37700-2', '36949-6', '42443-2', '36317-6', '36319-2', '36320-0', '36321-8', '36322-6', '36323-4', '37683-0', '36318-4', '36324-2', '37691-3', '30789-2', '36325-9', '36326-7', '37743-2', '36327-5', '43534-7', '43535-4', '36839-9', '37609-5', '37612-9', '36328-3', '69265-7', '36329-1', '36330-9', '37794-5', '37855-4', '37868-7', '37876-0', '36331-7', '36332-5', '48473-3', '37907-3', '37882-8', '38155-8', '37070-0', '37071-8', '37828-1', '37934-7', '69144-4', '39384-3', '39385-0', '39413-0', '39099-7', '69063-6', '39387-6', '69145-1', '39386-8', '69062-8', '38852-0', '37763-0', '36675-7', '36676-5', '37744-0', '36890-2', '37351-4', '30750-4', '36677-3', '37795-2', '37856-2', '24922-7', '24939-1', '30797-5', '37353-0', '37355-5', '37356-3', '37357-1', '37350-6', '37072-6', '37829-9', '39407-2', '69081-8', '37073-4', '69080-0', '39063-3', '42273-3', '36678-1', '36679-9', '37796-0', '42691-6', '38156-6', '37074-2', '37830-7', '36680-7', '36681-5', '36682-3', '36683-1', '37831-5', '42412-7', '39064-1', '69070-1', '38856-1', '37782-0', '24796-5', '24792-4', '24653-8', '24654-6', '37080-9', '37081-7', '37082-5', '38781-1', '39339-7', '37083-3', '38782-9', '37126-0', '37084-1', '38783-7', '39512-9', '39401-5', '69153-5', '69262-4', '37618-6', '37623-6', '39065-8', '37619-4', '24794-0', '30779-3', '36684-9', '36685-6', '37667-3', '36686-4', '36701-1', '37719-2', '36687-2', '39066-6', '36688-0', '36689-8', '36690-6', '36691-4', '37684-8', '36693-0', '36694-8', '36695-5', '37692-1', '39069-0', '36696-3', '36697-1', '37701-0', '42409-3', '69130-3', '48474-1', '38847-0', '37710-1', '36702-9', '36703-7', '36704-5', '37725-9', '36706-0', '36707-8', '36708-6', '37736-6', '36709-4', '36590-8', '36710-2', '37745-7', '36692-2', '69258-2', '36711-0', '42438-2', '36712-8', '36713-6', '37776-2', '37620-2', '36705-2', '36699-7', '36700-3', '37708-5', '36698-9', '37652-5', '36714-4', '36715-1', '37788-7', '37841-4', '36716-9', '24919-3', '24928-4', '24942-5', '37361-3', '39067-4', '43785-5', '24970-6', '30753-8', '38123-6', '37974-3', '37889-3', '36717-7', '36718-5', '37816-6', '37896-8', '36719-3', '37822-4', '30793-4', '38860-3', '37832-3', '37839-8', '39070-8', '42404-4', '39071-6', '37095-7', '37096-5', '37097-3', '37666-5', '39072-4', '36720-1', '36721-9', '37668-1', '36731-8', '36722-7', '36723-5', '36724-3', '37685-5', '36725-0', '36726-8', '36727-6', '37696-2', '36728-4', '36729-2', '36730-0', '37702-8', '69057-8', '38848-8', '37711-9', '36732-6', '36733-4', '37748-1', '37624-4', '36734-2', '36735-9', '37908-1', '36736-7', '37813-3', '37927-1', '37099-9', '38083-2', '37101-3', '42410-1', '37102-1', '37118-7', '37115-3', '69137-8', '39371-0', '39334-8', '39375-1', '42417-6', '42418-4', '39369-4', '37103-9', '37079-1', '39074-0', '39073-2', '69147-7', '39388-4', '37105-4', '37106-2', '37107-0', '37108-8', '37749-9', '37109-6', '37110-4', '38786-0', '37111-2', '37116-1', '37117-9', '37740-8', '38009-7', '37112-0', '37113-8', '37114-6', '37747-3', '69065-1', '37086-6', '37087-4', '37723-4', '37090-8', '69146-9', '37089-0', '37088-2', '38784-5', '30763-7', '37077-5', '37091-6', '37092-4', '37093-2', '37724-2', '30770-2', '42167-7', '37094-0', '38785-2', '41776-6', '24793-2', '44185-7', '44186-5', '41817-8', '41777-4', '30726-4', '37078-3', '30754-6', '39330-6', '42380-6', '39368-6', '39068-2', '39331-4', '39332-2', '39374-4', '24805-4', '26364-0', '26365-7', '26366-5', '39333-0', '38084-0', '37119-5', '39076-5', '37621-0', '37649-1', '39075-7', '37098-1', '44187-3', '37100-5', '24797-3', '37120-3', '37104-7', '42011-7', '24642-1', '24808-8', '26361-6', '26362-4', '26363-2', '37121-1', '37680-6', '37122-9', '37797-8', '37485-0', '39077-3', '46349-7', '38082-4', '38822-3', '37123-7', '38787-8', '36961-1', '37799-4', '37124-5', '37789-5', '69266-5', '37125-2', '38788-6', '24562-1', '24650-4', '24649-6', '37085-8', '37076-7', '24798-1', '43463-9', '24795-7', '42019-0', '39329-8', '39328-0', '39395-9', '39321-5', '39336-3', '39335-5', '39337-1', '39344-7', '39338-9', '39397-5', '39343-9', '39348-8', '39325-6', '39346-2', '39347-0', '39396-7', '24632-2', '37075-9', '43561-0', '38003-0', '38815-7', '42406-9', '42407-7', '42445-7', '37484-3', '37746-5', '42403-6', '42408-5', '42444-0', '42446-5', '39403-1', '37127-8', '37128-6', '37807-5', '46386-9', '39884-2', '39861-0', '42709-6', '39860-2', '26352-5', '26353-3', '26354-1', '24724-7', '37362-1', '24591-0', '37996-6', '37995-8', '37997-4', '38814-0', '37486-8', '37852-1', '39859-4', '39875-0', '39840-4', '39842-0', '39874-3', '39819-8', '39741-4', '24605-8', '39152-4', '69158-4', '48475-8', '69150-1', '69259-0', '26346-7', '39154-0', '26347-5', '42169-3', '26348-3', '42168-5', '46350-5', '24604-1', '26349-1', '26350-9', '26351-7', '46351-3', '39895-8', '39887-5', '39889-1', '39885-9', '39910-5', '39912-1', '39909-7', '39908-9', '39886-7', '39890-9', '39888-3', '39867-7', '39863-6', '39866-9', '39864-4', '39865-1', '39869-3', '39868-5', '39893-3', '43644-4', '39858-6', '39636-6', '39871-9', '42261-8', '42262-6', '43653-5', '39847-9', '39899-0', '42308-7', '42263-4', '39856-0', '43500-8', '44148-5', '43642-8', '43664-2', '43643-6', '43666-7', '43663-4', '43665-9', '39870-1', '43654-3', '39685-3', '39940-2', '43787-1', '43648-5', '43649-3', '39827-1', '39828-9', '39327-2', '44208-7', '30720-7', '42311-1', '42312-9', '39768-7', '39767-9', '24997-9', '39769-5', '39892-5', '39891-7', '43646-9', '43645-1', '43647-7', '39653-1', '39657-2', '39933-7', '39830-5', '39677-0', '39490-8', '24700-7', '39686-1', '42170-1', '39672-1', '72256-1', '24571-2', '24572-0', '43788-9', '43789-7', '39673-9', '30650-6', '39665-5', '39664-8', '39848-7', '39849-5', '24876-5', '44149-3', '39954-3', '44140-2', '39831-3', '39951-9', '39934-5', '39829-7', '42171-9', '39749-7', '39679-6', '39750-5', '42305-3', '42397-0', '39923-8', '39917-0', '39919-6', '39925-3', '39931-1', '42306-1', '39929-5', '39921-2', '39924-6', '39922-0', '39920-4', '39915-4', '39928-7', '39927-9', '39914-7', '46348-9', '44210-3', '48480-8', '46390-1', '46347-1', '48481-6', '46344-8', '46345-5', '48479-0', '43492-8', '43497-7', '43491-0', '43496-9', '43489-4', '43494-4', '43490-2', '43495-1', '44188-1', '48478-2', '48477-4', '48476-6', '47370-2', '47371-0', '43498-5', '43482-9', '47381-9', '43543-8', '44189-9', '48746-2', '43486-0', '46377-8', '48482-4', '43488-6', '43493-6', '44190-7', '48483-2', '46346-3', '46343-0', '48485-7', '48486-5', '48484-0', '44191-5', '44239-2', '44193-1', '44192-3', '44211-1', '47367-8', '47374-4', '47376-9', '47379-3', '48747-0', '48487-3', '44212-9', '47382-7', '47368-6', '44194-9', '44195-6', '43524-8', '44197-2', '44196-4', '49570-5', '37160-9', '38793-6', '37158-3', '37806-7', '37161-7', '69267-3', '37538-6', '38789-4', '37157-5', '38791-0', '39350-4', '37162-5', '38794-4', '37167-4', '38795-1', '69156-8', '43790-5', '38004-8', '38816-5', '37539-4', '37540-2', '30771-0', '37627-7', '37164-1', '37864-6', '37165-8', '37166-6', '37871-1', '37134-4', '37135-1', '37670-7', '42382-2', '39366-0', '43464-7', '37603-8', '39100-3', '39101-1', '39341-3', '39406-4', '39405-6', '42436-6', '37869-5', '37605-3', '37862-0', '37136-9', '37803-4', '39340-5', '37133-6', '37132-8', '38010-5', '37929-7', '69157-6', '39515-2', '37474-4', '37669-9', '43480-3', '37541-0', '47380-1', '43470-4', '47377-7', '24610-8', '26287-3', '26289-9', '26291-5', '41826-9', '41785-7', '36737-5', '41830-1', '41789-9', '36738-3', '36893-6', '42007-5', '37646-7', '44209-5', '48466-7', '42710-4', '36739-1', '38838-9', '37642-6', '41797-2', '42335-0', '38125-1', '38120-2', '37137-7', '39687-9', '39754-7', '49571-3', '39843-8', '41836-8', '39627-5', '39822-2', '39645-7', '39695-2', '39936-0', '37542-8', '37543-6', '37554-3', '38854-6', '37769-7', '30769-4', '38086-5', '39935-2', '39949-3', '39904-8', '39907-1', '39937-8', '39950-1', '36608-8', '36740-9', '36741-7', '37687-1', '36744-1', '37737-4', '36619-5', '36745-8', '36746-6', '37757-2', '36747-4', '37630-1', '36742-5', '36743-3', '37709-3', '48748-8', '36748-2', '43791-3', '48749-6', '36749-0', '37817-4', '36894-4', '37544-4', '38839-7', '37643-4', '42398-8', '37139-3', '37154-2', '37155-9', '43469-6', '37063-5', '37546-9', '48491-5', '48490-7', '48699-3', '37152-6', '37140-1', '37804-2', '36750-8', '42272-5', '36751-6', '36752-4', '36753-2', '37713-5', '36754-0', '30721-5', '37547-7', '37548-5', '37835-6', '37143-5', '37144-3', '37145-0', '37142-7', '37860-4', '37146-8', '30741-3', '39078-1', '36755-7', '36756-5', '36757-3', '37715-0', '37884-4', '37549-3', '37550-1', '37836-4', '36758-1', '37148-4', '37147-6', '30742-1', '30743-9', '30744-7', '24643-9', '37149-2', '38790-2', '37859-6', '69271-5', '24647-0', '24644-7', '36759-9', '39079-9', '37141-9', '39519-4', '39521-0', '39520-2', '24646-2', '24645-4', '37150-0', '24635-5', '46378-6', '43660-0', '43661-8', '43658-4', '43656-8', '39719-0', '43777-2', '39722-4', '39720-8', '39728-1', '39726-5', '39727-3', '39699-4', '39701-8', '39731-5', '39735-6', '39708-3', '39709-1', '39705-9', '39707-5', '39703-4', '39702-6', '39733-1', '39941-0', '39833-9', '39716-6', '39697-8', '39730-7', '39732-3', '39715-8', '39704-2', '39714-1', '39713-3', '30765-2', '30764-5', '41823-6', '41782-4', '30746-2', '41827-7', '41786-5', '41773-3', '41818-6', '41778-2', '43570-1', '41829-3', '41788-1', '37168-2', '37169-0', '38796-9', '37170-8', '41825-1', '41784-0', '41820-2', '41779-0', '30792-6', '30772-8', '30747-0', '41831-9', '41791-5', '46391-9', '41824-4', '41783-2', '30723-1', '37171-6', '44203-8', '37172-4', '41828-5', '41787-3', '37151-8', '30731-4', '30730-6', '24634-8', '24824-5', '42402-8', '43657-6', '30733-0', '37131-0', '37138-5', '41792-3', '24651-2', '42414-3', '37016-3', '37017-1', '37775-4', '30740-5', '30739-7', '43479-5', '30838-7', '37364-7', '38799-3', '38107-9', '37304-3', '37302-7', '38115-2', '24930-0', '30715-7', '42424-2', '39367-8', '42472-1', '42425-9', '43569-3', '30716-5', '30717-3', '24929-2', '24606-6', '39153-2', '69159-2', '48492-3', '26175-0', '42174-3', '26176-8', '46355-4', '26177-6', '46354-7', '46356-2', '37022-1', '37021-3', '37023-9', '38778-7', '37551-9', '37552-7', '38807-4', '37553-5', '43550-3', '39952-7', '39676-2', '39894-1', '39896-6', '39814-9', '39634-1', '39903-0', '39817-2', '39815-6', '39824-8', '39633-3', '39853-7', '39832-1', '39878-4', '39900-6', '39855-2', '43501-6', '44150-1', '39854-5', '37153-4', '69136-0', '37163-3', '37156-7', '37759-8', '39345-4', '69255-8', '38088-1', '38087-3', '38824-9', '24579-5', '43518-0', '37365-4', '39518-6', '43519-8', '38089-9', '37159-1', '38792-8', '43796-2', '69304-4', '69303-6', '69072-7', '37555-0', '38808-2', '43532-1', '39944-4', '39948-5', '39947-7', '39946-9', '39943-6', '30697-7', '39942-8', '24888-0', '39835-4', '39836-2', '39945-1', '39837-0', '39834-7', '46361-2', '39932-9', '39873-5', '39683-8', '39698-6', '39845-3', '42711-2', '42175-0', '39818-0', '39826-3', '39669-7', '24713-0', '39660-6', '39661-4', '39663-0', '42309-5', '24750-2', '43459-7', '24577-9', '47372-8', '25070-4', '24574-6', '46352-1', '43485-2', '39150-8', '69251-7', '42415-0', '42416-8', '37201-1', '37202-9', '37203-7', '37676-4', '37205-2', '37206-0', '37720-0', '38845-4', '37693-9', '24708-0', '26094-3', '26095-0', '26096-8', '37584-0', '38810-8', '24809-6', '26085-1', '26086-9', '26087-7', '37204-5', '69264-0', '37208-6', '69275-6', '38124-4', '37899-2', '37209-4', '37823-2', '44233-5', '44232-7', '37579-0', '37580-8', '37581-6', '37663-2', '39651-5', '38090-7', '38091-5', '39059-1', '24666-0', '46357-0', '30633-2', '42683-3', '43574-3', '44227-7', '37565-9', '38092-3', '41770-9', '43650-1', '30630-8', '30824-7', '37585-7', '38853-8', '37765-5', '37615-2', '37936-2', '37640-0', '64140-7', '64141-5', '38094-9', '37973-5', '25005-0', '25014-2', '37976-8', '42014-1', '37980-0', '37981-8', '37575-8', '38101-2', '46376-0', '38100-4', '38102-0', '25030-8', '30832-0', '30831-2', '37387-8', '37939-6', '38861-1', '37941-2', '24658-7', '30837-9', '24546-4', '37366-2', '69054-5', '37380-3', '37381-1', '37587-3', '37588-1', '37589-9', '37590-7', '37591-5', '37592-3', '37593-1', '37594-9', '37382-9', '37383-7', '38800-9', '37379-5', '37384-5', '37385-2', '37386-0', '24551-4', '30828-8', '37388-6', '24581-1', '69077-6', '37389-4', '24617-3', '26079-4', '39097-1', '39094-8', '39098-9', '38863-7', '37945-3', '30821-3', '30820-5', '37390-2', '37948-7', '38864-5', '37952-9', '26080-2', '26081-0', '39095-5', '38865-2', '37953-7', '38862-9', '37944-6', '37391-0', '37392-8', '37393-6', '37943-8', '24622-3', '37403-3', '37394-4', '37173-2', '30891-6', '37174-0', '37595-6', '30848-6', '30849-4', '37395-1', '37949-5', '37175-7', '37176-5', '37397-7', '37398-5', '38801-7', '37399-3', '30822-1', '62448-6', '62449-4', '30823-9', '25076-1', '43782-2', '37177-3', '24862-5', '37178-1', '37739-0', '37179-9', '25079-5', '37487-6', '47986-5', '47987-3', '30829-6', '64995-4', '65000-2', '37401-7', '24833-6', '24860-9', '30833-8', '37935-4', '24874-0', '44240-0', '69249-1', '37181-5', '37778-8', '37404-1', '39057-5', '30830-4', '37182-3', '37779-6', '30834-6', '62446-0', '62447-8', '24925-0', '26082-8', '26083-6', '26084-4', '24992-0', '24991-2', '37886-9', '37405-8', '37406-6', '37966-9', '37180-7', '37402-5', '38119-4', '37900-8', '37489-2', '37977-6', '37396-9', '37488-4', '37967-7', '24576-1', '37979-2', '37407-4', '37490-0', '37968-5', '42156-0', '25017-5', '43559-4', '37586-5', '39054-2', '38095-6', '38096-4', '38825-6', '30810-6', '38098-0', '38099-8', '38827-2', '24845-0', '30850-2', '30851-0', '37599-8', '38812-4', '24827-8', '30839-5', '30840-3', '37597-2', '37598-0', '37596-4', '38811-6', '37600-4', '39510-3', '37601-2', '38813-2', '39148-2', '39146-6', '39145-8', '39147-4', '24661-1', '38116-0', '38097-2', '38826-4', '24902-9', '26067-9', '26068-7', '26069-5', '38153-3', '48698-5', '42460-6', '48696-9', '24912-8', '24552-2', '25016-7', '39151-6', '37183-1', '37184-9', '37185-6', '37942-0', '37186-4', '37187-2', '37188-0', '37947-9', '24764-3', '26070-3', '26071-1', '26072-9', '24800-5', '26073-7', '26074-5', '26075-2', '37647-5', '37189-8', '37190-6', '37785-3', '24910-2', '26076-0', '26077-8', '26078-6', '37901-6', '37409-0', '37410-8', '37818-2', '25034-0', '37570-9', '37571-7', '37641-8', '37191-4', '24825-2', '30813-0', '64996-2', '64997-0', '24927-6', '37192-2', '37193-0', '70933-7', '25022-5', '30811-4', '37572-5', '24947-4', '38103-8', '30808-0', '38104-6', '24974-8', '24985-4', '69066-9', '30843-7', '37602-0', '30844-5', '37940-4', '58746-9', '24569-6', '37411-6', '24573-8', '37195-5', '30819-7', '39055-9', '37412-4', '37413-2', '37950-3', '42157-8', '37416-5', '39093-0', '37421-5', '37419-9', '37197-1', '37420-7', '37954-5', '37607-9', '24788-2', '37414-0', '37196-3', '37767-1', '37574-1', '30825-4', '37422-3', '37958-6', '30852-8', '24685-0', '69250-9', '30847-8', '30846-0', '37423-1', '37959-4', '30827-0', '65803-9', '65802-1', '65804-7', '65805-4', '30826-2', '37969-3', '37970-1', '37971-9', '37972-7', '24550-6', '37415-7', '38859-5', '37824-0', '25023-3', '26064-6', '26065-3', '26066-1', '25025-8', '30845-2', '30645-6', '43554-5', '39096-3', '43783-0', '25080-3', '30816-3', '24575-3', '37200-3', '37199-7', '37198-9', '24678-5', '24712-2', '42459-8', '24924-3', '24673-6', '24681-9', '24667-8', '24894-8', '39363-7', '38105-3', '39349-6', '30761-1', '38873-6', '38113-7', '25020-9', '30841-1', '30842-9', '37566-7', '37567-5', '37568-3', '69272-3', '24780-9', '38872-8', '38112-9', '37569-1', '30647-2', '39696-0', '42161-0', '39652-3', '42383-0', '42690-8', '24945-8', '24971-4', '43481-1', '30785-0', '43461-3', '39688-7', '24679-3', '42684-1', '42681-7', '37576-6', '39850-3', '25007-6', '39841-2', '39857-8', '39624-2', '24770-0', '39846-1', '39738-0', '25032-4', '42708-8', '30736-3', '24682-7', '37556-8', '37557-6', '37558-4', '37673-1', '37559-2', '37705-1', '37560-0', '37561-8', '37562-6', '37753-1', '37563-4', '37564-2', '37814-1', '39056-7', '38093-1', '39670-5', '64051-6', '64052-4', '24826-0', '24663-7', '42158-6', '42776-5', '25031-6', '24730-4', '39643-2', '39646-5', '39650-7', '24776-7', '30877-5', '24804-7', '26088-5', '26089-3', '26090-1', '39693-7', '39694-5', '43557-8', '39897-4', '39877-6', '39629-1', '39737-2', '39739-8', '39742-2', '39619-2', '43669-1', '39747-1', '30696-9', '39751-3', '30695-1', '25018-3', '39626-7', '49118-3', '39939-4', '39671-3', '39752-1', '24773-4', '30713-2', '42413-5', '43651-9', '39820-6', '39666-3', '39667-1', '69231-9', '69232-7', '24819-5', '39744-8', '39674-7', '41771-7', '39625-9', '39745-5', '43667-5', '39753-9', '39765-3', '39642-4', '44234-3', '39766-1', '39812-3', '39630-9', '39757-0', '24831-0', '44141-0', '44142-8', '39746-3', '69233-5', '25001-9', '26091-9', '26092-7', '26093-5', '44146-9', '39689-5', '69230-1', '39764-6', '24683-5', '44145-1', '39756-2', '24714-8', '44143-6', '39690-3', '42700-5', '24751-0', '39635-8', '51389-5', '42012-5', '24669-4', '37577-4', '37578-2', '44144-4', '37582-4', '69055-2', '52073-4', '28631-0', '46242-4', '52070-0', '74282-5', '71683-7', '71685-2', '34086-9', '60555-0', '34084-4', '69761-5', '70946-9', '34091-9', '48767-8', '60556-8', '35519-8', '35517-2', '35511-5', '34066-1', '60557-6', '72135-7', '34083-6', '60684-8', '60558-4', '34090-1', '34092-7', '35528-9', '69760-7', '60559-2', '70940-2', '34070-3', '34085-1', '57826-0', '57025-9', '35524-8', '34087-7', '34089-3', '69758-1', '35521-4', '69763-1', '34068-7', '43678-2', '34074-5', '42227-9', '34073-7', '35518-0', '35523-0', '61147-5', '70943-6', '70941-0', '70944-4', '35525-5', '35510-7', '34072-9', '71743-9', '34082-8', '61146-7', '71744-7', '69719-3', '69670-8', '34069-5', '72090-4', '64123-3', '71446-9', '60685-5', '73815-3', '64124-1', '34067-9', '34076-0', '69730-0', '59845-8', '60560-0', '62387-6', '34079-4', '34075-2', '70945-1', '70939-4', '66105-8', '74045-6', '57027-5', '43679-0', '49489-8', '43680-8', '34078-6', '34080-2', '61149-1', '70942-8', '70934-5', '70948-5', '70935-2', '60561-8', '34088-5', '51941-3', '51947-0', '51948-8', '51945-4', '51944-7', '51943-9', '51942-1', '51946-2', '34081-0', '43681-6', '66106-6', '43682-4', '59772-4', '60683-0', '71681-1', '71684-5', '71686-0', '71682-9', '71687-8', '71688-6', '57026-7', '69669-0', '59769-0', '42232-9', '42228-7', '57059-8', '59774-0', '59775-7', '59770-8', '59776-5', '59771-6', '59768-2', '59773-2', '35526-3', '35522-2', '57827-8', '43683-2', '34093-5', '70938-6', '69759-9', '48779-3', '48780-1', '42231-1', '42230-3', '38056-8', '42229-5', '69718-5', '35520-6', '44425-7', '35515-6', '35514-9', '61150-9', '35527-1', '55122-6', '34077-8', '35516-4', '35513-1', '42796-3', '35512-3', '69762-3', '43684-0', '54433-8', '70936-0', '43685-7', '34071-1', '74477-1', '74479-7', '74476-3', '74480-5', '74478-9', '42566-0', '21862-8', '69764-9', '48766-0', '70949-3', '60572-5', '60573-3', '60574-1', '73983-9', '40811-2', '29112-0', '29111-2', '72169-6', '44943-9', '11206-0', '26988-6', '50081-9', '57553-0', '57552-2', '57551-4', '53347-1', '1656-8', '42855-7', '16110-9', '40818-7', '53348-9', '25561-2', '55808-0', '56611-7', '56608-3', '57493-9', '40816-1', '56602-6', '56613-3', '56609-1', '56612-5', '56603-4', '57492-1', '56556-4', '56604-2', '56610-9', '56605-9', '59987-8', '59986-0', '59985-2', '59984-5', '56555-6', '16294-1', '57491-3', '56606-7', '13480-9', '44729-2', '69799-5', '57562-1', '57561-3', '57560-5', '72510-1', '72509-3']}, 'type'=>'CodeableConcept', 'path'=>'DocumentReference.type', 'min'=>1, 'max'=>1, 'binding'=>{'strength'=>'preferred', 'uri'=>'http://hl7.org/fhir/ValueSet/c80-doc-typecodes'}},
        'class' => {'local_name'=>'local_class', 'valid_codes'=>{'http://loinc.org'=>['11369-6', '11485-0', '11486-8', '11488-4', '11506-3', '11543-6', '15508-5', '18726-0', '18761-7', '18842-5', '26436-6', '26441-6', '26442-4', '27895-2', '27896-0', '27897-8', '27898-6', '28570-0', '28619-5', '28634-4', '29749-9', '29750-7', '29751-5', '29752-3', '34109-9', '34117-2', '34121-4', '34122-2', '34133-9', '34140-4', '34748-4', '34775-7', '47039-3', '47042-7', '47045-0', '47046-8', '47049-2', '57017-6', '57016-8', '56445-0', '53576-5', '56447-6', '18748-4', '11504-8', '57133-1']}, 'type'=>'CodeableConcept', 'path'=>'DocumentReference.class', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/c80-doc-classcodes'}},
        'subject' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Patient', 'http://hl7.org/fhir/StructureDefinition/Practitioner', 'http://hl7.org/fhir/StructureDefinition/Group', 'http://hl7.org/fhir/StructureDefinition/Device'], 'type'=>'Reference', 'path'=>'DocumentReference.subject', 'min'=>0, 'max'=>1},
        'created' => {'type'=>'dateTime', 'path'=>'DocumentReference.created', 'min'=>0, 'max'=>1},
        'indexed' => {'type'=>'instant', 'path'=>'DocumentReference.indexed', 'min'=>1, 'max'=>1},
        'author' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Practitioner', 'http://hl7.org/fhir/StructureDefinition/Organization', 'http://hl7.org/fhir/StructureDefinition/Device', 'http://hl7.org/fhir/StructureDefinition/Patient', 'http://hl7.org/fhir/StructureDefinition/RelatedPerson'], 'type'=>'Reference', 'path'=>'DocumentReference.author', 'min'=>0, 'max'=>Float::INFINITY},
        'authenticator' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Practitioner', 'http://hl7.org/fhir/StructureDefinition/Organization'], 'type'=>'Reference', 'path'=>'DocumentReference.authenticator', 'min'=>0, 'max'=>1},
        'custodian' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Organization'], 'type'=>'Reference', 'path'=>'DocumentReference.custodian', 'min'=>0, 'max'=>1},
        'relatesTo' => {'type'=>'DocumentReference::RelatesTo', 'path'=>'DocumentReference.relatesTo', 'min'=>0, 'max'=>Float::INFINITY},
        'description' => {'type'=>'string', 'path'=>'DocumentReference.description', 'min'=>0, 'max'=>1},
        'securityLabel' => {'valid_codes'=>{'http://hl7.org/fhir/v3/Confidentiality'=>['U', 'L', 'M', 'N', 'R', 'V'], 'http://hl7.org/fhir/v3/ActCode'=>['ETH', 'GDIS', 'HIV', 'PSY', 'SCA', 'SOC', 'SDV', 'SEX', 'STD', 'TBOO', 'SICKLE', 'DEMO', 'DOB', 'GENDER', 'LIVARG', 'MARST', 'RACE', 'REL', 'B', 'EMPL', 'LOCIS', 'SSP', 'ADOL', 'CEL', 'DIA', 'DRGIS', 'EMP', 'PDS', 'PRS', 'COMPT', 'HRCOMPT', 'RESCOMPT', 'RMGTCOMPT', 'SecurityPolicy', 'ObligationPolicy', 'ANONY', 'AOD', 'AUDIT', 'AUDTR', 'CPLYCC', 'CPLYCD', 'CPLYJPP', 'CPLYOPP', 'CPLYOSP', 'CPLYPOL', 'DECLASSIFYLABEL', 'DEID', 'DELAU', 'DOWNGRDLABEL', 'DRIVLABEL', 'ENCRYPT', 'ENCRYPTR', 'ENCRYPTT', 'ENCRYPTU', 'HUAPRV', 'LABEL', 'MASK', 'MINEC', 'PERSISTLABEL', 'PRIVMARK', 'PSEUD', 'REDACT', 'UPGRDLABEL', 'RefrainPolicy', 'NOAUTH', 'NOCOLLECT', 'NODSCLCD', 'NODSCLCDS', 'NOINTEGRATE', 'NOLIST', 'NOMOU', 'NOORGPOL', 'NOPAT', 'NOPERSISTP', 'NORDSCLCD', 'NORDSCLCDS', 'NORDSCLW', 'NORELINK', 'NOREUSE', 'NOVIP', 'ORCON'], 'http://hl7.org/fhir/v3/ObservationValue'=>['ABSTRED', 'AGGRED', 'ANONYED', 'MAPPED', 'MASKED', 'PSEUDED', 'REDACTED', 'SUBSETTED', 'SYNTAC', 'TRSLT', 'VERSIONED', 'CRYTOHASH', 'DIGSIG', 'HRELIABLE', 'RELIABLE', 'UNCERTREL', 'UNRELIABLE', 'CLINAST', 'DEVAST', 'HCPAST', 'PACQAST', 'PATAST', 'PAYAST', 'PROAST', 'SDMAST', 'CLINRPT', 'DEVRPT', 'HCPRPT', 'PACQRPT', 'PATRPT', 'PAYRPT', 'PRORPT', 'SDMRPT'], 'http://hl7.org/fhir/v3/ActReason'=>['PurposeOfUse', 'HMARKT', 'HOPERAT', 'DONAT', 'FRAUD', 'GOV', 'HACCRED', 'HCOMPL', 'HDECD', 'HDIRECT', 'HLEGAL', 'HOUTCOMS', 'HPRGRP', 'HQUALIMP', 'HSYSADMIN', 'MEMADMIN', 'PATADMIN', 'PATSFTY', 'PERFMSR', 'RECORDMGT', 'TRAIN', 'HPAYMT', 'CLMATTCH', 'COVAUTH', 'COVERAGE', 'ELIGDTRM', 'ELIGVER', 'ENROLLM', 'REMITADV', 'HRESCH', 'CLINTRCH', 'PATRQT', 'FAMRQT', 'PWATRNY', 'SUPNWK', 'PUBHLTH', 'DISASTER', 'THREAT', 'TREAT', 'CAREMGT', 'CLINTRL', 'ETREAT', 'POPHLTH'], 'http://hl7.org/fhir/v3/ActUSPrivacyLaw'=>['_ActUSPrivacyLaw', '42CFRPart2', 'CommonRule', 'HIPAANOPP', 'HIPAAPsyNotes', 'HIPAASelfPay', 'Title38Section7332'], nil=>[]}, 'type'=>'CodeableConcept', 'path'=>'DocumentReference.securityLabel', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'extensible', 'uri'=>'http://hl7.org/fhir/ValueSet/security-labels'}},
        'content' => {'type'=>'DocumentReference::Content', 'path'=>'DocumentReference.content', 'min'=>1, 'max'=>Float::INFINITY},
        'context' => {'type'=>'DocumentReference::Context', 'path'=>'DocumentReference.context', 'min'=>0, 'max'=>1}
      }

      class RelatesTo < FHIR::STU3::Model
        include FHIR::STU3::Hashable
        include FHIR::STU3::Json
        include FHIR::STU3::Xml

        METADATA = {
          'id' => {'type'=>'string', 'path'=>'RelatesTo.id', 'min'=>0, 'max'=>1},
          'extension' => {'type'=>'Extension', 'path'=>'RelatesTo.extension', 'min'=>0, 'max'=>Float::INFINITY},
          'modifierExtension' => {'type'=>'Extension', 'path'=>'RelatesTo.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
          'code' => {'valid_codes'=>{'http://hl7.org/fhir/document-relationship-type'=>['replaces', 'transforms', 'signs', 'appends']}, 'type'=>'code', 'path'=>'RelatesTo.code', 'min'=>1, 'max'=>1, 'binding'=>{'strength'=>'required', 'uri'=>'http://hl7.org/fhir/ValueSet/document-relationship-type'}},
          'target' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/DocumentReference'], 'type'=>'Reference', 'path'=>'RelatesTo.target', 'min'=>1, 'max'=>1}
        }

        attr_accessor :id                # 0-1 string
        attr_accessor :extension         # 0-* [ Extension ]
        attr_accessor :modifierExtension # 0-* [ Extension ]
        attr_accessor :code              # 1-1 code
        attr_accessor :target            # 1-1 Reference(DocumentReference)
      end

      class Content < FHIR::STU3::Model
        include FHIR::STU3::Hashable
        include FHIR::STU3::Json
        include FHIR::STU3::Xml

        METADATA = {
          'id' => {'type'=>'string', 'path'=>'Content.id', 'min'=>0, 'max'=>1},
          'extension' => {'type'=>'Extension', 'path'=>'Content.extension', 'min'=>0, 'max'=>Float::INFINITY},
          'modifierExtension' => {'type'=>'Extension', 'path'=>'Content.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
          'attachment' => {'type'=>'Attachment', 'path'=>'Content.attachment', 'min'=>1, 'max'=>1},
          'format' => {'valid_codes'=>{'urn:oid:1.3.6.1.4.1.19376.1.2.3'=>['urn:ihe:pcc:handp:2008', 'urn:ihe:pcc:xphr:2007', 'urn:ihe:pcc:aps:2007', 'urn:ihe:pcc:xds-ms:2007', 'urn:ihe:pcc:edr:2007', 'urn:ihe:pcc:edes:2007', 'urn:ihe:pcc:apr:handp:2008', 'urn:ihe:pcc:apr:lab:2008', 'urn:ihe:pcc:apr:edu:2008', 'urn:ihe:pcc:irc:2008', 'urn:ihe:pcc:crc:2008', 'urn:ihe:pcc:cm:2008', 'urn:ihe:pcc:ic:2009', 'urn:ihe:pcc:tn:2007', 'urn:ihe:pcc:nn:2007', 'urn:ihe:pcc:ctn:2007', 'urn:ihe:pcc:edpn:2007', 'urn:ihe:pcc:hp:2008', 'urn:ihe:pcc:ldhp:2009', 'urn:ihe:pcc:lds:2009', 'urn:ihe:pcc:mds:2009', 'urn:ihe:pcc:nds:2010', 'urn:ihe:pcc:ppvs:2010', 'urn:ihe:pcc:trs:2011', 'urn:ihe:pcc:ets:2011', 'urn:ihe:pcc:its:2011', 'urn:ihe:iti:bppc:2007', 'urn:ihe:iti:bppc-sd:2007', 'urn:ihe:iti:xdw:2011:workflowDoc', 'urn:ihe:iti:dsg:detached:2014', 'urn:ihe:iti:dsg:enveloping:2014', 'urn:ihe:iti:xds-sd:pdf:2008', 'urn:ihe:iti:xds-sd:text:2008', 'urn:ihe:lab:xd-lab:2008', 'urn:ihe:rad:TEXT', 'urn:ihe:rad:PDF', 'urn:ihe:rad:CDA:ImagingReportStructuredHeadings:2013', 'urn:ihe:card:imaging:2011', 'urn:ihe:card:CRC:2012', 'urn:ihe:card:EPRC-IE:2014', 'urn:ihe:dent:TEXT', 'urn:ihe:dent:PDF', 'urn:ihe:dent:CDA:ImagingReportStructuredHeadings:2013', 'urn:ihe:pat:apsr:all:2010', 'urn:ihe:pat:apsr:cancer:all:2010', 'urn:ihe:pat:apsr:cancer:breast:2010', 'urn:ihe:pat:apsr:cancer:colon:2010', 'urn:ihe:pat:apsr:cancer:prostate:2010', 'urn:ihe:pat:apsr:cancer:thyroid:2010', 'urn:ihe:pat:apsr:cancer:lung:2010', 'urn:ihe:pat:apsr:cancer:skin:2010', 'urn:ihe:pat:apsr:cancer:kidney:2010', 'urn:ihe:pat:apsr:cancer:cervix:2010', 'urn:ihe:pat:apsr:cancer:endometrium:2010', 'urn:ihe:pat:apsr:cancer:ovary:2010', 'urn:ihe:pat:apsr:cancer:esophagus: 2010', 'urn:ihe:pat:apsr:cancer:stomach: 2010', 'urn:ihe:pat:apsr:cancer:liver:2010', 'urn:ihe:pat:apsr:cancer:pancreas: 2010', 'urn:ihe:pat:apsr:cancer:testis:2010', 'urn:ihe:pat:apsr:cancer:urinary_bladder:2010', 'urn:ihe:pat:apsr:cancer:lip_oral_cavity:2010', 'urn:ihe:pat:apsr:cancer:pharynx:2010', 'urn:ihe:pat:apsr:cancer:salivary_gland:2010', 'urn:ihe:pat:apsr:cancer:larynx:2010', 'urn:ihe:pharm:pre:2010', 'urn:ihe:pharm:padv:2010', 'urn:ihe:pharm:dis:2010', 'urn:ihe:pharm:pml:2013', 'urn:hl7-org:sdwg:ccda-structuredBody:1.1', 'urn:hl7-org:sdwg:ccda-nonXMLBody:1.1', 'urn:hl7-org:sdwg:ccda-structuredBody:2.1', 'urn:hl7-org:sdwg:ccda-nonXMLBody:2.1']}, 'type'=>'Coding', 'path'=>'Content.format', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'preferred', 'uri'=>'http://hl7.org/fhir/ValueSet/formatcodes'}}
        }

        attr_accessor :id                # 0-1 string
        attr_accessor :extension         # 0-* [ Extension ]
        attr_accessor :modifierExtension # 0-* [ Extension ]
        attr_accessor :attachment        # 1-1 Attachment
        attr_accessor :format            # 0-1 Coding
      end

      class Context < FHIR::STU3::Model
        include FHIR::STU3::Hashable
        include FHIR::STU3::Json
        include FHIR::STU3::Xml

        METADATA = {
          'id' => {'type'=>'string', 'path'=>'Context.id', 'min'=>0, 'max'=>1},
          'extension' => {'type'=>'Extension', 'path'=>'Context.extension', 'min'=>0, 'max'=>Float::INFINITY},
          'modifierExtension' => {'type'=>'Extension', 'path'=>'Context.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
          'encounter' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Encounter'], 'type'=>'Reference', 'path'=>'Context.encounter', 'min'=>0, 'max'=>1},
          'event' => {'valid_codes'=>{'http://hl7.org/fhir/v3/ActCode'=>['ACCTRECEIVABLE', 'CASH', 'CC', 'AE', 'DN', 'DV', 'MC', 'V', 'PBILLACCT', 'CONT', 'DAY', 'LOC', 'MONTH', 'PERIOD', 'PROV', 'WEEK', 'YEAR', 'AA', 'ANF', 'AR', 'AS', 'DISPLAY', 'FORM', 'CPTM', 'HCPCSA', 'BLK', 'CAP', 'CONTF', 'FINBILL', 'ROST', 'SESS', 'FFS', 'FFPS', 'FFCS', 'TFS', 'ROIFS', 'ROIPS', 'CACC', 'CAIC', 'CAMC', 'CANC', 'CAPC', 'CBGC', 'CCCC', 'CCGC', 'CCPC', 'CCSC', 'CDEC', 'CDRC', 'CEMC', 'CFPC', 'CIMC', 'CMGC', 'CNEC', 'CNMC', 'CNQC', 'CNSC', 'COGC', 'COMC', 'COPC', 'COSC', 'COTC', 'CPEC', 'CPGC', 'CPHC', 'CPRC', 'CPSC', 'CPYC', 'CROC', 'CRPC', 'CSUC', 'CTSC', 'CURC', 'CVSC', 'LGPC', 'AALC', 'AAMC', 'ABHC', 'ACAC', 'ACHC', 'AHOC', 'ALTC', 'AOSC', 'CACS', 'CAMI', 'CAST', 'CBAR', 'CCAD', 'CCAR', 'CDEP', 'CDGD', 'CDIA', 'CEPI', 'CFEL', 'CHFC', 'CHRO', 'CHYP', 'CMIH', 'CMSC', 'COJR', 'CONC', 'COPD', 'CORT', 'CPAD', 'CPND', 'CPST', 'CSDM', 'CSIC', 'CSLD', 'CSPT', 'CTBU', 'CVDC', 'CWMA', 'CWOH', 'AMB', 'EMER', 'FLD', 'HH', 'IMP', 'ACUTE', 'NONAC', 'PRENC', 'SS', 'VR', 'ALC', 'CARD', 'CHR', 'DNTL', 'DRGRHB', 'GENRL', 'MED', 'OBS', 'ONC', 'PALL', 'PED', 'PHAR', 'PHYRHB', 'PSYCH', 'SURG', 'AUTOATTCH', 'DOCUMENT', 'HEALTHREC', 'IMG', 'LABRESULTS', 'MODEL', 'WIATTCH', 'XRAY', 'ICOL', 'IDSCL', 'INFA', 'INFAO', 'INFASO', 'IRDSCL', 'RESEARCH', 'RSDID', 'RSREID', 'ID', 'IP', 'L', 'M', 'O', 'R', 'X', 'AUTO', 'ENDC', 'REFLEX', 'AUTH', 'NAUTH', 'ELG', 'NELG', 'COVPRD', 'LFEMX', 'NETAMT', 'PRDMX', 'UNITPRICE', 'UNITQTY', 'COVMX', 'EHCPOL', 'HSAPOL', 'AUTOPOL', 'COL', 'UNINSMOT', 'PUBLICPOL', 'DENTPRG', 'DISEASEPRG', 'CANPRG', 'ENDRENAL', 'HIVAIDS', 'MANDPOL', 'MENTPRG', 'SAFNET', 'SUBPRG', 'SUBSIDIZ', 'SUBSIDMC', 'SUBSUPP', 'WCBPOL', 'DENTAL', 'DISEASE', 'DRUGPOL', 'HIP', 'LTC', 'MCPOL', 'POS', 'HMO', 'PPO', 'MENTPOL', 'SUBPOL', 'VISPOL', 'DIS', 'EWB', 'FLEXP', 'LIFE', 'ANNU', 'TLIFE', 'ULIFE', 'PNC', 'REI', 'SURPL', 'UMBRL', 'CHAR', 'CRIME', 'EAP', 'GOVEMP', 'HIRISK', 'IND', 'MILITARY', 'RETIRE', 'SOCIAL', 'VET', 'EMAUTH', '21', '1', '19', '2', '22', '23', '3', '4', '5', '6', '7', '14', '15', '16', '17', '18', '20', '8', '10', '11', '12', '13', '9', 'CHLDCARE', 'CONVEYNC', 'HLTHCARE', 'HOMECARE', 'HOSPPTNT', 'HOSPVSTR', 'HOUSEHLD', 'INMATE', 'INTIMATE', 'LTRMCARE', 'PLACE', 'PTNTCARE', 'SCHOOL2', 'SOCIAL2', 'SUBSTNCE', 'TRAVINT', 'WORK2', 'CHRG', 'REV', 'MVA', 'SCHOOL', 'SPT', 'WPA', 'ACADR', 'ACALL', 'ACALLG', 'ACCONS', 'ACDEMO', 'ACDI', 'ACIMMUN', 'ACLAB', 'ACMED', 'ACMEDC', 'ACMEN', 'ACOBS', 'ACPOLPRG', 'ACPROV', 'ACPSERV', 'ACSUBSTAB', 'INFAUT', 'INFCON', 'INFCRT', 'INFDNG', 'INFEMER', 'INFPWR', 'INFREG', 'ALLCAT', 'ALLGCAT', 'ARCAT', 'COBSCAT', 'DEMOCAT', 'DICAT', 'IMMUCAT', 'LABCAT', 'MEDCCAT', 'MENCAT', 'PSVCCAT', 'RXCAT', 'ALEC', 'BONUS', 'CFWD', 'EDU', 'EPYMT', 'GARN', 'INVOICE', 'PINV', 'PPRD', 'PROA', 'RECOV', 'RETRO', 'TRAN', 'INVTYPE', 'PAYEE', 'PAYOR', 'SENDAPP', 'UNSPSC', 'GTIN', 'UPC', 'COIN', 'COPAYMENT', 'DEDUCTIBLE', 'PAY', 'SPEND', 'COINS', 'AFTHRS', 'ISOL', 'OOO', 'CANCAPT', 'DSC', 'ESA', 'FFSTOP', 'FNLFEE', 'FRSTFEE', 'MARKUP', 'MISSAPT', 'PERFEE', 'PERMBNS', 'RESTOCK', 'TRAVEL', 'URGENT', 'FST', 'HST', 'PST', 'I', 'P', 'S', 'SP', 'W', 'CPNDDRGING', 'CPNDINDING', 'CPNDSUPING', 'DRUGING', 'FRAMEING', 'LENSING', 'PRDING', 'CPINV', 'CSINV', 'CSPINV', 'FININV', 'OHSINV', 'PAINV', 'RXCINV', 'RXDINV', 'SBFINV', 'VRXINV', 'ADNFPPELAT', 'ADNFPPELCT', 'ADNFPPMNAT', 'ADNFPPMNCT', 'ADNFSPELAT', 'ADNFSPELCT', 'ADNFSPMNAT', 'ADNFSPMNCT', 'ADNPPPELAT', 'ADNPPPELCT', 'ADNPPPMNAT', 'ADNPPPMNCT', 'ADNPSPELAT', 'ADNPSPELCT', 'ADNPSPMNAT', 'ADNPSPMNCT', 'ADPPPPELAT', 'ADPPPPELCT', 'ADPPPPMNAT', 'ADPPPPMNCT', 'ADPPSPELAT', 'ADPPSPELCT', 'ADPPSPMNAT', 'ADPPSPMNCT', 'ADRFPPELAT', 'ADRFPPELCT', 'ADRFPPMNAT', 'ADRFPPMNCT', 'ADRFSPELAT', 'ADRFSPELCT', 'ADRFSPMNAT', 'ADRFSPMNCT', 'PDNFPPELAT', 'PDNFPPELCT', 'PDNFPPMNAT', 'PDNFPPMNCT', 'PDNFSPELAT', 'PDNFSPELCT', 'PDNFSPMNAT', 'PDNFSPMNCT', 'PDNPPPELAT', 'PDNPPPELCT', 'PDNPPPMNAT', 'PDNPPPMNCT', 'PDNPSPELAT', 'PDNPSPELCT', 'PDNPSPMNAT', 'PDNPSPMNCT', 'PDPPPPELAT', 'PDPPPPELCT', 'PDPPPPMNAT', 'PDPPPPMNCT', 'PDPPSPELAT', 'PDPPSPELCT', 'PDPPSPMNAT', 'PDPPSPMNCT', 'SBBLELAT', 'SBBLELCT', 'SBNFELAT', 'SBNFELCT', 'SBPDELAT', 'SBPDELCT', 'COVGE', 'EFORM', 'FAX', 'GFTH', 'LATE', 'MANUAL', 'OOJ', 'ORTHO', 'PAPER', 'PIE', 'PYRDELAY', 'REFNR', 'REPSERV', 'UNRELAT', 'VERBAUTH', 'CARELIST', 'CONDLIST', 'INTOLIST', 'PROBLIST', 'RISKLIST', 'GOALLIST', 'ACU', 'CHRON', 'ONET', 'PRN', 'MEDLIST', 'CURMEDLIST', 'DISCMEDLIST', 'HISTMEDLIST', 'CTLSUB', 'INV', 'LU', 'OTC', 'RX', 'SA', 'SAC', 'IND01', 'IND02', 'IND03', 'IND04', 'IND05', 'VFPAPER', 'ACH', 'CHK', 'DDP', 'NON', 'DF', 'EM', 'SO', 'FF', 'FFC', 'FFP', 'FFSS', 'TF', 'FS', 'MS', 'RF', 'UD', 'RFC', 'RFCS', 'RFF', 'RFFS', 'RFP', 'RFPS', 'RFS', 'TB', 'TBS', 'UDE', 'EMRGONLY', 'GRANTORCHOICE', 'IMPLIED', 'IMPLIEDD', 'NOCONSENT', 'NOPP', 'OPTIN', 'OPTINR', 'OPTOUT', 'OPTOUTE', '_ActUSPrivacyLaw', '42CFRPart2', 'CommonRule', 'HIPAANOPP', 'HIPAAPsyNotes', 'HIPAASelfPay', 'Title38Section7332', 'ETH', 'GDIS', 'HIV', 'PSY', 'SCA', 'SOC', 'SDV', 'SEX', 'STD', 'TBOO', 'SICKLE', 'DEMO', 'DOB', 'GENDER', 'LIVARG', 'MARST', 'RACE', 'REL', 'B', 'EMPL', 'LOCIS', 'SSP', 'ADOL', 'CEL', 'DIA', 'DRGIS', 'EMP', 'PDS', 'PRS', 'COMPT', 'HRCOMPT', 'RESCOMPT', 'RMGTCOMPT', 'TRSTACCRD', 'TRSTAGRE', 'TRSTASSUR', 'TRSTCERT', 'TRSTFWK', 'TRSTMEC', 'COVPOL', 'SecurityPolicy', 'ObligationPolicy', 'ANONY', 'AOD', 'AUDIT', 'AUDTR', 'CPLYCC', 'CPLYCD', 'CPLYJPP', 'CPLYOPP', 'CPLYOSP', 'CPLYPOL', 'DECLASSIFYLABEL', 'DEID', 'DELAU', 'DOWNGRDLABEL', 'DRIVLABEL', 'ENCRYPT', 'ENCRYPTR', 'ENCRYPTT', 'ENCRYPTU', 'HUAPRV', 'LABEL', 'MASK', 'MINEC', 'PERSISTLABEL', 'PRIVMARK', 'PSEUD', 'REDACT', 'UPGRDLABEL', 'RefrainPolicy', 'NOAUTH', 'NOCOLLECT', 'NODSCLCD', 'NODSCLCDS', 'NOINTEGRATE', 'NOLIST', 'NOMOU', 'NOORGPOL', 'NOPAT', 'NOPERSISTP', 'NORDSCLCD', 'NORDSCLCDS', 'NORDSCLW', 'NORELINK', 'NOREUSE', 'NOVIP', 'ORCON', 'LOAN', 'RENT', 'TRANSFER', 'SALE', 'SREC', 'SSTOR', 'STRAN', 'ACID', 'ALK', 'DEFB', 'FILT', 'LDLP', 'NEUT', 'RECA', 'UFIL', 'DRUG', 'FD', 'IMMUNIZ', 'BOOSTER', 'INITIMMUNIZ', 'OE', 'LABOE', 'MEDOE', 'PATDOC', 'ALLERLREV', 'CLINNOTEE', 'DIAGLISTE', 'DISCHINSTE', 'DISCHSUME', 'PATEDUE', 'PATREPE', 'PROBLISTE', 'RADREPE', 'IMMLREV', 'REMLREV', 'WELLREMLREV', 'PATINFO', 'ALLERLE', 'CDSREV', 'CLINNOTEREV', 'DISCHSUMREV', 'DIAGLISTREV', 'IMMLE', 'LABRREV', 'MICRORREV', 'MICROORGRREV', 'MICROSENSRREV', 'MLREV', 'MARWLREV', 'OREV', 'PATREPREV', 'PROBLISTREV', 'RADREPREV', 'REMLE', 'WELLREMLE', 'RISKASSESS', 'FALLRISK', 'AFOOT', 'AMBT', 'AMBAIR', 'AMBGRND', 'AMBHELO', 'LAWENF', 'PRVTRN', 'PUBTRN', 'ARTBLD', 'DILUTION', 'AUTO-HIGH', 'AUTO-LOW', 'PRE', 'RERUN', 'EVNFCTS', 'INTFR', 'FIBRIN', 'HEMOLYSIS', 'ICTERUS', 'LIPEMIA', 'VOLUME', 'AVAILABLE', 'CONSUMPTION', 'CURRENT', 'INITIAL', '_ActPatientAnnotationType', 'ANNDI', 'ANNGEN', 'ANNIMM', 'ANNLAB', 'ANNMED', 'GENE', '_ImmunizationObservationType', 'OBSANTC', 'OBSANTV', 'PAT_ADV_EVNT', 'VAC_PROBLEM', '21611-9', '21612-7', '29553-5', '30525-0', '30972-4', 'REP_HALF_LIFE', 'SPLCOATING', 'SPLCOLOR', 'SPLIMAGE', 'SPLIMPRINT', 'SPLSCORING', 'SPLSHAPE', 'SPLSIZE', 'SPLSYMBOL', 'AIRTRNS', 'ANANTRNS', 'ANHUMTRNS', 'BDYFLDTRNS', 'BLDTRNS', 'DERMTRNS', 'ENVTRNS', 'FECTRNS', 'FOMTRNS', 'FOODTRNS', 'HUMHUMTRNS', 'INDTRNS', 'LACTTRNS', 'NOSTRNS', 'PARTRNS', 'PLACTRNS', 'SEXTRNS', 'TRNSFTRNS', 'VECTRNS', 'WATTRNS', '_ObservationQualityMeasureAttribute', 'AGGREGATE', 'CMPMSRMTH', 'CMPMSRSCRWGHT', 'COPY', 'CRS', 'DEF', 'DISC', 'FINALDT', 'GUIDE', 'IDUR', 'ITMCNT', 'KEY', 'MEDT', 'MSD', 'MSRADJ', 'MSRAGG', 'MSRIMPROV', 'MSRJUR', 'MSRRPTR', 'MSRRPTTIME', 'MSRSCORE', 'MSRSET', 'MSRTOPIC', 'MSRTP', 'MSRTYPE', 'RAT', 'REF', 'SDE', 'STRAT', 'TRANF', 'USE', 'TIME_ABSOLUTE', 'TIME_RELATIVE', 'REPRESENTATIVE_BEAT', 'RHYTHM', '_PatientImmunizationRelatedObservationType', 'CLSSRM', 'GRADE', 'SCHL', 'SCHLDIV', 'TEACHER', 'DENEX', 'DENEXCEP', 'DENOM', 'IPOP', 'IPPOP', 'MSRPOPL', 'MSRPOPLEX', 'NUMER', 'NUMEX', 'PREFSTRENGTH', 'ADVERSE_REACTION', 'ASSERTION', 'CASESER', 'CDIO', 'CRIT', 'CTMO', 'DX', 'ADMDX', 'DISDX', 'INTDX', 'NOI', 'GISTIER', 'HHOBS', 'ISSUE', 'NAT', 'SUPPRESSED', 'VALIDAT', 'KEY204', 'KEY205', 'COMPLY', 'DUPTHPY', 'DUPTHPCLS', 'DUPTHPGEN', 'ABUSE', 'FRAUD', 'PLYDOC', 'PLYPHRM', 'DOSE', 'DOSECOND', 'DOSEDUR', 'DOSEDURH', 'DOSEDURHIND', 'DOSEDURL', 'DOSEDURLIND', 'DOSEH', 'DOSEHINDA', 'DOSEHIND', 'DOSEHINDSA', 'DOSEHINDW', 'DOSEIVL', 'DOSEIVLIND', 'DOSEL', 'DOSELINDA', 'DOSELIND', 'DOSELINDSA', 'DOSELINDW', 'MDOSE', 'OBSA', 'AGE', 'ADALRT', 'GEALRT', 'PEALRT', 'COND', 'HGHT', 'LACT', 'PREG', 'WGHT', 'CREACT', 'GEN', 'GEND', 'LAB', 'REACT', 'ALGY', 'INT', 'RREACT', 'RALG', 'RAR', 'RINT', 'BUS', 'CODE_INVAL', 'CODE_DEPREC', 'FORMAT', 'ILLEGAL', 'LEN_RANGE', 'LEN_LONG', 'LEN_SHORT', 'MISSCOND', 'MISSMAND', 'NODUPS', 'NOPERSIST', 'REP_RANGE', 'MAXOCCURS', 'MINOCCURS', 'KEY206', 'OBSOLETE', 'FOOD', 'TPROD', 'DRG', 'NHP', 'NONRX', 'PREVINEF', 'DACT', 'TIME', 'ALRTENDLATE', 'ALRTSTRTLATE', 'ENDLATE', 'STRTLATE', 'ALLDONE', 'FULFIL', 'NOTACTN', 'NOTEQUIV', 'NOTEQUIVGEN', 'NOTEQUIVTHER', 'TIMING', 'INTERVAL', 'MINFREQ', 'HELD', 'TOOLATE', 'TOOSOON', 'HISTORIC', 'PATPREF', 'PATPREFALT', 'KSUBJ', 'KSUBT', 'OINT', 'ALG', 'DALG', 'EALG', 'FALG', 'DINT', 'DNAINT', 'EINT', 'ENAINT', 'FINT', 'FNAINT', 'NAINT', 'SEV', 'FDACOATING', 'FDACOLOR', 'FDAIMPRINTCD', 'FDALOGO', 'FDASCORING', 'FDASHAPE', 'FDASIZE', 'CIRCLE', 'ELLIPSE', 'POINT', 'POLY', 'C', 'DIET', 'BR', 'DM', 'FAST', 'FORMULA', 'GF', 'LF', 'LP', 'LQ', 'LS', 'N', 'NF', 'PAF', 'PAR', 'RD', 'SCH', 'SUPPLEMENT', 'T', 'VLI', 'DRUGPRG', 'F', 'PRLMN', 'SECCATOBS', 'SECCLASSOBS', 'SECCONOBS', 'SECINTOBS', 'SECALTINTOBS', 'SECDATINTOBS', 'SECINTCONOBS', 'SECINTPRVABOBS', 'SECINTPRVRBOBS', 'SECINTSTOBS', 'TRSTACCRDOBS', 'TRSTAGREOBS', 'TRSTCERTOBS', 'TRSTFWKOBS', 'TRSTLOAOBS', 'TRSTMECOBS', 'SUBSIDFFS', 'WRKCOMP', 'COPAY', 'DEDUCT', 'DOSEIND', 'PRA', 'STORE']}, 'type'=>'CodeableConcept', 'path'=>'Context.event', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/v3-ActCode'}},
          'period' => {'type'=>'Period', 'path'=>'Context.period', 'min'=>0, 'max'=>1},
          'facilityType' => {'valid_codes'=>{'http://snomed.info/sct'=>['82242000', '225732001', '79993009', '32074000', '4322002', '224687002', '62480006', '80522000', '36125001', '48311003', '284546000', '42665001', '45618002', '418518002', '73770003', '69362002', '52668009', '360957003', '10206005', '37550003', '73644007', '31628002', '58482006', '90484001', '1814000', '22549003', '56293002', '360966004', '2849009', '14866005', '38238005', '56189001', '89972002', '78088001', '78001009', '23392004', '36293008', '3729002', '5584006', '37546005', '57159002', '331006', '50569004', '79491001', '33022008', '19602009', '39350007', '83891005', '394759007', '405607001', '309900005', '275576008', '10531005', '91154008', '41844007', '45899008', '51563005', '1773006', '72311000', '6827000', '309898008', '39913001', '77931003', '25681007', '20078004', '46224007', '81234003', '35971002', '11424001', '409519008', '901005', '2081004', '59374000', '413456002', '413817003', '310205006', '419955002', '272501009', '394777002']}, 'type'=>'CodeableConcept', 'path'=>'Context.facilityType', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/c80-facilitycodes'}},
          'practiceSetting' => {'valid_codes'=>{'http://snomed.info/sct'=>['408467006', '394577000', '394578005', '421661004', '408462000', '394579002', '394804000', '394580004', '394803006', '408480009', '408454008', '394809005', '394592004', '394600006', '394601005', '394581000', '408478003', '394812008', '408444009', '394582007', '408475000', '410005002', '394583002', '419772000', '394584008', '408443003', '394802001', '394915009', '394814009', '394808002', '394811001', '408446006', '394586005', '394916005', '408472002', '394597005', '394598000', '394807007', '419192003', '408468001', '394593009', '394813003', '410001006', '394589003', '394591006', '394599008', '394649004', '408470005', '394585009', '394821009', '422191005', '394594003', '416304004', '418960008', '394882004', '394806003', '394588006', '408459003', '394607009', '419610006', '418058008', '420208008', '418652005', '418535003', '418862001', '419365004', '418002000', '419983000', '419170002', '419472004', '394539006', '420112009', '409968004', '394587001', '394913002', '408440000', '418112009', '419815003', '394914008', '408455009', '394602003', '408447002', '394810000', '408450004', '408476004', '408469009', '408466002', '408471009', '408464004', '408441001', '408465003', '394605001', '394608004', '408461007', '408460008', '394606000', '408449004', '418018006', '394604002', '394609007', '408474001', '394610002', '394611003', '408477008', '394801008', '408463005', '419321007', '394576009', '394590007', '409967009', '408448007', '419043006', '394612005', '394733009', '394732004']}, 'type'=>'CodeableConcept', 'path'=>'Context.practiceSetting', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/c80-practice-codes'}},
          'sourcePatientInfo' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Patient'], 'type'=>'Reference', 'path'=>'Context.sourcePatientInfo', 'min'=>0, 'max'=>1},
          'related' => {'type'=>'DocumentReference::Context::Related', 'path'=>'Context.related', 'min'=>0, 'max'=>Float::INFINITY}
        }

        class Related < FHIR::STU3::Model
          include FHIR::STU3::Hashable
          include FHIR::STU3::Json
          include FHIR::STU3::Xml

          METADATA = {
            'id' => {'type'=>'string', 'path'=>'Related.id', 'min'=>0, 'max'=>1},
            'extension' => {'type'=>'Extension', 'path'=>'Related.extension', 'min'=>0, 'max'=>Float::INFINITY},
            'modifierExtension' => {'type'=>'Extension', 'path'=>'Related.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
            'identifier' => {'type'=>'Identifier', 'path'=>'Related.identifier', 'min'=>0, 'max'=>1},
            'ref' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Resource'], 'type'=>'Reference', 'path'=>'Related.ref', 'min'=>0, 'max'=>1}
          }

          attr_accessor :id                # 0-1 string
          attr_accessor :extension         # 0-* [ Extension ]
          attr_accessor :modifierExtension # 0-* [ Extension ]
          attr_accessor :identifier        # 0-1 Identifier
          attr_accessor :ref               # 0-1 Reference(Resource)
        end

        attr_accessor :id                # 0-1 string
        attr_accessor :extension         # 0-* [ Extension ]
        attr_accessor :modifierExtension # 0-* [ Extension ]
        attr_accessor :encounter         # 0-1 Reference(Encounter)
        attr_accessor :event             # 0-* [ CodeableConcept ]
        attr_accessor :period            # 0-1 Period
        attr_accessor :facilityType      # 0-1 CodeableConcept
        attr_accessor :practiceSetting   # 0-1 CodeableConcept
        attr_accessor :sourcePatientInfo # 0-1 Reference(Patient)
        attr_accessor :related           # 0-* [ DocumentReference::Context::Related ]
      end

      attr_accessor :id                # 0-1 id
      attr_accessor :meta              # 0-1 Meta
      attr_accessor :implicitRules     # 0-1 uri
      attr_accessor :language          # 0-1 code
      attr_accessor :text              # 0-1 Narrative
      attr_accessor :contained         # 0-* [ Resource ]
      attr_accessor :extension         # 0-* [ Extension ]
      attr_accessor :modifierExtension # 0-* [ Extension ]
      attr_accessor :masterIdentifier  # 0-1 Identifier
      attr_accessor :identifier        # 0-* [ Identifier ]
      attr_accessor :status            # 1-1 code
      attr_accessor :docStatus         # 0-1 code
      attr_accessor :type              # 1-1 CodeableConcept
      attr_accessor :local_class       # 0-1 CodeableConcept
      attr_accessor :subject           # 0-1 Reference(Patient|Practitioner|Group|Device)
      attr_accessor :created           # 0-1 dateTime
      attr_accessor :indexed           # 1-1 instant
      attr_accessor :author            # 0-* [ Reference(Practitioner|Organization|Device|Patient|RelatedPerson) ]
      attr_accessor :authenticator     # 0-1 Reference(Practitioner|Organization)
      attr_accessor :custodian         # 0-1 Reference(Organization)
      attr_accessor :relatesTo         # 0-* [ DocumentReference::RelatesTo ]
      attr_accessor :description       # 0-1 string
      attr_accessor :securityLabel     # 0-* [ CodeableConcept ]
      attr_accessor :content           # 1-* [ DocumentReference::Content ]
      attr_accessor :context           # 0-1 DocumentReference::Context

      def resourceType
        'DocumentReference'
      end
    end
  end
end