module FHIR
  module STU3
    class ImagingStudy < FHIR::STU3::Model
      include FHIR::STU3::Hashable
      include FHIR::STU3::Json
      include FHIR::STU3::Xml

      SEARCH_PARAMS = ['identifier', 'patient', 'accession', 'basedon', 'bodysite', 'context', 'dicom-class', 'endpoint', 'modality', 'performer', 'reason', 'series', 'started', 'study', 'uid']
      METADATA = {
        'id' => {'type'=>'id', 'path'=>'ImagingStudy.id', 'min'=>0, 'max'=>1},
        'meta' => {'type'=>'Meta', 'path'=>'ImagingStudy.meta', 'min'=>0, 'max'=>1},
        'implicitRules' => {'type'=>'uri', 'path'=>'ImagingStudy.implicitRules', 'min'=>0, 'max'=>1},
        'language' => {'valid_codes'=>{'urn:ietf:bcp:47'=>['ar', 'bn', 'cs', 'da', 'de', 'de-AT', 'de-CH', 'de-DE', 'el', 'en', 'en-AU', 'en-CA', 'en-GB', 'en-IN', 'en-NZ', 'en-SG', 'en-US', 'es', 'es-AR', 'es-ES', 'es-UY', 'fi', 'fr', 'fr-BE', 'fr-CH', 'fr-FR', 'fy', 'fy-NL', 'hi', 'hr', 'it', 'it-CH', 'it-IT', 'ja', 'ko', 'nl', 'nl-BE', 'nl-NL', 'no', 'no-NO', 'pa', 'pt', 'pt-BR', 'ru', 'ru-RU', 'sr', 'sr-SP', 'sv', 'sv-SE', 'te', 'zh', 'zh-CN', 'zh-HK', 'zh-SG', 'zh-TW']}, 'type'=>'code', 'path'=>'ImagingStudy.language', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'extensible', 'uri'=>'http://hl7.org/fhir/ValueSet/languages'}},
        'text' => {'type'=>'Narrative', 'path'=>'ImagingStudy.text', 'min'=>0, 'max'=>1},
        'contained' => {'type'=>'Resource', 'path'=>'ImagingStudy.contained', 'min'=>0, 'max'=>Float::INFINITY},
        'extension' => {'type'=>'Extension', 'path'=>'ImagingStudy.extension', 'min'=>0, 'max'=>Float::INFINITY},
        'modifierExtension' => {'type'=>'Extension', 'path'=>'ImagingStudy.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
        'uid' => {'type'=>'oid', 'path'=>'ImagingStudy.uid', 'min'=>1, 'max'=>1},
        'accession' => {'type'=>'Identifier', 'path'=>'ImagingStudy.accession', 'min'=>0, 'max'=>1},
        'identifier' => {'type'=>'Identifier', 'path'=>'ImagingStudy.identifier', 'min'=>0, 'max'=>Float::INFINITY},
        'availability' => {'valid_codes'=>{'http://dicom.nema.org/resources/ontology/DCM'=>['ONLINE', 'OFFLINE', 'NEARLINE', 'UNAVAILABLE', 'ARCHIVE', 'AR', 'AS', 'AU', 'BDUS', 'BI', 'BMD', 'CAD', 'CAPTURE', 'CD', 'CF', 'COMP', 'CP', 'CR', 'CS', 'CT', 'DD', 'DF', 'DG', 'DM', 'DOCD', 'DS', 'DSS', 'DX', 'EC', 'ECG', 'EPS', 'ES', 'F', 'FA', 'FC', 'FILMD', 'FP', 'FS', 'GM', 'H', 'HC', 'HD', 'IO', 'IVOCT', 'IVUS', 'KER', 'KO', 'LEN', 'LOG', 'LP', 'LS', 'M', 'MA', 'MC', 'MCD', 'MEDIM', 'MG', 'MP', 'MR', 'MS', 'NM', 'OAM', 'OCT', 'OP', 'OPM', 'OPR', 'OPT', 'OPV', 'OSS', 'OT', 'PR', 'PRINT', 'PT', 'PX', 'REG', 'RF', 'RG', 'RT', 'RTDOSE', 'RTIMAGE', 'RTPLAN', 'RTRECORD', 'RTSTRUCT', 'SEG', 'SM', 'SMR', 'SR', 'SRF', 'ST', 'TG', 'U', 'US', 'VA', 'VF', 'VIDD', 'WSD', 'XA', 'XC', '109001', '109002', '109003', '109004', '109005', '109006', '109007', '109008', '109009', '109010', '109011', '109012', '109013', '109014', '109015', '109016', '109017', '109018', '109019', '109020', '109021', '109022', '109023', '109024', '109025', '109026', '109027', '109028', '109029', '109030', '109031', '109032', '109033', '109034', '109035', '109036', '109037', '109038', '109039', '109040', '109041', '109042', '109043', '109044', '109045', '109046', '109047', '109048', '109049', '109050', '109051', '109052', '109053', '109054', '109055', '109056', '109057', '109058', '109059', '109060', '109061', '109063', '109070', '109071', '109072', '109073', '109080', '109081', '109082', '109083', '109091', '109092', '109093', '109094', '109095', '109096', '109101', '109102', '109103', '109104', '109105', '109106', '109110', '109111', '109112', '109113', '109114', '109115', '109116', '109117', '109120', '109121', '109122', '109123', '109124', '109125', '109132', '109133', '109134', '109135', '109136', '109200', '109201', '109202', '109203', '109204', '109205', '109206', '109207', '109208', '109209', '109210', '109211', '109212', '109213', '109214', '109215', '109216', '109217', '109218', '109219', '109220', '109221', '109222', '109701', '109702', '109703', '109704', '109705', '109706', '109707', '109708', '109709', '109710', '109801', '109802', '109803', '109804', '109805', '109806', '109807', '109808', '109809', '109810', '109811', '109812', '109813', '109814', '109815', '109816', '109817', '109818', '109819', '109820', '109821', '109822', '109823', '109824', '109825', '109826', '109827', '109828', '109829', '109830', '109831', '109832', '109833', '109834', '109835', '109836', '109837', '109838', '109839', '109840', '109841', '109842', '109843', '109844', '109845', '109846', '109847', '109848', '109849', '109850', '109851', '109852', '109853', '109854', '109855', '109856', '109857', '109858', '109859', '109860', '109861', '109862', '109863', '109864', '109865', '109866', '109867', '109868', '109869', '109870', '109871', '109872', '109873', '109874', '109875', '109876', '109877', '109878', '109879', '109880', '109881', '109901', '109902', '109903', '109904', '109905', '109906', '109907', '109908', '109909', '109910', '109911', '109912', '109913', '109914', '109915', '109916', '109917', '109918', '109919', '109920', '109921', '109931', '109932', '109933', '109941', '109943', '109991', '109992', '109993', '109994', '109995', '109996', '109997', '109998', '109999', '110001', '110002', '110003', '110004', '110005', '110006', '110007', '110008', '110009', '110010', '110011', '110012', '110013', '110020', '110021', '110022', '110023', '110024', '110025', '110026', '110027', '110028', '110030', '110031', '110032', '110033', '110034', '110035', '110036', '110037', '110038', '110100', '110101', '110102', '110103', '110104', '110105', '110106', '110107', '110108', '110109', '110110', '110111', '110112', '110113', '110114', '110120', '110121', '110122', '110123', '110124', '110125', '110126', '110127', '110128', '110129', '110130', '110131', '110132', '110133', '110134', '110135', '110136', '110137', '110138', '110139', '110140', '110141', '110142', '110150', '110151', '110152', '110153', '110154', '110155', '110180', '110181', '110182', '110190', '110500', '110501', '110502', '110503', '110504', '110505', '110506', '110507', '110508', '110509', '110510', '110511', '110512', '110513', '110514', '110515', '110516', '110518', '110519', '110521', '110522', '110523', '110524', '110526', '110527', '110528', '110529', '110700', '110701', '110702', '110703', '110704', '110705', '110706', '110800', '110801', '110802', '110803', '110804', '110805', '110806', '110807', '110808', '110809', '110810', '110811', '110812', '110813', '110814', '110815', '110816', '110817', '110818', '110819', '110820', '110821', '110822', '110823', '110824', '110825', '110826', '110827', '110828', '110829', '110830', '110831', '110832', '110833', '110834', '110835', '110836', '110837', '110838', '110839', '110840', '110841', '110842', '110843', '110844', '110845', '110846', '110847', '110848', '110849', '110850', '110851', '110852', '110853', '110854', '110855', '110856', '110857', '110858', '110859', '110860', '110861', '110862', '110863', '110864', '110865', '110866', '110867', '110868', '110869', '110870', '110871', '110872', '110873', '110874', '110875', '110876', '110877', '110901', '110902', '110903', '110904', '110905', '110906', '110907', '110908', '110909', '110910', '110911', '111001', '111002', '111003', '111004', '111005', '111006', '111007', '111008', '111009', '111010', '111011', '111012', '111013', '111014', '111015', '111016', '111017', '111018', '111019', '111020', '111021', '111022', '111023', '111024', '111025', '111026', '111027', '111028', '111029', '111030', '111031', '111032', '111033', '111034', '111035', '111036', '111037', '111038', '111039', '111040', '111041', '111042', '111043', '111044', '111045', '111046', '111047', '111048', '111049', '111050', '111051', '111052', '111053', '111054', '111055', '111056', '111057', '111058', '111059', '111060', '111061', '111062', '111063', '111064', '111065', '111066', '111069', '111071', '111072', '111081', '111086', '111087', '111088', '111089', '111090', '111091', '111092', '111093', '111099', '111100', '111101', '111102', '111103', '111104', '111105', '111111', '111112', '111113', '111120', '111121', '111122', '111123', '111124', '111125', '111126', '111127', '111128', '111129', '111130', '111135', '111136', '111137', '111138', '111139', '111140', '111141', '111142', '111143', '111144', '111145', '111146', '111147', '111148', '111149', '111150', '111151', '111152', '111153', '111154', '111155', '111156', '111157', '111158', '111159', '111168', '111170', '111171', '111172', '111173', '111174', '111175', '111176', '111177', '111178', '111179', '111180', '111181', '111182', '111183', '111184', '111185', '111186', '111187', '111188', '111189', '111190', '111191', '111192', '111193', '111194', '111195', '111196', '111197', '111198', '111199', '111200', '111201', '111202', '111203', '111204', '111205', '111206', '111207', '111208', '111209', '111210', '111211', '111212', '111213', '111214', '111215', '111216', '111217', '111218', '111219', '111220', '111221', '111222', '111223', '111224', '111225', '111233', '111234', '111235', '111236', '111237', '111238', '111239', '111240', '111241', '111242', '111243', '111244', '111245', '111248', '111249', '111250', '111251', '111252', '111253', '111254', '111255', '111256', '111257', '111258', '111259', '111260', '111262', '111263', '111264', '111265', '111269', '111271', '111273', '111277', '111278', '111279', '111281', '111283', '111284', '111285', '111286', '111287', '111288', '111290', '111291', '111292', '111293', '111294', '111296', '111297', '111298', '111299', '111300', '111301', '111302', '111303', '111304', '111305', '111306', '111307', '111308', '111309', '111310', '111311', '111312', '111313', '111314', '111315', '111316', '111317', '111318', '111320', '111321', '111322', '111323', '111324', '111325', '111326', '111327', '111328', '111329', '111330', '111331', '111332', '111333', '111334', '111335', '111336', '111338', '111340', '111341', '111342', '111343', '111344', '111345', '111346', '111347', '111350', '111351', '111352', '111353', '111354', '111355', '111356', '111357', '111358', '111359', '111360', '111361', '111362', '111363', '111364', '111365', '111366', '111367', '111368', '111369', '111370', '111371', '111372', '111373', '111374', '111375', '111376', '111377', '111380', '111381', '111382', '111383', '111384', '111385', '111386', '111387', '111388', '111389', '111390', '111391', '111392', '111393', '111394', '111395', '111396', '111397', '111398', '111399', '111400', '111401', '111402', '111403', '111404', '111405', '111406', '111407', '111408', '111409', '111410', '111411', '111412', '111413', '111414', '111415', '111416', '111417', '111418', '111419', '111420', '111421', '111423', '111424', '111425', '111426', '111427', '111428', '111429', '111430', '111431', '111432', '111433', '111434', '111435', '111436', '111437', '111438', '111439', '111440', '111441', '111442', '111443', '111444', '111445', '111446', '111447', '111448', '111449', '111450', '111451', '111452', '111453', '111454', '111455', '111456', '111457', '111458', '111459', '111460', '111461', '111462', '111463', '111464', '111465', '111466', '111467', '111468', '111469', '111470', '111471', '111472', '111473', '111474', '111475', '111476', '111477', '111478', '111479', '111480', '111481', '111482', '111483', '111484', '111485', '111486', '111487', '111488', '111489', '111490', '111491', '111492', '111494', '111495', '111496', '111497', '111498', '111499', '111500', '111501', '111502', '111503', '111504', '111505', '111506', '111507', '111508', '111509', '111510', '111511', '111512', '111513', '111514', '111515', '111516', '111517', '111518', '111519', '111520', '111521', '111522', '111523', '111524', '111525', '111526', '111527', '111528', '111529', '111530', '111531', '111532', '111533', '111534', '111535', '111536', '111537', '111538', '111539', '111540', '111541', '111542', '111543', '111544', '111545', '111546', '111547', '111548', '111549', '111550', '111551', '111552', '111553', '111554', '111555', '111556', '111557', '111558', '111559', '111560', '111561', '111562', '111563', '111564', '111565', '111566', '111567', '111568', '111569', '111570', '111571', '111572', '111573', '111574', '111575', '111576', '111577', '111578', '111579', '111580', '111581', '111582', '111583', '111584', '111585', '111586', '111587', '111590', '111591', '111592', '111593', '111601', '111602', '111603', '111604', '111605', '111606', '111607', '111609', '111621', '111622', '111623', '111625', '111626', '111627', '111628', '111629', '111630', '111631', '111632', '111633', '111634', '111635', '111636', '111637', '111638', '111641', '111642', '111643', '111644', '111645', '111646', '111671', '111672', '111673', '111674', '111675', '111676', '111677', '111678', '111679', '111680', '111685', '111686', '111687', '111688', '111689', '111690', '111691', '111692', '111693', '111694', '111695', '111696', '111697', '111698', '111700', '111701', '111702', '111703', '111704', '111705', '111706', '111707', '111708', '111709', '111710', '111711', '111712', '111718', '111719', '111720', '111721', '111723', '111724', '111726', '111727', '111729', '111741', '111742', '111743', '111744', '111745', '111746', '111747', '111748', '111749', '111750', '111751', '111752', '111753', '111754', '111755', '111756', '111760', '111761', '111762', '111763', '111764', '111765', '111766', '111767', '111768', '111769', '111770', '111771', '111772', '111773', '111776', '111777', '111778', '111779', '111780', '111781', '111782', '111783', '111786', '111787', '111791', '111792', '111800', '111801', '111802', '111803', '111804', '111805', '111806', '111807', '111808', '111809', '111810', '111811', '111812', '111813', '111814', '111815', '111816', '111817', '111818', '111819', '111820', '111821', '111822', '111823', '111824', '111825', '111826', '111827', '111828', '111829', '111830', '111831', '111832', '111833', '111834', '111835', '111836', '111837', '111838', '111839', '111840', '111841', '111842', '111843', '111844', '111845', '111846', '111847', '111848', '111849', '111850', '111851', '111852', '111853', '111854', '111855', '111856', '111900', '111901', '111902', '111903', '111904', '111905', '111906', '111907', '111908', '111909', '111910', '111911', '111912', '111913', '111914', '111915', '111916', '111917', '111918', '111919', '111920', '111921', '111922', '111923', '111924', '111925', '111926', '111927', '111928', '111929', '111930', '111931', '111932', '111933', '111934', '111935', '111936', '111937', '111938', '111939', '111940', '111941', '111942', '111943', '111944', '111945', '111946', '111947', '112000', '112001', '112002', '112003', '112004', '112005', '112006', '112007', '112008', '112009', '112010', '112011', '112012', '112013', '112014', '112015', '112016', '112017', '112018', '112019', '112020', '112021', '112022', '112023', '112024', '112025', '112026', '112027', '112028', '112029', '112030', '112031', '112032', '112033', '112034', '112035', '112036', '112037', '112038', '112039', '112040', '112041', '112042', '112043', '112044', '112045', '112046', '112047', '112048', '112049', '112050', '112051', '112052', '112053', '112054', '112055', '112056', '112057', '112058', '112059', '112060', '112061', '112062', '112063', '112064', '112065', '112066', '112067', '112068', '112069', '112070', '112071', '112072', '112073', '112074', '112075', '112076', '112077', '112078', '112079', '112080', '112081', '112082', '112083', '112084', '112085', '112086', '112087', '112088', '112089', '112090', '112091', '112092', '112093', '112094', '112095', '112096', '112097', '112098', '112099', '112100', '112101', '112102', '112103', '112104', '112105', '112106', '112107', '112108', '112109', '112110', '112111', '112112', '112113', '112114', '112115', '112116', '112117', '112118', '112119', '112120', '112121', '112122', '112123', '112124', '112125', '112126', '112127', '112128', '112129', '112130', '112131', '112132', '112133', '112134', '112135', '112136', '112137', '112138', '112139', '112140', '112141', '112142', '112143', '112144', '112145', '112146', '112147', '112148', '112149', '112150', '112151', '112152', '112153', '112154', '112155', '112156', '112157', '112158', '112159', '112160', '112161', '112162', '112163', '112164', '112165', '112166', '112167', '112168', '112169', '112170', '112171', '112172', '112173', '112174', '112175', '112176', '112177', '112178', '112179', '112180', '112181', '112182', '112183', '112184', '112185', '112186', '112187', '112188', '112189', '112191', '112192', '112193', '112194', '112195', '112196', '112197', '112198', '112199', '112200', '112201', '112220', '112222', '112224', '112225', '112226', '112227', '112228', '112229', '112232', '112233', '112238', '112240', '112241', '112242', '112243', '112244', '112248', '112249', '112300', '112301', '112302', '112303', '112304', '112305', '112306', '112307', '112308', '112309', '112310', '112311', '112312', '112313', '112314', '112315', '112316', '112317', '112318', '112319', '112320', '112321', '112325', '112340', '112341', '112342', '112343', '112344', '112345', '112346', '112347', '112348', '112350', '112351', '112352', '112353', '112354', '112355', '112356', '112357', '112358', '112359', '112360', '112361', '112362', '112363', '112364', '112365', '112366', '112367', '112368', '112369', '112370', '112371', '112372', '112373', '112374', '112375', '112376', '112377', '112378', '112379', '112380', '112381', '112700', '112701', '112702', '112703', '112704', '112705', '112706', '112707', '112708', '112709', '112710', '112711', '112712', '112713', '112714', '112715', '112716', '112717', '112718', '112719', '112720', '112721', '113000', '113001', '113002', '113003', '113004', '113005', '113006', '113007', '113008', '113009', '113010', '113011', '113012', '113013', '113014', '113015', '113016', '113017', '113018', '113020', '113021', '113026', '113030', '113031', '113032', '113033', '113034', '113035', '113036', '113037', '113038', '113039', '113040', '113041', '113042', '113043', '113044', '113045', '113046', '113047', '113048', '113049', '113050', '113051', '113052', '113053', '113054', '113055', '113056', '113057', '113058', '113059', '113060', '113061', '113062', '113063', '113064', '113065', '113066', '113067', '113068', '113069', '113070', '113071', '113072', '113073', '113074', '113075', '113076', '113077', '113078', '113079', '113080', '113081', '113082', '113083', '113085', '113086', '113087', '113088', '113089', '113090', '113091', '113092', '113093', '113094', '113095', '113096', '113097', '113100', '113101', '113102', '113103', '113104', '113105', '113106', '113107', '113108', '113109', '113110', '113111', '113500', '113502', '113503', '113505', '113506', '113507', '113508', '113509', '113510', '113511', '113512', '113513', '113514', '113516', '113517', '113518', '113520', '113521', '113522', '113523', '113526', '113527', '113528', '113529', '113530', '113540', '113541', '113542', '113543', '113550', '113551', '113552', '113560', '113561', '113562', '113563', '113568', '113570', '113571', '113572', '113573', '113574', '113575', '113576', '113577', '113601', '113602', '113603', '113605', '113606', '113607', '113608', '113609', '113611', '113612', '113613', '113620', '113621', '113622', '113630', '113631', '113650', '113651', '113652', '113653', '113661', '113662', '113663', '113664', '113665', '113666', '113669', '113670', '113671', '113680', '113681', '113682', '113683', '113684', '113685', '113686', '113687', '113688', '113689', '113690', '113691', '113692', '113701', '113702', '113704', '113705', '113706', '113710', '113711', '113720', '113721', '113722', '113723', '113724', '113725', '113726', '113727', '113728', '113729', '113730', '113731', '113732', '113733', '113734', '113735', '113736', '113737', '113738', '113739', '113740', '113742', '113743', '113744', '113745', '113748', '113750', '113751', '113752', '113753', '113754', '113755', '113756', '113757', '113758', '113759', '113760', '113761', '113763', '113764', '113766', '113767', '113768', '113769', '113770', '113771', '113772', '113773', '113780', '113788', '113789', '113790', '113791', '113792', '113793', '113794', '113795', '113800', '113801', '113802', '113803', '113804', '113805', '113806', '113807', '113808', '113809', '113810', '113811', '113812', '113813', '113814', '113815', '113816', '113817', '113818', '113819', '113820', '113821', '113822', '113823', '113824', '113825', '113826', '113827', '113828', '113829', '113830', '113831', '113832', '113833', '113834', '113835', '113836', '113837', '113838', '113839', '113840', '113841', '113842', '113845', '113846', '113847', '113850', '113851', '113852', '113853', '113854', '113855', '113856', '113857', '113858', '113859', '113860', '113861', '113862', '113863', '113864', '113865', '113866', '113867', '113868', '113870', '113871', '113872', '113873', '113874', '113875', '113876', '113877', '113878', '113879', '113880', '113890', '113893', '113895', '113896', '113897', '113898', '113899', '113900', '113901', '113902', '113903', '113904', '113905', '113906', '113907', '113908', '113909', '113910', '113911', '113912', '113913', '113914', '113921', '113922', '113923', '113930', '113931', '113932', '113933', '113934', '113935', '113936', '113937', '113940', '113941', '113942', '113943', '113944', '113945', '113946', '113947', '113948', '113949', '113950', '113951', '113952', '113953', '113954', '113955', '113956', '113957', '113958', '113959', '113961', '113962', '113963', '113970', '114000', '114001', '114002', '114003', '114004', '114005', '114006', '114007', '114008', '114009', '114010', '114011', '114201', '114202', '114203', '114204', '114205', '114206', '114207', '114208', '114209', '114210', '114211', '114213', '114215', '114216', '121001', '121002', '121003', '121004', '121005', '121006', '121007', '121008', '121009', '121010', '121011', '121012', '121013', '121014', '121015', '121016', '121017', '121018', '121019', '121020', '121021', '121022', '121023', '121024', '121025', '121026', '121027', '121028', '121029', '121030', '121031', '121032', '121033', '121034', '121035', '121036', '121037', '121038', '121039', '121040', '121041', '121042', '121043', '121044', '121045', '121046', '121047', '121048', '121049', '121050', '121051', '121052', '121053', '121054', '121055', '121056', '121057', '121058', '121059', '121060', '121062', '121064', '121065', '121066', '121068', '121069', '121070', '121071', '121072', '121073', '121074', '121075', '121076', '121077', '121078', '121079', '121080', '121081', '121082', '121083', '121084', '121085', '121086', '121087', '121088', '121089', '121090', '121091', '121092', '121093', '121094', '121095', '121096', '121097', '121098', '121099', '121100', '121101', '121102', '121103', '121104', '121105', '121106', '121109', '121110', '121111', '121112', '121113', '121114', '121115', '121116', '121117', '121118', '121120', '121121', '121122', '121123', '121124', '121125', '121126', '121127', '121128', '121130', '121131', '121132', '121133', '121135', '121136', '121137', '121138', '121139', '121140', '121141', '121142', '121143', '121144', '121145', '121146', '121147', '121148', '121149', '121150', '121151', '121152', '121153', '121154', '121155', '121156', '121157', '121158', '121160', '121161', '121162', '121163', '121165', '121166', '121167', '121168', '121169', '121171', '121172', '121173', '121174', '121180', '121181', '121190', '121191', '121192', '121193', '121194', '121195', '121196', '121197', '121198', '121200', '121201', '121202', '121206', '121207', '121208', '121210', '121211', '121213', '121214', '121216', '121217', '121218', '121219', '121220', '121221', '121222', '121230', '121231', '121232', '121233', '121242', '121243', '121244', '121290', '121291', '121301', '121302', '121303', '121304', '121305', '121306', '121307', '121311', '121312', '121313', '121314', '121315', '121316', '121317', '121318', '121320', '121321', '121322', '121323', '121324', '121325', '121326', '121327', '121328', '121329', '121330', '121331', '121332', '121333', '121334', '121335', '121338', '121339', '121340', '121341', '121342', '121346', '121347', '121348', '121349', '121350', '121351', '121352', '121353', '121354', '121358', '121360', '121361', '121362', '121363', '121370', '121371', '121372', '121380', '121381', '121382', '121383', '121401', '121402', '121403', '121404', '121405', '121406', '121407', '121408', '121410', '121411', '121412', '121414', '121415', '121416', '121417', '121420', '121421', '121422', '121423', '121424', '121425', '121427', '121428', '121430', '121431', '121432', '121433', '121434', '121435', '121436', '121437', '121438', '121439', '121701', '121702', '121703', '121704', '121705', '121706', '121707', '121708', '121709', '121710', '121711', '121712', '121713', '121714', '121715', '121716', '121717', '121718', '121719', '121720', '121721', '121722', '121723', '121724', '121725', '121726', '121727', '121728', '121729', '121730', '121731', '121732', '121733', '121734', '121740', '122001', '122002', '122003', '122004', '122005', '122006', '122007', '122008', '122009', '122010', '122011', '122012', '122020', '122021', '122022', '122023', '122024', '122025', '122026', '122027', '122028', '122029', '122030', '122031', '122032', '122033', '122034', '122035', '122036', '122037', '122038', '122039', '122041', '122042', '122043', '122044', '122045', '122046', '122047', '122048', '122049', '122052', '122053', '122054', '122055', '122056', '122057', '122058', '122059', '122060', '122061', '122062', '122072', '122073', '122075', '122076', '122077', '122078', '122079', '122081', '122082', '122083', '122084', '122085', '122086', '122087', '122088', '122089', '122090', '122091', '122092', '122093', '122094', '122095', '122096', '122097', '122098', '122099', '122101', '122102', '122103', '122104', '122105', '122106', '122107', '122108', '122109', '122110', '122111', '122112', '122113', '122114', '122120', '122121', '122122', '122123', '122124', '122125', '122126', '122127', '122128', '122129', '122130', '122131', '122132', '122133', '122134', '122138', '122139', '122140', '122141', '122142', '122143', '122144', '122145', '122146', '122147', '122148', '122149', '122150', '122151', '122152', '122153', '122154', '122157', '122158', '122159', '122160', '122161', '122162', '122163', '122164', '122165', '122166', '122167', '122170', '122171', '122172', '122173', '122175', '122176', '122177', '122178', '122179', '122180', '122181', '122182', '122183', '122185', '122187', '122188', '122189', '122190', '122191', '122192', '122193', '122194', '122195', '122196', '122197', '122198', '122199', '122201', '122202', '122203', '122204', '122205', '122206', '122207', '122208', '122209', '122210', '122211', '122212', '122213', '122214', '122215', '122216', '122217', '122218', '122219', '122220', '122221', '122222', '122223', '122224', '122225', '122227', '122228', '122229', '122230', '122231', '122232', '122233', '122234', '122235', '122236', '122237', '122238', '122239', '122240', '122241', '122242', '122243', '122244', '122245', '122246', '122247', '122248', '122249', '122250', '122251', '122252', '122253', '122254', '122255', '122256', '122257', '122258', '122259', '122260', '122261', '122262', '122263', '122265', '122266', '122267', '122268', '122269', '122270', '122271', '122272', '122273', '122274', '122275', '122276', '122277', '122278', '122279', '122281', '122282', '122283', '122288', '122291', '122292', '122301', '122302', '122303', '122304', '122305', '122306', '122307', '122308', '122309', '122310', '122311', '122312', '122313', '122319', '122320', '122321', '122322', '122325', '122330', '122331', '122332', '122333', '122334', '122335', '122336', '122337', '122339', '122340', '122341', '122343', '122344', '122345', '122346', '122347', '122348', '122350', '122351', '122352', '122354', '122355', '122356', '122357', '122360', '122361', '122363', '122364', '122367', '122368', '122369', '122370', '122371', '122372', '122374', '122375', '122376', '122380', '122381', '122382', '122383', '122384', '122385', '122386', '122387', '122388', '122389', '122390', '122391', '122393', '122394', '122395', '122398', '122399', '122400', '122401', '122402', '122403', '122404', '122405', '122406', '122407', '122408', '122410', '122411', '122417', '122421', '122422', '122423', '122428', '122429', '122430', '122431', '122432', '122433', '122434', '122435', '122438', '122445', '122446', '122447', '122448', '122449', '122450', '122451', '122452', '122453', '122459', '122461', '122464', '122465', '122466', '122467', '122468', '122469', '122470', '122471', '122472', '122473', '122474', '122475', '122476', '122477', '122480', '122481', '122482', '122485', '122486', '122487', '122488', '122489', '122490', '122491', '122493', '122495', '122496', '122497', '122498', '122499', '122501', '122502', '122503', '122505', '122507', '122508', '122509', '122510', '122511', '122516', '122517', '122528', '122529', '122542', '122544', '122545', '122546', '122547', '122548', '122549', '122550', '122551', '122554', '122555', '122558', '122559', '122560', '122562', '122563', '122564', '122565', '122566', '122572', '122574', '122575', '122582', '122600', '122601', '122602', '122603', '122604', '122605', '122606', '122607', '122608', '122609', '122611', '122612', '122616', '122617', '122618', '122619', '122620', '122621', '122624', '122627', '122628', '122631', '122633', '122634', '122635', '122636', '122637', '122638', '122639', '122640', '122642', '122643', '122645', '122650', '122651', '122652', '122655', '122656', '122657', '122658', '122659', '122660', '122661', '122664', '122665', '122666', '122667', '122668', '122670', '122675', '122680', '122683', '122684', '122685', '122686', '122687', '122698', '122699', '122700', '122701', '122702', '122703', '122704', '122705', '122706', '122707', '122708', '122709', '122710', '122711', '122712', '122713', '122715', '122716', '122717', '122718', '122720', '122721', '122726', '122727', '122728', '122729', '122730', '122731', '122732', '122733', '122734', '122735', '122739', '122740', '122741', '122742', '122743', '122744', '122745', '122748', '122750', '122751', '122752', '122753', '122755', '122756', '122757', '122758', '122759', '122760', '122762', '122764', '122768', '122769', '122770', '122771', '122772', '122773', '122775', '122776', '122781', '122782', '122783', '122784', '122785', '122791', '122792', '122793', '122795', '122796', '122797', '122799', '123001', '123003', '123004', '123005', '123006', '123007', '123009', '123010', '123011', '123012', '123014', '123015', '123016', '123019', '123101', '123102', '123103', '123104', '123105', '123106', '123107', '123108', '123109', '123110', '123111', '125000', '125001', '125002', '125003', '125004', '125005', '125006', '125007', '125008', '125009', '125010', '125011', '125012', '125013', '125015', '125016', '125021', '125022', '125023', '125024', '125025', '125030', '125031', '125032', '125033', '125034', '125035', '125036', '125037', '125038', '125040', '125041', '125100', '125101', '125102', '125105', '125106', '125107', '125195', '125196', '125197', '125200', '125201', '125202', '125203', '125204', '125205', '125206', '125207', '125208', '125209', '125210', '125211', '125212', '125213', '125214', '125215', '125216', '125217', '125218', '125219', '125220', '125221', '125222', '125223', '125224', '125225', '125226', '125227', '125228', '125230', '125231', '125233', '125234', '125235', '125236', '125237', '125238', '125239', '125240', '125241', '125242', '125251', '125252', '125253', '125254', '125255', '125256', '125257', '125258', '125259', '125261', '125262', '125263', '125264', '125265', '125270', '125271', '125272', '125273', '125901', '125902', '125903', '125904', '125905', '125906', '125907', '125908', '126000', '126001', '126002', '126003', '126010', '126011', '126020', '126021', '126022', '126030', '126031', '126032', '126033', '126034', '126035', '126036', '126037', '126038', '126039', '126040', '126050', '126051', '126052', '126060', '126061', '126062', '126063', '126064', '126065', '126066', '126067', '126070', '126071', '126072', '126073', '126074', '126075', '126080', '126081', '126100', '126200', '126201', '126202', '126203', '126220', '126300', '126301', '126302', '126303', '126310', '126311', '126312', '126313', '126314', '126320', '126321', '126322', '126330', '126331', '126340', '126341', '126342', '126343', '126344', '126350', '126351', '126352', '126353', '126360', '126361', '126362', '126363', '126364', '126370', '126371', '126372', '126373', '126374', '126375', '126376', '126377', '126380', '126390', '126391', '126392', '126393', '126394', '126400', '126401', '126402', '126403', '126404', '126410', '126411', '126412', '126413', '126500', '126501', '126502', '126503', '126510', '126511', '126512', '126513', '126514', '126515', '126516', '126517', '126518', '126519', '126520', '126600', '126601', '126602', '126603', '126604', '126605', '126606', '126700', '126701', '126702', '126703', '126704', '126705', '126706', '126707', '126708', '126709', '126710', '126711', '126712', '126713', '126714', '126715', '126716', '126801', '126802', '126803', '126804', '126805', '126806', '126807', '126808', '126809', '126810', '126811']}, 'type'=>'code', 'path'=>'ImagingStudy.availability', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'required', 'uri'=>'http://hl7.org/fhir/ValueSet/instance-availability'}},
        'modalityList' => {'valid_codes'=>{'http://dicom.nema.org/resources/ontology/DCM'=>['AR', 'BMD', 'BDUS', 'EPS', 'CR', 'CT', 'DX', 'ECG', 'ES', 'XC', 'GM', 'HD', 'IO', 'IVOCT', 'IVUS', 'KER', 'LEN', 'MR', 'MG', 'NM', 'OAM', 'OCT', 'OPM', 'OP', 'OPR', 'OPT', 'OPV', 'OSS', 'PX', 'PT', 'RF', 'RG', 'SM', 'SRF', 'US', 'VA', 'XA', 'ARCHIVE', 'AS', 'AU', 'BI', 'CAD', 'CAPTURE', 'CD', 'CF', 'COMP', 'CP', 'CS', 'DD', 'DF', 'DG', 'DM', 'DOCD', 'DS', 'DSS', 'EC', 'F', 'FA', 'FC', 'FILMD', 'FP', 'FS', 'H', 'HC', 'KO', 'LOG', 'LP', 'LS', 'M', 'MA', 'MC', 'MCD', 'MEDIM', 'MP', 'MS', 'NEARLINE', 'OFFLINE', 'ONLINE', 'OT', 'PR', 'PRINT', 'REG', 'RT', 'RTDOSE', 'RTIMAGE', 'RTPLAN', 'RTRECORD', 'RTSTRUCT', 'SEG', 'SMR', 'SR', 'ST', 'TG', 'U', 'UNAVAILABLE', 'VF', 'VIDD', 'WSD', '109001', '109002', '109003', '109004', '109005', '109006', '109007', '109008', '109009', '109010', '109011', '109012', '109013', '109014', '109015', '109016', '109017', '109018', '109019', '109020', '109021', '109022', '109023', '109024', '109025', '109026', '109027', '109028', '109029', '109030', '109031', '109032', '109033', '109034', '109035', '109036', '109037', '109038', '109039', '109040', '109041', '109042', '109043', '109044', '109045', '109046', '109047', '109048', '109049', '109050', '109051', '109052', '109053', '109054', '109055', '109056', '109057', '109058', '109059', '109060', '109061', '109063', '109070', '109071', '109072', '109073', '109080', '109081', '109082', '109083', '109091', '109092', '109093', '109094', '109095', '109096', '109101', '109102', '109103', '109104', '109105', '109106', '109110', '109111', '109112', '109113', '109114', '109115', '109116', '109117', '109120', '109121', '109122', '109123', '109124', '109125', '109132', '109133', '109134', '109135', '109136', '109200', '109201', '109202', '109203', '109204', '109205', '109206', '109207', '109208', '109209', '109210', '109211', '109212', '109213', '109214', '109215', '109216', '109217', '109218', '109219', '109220', '109221', '109222', '109701', '109702', '109703', '109704', '109705', '109706', '109707', '109708', '109709', '109710', '109801', '109802', '109803', '109804', '109805', '109806', '109807', '109808', '109809', '109810', '109811', '109812', '109813', '109814', '109815', '109816', '109817', '109818', '109819', '109820', '109821', '109822', '109823', '109824', '109825', '109826', '109827', '109828', '109829', '109830', '109831', '109832', '109833', '109834', '109835', '109836', '109837', '109838', '109839', '109840', '109841', '109842', '109843', '109844', '109845', '109846', '109847', '109848', '109849', '109850', '109851', '109852', '109853', '109854', '109855', '109856', '109857', '109858', '109859', '109860', '109861', '109862', '109863', '109864', '109865', '109866', '109867', '109868', '109869', '109870', '109871', '109872', '109873', '109874', '109875', '109876', '109877', '109878', '109879', '109880', '109881', '109901', '109902', '109903', '109904', '109905', '109906', '109907', '109908', '109909', '109910', '109911', '109912', '109913', '109914', '109915', '109916', '109917', '109918', '109919', '109920', '109921', '109931', '109932', '109933', '109941', '109943', '109991', '109992', '109993', '109994', '109995', '109996', '109997', '109998', '109999', '110001', '110002', '110003', '110004', '110005', '110006', '110007', '110008', '110009', '110010', '110011', '110012', '110013', '110020', '110021', '110022', '110023', '110024', '110025', '110026', '110027', '110028', '110030', '110031', '110032', '110033', '110034', '110035', '110036', '110037', '110038', '110100', '110101', '110102', '110103', '110104', '110105', '110106', '110107', '110108', '110109', '110110', '110111', '110112', '110113', '110114', '110120', '110121', '110122', '110123', '110124', '110125', '110126', '110127', '110128', '110129', '110130', '110131', '110132', '110133', '110134', '110135', '110136', '110137', '110138', '110139', '110140', '110141', '110142', '110150', '110151', '110152', '110153', '110154', '110155', '110180', '110181', '110182', '110190', '110500', '110501', '110502', '110503', '110504', '110505', '110506', '110507', '110508', '110509', '110510', '110511', '110512', '110513', '110514', '110515', '110516', '110518', '110519', '110521', '110522', '110523', '110524', '110526', '110527', '110528', '110529', '110700', '110701', '110702', '110703', '110704', '110705', '110706', '110800', '110801', '110802', '110803', '110804', '110805', '110806', '110807', '110808', '110809', '110810', '110811', '110812', '110813', '110814', '110815', '110816', '110817', '110818', '110819', '110820', '110821', '110822', '110823', '110824', '110825', '110826', '110827', '110828', '110829', '110830', '110831', '110832', '110833', '110834', '110835', '110836', '110837', '110838', '110839', '110840', '110841', '110842', '110843', '110844', '110845', '110846', '110847', '110848', '110849', '110850', '110851', '110852', '110853', '110854', '110855', '110856', '110857', '110858', '110859', '110860', '110861', '110862', '110863', '110864', '110865', '110866', '110867', '110868', '110869', '110870', '110871', '110872', '110873', '110874', '110875', '110876', '110877', '110901', '110902', '110903', '110904', '110905', '110906', '110907', '110908', '110909', '110910', '110911', '111001', '111002', '111003', '111004', '111005', '111006', '111007', '111008', '111009', '111010', '111011', '111012', '111013', '111014', '111015', '111016', '111017', '111018', '111019', '111020', '111021', '111022', '111023', '111024', '111025', '111026', '111027', '111028', '111029', '111030', '111031', '111032', '111033', '111034', '111035', '111036', '111037', '111038', '111039', '111040', '111041', '111042', '111043', '111044', '111045', '111046', '111047', '111048', '111049', '111050', '111051', '111052', '111053', '111054', '111055', '111056', '111057', '111058', '111059', '111060', '111061', '111062', '111063', '111064', '111065', '111066', '111069', '111071', '111072', '111081', '111086', '111087', '111088', '111089', '111090', '111091', '111092', '111093', '111099', '111100', '111101', '111102', '111103', '111104', '111105', '111111', '111112', '111113', '111120', '111121', '111122', '111123', '111124', '111125', '111126', '111127', '111128', '111129', '111130', '111135', '111136', '111137', '111138', '111139', '111140', '111141', '111142', '111143', '111144', '111145', '111146', '111147', '111148', '111149', '111150', '111151', '111152', '111153', '111154', '111155', '111156', '111157', '111158', '111159', '111168', '111170', '111171', '111172', '111173', '111174', '111175', '111176', '111177', '111178', '111179', '111180', '111181', '111182', '111183', '111184', '111185', '111186', '111187', '111188', '111189', '111190', '111191', '111192', '111193', '111194', '111195', '111196', '111197', '111198', '111199', '111200', '111201', '111202', '111203', '111204', '111205', '111206', '111207', '111208', '111209', '111210', '111211', '111212', '111213', '111214', '111215', '111216', '111217', '111218', '111219', '111220', '111221', '111222', '111223', '111224', '111225', '111233', '111234', '111235', '111236', '111237', '111238', '111239', '111240', '111241', '111242', '111243', '111244', '111245', '111248', '111249', '111250', '111251', '111252', '111253', '111254', '111255', '111256', '111257', '111258', '111259', '111260', '111262', '111263', '111264', '111265', '111269', '111271', '111273', '111277', '111278', '111279', '111281', '111283', '111284', '111285', '111286', '111287', '111288', '111290', '111291', '111292', '111293', '111294', '111296', '111297', '111298', '111299', '111300', '111301', '111302', '111303', '111304', '111305', '111306', '111307', '111308', '111309', '111310', '111311', '111312', '111313', '111314', '111315', '111316', '111317', '111318', '111320', '111321', '111322', '111323', '111324', '111325', '111326', '111327', '111328', '111329', '111330', '111331', '111332', '111333', '111334', '111335', '111336', '111338', '111340', '111341', '111342', '111343', '111344', '111345', '111346', '111347', '111350', '111351', '111352', '111353', '111354', '111355', '111356', '111357', '111358', '111359', '111360', '111361', '111362', '111363', '111364', '111365', '111366', '111367', '111368', '111369', '111370', '111371', '111372', '111373', '111374', '111375', '111376', '111377', '111380', '111381', '111382', '111383', '111384', '111385', '111386', '111387', '111388', '111389', '111390', '111391', '111392', '111393', '111394', '111395', '111396', '111397', '111398', '111399', '111400', '111401', '111402', '111403', '111404', '111405', '111406', '111407', '111408', '111409', '111410', '111411', '111412', '111413', '111414', '111415', '111416', '111417', '111418', '111419', '111420', '111421', '111423', '111424', '111425', '111426', '111427', '111428', '111429', '111430', '111431', '111432', '111433', '111434', '111435', '111436', '111437', '111438', '111439', '111440', '111441', '111442', '111443', '111444', '111445', '111446', '111447', '111448', '111449', '111450', '111451', '111452', '111453', '111454', '111455', '111456', '111457', '111458', '111459', '111460', '111461', '111462', '111463', '111464', '111465', '111466', '111467', '111468', '111469', '111470', '111471', '111472', '111473', '111474', '111475', '111476', '111477', '111478', '111479', '111480', '111481', '111482', '111483', '111484', '111485', '111486', '111487', '111488', '111489', '111490', '111491', '111492', '111494', '111495', '111496', '111497', '111498', '111499', '111500', '111501', '111502', '111503', '111504', '111505', '111506', '111507', '111508', '111509', '111510', '111511', '111512', '111513', '111514', '111515', '111516', '111517', '111518', '111519', '111520', '111521', '111522', '111523', '111524', '111525', '111526', '111527', '111528', '111529', '111530', '111531', '111532', '111533', '111534', '111535', '111536', '111537', '111538', '111539', '111540', '111541', '111542', '111543', '111544', '111545', '111546', '111547', '111548', '111549', '111550', '111551', '111552', '111553', '111554', '111555', '111556', '111557', '111558', '111559', '111560', '111561', '111562', '111563', '111564', '111565', '111566', '111567', '111568', '111569', '111570', '111571', '111572', '111573', '111574', '111575', '111576', '111577', '111578', '111579', '111580', '111581', '111582', '111583', '111584', '111585', '111586', '111587', '111590', '111591', '111592', '111593', '111601', '111602', '111603', '111604', '111605', '111606', '111607', '111609', '111621', '111622', '111623', '111625', '111626', '111627', '111628', '111629', '111630', '111631', '111632', '111633', '111634', '111635', '111636', '111637', '111638', '111641', '111642', '111643', '111644', '111645', '111646', '111671', '111672', '111673', '111674', '111675', '111676', '111677', '111678', '111679', '111680', '111685', '111686', '111687', '111688', '111689', '111690', '111691', '111692', '111693', '111694', '111695', '111696', '111697', '111698', '111700', '111701', '111702', '111703', '111704', '111705', '111706', '111707', '111708', '111709', '111710', '111711', '111712', '111718', '111719', '111720', '111721', '111723', '111724', '111726', '111727', '111729', '111741', '111742', '111743', '111744', '111745', '111746', '111747', '111748', '111749', '111750', '111751', '111752', '111753', '111754', '111755', '111756', '111760', '111761', '111762', '111763', '111764', '111765', '111766', '111767', '111768', '111769', '111770', '111771', '111772', '111773', '111776', '111777', '111778', '111779', '111780', '111781', '111782', '111783', '111786', '111787', '111791', '111792', '111800', '111801', '111802', '111803', '111804', '111805', '111806', '111807', '111808', '111809', '111810', '111811', '111812', '111813', '111814', '111815', '111816', '111817', '111818', '111819', '111820', '111821', '111822', '111823', '111824', '111825', '111826', '111827', '111828', '111829', '111830', '111831', '111832', '111833', '111834', '111835', '111836', '111837', '111838', '111839', '111840', '111841', '111842', '111843', '111844', '111845', '111846', '111847', '111848', '111849', '111850', '111851', '111852', '111853', '111854', '111855', '111856', '111900', '111901', '111902', '111903', '111904', '111905', '111906', '111907', '111908', '111909', '111910', '111911', '111912', '111913', '111914', '111915', '111916', '111917', '111918', '111919', '111920', '111921', '111922', '111923', '111924', '111925', '111926', '111927', '111928', '111929', '111930', '111931', '111932', '111933', '111934', '111935', '111936', '111937', '111938', '111939', '111940', '111941', '111942', '111943', '111944', '111945', '111946', '111947', '112000', '112001', '112002', '112003', '112004', '112005', '112006', '112007', '112008', '112009', '112010', '112011', '112012', '112013', '112014', '112015', '112016', '112017', '112018', '112019', '112020', '112021', '112022', '112023', '112024', '112025', '112026', '112027', '112028', '112029', '112030', '112031', '112032', '112033', '112034', '112035', '112036', '112037', '112038', '112039', '112040', '112041', '112042', '112043', '112044', '112045', '112046', '112047', '112048', '112049', '112050', '112051', '112052', '112053', '112054', '112055', '112056', '112057', '112058', '112059', '112060', '112061', '112062', '112063', '112064', '112065', '112066', '112067', '112068', '112069', '112070', '112071', '112072', '112073', '112074', '112075', '112076', '112077', '112078', '112079', '112080', '112081', '112082', '112083', '112084', '112085', '112086', '112087', '112088', '112089', '112090', '112091', '112092', '112093', '112094', '112095', '112096', '112097', '112098', '112099', '112100', '112101', '112102', '112103', '112104', '112105', '112106', '112107', '112108', '112109', '112110', '112111', '112112', '112113', '112114', '112115', '112116', '112117', '112118', '112119', '112120', '112121', '112122', '112123', '112124', '112125', '112126', '112127', '112128', '112129', '112130', '112131', '112132', '112133', '112134', '112135', '112136', '112137', '112138', '112139', '112140', '112141', '112142', '112143', '112144', '112145', '112146', '112147', '112148', '112149', '112150', '112151', '112152', '112153', '112154', '112155', '112156', '112157', '112158', '112159', '112160', '112161', '112162', '112163', '112164', '112165', '112166', '112167', '112168', '112169', '112170', '112171', '112172', '112173', '112174', '112175', '112176', '112177', '112178', '112179', '112180', '112181', '112182', '112183', '112184', '112185', '112186', '112187', '112188', '112189', '112191', '112192', '112193', '112194', '112195', '112196', '112197', '112198', '112199', '112200', '112201', '112220', '112222', '112224', '112225', '112226', '112227', '112228', '112229', '112232', '112233', '112238', '112240', '112241', '112242', '112243', '112244', '112248', '112249', '112300', '112301', '112302', '112303', '112304', '112305', '112306', '112307', '112308', '112309', '112310', '112311', '112312', '112313', '112314', '112315', '112316', '112317', '112318', '112319', '112320', '112321', '112325', '112340', '112341', '112342', '112343', '112344', '112345', '112346', '112347', '112348', '112350', '112351', '112352', '112353', '112354', '112355', '112356', '112357', '112358', '112359', '112360', '112361', '112362', '112363', '112364', '112365', '112366', '112367', '112368', '112369', '112370', '112371', '112372', '112373', '112374', '112375', '112376', '112377', '112378', '112379', '112380', '112381', '112700', '112701', '112702', '112703', '112704', '112705', '112706', '112707', '112708', '112709', '112710', '112711', '112712', '112713', '112714', '112715', '112716', '112717', '112718', '112719', '112720', '112721', '113000', '113001', '113002', '113003', '113004', '113005', '113006', '113007', '113008', '113009', '113010', '113011', '113012', '113013', '113014', '113015', '113016', '113017', '113018', '113020', '113021', '113026', '113030', '113031', '113032', '113033', '113034', '113035', '113036', '113037', '113038', '113039', '113040', '113041', '113042', '113043', '113044', '113045', '113046', '113047', '113048', '113049', '113050', '113051', '113052', '113053', '113054', '113055', '113056', '113057', '113058', '113059', '113060', '113061', '113062', '113063', '113064', '113065', '113066', '113067', '113068', '113069', '113070', '113071', '113072', '113073', '113074', '113075', '113076', '113077', '113078', '113079', '113080', '113081', '113082', '113083', '113085', '113086', '113087', '113088', '113089', '113090', '113091', '113092', '113093', '113094', '113095', '113096', '113097', '113100', '113101', '113102', '113103', '113104', '113105', '113106', '113107', '113108', '113109', '113110', '113111', '113500', '113502', '113503', '113505', '113506', '113507', '113508', '113509', '113510', '113511', '113512', '113513', '113514', '113516', '113517', '113518', '113520', '113521', '113522', '113523', '113526', '113527', '113528', '113529', '113530', '113540', '113541', '113542', '113543', '113550', '113551', '113552', '113560', '113561', '113562', '113563', '113568', '113570', '113571', '113572', '113573', '113574', '113575', '113576', '113577', '113601', '113602', '113603', '113605', '113606', '113607', '113608', '113609', '113611', '113612', '113613', '113620', '113621', '113622', '113630', '113631', '113650', '113651', '113652', '113653', '113661', '113662', '113663', '113664', '113665', '113666', '113669', '113670', '113671', '113680', '113681', '113682', '113683', '113684', '113685', '113686', '113687', '113688', '113689', '113690', '113691', '113692', '113701', '113702', '113704', '113705', '113706', '113710', '113711', '113720', '113721', '113722', '113723', '113724', '113725', '113726', '113727', '113728', '113729', '113730', '113731', '113732', '113733', '113734', '113735', '113736', '113737', '113738', '113739', '113740', '113742', '113743', '113744', '113745', '113748', '113750', '113751', '113752', '113753', '113754', '113755', '113756', '113757', '113758', '113759', '113760', '113761', '113763', '113764', '113766', '113767', '113768', '113769', '113770', '113771', '113772', '113773', '113780', '113788', '113789', '113790', '113791', '113792', '113793', '113794', '113795', '113800', '113801', '113802', '113803', '113804', '113805', '113806', '113807', '113808', '113809', '113810', '113811', '113812', '113813', '113814', '113815', '113816', '113817', '113818', '113819', '113820', '113821', '113822', '113823', '113824', '113825', '113826', '113827', '113828', '113829', '113830', '113831', '113832', '113833', '113834', '113835', '113836', '113837', '113838', '113839', '113840', '113841', '113842', '113845', '113846', '113847', '113850', '113851', '113852', '113853', '113854', '113855', '113856', '113857', '113858', '113859', '113860', '113861', '113862', '113863', '113864', '113865', '113866', '113867', '113868', '113870', '113871', '113872', '113873', '113874', '113875', '113876', '113877', '113878', '113879', '113880', '113890', '113893', '113895', '113896', '113897', '113898', '113899', '113900', '113901', '113902', '113903', '113904', '113905', '113906', '113907', '113908', '113909', '113910', '113911', '113912', '113913', '113914', '113921', '113922', '113923', '113930', '113931', '113932', '113933', '113934', '113935', '113936', '113937', '113940', '113941', '113942', '113943', '113944', '113945', '113946', '113947', '113948', '113949', '113950', '113951', '113952', '113953', '113954', '113955', '113956', '113957', '113958', '113959', '113961', '113962', '113963', '113970', '114000', '114001', '114002', '114003', '114004', '114005', '114006', '114007', '114008', '114009', '114010', '114011', '114201', '114202', '114203', '114204', '114205', '114206', '114207', '114208', '114209', '114210', '114211', '114213', '114215', '114216', '121001', '121002', '121003', '121004', '121005', '121006', '121007', '121008', '121009', '121010', '121011', '121012', '121013', '121014', '121015', '121016', '121017', '121018', '121019', '121020', '121021', '121022', '121023', '121024', '121025', '121026', '121027', '121028', '121029', '121030', '121031', '121032', '121033', '121034', '121035', '121036', '121037', '121038', '121039', '121040', '121041', '121042', '121043', '121044', '121045', '121046', '121047', '121048', '121049', '121050', '121051', '121052', '121053', '121054', '121055', '121056', '121057', '121058', '121059', '121060', '121062', '121064', '121065', '121066', '121068', '121069', '121070', '121071', '121072', '121073', '121074', '121075', '121076', '121077', '121078', '121079', '121080', '121081', '121082', '121083', '121084', '121085', '121086', '121087', '121088', '121089', '121090', '121091', '121092', '121093', '121094', '121095', '121096', '121097', '121098', '121099', '121100', '121101', '121102', '121103', '121104', '121105', '121106', '121109', '121110', '121111', '121112', '121113', '121114', '121115', '121116', '121117', '121118', '121120', '121121', '121122', '121123', '121124', '121125', '121126', '121127', '121128', '121130', '121131', '121132', '121133', '121135', '121136', '121137', '121138', '121139', '121140', '121141', '121142', '121143', '121144', '121145', '121146', '121147', '121148', '121149', '121150', '121151', '121152', '121153', '121154', '121155', '121156', '121157', '121158', '121160', '121161', '121162', '121163', '121165', '121166', '121167', '121168', '121169', '121171', '121172', '121173', '121174', '121180', '121181', '121190', '121191', '121192', '121193', '121194', '121195', '121196', '121197', '121198', '121200', '121201', '121202', '121206', '121207', '121208', '121210', '121211', '121213', '121214', '121216', '121217', '121218', '121219', '121220', '121221', '121222', '121230', '121231', '121232', '121233', '121242', '121243', '121244', '121290', '121291', '121301', '121302', '121303', '121304', '121305', '121306', '121307', '121311', '121312', '121313', '121314', '121315', '121316', '121317', '121318', '121320', '121321', '121322', '121323', '121324', '121325', '121326', '121327', '121328', '121329', '121330', '121331', '121332', '121333', '121334', '121335', '121338', '121339', '121340', '121341', '121342', '121346', '121347', '121348', '121349', '121350', '121351', '121352', '121353', '121354', '121358', '121360', '121361', '121362', '121363', '121370', '121371', '121372', '121380', '121381', '121382', '121383', '121401', '121402', '121403', '121404', '121405', '121406', '121407', '121408', '121410', '121411', '121412', '121414', '121415', '121416', '121417', '121420', '121421', '121422', '121423', '121424', '121425', '121427', '121428', '121430', '121431', '121432', '121433', '121434', '121435', '121436', '121437', '121438', '121439', '121701', '121702', '121703', '121704', '121705', '121706', '121707', '121708', '121709', '121710', '121711', '121712', '121713', '121714', '121715', '121716', '121717', '121718', '121719', '121720', '121721', '121722', '121723', '121724', '121725', '121726', '121727', '121728', '121729', '121730', '121731', '121732', '121733', '121734', '121740', '122001', '122002', '122003', '122004', '122005', '122006', '122007', '122008', '122009', '122010', '122011', '122012', '122020', '122021', '122022', '122023', '122024', '122025', '122026', '122027', '122028', '122029', '122030', '122031', '122032', '122033', '122034', '122035', '122036', '122037', '122038', '122039', '122041', '122042', '122043', '122044', '122045', '122046', '122047', '122048', '122049', '122052', '122053', '122054', '122055', '122056', '122057', '122058', '122059', '122060', '122061', '122062', '122072', '122073', '122075', '122076', '122077', '122078', '122079', '122081', '122082', '122083', '122084', '122085', '122086', '122087', '122088', '122089', '122090', '122091', '122092', '122093', '122094', '122095', '122096', '122097', '122098', '122099', '122101', '122102', '122103', '122104', '122105', '122106', '122107', '122108', '122109', '122110', '122111', '122112', '122113', '122114', '122120', '122121', '122122', '122123', '122124', '122125', '122126', '122127', '122128', '122129', '122130', '122131', '122132', '122133', '122134', '122138', '122139', '122140', '122141', '122142', '122143', '122144', '122145', '122146', '122147', '122148', '122149', '122150', '122151', '122152', '122153', '122154', '122157', '122158', '122159', '122160', '122161', '122162', '122163', '122164', '122165', '122166', '122167', '122170', '122171', '122172', '122173', '122175', '122176', '122177', '122178', '122179', '122180', '122181', '122182', '122183', '122185', '122187', '122188', '122189', '122190', '122191', '122192', '122193', '122194', '122195', '122196', '122197', '122198', '122199', '122201', '122202', '122203', '122204', '122205', '122206', '122207', '122208', '122209', '122210', '122211', '122212', '122213', '122214', '122215', '122216', '122217', '122218', '122219', '122220', '122221', '122222', '122223', '122224', '122225', '122227', '122228', '122229', '122230', '122231', '122232', '122233', '122234', '122235', '122236', '122237', '122238', '122239', '122240', '122241', '122242', '122243', '122244', '122245', '122246', '122247', '122248', '122249', '122250', '122251', '122252', '122253', '122254', '122255', '122256', '122257', '122258', '122259', '122260', '122261', '122262', '122263', '122265', '122266', '122267', '122268', '122269', '122270', '122271', '122272', '122273', '122274', '122275', '122276', '122277', '122278', '122279', '122281', '122282', '122283', '122288', '122291', '122292', '122301', '122302', '122303', '122304', '122305', '122306', '122307', '122308', '122309', '122310', '122311', '122312', '122313', '122319', '122320', '122321', '122322', '122325', '122330', '122331', '122332', '122333', '122334', '122335', '122336', '122337', '122339', '122340', '122341', '122343', '122344', '122345', '122346', '122347', '122348', '122350', '122351', '122352', '122354', '122355', '122356', '122357', '122360', '122361', '122363', '122364', '122367', '122368', '122369', '122370', '122371', '122372', '122374', '122375', '122376', '122380', '122381', '122382', '122383', '122384', '122385', '122386', '122387', '122388', '122389', '122390', '122391', '122393', '122394', '122395', '122398', '122399', '122400', '122401', '122402', '122403', '122404', '122405', '122406', '122407', '122408', '122410', '122411', '122417', '122421', '122422', '122423', '122428', '122429', '122430', '122431', '122432', '122433', '122434', '122435', '122438', '122445', '122446', '122447', '122448', '122449', '122450', '122451', '122452', '122453', '122459', '122461', '122464', '122465', '122466', '122467', '122468', '122469', '122470', '122471', '122472', '122473', '122474', '122475', '122476', '122477', '122480', '122481', '122482', '122485', '122486', '122487', '122488', '122489', '122490', '122491', '122493', '122495', '122496', '122497', '122498', '122499', '122501', '122502', '122503', '122505', '122507', '122508', '122509', '122510', '122511', '122516', '122517', '122528', '122529', '122542', '122544', '122545', '122546', '122547', '122548', '122549', '122550', '122551', '122554', '122555', '122558', '122559', '122560', '122562', '122563', '122564', '122565', '122566', '122572', '122574', '122575', '122582', '122600', '122601', '122602', '122603', '122604', '122605', '122606', '122607', '122608', '122609', '122611', '122612', '122616', '122617', '122618', '122619', '122620', '122621', '122624', '122627', '122628', '122631', '122633', '122634', '122635', '122636', '122637', '122638', '122639', '122640', '122642', '122643', '122645', '122650', '122651', '122652', '122655', '122656', '122657', '122658', '122659', '122660', '122661', '122664', '122665', '122666', '122667', '122668', '122670', '122675', '122680', '122683', '122684', '122685', '122686', '122687', '122698', '122699', '122700', '122701', '122702', '122703', '122704', '122705', '122706', '122707', '122708', '122709', '122710', '122711', '122712', '122713', '122715', '122716', '122717', '122718', '122720', '122721', '122726', '122727', '122728', '122729', '122730', '122731', '122732', '122733', '122734', '122735', '122739', '122740', '122741', '122742', '122743', '122744', '122745', '122748', '122750', '122751', '122752', '122753', '122755', '122756', '122757', '122758', '122759', '122760', '122762', '122764', '122768', '122769', '122770', '122771', '122772', '122773', '122775', '122776', '122781', '122782', '122783', '122784', '122785', '122791', '122792', '122793', '122795', '122796', '122797', '122799', '123001', '123003', '123004', '123005', '123006', '123007', '123009', '123010', '123011', '123012', '123014', '123015', '123016', '123019', '123101', '123102', '123103', '123104', '123105', '123106', '123107', '123108', '123109', '123110', '123111', '125000', '125001', '125002', '125003', '125004', '125005', '125006', '125007', '125008', '125009', '125010', '125011', '125012', '125013', '125015', '125016', '125021', '125022', '125023', '125024', '125025', '125030', '125031', '125032', '125033', '125034', '125035', '125036', '125037', '125038', '125040', '125041', '125100', '125101', '125102', '125105', '125106', '125107', '125195', '125196', '125197', '125200', '125201', '125202', '125203', '125204', '125205', '125206', '125207', '125208', '125209', '125210', '125211', '125212', '125213', '125214', '125215', '125216', '125217', '125218', '125219', '125220', '125221', '125222', '125223', '125224', '125225', '125226', '125227', '125228', '125230', '125231', '125233', '125234', '125235', '125236', '125237', '125238', '125239', '125240', '125241', '125242', '125251', '125252', '125253', '125254', '125255', '125256', '125257', '125258', '125259', '125261', '125262', '125263', '125264', '125265', '125270', '125271', '125272', '125273', '125901', '125902', '125903', '125904', '125905', '125906', '125907', '125908', '126000', '126001', '126002', '126003', '126010', '126011', '126020', '126021', '126022', '126030', '126031', '126032', '126033', '126034', '126035', '126036', '126037', '126038', '126039', '126040', '126050', '126051', '126052', '126060', '126061', '126062', '126063', '126064', '126065', '126066', '126067', '126070', '126071', '126072', '126073', '126074', '126075', '126080', '126081', '126100', '126200', '126201', '126202', '126203', '126220', '126300', '126301', '126302', '126303', '126310', '126311', '126312', '126313', '126314', '126320', '126321', '126322', '126330', '126331', '126340', '126341', '126342', '126343', '126344', '126350', '126351', '126352', '126353', '126360', '126361', '126362', '126363', '126364', '126370', '126371', '126372', '126373', '126374', '126375', '126376', '126377', '126380', '126390', '126391', '126392', '126393', '126394', '126400', '126401', '126402', '126403', '126404', '126410', '126411', '126412', '126413', '126500', '126501', '126502', '126503', '126510', '126511', '126512', '126513', '126514', '126515', '126516', '126517', '126518', '126519', '126520', '126600', '126601', '126602', '126603', '126604', '126605', '126606', '126700', '126701', '126702', '126703', '126704', '126705', '126706', '126707', '126708', '126709', '126710', '126711', '126712', '126713', '126714', '126715', '126716', '126801', '126802', '126803', '126804', '126805', '126806', '126807', '126808', '126809', '126810', '126811']}, 'type'=>'Coding', 'path'=>'ImagingStudy.modalityList', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'extensible', 'uri'=>'http://hl7.org/fhir/ValueSet/dicom-cid29'}},
        'patient' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Patient'], 'type'=>'Reference', 'path'=>'ImagingStudy.patient', 'min'=>1, 'max'=>1},
        'context' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Encounter', 'http://hl7.org/fhir/StructureDefinition/EpisodeOfCare'], 'type'=>'Reference', 'path'=>'ImagingStudy.context', 'min'=>0, 'max'=>1},
        'started' => {'type'=>'dateTime', 'path'=>'ImagingStudy.started', 'min'=>0, 'max'=>1},
        'basedOn' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/ReferralRequest', 'http://hl7.org/fhir/StructureDefinition/CarePlan', 'http://hl7.org/fhir/StructureDefinition/ProcedureRequest'], 'type'=>'Reference', 'path'=>'ImagingStudy.basedOn', 'min'=>0, 'max'=>Float::INFINITY},
        'referrer' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Practitioner'], 'type'=>'Reference', 'path'=>'ImagingStudy.referrer', 'min'=>0, 'max'=>1},
        'interpreter' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Practitioner'], 'type'=>'Reference', 'path'=>'ImagingStudy.interpreter', 'min'=>0, 'max'=>Float::INFINITY},
        'endpoint' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Endpoint'], 'type'=>'Reference', 'path'=>'ImagingStudy.endpoint', 'min'=>0, 'max'=>Float::INFINITY},
        'numberOfSeries' => {'type'=>'unsignedInt', 'path'=>'ImagingStudy.numberOfSeries', 'min'=>0, 'max'=>1},
        'numberOfInstances' => {'type'=>'unsignedInt', 'path'=>'ImagingStudy.numberOfInstances', 'min'=>0, 'max'=>1},
        'procedureReference' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Procedure'], 'type'=>'Reference', 'path'=>'ImagingStudy.procedureReference', 'min'=>0, 'max'=>Float::INFINITY},
        'procedureCode' => {'valid_codes'=>{'http://snomed.info/sct'=>['104001', '115006', '119000', '121005', '128004', '133000', '135007', '142007', '146005', '153001', '160007', '166001', '170009', '174000', '176003', '189009', '197002', '230009', '243009', '245002', '262007', '267001', '285008', '294002', '295001', '306005', '316002', '334003', '342002', '346004', '348003', '351005', '352003', '353008', '374009', '388008', '389000', '401004', '406009', '417005', '435001', '445004', '456004', '459006', '463004', '468008', '474008', '489004', '493005', '494004', '497006', '503003', '531007', '533005', '535003', '540006', '543008', '545001', '549007', '550007', '559008', '570001', '574005', '603006', '617002', '618007', '625000', '628003', '629006', '633004', '637003', '642006', '645008', '647000', '657004', '665001', '670008', '671007', '673005', '674004', '676002', '680007', '687005', '695009', '697001', '710006', '712003', '721002', '722009', '726007', '730005', '741007', '746002', '753006', '754000', '759005', '762008', '764009', '767002', '789003', '791006', '807005', '814007', '817000', '831000', '851001', '853003', '867007', '870006', '879007', '881009', '893000', '897004', '910002', '911003', '913000', '926001', '935008', '941001', '945005', '948007', '951000', '956005', '967006', '969009', '971009', '1001000', '1008006', '1019009', '1021004', '1029002', '1032004', '1035002', '1036001', '1041009', '1042002', '1043007', '1044001', '1048003', '1054002', '1071001', '1084005', '1093006', '1103000', '1104006', '1115001', '1119007', '1121002', '1127003', '1133007', '1163003', '1176009', '1181000', '1186005', '1198000', '1209007', '1225002', '1227005', '1235008', '1237000', '1238005', '1251000', '1253002', '1258006', '1266002', '1267006', '1278003', '1279006', '1292009', '1299000', '1315009', '1316005', '1324000', '1327007', '1328002', '1329005', '1337002', '1339004', '1347004', '1352009', '1358008', '1366004', '1385001', '1390003', '1398005', '1399002', '1407007', '1410000', '1411001', '1413003', '1414009', '1417002', '1431002', '1440003', '1449002', '1453000', '1455007', '1457004', '1494008', '1500007', '1501006', '1505002', '1529009', '1533002', '1550000', '1555005', '1559004', '1576000', '1577009', '1578004', '1583007', '1585000', '1596008', '1597004', '1602006', '1614003', '1615002', '1616001', '1636000', '1638004', '1640009', '1645004', '1651009', '1653007', '1669000', '1677001', '1678006', '1680000', '1683003', '1689004', '1691007', '1699009', '1702002', '1704001', '1709006', '1712009', '1713004', '1730002', '1746005', '1747001', '1753001', '1757000', '1759002', '1770009', '1774000', '1775004', '1784004', '1787006', '1788001', '1801001', '1805005', '1811008', '1813006', '1820004', '1830008', '1836002', '1844002', '1854003', '1859008', '1861004', '1862006', '1866009', '1868005', '1870001', '1871002', '1872009', '1876007', '1879000', '1889001', '1906007', '1907003', '1917008', '1924009', '1950008', '1958001', '1966005', '1983001', '1995001', '1999007', '2002009', '2021001', '2051007', '2054004', '2067001', '2069003', '2078009', '2079001', '2080003', '2098004', '2115003', '2119009', '2127000', '2137005', '2153008', '2161003', '2164006', '2166008', '2171001', '2178007', '2181002', '2188008', '2193006', '2196003', '2199005', '2214008', '2220009', '2225004', '2234009', '2238007', '2242005', '2244006', '2250001', '2252009', '2266004', '2267008', '2270007', '2276001', '2278000', '2279008', '2290003', '2315006', '2318008', '2321005', '2322003', '2337004', '2344008', '2347001', '2364003', '2371008', '2373006', '2382000', '2386002', '2393003', '2406000', '2407009', '2408004', '2409007', '2425002', '2442008', '2448007', '2455009', '2457001', '2458006', '2459003', '2461007', '2474001', '2475000', '2480009', '2486003', '2488002', '2494005', '2498008', '2507007', '2508002', '2514009', '2517002', '2530001', '2531002', '2535006', '2536007', '2547000', '2552005', '2564002', '2566000', '2567009', '2580007', '2598006', '2601001', '2607002', '2613006', '2614000', '2616003', '2619005', '2629003', '2632000', '2642003', '2643008', '2644002', '2645001', '2646000', '2658000', '2659008', '2668005', '2670001', '2673004', '2677003', '2690005', '2693007', '2696004', '2697008', '2716009', '2722000', '2731000', '2732007', '2737001', '2742009', '2743004', '2745006', '2752008', '2780005', '2794006', '2802005', '2811005', '2813008', '2837008', '2842000', '2843005', '2847006', '2851008', '2854000', '2857007', '2866006', '2875008', '2876009', '2885009', '2891006', '2898000', '2903001', '2908005', '2914003', '2915002', '2933008', '2945004', '2947007', '2960001', '2968008', '2970004', '2971000', '2977001', '3001009', '3010001', '3016007', '3025001', '3026000', '3029007', '3041000', '3047001', '3060007', '3061006', '3063009', '3075004', '3078002', '3083005', '3088001', '3090000', '3112006', '3116009', '3130004', '3133002', '3137001', '3143004', '3162001', '3164000', '3165004', '3166003', '3177009', '3183007', '3186004', '3190002', '3204007', '3241008', '3249005', '3251009', '3256004', '3257008', '3258003', '3268008', '3270004', '3278006', '3287002', '3320000', '3324009', '3326006', '3328007', '3333006', '3338002', '3352000', '3357006', '3360004', '3390006', '3399007', '3407002', '3413006', '3418002', '3432000', '3443008', '3448004', '3450007', '3457005', '3479000', '3498003', '3499006', '3509001', '3512003', '3515001', '3517009', '3518004', '3527003', '3546002', '3559005', '3562008', '3564009', '3575008', '3580004', '3605001', '3607009', '3620007', '3625002', '3651000', '3654008', '3659003', '3664004', '3666002', '3669009', '3673007', '3683006', '3686003', '3688002', '3690001', '3691002', '3697003', '3700004', '3701000', '3713005', '3717006', '3734003', '3735002', '3740005', '3748003', '3749006', '3758004', '3770000', '3778007', '3780001', '3784005', '3786007', '3787003', '3794000', '3796003', '3799005', '3802001', '3819004', '3826004', '3828003', '3831002', '3843001', '3858009', '3861005', '3862003', '3864002', '3880007', '3881006', '3887005', '3889008', '3891000', '3895009', '3907006', '3911000', '3915009', '3917001', '3918006', '3926003', '3929005', '3936006', '3938007', '3942005', '3955006', '3957003', '3963007', '3967008', '3968003', '3969006', '3971006', '3980006', '3981005', '3985001', '3991004', '3998005', '4007002', '4008007', '4010009', '4027001', '4034004', '4035003', '4036002', '4037006', '4044002', '4045001', '4052004', '4064007', '4068005', '4083000', '4084006', '4090005', '4094001', '4101004', '4102006', '4114003', '4116001', '4119008', '4131005', '4134002', '4139007', '4143006', '4149005', '4154001', '4165006', '4176005', '4192000', '4213001', '4214007', '4226002', '4252008', '4263006', '4266003', '4285000', '4293000', '4304000', '4319004', '4321009', '4323007', '4331002', '4333004', '4336007', '4337003', '4339000', '4341004', '4344007', '4348005', '4350002', '4363008', '4365001', '4380007', '4387005', '4388000', '4407008', '4411002', '4420006', '4424002', '4436008', '4438009', '4443002', '4447001', '4449003', '4450003', '4455008', '4457000', '4466001', '4467005', '4475004', '4487006', '4489009', '4496006', '4503005', '4504004', '4505003', '4507006', '4511000', '4516005', '4520009', '4525004', '4533003', '4535005', '4539004', '4542005', '4544006', '4558008', '4563007', '4570007', '4579008', '4581005', '4585001', '4587009', '4589007', '4593001', '4594007', '4613005', '4625008', '4626009', '4636001', '4640005', '4642002', '4660002', '4670000', '4671001', '4672008', '4691008', '4692001', '4694000', '4699005', '4701005', '4707009', '4712005', '4713000', '4719001', '4727005', '4734007', '4737000', '4756005', '4758006', '4764004', '4765003', '4770005', '4772002', '4784000', '4804005', '4811009', '4815000', '4820000', '4827002', '4829004', '4847005', '4849008', '4862007', '4877004', '4891005', '4895001', '4902005', '4903000', '4904006', '4914002', '4929000', '4930005', '4934001', '4957007', '4966006', '4970003', '4974007', '4976009', '4987001', '4992004', '4993009', '5016005', '5019003', '5021008', '5022001', '5025004', '5032008', '5034009', '5048009', '5055006', '5057003', '5065000', '5091004', '5105000', '5110001', '5113004', '5119000', '5121005', '5123008', '5130002', '5131003', '5135007', '5147001', '5151004', '5154007', '5161006', '5162004', '5165002', '5176003', '5182000', '5184004', '5186002', '5190000', '5191001', '5212002', '5216004', '5233006', '5243009', '5245002', '5246001', '5264008', '5267001', '5270002', '5273000', '5282006', '5290006', '5298004', '5304008', '5316002', '5317006', '5326009', '5328005', '5337005', '5338000', '5342002', '5348003', '5357009', '5373003', '5384005', '5391008', '5393006', '5402006', '5407000', '5415002', '5419008', '5422005', '5429001', '5431005', '5433008', '5446003', '5447007', '5452002', '5456004', '5457008', '5460001', '5479003', '5482008', '5486006', '5489004', '5506006', '5517007', '5521000', '5536002', '5545001', '5551006', '5556001', '5570001', '5571002', '5572009', '5586008', '5608002', '5616006', '5621009', '5632009', '5636007', '5638008', '5648005', '5651003', '5663008', '5669007', '5671007', '5687005', '5690004', '5694008', '5721002', '5722009', '5726007', '5728008', '5731009', '5733007', '5738003', '5745003', '5760000', '5771004', '5777000', '5781000', '5785009', '5787001', '5789003', '5796001', '5806001', '5807005', '5809008', '5812006', '5818005', '5821007', '5823005', '5832007', '5845006', '5846007', '5857002', '5865004', '5870006', '5880005', '5892005', '5894006', '5897004', '5902003', '5925002', '5930003', '5947002', '5961007', '5966002', '5971009', '5983006', '5986003', '5992009', '5995006', '5997003', '5998008', '6005008', '6007000', '6019008', '6025007', '6026008', '6029001', '6035001', '6063004', '6069000', '6082008', '6092000', '6100001', '6108008', '6119006', '6125005', '6126006', '6127002', '6130009', '6133006', '6143009', '6146001', '6148000', '6157006', '6159009', '6161000', '6164008', '6166005', '6177004', '6187000', '6188005', '6189002', '6190006', '6195001', '6198004', '6200005', '6205000', '6213004', '6221005', '6225001', '6226000', '6227009', '6231003', '6238009', '6240004', '6255008', '6271008', '6274000', '6286002', '6289009', '6295005', '6307005', '6309008', '6319002', '6337001', '6339003', '6343004', '6353003', '6354009', '6355005', '6358007', '6361008', '6363006', '6370006', '6384001', '6385000', '6388003', '6396008', '6397004', '6399001', '6402000', '6403005', '6419003', '6429005', '6433003', '6434009', '6438007', '6439004', '6443000', '6444006', '6465000', '6466004', '6470007', '6473009', '6480006', '6486000', '6487009', '6491004', '6499002', '6502003', '6506000', '6519001', '6521006', '6527005', '6535008', '6536009', '6543003', '6547002', '6555009', '6556005', '6562000', '6563005', '6567006', '6568001', '6585004', '6589005', '6601003', '6614002', '6615001', '6622009', '6634001', '6639006', '6650009', '6656003', '6657007', '6658002', '6661001', '6665005', '6668007', '6670003']}, 'type'=>'CodeableConcept', 'path'=>'ImagingStudy.procedureCode', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/procedure-code'}},
        'reason' => {'valid_codes'=>{'http://snomed.info/sct'=>['109006', '122003', '127009', '129007', '134006', '140004', '144008', '147001', '150003', '151004', '162004', '165002', '168000', '171008', '172001', '175004', '177007', '179005', '181007', '183005', '184004', '188001', '192008', '193003', '195005', '198007', '199004', '208008', '216004', '219006', '222008', '223003', '228007', '241006', '242004', '253005', '257006', '258001', '264008', '276008', '279001', '281004', '282006', '290006', '292003', '297009', '299007', '303002', '308006', '310008', '313005', '317006', '320003', '324007', '330007', '335002', '341009', '349006', '355001', '357009', '358004', '359007', '360002', '364006', '366008', '368009', '369001', '378007', '382009', '383004', '385006', '387003', '398002', '407000', '408005', '409002', '426008', '431005', '437009', '440009', '442001', '443006', '447007', '450005', '452002', '460001', '467003', '470004', '479003', '486006', '488007', '490008', '496002', '504009', '517007', '518002', '520004', '527001', '536002', '539009', '547009', '548004', '554003', '555002', '563001', '568005', '586008', '590005', '596004', '599006', '600009', '602001', '607007', '610000', '613003', '615005', '616006', '626004', '631002', '634005', '640003', '643001', '646009', '649002', '651003', '652005', '655007', '658009', '663008', '664002', '666000', '675003', '682004', '685002', '701003', '703000', '714002', '715001', '718004', '733007', '734001', '736004', '750009', '755004', '756003', '758002', '775008', '776009', '781000', '786005', '787001', '788006', '792004', '799008', '801006', '805002', '811004', '813001', '815008', '816009', '818005', '825003', '827006', '832007', '834008', '841002', '842009', '843004', '844005', '845006', '849000', '857002', '862001', '865004', '871005', '874002', '875001', '888003', '890002', '899001', '903008', '904002', '908004', '919001', '928000', '931004', '932006', '934007', '943003', '954008', '961007', '962000', '964004', '965003', '975000', '978003', '981008', '984000', '987007', '991002', '998008', '1003002', '1020003', '1023001', '1027000', '1031006', '1033009', '1034003', '1038000', '1045000', '1046004', '1051005', '1055001', '1059007', '1070000', '1073003', '1074009', '1077002', '1079004', '1085006', '1089000', '1102005', '1107004', '1108009', '1111005', '1112003', '1116000', '1124005', '1125006', '1126007', '1131009', '1134001', '1135000', '1139006', '1140008', '1141007', '1145003', '1150009', '1151008', '1152001', '1155004', '1156003', '1168007', '1184008', '1192004', '1194003', '1196001', '1197005', '1201005', '1203008', '1207009', '1208004', '1212005', '1214006', '1230003', '1232006', '1239002', '1240000', '1259003', '1261007', '1264004', '1271009', '1280009', '1282001', '1283006', '1284000', '1286003', '1287007', '1297003', '1308001', '1310004', '1317001', '1318006', '1323006', '1332008', '1335005', '1343000', '1345007', '1351002', '1356007', '1361009', '1363007', '1367008', '1370007', '1372004', '1376001', '1378000', '1380006', '1383008', '1384002', '1386000', '1387009', '1388004', '1393001', '1395008', '1402001', '1412008', '1415005', '1418007', '1419004', '1426004', '1427008', '1430001', '1447000', '1469007', '1474004', '1475003', '1478001', '1479009', '1482004', '1486001', '1488000', '1489008', '1492007', '1493002', '1499003', '1512006', '1515008', '1518005', '1519002', '1521007', '1523005', '1525003', '1531000', '1532007', '1534008', '1538006', '1539003', '1542009', '1544005', '1551001', '1556006', '1563006', '1567007', '1588003', '1592005', '1593000', '1606009', '1608005', '1639007', '1647007', '1648002', '1654001', '1657008', '1658003', '1663004', '1667003', '1670004', '1671000', '1674008', '1679003', '1682008', '1685005', '1686006', '1694004', '1698001', '1703007', '1705000', '1708003', '1714005', '1717003', '1723008', '1724002', '1734006', '1735007', '1739001', '1742007', '1744008', '1748006', '1755008', '1761006', '1763009', '1767005', '1769008', '1771008', '1776003', '1777007', '1778002', '1779005', '1794009', '1816003', '1821000', '1822007', '1824008', '1826005', '1828006', '1829003', '1833005', '1835003', '1837006', '1845001', '1847009', '1848004', '1852004', '1855002', '1856001', '1857005', '1858000', '1860003', '1865008', '1869002', '1881003', '1892002', '1896004', '1897008', '1899006', '1903004', '1908008', '1909000', '1922008', '1926006', '1938002', '1939005', '1943009', '1953005', '1954004', '1955003', '1959009', '1961000', '1963002', '1965009', '1967001', '1973000', '1977004', '1979001', '1980003', '1981004', '1988005', '1989002', '2004005', '2012002', '2024009', '2028007', '2032001', '2036003', '2040007', '2041006', '2043009', '2053005', '2055003', '2058001', '2061000', '2065009', '2066005', '2070002', '2073000', '2087000', '2089002', '2091005', '2094002', '2102007', '2103002', '2107001', '2109003', '2114004', '2116002', '2120003', '2121004', '2128005', '2129002', '2132004', '2134003', '2136001', '2138000', '2145000', '2149006', '2158004', '2167004', '2169001', '2170000', '2176006', '2177002', '2186007', '2198002', '2202000', '2204004', '2213002', '2216005', '2217001', '2219003', '2224000', '2228002', '2229005', '2231001', '2237002', '2239004', '2241003', '2243000', '2245007', '2251002', '2256007', '2261009', '2268003', '2284002', '2295008', '2296009', '2298005', '2301009', '2303007', '2304001', '2307008', '2308003', '2312009', '2314005', '2326000', '2339001', '2341000', '2351004', '2355008', '2359002', '2365002', '2366001', '2367005', '2374000', '2385003', '2388001', '2390000', '2391001', '2396006', '2398007', '2403008', '2415007', '2418009', '2419001', '2420007', '2432006', '2435008', '2437000', '2438005', '2439002', '2443003', '2452007', '2463005', '2469009', '2470005', '2471009', '2472002', '2473007', '2477008', '2492009', '2495006', '2496007', '2506003', '2513003', '2518007', '2521009', '2523007', '2526004', '2528003', '2532009', '2534005', '2538008', '2541004', '2554006', '2556008', '2560006', '2562003', '2576002', '2581006', '2582004', '2583009', '2584003', '2585002', '2589008', '2591000', '2593002', '2602008', '2606006', '2615004', '2618002', '2622007', '2624008', '2625009', '2630008', '2634004', '2638001', '2640006', '2651006', '2655002', '2657005', '2663001', '2665008', '2683000', '2689001', '2694001', '2704003', '2707005', '2713001', '2724004', '2725003', '2733002', '2736005', '2740001', '2749000', '2751001', '2761008', '2764000', '2770006', '2772003', '2775001', '2776000', '2781009', '2782002', '2783007', '2786004', '2790002', '2805007', '2806008', '2807004', '2808009', '2815001', '2816000', '2818004', '2819007', '2825006', '2828008', '2829000', '2831009', '2835000', '2836004', '2838003', '2840008', '2850009', '2853006', '2856003', '2858002', '2884008', '2893009', '2897005', '2899008', '2900003', '2901004', '2902006', '2904007', '2910007', '2912004', '2917005', '2918000', '2919008', '2929001', '2935001', '2940009', '2946003', '2951009', '2955000', '2965006', '2967003', '2972007', '2973002', '2978006', '2981001', '2989004', '2990008', '2992000', '2994004', '2999009', '3002002', '3004001', '3006004', '3009006', '3013004', '3014005', '3018008', '3019000', '3021005', '3023008', '3032005', '3033000', '3038009', '3044008', '3053001', '3059002', '3067005', '3071008', '3072001', '3073006', '3084004', '3089009', '3094009', '3095005', '3097002', '3098007', '3105002', '3109008', '3110003', '3119002', '3129009', '3135009', '3140001', '3144005', '3158007', '3160009', '3163006', '3168002', '3185000', '3199001', '3200003', '3208005', '3214003', '3217005', '3218000', '3219008', '3228009', '3229001', '3230006', '3238004', '3239007', '3253007', '3254001', '3259006', '3261002', '3263004', '3272007', '3274008', '3275009', '3276005', '3277001', '3282008', '3283003', '3286006', '3289004', '3291007', '3298001', '3303004', '3304005', '3305006', '3308008', '3310005', '3321001', '3323003', '3327002', '3331008', '3344003', '3345002', '3355003', '3358001', '3368006', '3376008', '3381004', '3387000', '3391005', '3393008', '3398004', '3401001', '3415004', '3419005', '3421000', '3424008', '3426005', '3427001', '3434004', '3439009', '3441005', '3446000', '3449007', '3456001', '3458000', '3461004', '3464007', '3468005', '3469002', '3472009', '3474005', '3480002', '3482005', '3483000', '3487004', '3500002', '3502005', '3503000', '3505007', '3506008', '3507004', '3511005', '3514002', '3519007', '3528008', '3529000', '3530005', '3531009', '3533007', '3539006', '3542000', '3544004', '3545003', '3548001', '3549009', '3558002', '3560000', '3570003', '3571004', '3577000', '3585009', '3586005', '3589003', '3590007', '3591006', '3598000', '3611003', '3633001', '3634007', '3639002', '3640000', '3641001', '3642008', '3644009', '3649004', '3650004', '3652007', '3657001', '3660008', '3662000', '3677008', '3680009', '3681008', '3696007', '3699000', '3703002', '3704008', '3705009', '3712000', '3716002', '3720003', '3723001', '3733009', '3736001', '3738000', '3744001', '3745000', '3747008', '3750006', '3751005', '3752003', '3754002', '3755001', '3756000', '3759007', '3760002', '3762005', '3763000', '3783004', '3797007', '3798002', '3815005', '3820005', '3827008', '3830001', '3841004', '3845008', '3855007', '3859001', '3873005', '3885002', '3886001', '3899003', '3900008', '3902000', '3903005', '3908001', '3909009', '3913002', '3914008', '3928002', '3939004', '3944006', '3947004', '3950001', '3951002', '3972004', '3975002', '3978000', '3987009', '3993001', '3999002', '4003003', '4004009', '4006006', '4009004', '4016003', '4017007', '4022007', '4026005', '4030008', '4038001', '4039009', '4040006', '4041005', '4046000', '4062006', '4063001', '4069002', '4070001', '4075006', '4082005', '4088009', '4089001', '4092002', '4103001', '4106009', '4107000', '4113009', '4120002', '4124006', '4127004', '4129001', '4135001', '4136000', '4142001', '4152002', '4160001', '4168008', '4170004', '4174008', '4175009', '4178006', '4181001', '4183003', '4184009', '4191007', '4195003', '4197006', '4199009', '4208000', '4210003', '4223005', '4224004', '4225003', '4229009', '4232007', '4237001', '4240001', '4241002', '4242009', '4244005', '4248008', '4249000', '4251001', '4260009', '4262001', '4264000', '4269005', '4273008', '4275001', '4278004', '4283007', '4287008', '4294006', '4300009', '4301008', '4306003', '4307007', '4308002', '4310000', '4313003', '4316006', '4320005', '4324001', '4325000', '4332009', '4338008', '4340003', '4349002', '4354006', '4356008', '4359001', '4364002', '4367009', '4373005', '4374004', '4381006', '4386001', '4390004', '4397001', '4399003', '4403007', '4406004', '4409006', '4410001', '4412009', '4414005', '4416007', '4418008', '4426000', '4434006', '4439001', '4441000', '4445009', '4448006', '4451004', '4461006', '4463009', '4464003', '4465002', '4468000', '4470009', '4473006', '4477007', '4478002', '4481007', '4483005']}, 'type'=>'CodeableConcept', 'path'=>'ImagingStudy.reason', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/procedure-reason'}},
        'description' => {'type'=>'string', 'path'=>'ImagingStudy.description', 'min'=>0, 'max'=>1},
        'series' => {'type'=>'ImagingStudy::Series', 'path'=>'ImagingStudy.series', 'min'=>0, 'max'=>Float::INFINITY}
      }

      class Series < FHIR::STU3::Model
        include FHIR::STU3::Hashable
        include FHIR::STU3::Json
        include FHIR::STU3::Xml

        METADATA = {
          'id' => {'type'=>'string', 'path'=>'Series.id', 'min'=>0, 'max'=>1},
          'extension' => {'type'=>'Extension', 'path'=>'Series.extension', 'min'=>0, 'max'=>Float::INFINITY},
          'modifierExtension' => {'type'=>'Extension', 'path'=>'Series.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
          'uid' => {'type'=>'oid', 'path'=>'Series.uid', 'min'=>1, 'max'=>1},
          'number' => {'type'=>'unsignedInt', 'path'=>'Series.number', 'min'=>0, 'max'=>1},
          'modality' => {'valid_codes'=>{'http://dicom.nema.org/resources/ontology/DCM'=>['AR', 'BMD', 'BDUS', 'EPS', 'CR', 'CT', 'DX', 'ECG', 'ES', 'XC', 'GM', 'HD', 'IO', 'IVOCT', 'IVUS', 'KER', 'LEN', 'MR', 'MG', 'NM', 'OAM', 'OCT', 'OPM', 'OP', 'OPR', 'OPT', 'OPV', 'OSS', 'PX', 'PT', 'RF', 'RG', 'SM', 'SRF', 'US', 'VA', 'XA', 'ARCHIVE', 'AS', 'AU', 'BI', 'CAD', 'CAPTURE', 'CD', 'CF', 'COMP', 'CP', 'CS', 'DD', 'DF', 'DG', 'DM', 'DOCD', 'DS', 'DSS', 'EC', 'F', 'FA', 'FC', 'FILMD', 'FP', 'FS', 'H', 'HC', 'KO', 'LOG', 'LP', 'LS', 'M', 'MA', 'MC', 'MCD', 'MEDIM', 'MP', 'MS', 'NEARLINE', 'OFFLINE', 'ONLINE', 'OT', 'PR', 'PRINT', 'REG', 'RT', 'RTDOSE', 'RTIMAGE', 'RTPLAN', 'RTRECORD', 'RTSTRUCT', 'SEG', 'SMR', 'SR', 'ST', 'TG', 'U', 'UNAVAILABLE', 'VF', 'VIDD', 'WSD', '109001', '109002', '109003', '109004', '109005', '109006', '109007', '109008', '109009', '109010', '109011', '109012', '109013', '109014', '109015', '109016', '109017', '109018', '109019', '109020', '109021', '109022', '109023', '109024', '109025', '109026', '109027', '109028', '109029', '109030', '109031', '109032', '109033', '109034', '109035', '109036', '109037', '109038', '109039', '109040', '109041', '109042', '109043', '109044', '109045', '109046', '109047', '109048', '109049', '109050', '109051', '109052', '109053', '109054', '109055', '109056', '109057', '109058', '109059', '109060', '109061', '109063', '109070', '109071', '109072', '109073', '109080', '109081', '109082', '109083', '109091', '109092', '109093', '109094', '109095', '109096', '109101', '109102', '109103', '109104', '109105', '109106', '109110', '109111', '109112', '109113', '109114', '109115', '109116', '109117', '109120', '109121', '109122', '109123', '109124', '109125', '109132', '109133', '109134', '109135', '109136', '109200', '109201', '109202', '109203', '109204', '109205', '109206', '109207', '109208', '109209', '109210', '109211', '109212', '109213', '109214', '109215', '109216', '109217', '109218', '109219', '109220', '109221', '109222', '109701', '109702', '109703', '109704', '109705', '109706', '109707', '109708', '109709', '109710', '109801', '109802', '109803', '109804', '109805', '109806', '109807', '109808', '109809', '109810', '109811', '109812', '109813', '109814', '109815', '109816', '109817', '109818', '109819', '109820', '109821', '109822', '109823', '109824', '109825', '109826', '109827', '109828', '109829', '109830', '109831', '109832', '109833', '109834', '109835', '109836', '109837', '109838', '109839', '109840', '109841', '109842', '109843', '109844', '109845', '109846', '109847', '109848', '109849', '109850', '109851', '109852', '109853', '109854', '109855', '109856', '109857', '109858', '109859', '109860', '109861', '109862', '109863', '109864', '109865', '109866', '109867', '109868', '109869', '109870', '109871', '109872', '109873', '109874', '109875', '109876', '109877', '109878', '109879', '109880', '109881', '109901', '109902', '109903', '109904', '109905', '109906', '109907', '109908', '109909', '109910', '109911', '109912', '109913', '109914', '109915', '109916', '109917', '109918', '109919', '109920', '109921', '109931', '109932', '109933', '109941', '109943', '109991', '109992', '109993', '109994', '109995', '109996', '109997', '109998', '109999', '110001', '110002', '110003', '110004', '110005', '110006', '110007', '110008', '110009', '110010', '110011', '110012', '110013', '110020', '110021', '110022', '110023', '110024', '110025', '110026', '110027', '110028', '110030', '110031', '110032', '110033', '110034', '110035', '110036', '110037', '110038', '110100', '110101', '110102', '110103', '110104', '110105', '110106', '110107', '110108', '110109', '110110', '110111', '110112', '110113', '110114', '110120', '110121', '110122', '110123', '110124', '110125', '110126', '110127', '110128', '110129', '110130', '110131', '110132', '110133', '110134', '110135', '110136', '110137', '110138', '110139', '110140', '110141', '110142', '110150', '110151', '110152', '110153', '110154', '110155', '110180', '110181', '110182', '110190', '110500', '110501', '110502', '110503', '110504', '110505', '110506', '110507', '110508', '110509', '110510', '110511', '110512', '110513', '110514', '110515', '110516', '110518', '110519', '110521', '110522', '110523', '110524', '110526', '110527', '110528', '110529', '110700', '110701', '110702', '110703', '110704', '110705', '110706', '110800', '110801', '110802', '110803', '110804', '110805', '110806', '110807', '110808', '110809', '110810', '110811', '110812', '110813', '110814', '110815', '110816', '110817', '110818', '110819', '110820', '110821', '110822', '110823', '110824', '110825', '110826', '110827', '110828', '110829', '110830', '110831', '110832', '110833', '110834', '110835', '110836', '110837', '110838', '110839', '110840', '110841', '110842', '110843', '110844', '110845', '110846', '110847', '110848', '110849', '110850', '110851', '110852', '110853', '110854', '110855', '110856', '110857', '110858', '110859', '110860', '110861', '110862', '110863', '110864', '110865', '110866', '110867', '110868', '110869', '110870', '110871', '110872', '110873', '110874', '110875', '110876', '110877', '110901', '110902', '110903', '110904', '110905', '110906', '110907', '110908', '110909', '110910', '110911', '111001', '111002', '111003', '111004', '111005', '111006', '111007', '111008', '111009', '111010', '111011', '111012', '111013', '111014', '111015', '111016', '111017', '111018', '111019', '111020', '111021', '111022', '111023', '111024', '111025', '111026', '111027', '111028', '111029', '111030', '111031', '111032', '111033', '111034', '111035', '111036', '111037', '111038', '111039', '111040', '111041', '111042', '111043', '111044', '111045', '111046', '111047', '111048', '111049', '111050', '111051', '111052', '111053', '111054', '111055', '111056', '111057', '111058', '111059', '111060', '111061', '111062', '111063', '111064', '111065', '111066', '111069', '111071', '111072', '111081', '111086', '111087', '111088', '111089', '111090', '111091', '111092', '111093', '111099', '111100', '111101', '111102', '111103', '111104', '111105', '111111', '111112', '111113', '111120', '111121', '111122', '111123', '111124', '111125', '111126', '111127', '111128', '111129', '111130', '111135', '111136', '111137', '111138', '111139', '111140', '111141', '111142', '111143', '111144', '111145', '111146', '111147', '111148', '111149', '111150', '111151', '111152', '111153', '111154', '111155', '111156', '111157', '111158', '111159', '111168', '111170', '111171', '111172', '111173', '111174', '111175', '111176', '111177', '111178', '111179', '111180', '111181', '111182', '111183', '111184', '111185', '111186', '111187', '111188', '111189', '111190', '111191', '111192', '111193', '111194', '111195', '111196', '111197', '111198', '111199', '111200', '111201', '111202', '111203', '111204', '111205', '111206', '111207', '111208', '111209', '111210', '111211', '111212', '111213', '111214', '111215', '111216', '111217', '111218', '111219', '111220', '111221', '111222', '111223', '111224', '111225', '111233', '111234', '111235', '111236', '111237', '111238', '111239', '111240', '111241', '111242', '111243', '111244', '111245', '111248', '111249', '111250', '111251', '111252', '111253', '111254', '111255', '111256', '111257', '111258', '111259', '111260', '111262', '111263', '111264', '111265', '111269', '111271', '111273', '111277', '111278', '111279', '111281', '111283', '111284', '111285', '111286', '111287', '111288', '111290', '111291', '111292', '111293', '111294', '111296', '111297', '111298', '111299', '111300', '111301', '111302', '111303', '111304', '111305', '111306', '111307', '111308', '111309', '111310', '111311', '111312', '111313', '111314', '111315', '111316', '111317', '111318', '111320', '111321', '111322', '111323', '111324', '111325', '111326', '111327', '111328', '111329', '111330', '111331', '111332', '111333', '111334', '111335', '111336', '111338', '111340', '111341', '111342', '111343', '111344', '111345', '111346', '111347', '111350', '111351', '111352', '111353', '111354', '111355', '111356', '111357', '111358', '111359', '111360', '111361', '111362', '111363', '111364', '111365', '111366', '111367', '111368', '111369', '111370', '111371', '111372', '111373', '111374', '111375', '111376', '111377', '111380', '111381', '111382', '111383', '111384', '111385', '111386', '111387', '111388', '111389', '111390', '111391', '111392', '111393', '111394', '111395', '111396', '111397', '111398', '111399', '111400', '111401', '111402', '111403', '111404', '111405', '111406', '111407', '111408', '111409', '111410', '111411', '111412', '111413', '111414', '111415', '111416', '111417', '111418', '111419', '111420', '111421', '111423', '111424', '111425', '111426', '111427', '111428', '111429', '111430', '111431', '111432', '111433', '111434', '111435', '111436', '111437', '111438', '111439', '111440', '111441', '111442', '111443', '111444', '111445', '111446', '111447', '111448', '111449', '111450', '111451', '111452', '111453', '111454', '111455', '111456', '111457', '111458', '111459', '111460', '111461', '111462', '111463', '111464', '111465', '111466', '111467', '111468', '111469', '111470', '111471', '111472', '111473', '111474', '111475', '111476', '111477', '111478', '111479', '111480', '111481', '111482', '111483', '111484', '111485', '111486', '111487', '111488', '111489', '111490', '111491', '111492', '111494', '111495', '111496', '111497', '111498', '111499', '111500', '111501', '111502', '111503', '111504', '111505', '111506', '111507', '111508', '111509', '111510', '111511', '111512', '111513', '111514', '111515', '111516', '111517', '111518', '111519', '111520', '111521', '111522', '111523', '111524', '111525', '111526', '111527', '111528', '111529', '111530', '111531', '111532', '111533', '111534', '111535', '111536', '111537', '111538', '111539', '111540', '111541', '111542', '111543', '111544', '111545', '111546', '111547', '111548', '111549', '111550', '111551', '111552', '111553', '111554', '111555', '111556', '111557', '111558', '111559', '111560', '111561', '111562', '111563', '111564', '111565', '111566', '111567', '111568', '111569', '111570', '111571', '111572', '111573', '111574', '111575', '111576', '111577', '111578', '111579', '111580', '111581', '111582', '111583', '111584', '111585', '111586', '111587', '111590', '111591', '111592', '111593', '111601', '111602', '111603', '111604', '111605', '111606', '111607', '111609', '111621', '111622', '111623', '111625', '111626', '111627', '111628', '111629', '111630', '111631', '111632', '111633', '111634', '111635', '111636', '111637', '111638', '111641', '111642', '111643', '111644', '111645', '111646', '111671', '111672', '111673', '111674', '111675', '111676', '111677', '111678', '111679', '111680', '111685', '111686', '111687', '111688', '111689', '111690', '111691', '111692', '111693', '111694', '111695', '111696', '111697', '111698', '111700', '111701', '111702', '111703', '111704', '111705', '111706', '111707', '111708', '111709', '111710', '111711', '111712', '111718', '111719', '111720', '111721', '111723', '111724', '111726', '111727', '111729', '111741', '111742', '111743', '111744', '111745', '111746', '111747', '111748', '111749', '111750', '111751', '111752', '111753', '111754', '111755', '111756', '111760', '111761', '111762', '111763', '111764', '111765', '111766', '111767', '111768', '111769', '111770', '111771', '111772', '111773', '111776', '111777', '111778', '111779', '111780', '111781', '111782', '111783', '111786', '111787', '111791', '111792', '111800', '111801', '111802', '111803', '111804', '111805', '111806', '111807', '111808', '111809', '111810', '111811', '111812', '111813', '111814', '111815', '111816', '111817', '111818', '111819', '111820', '111821', '111822', '111823', '111824', '111825', '111826', '111827', '111828', '111829', '111830', '111831', '111832', '111833', '111834', '111835', '111836', '111837', '111838', '111839', '111840', '111841', '111842', '111843', '111844', '111845', '111846', '111847', '111848', '111849', '111850', '111851', '111852', '111853', '111854', '111855', '111856', '111900', '111901', '111902', '111903', '111904', '111905', '111906', '111907', '111908', '111909', '111910', '111911', '111912', '111913', '111914', '111915', '111916', '111917', '111918', '111919', '111920', '111921', '111922', '111923', '111924', '111925', '111926', '111927', '111928', '111929', '111930', '111931', '111932', '111933', '111934', '111935', '111936', '111937', '111938', '111939', '111940', '111941', '111942', '111943', '111944', '111945', '111946', '111947', '112000', '112001', '112002', '112003', '112004', '112005', '112006', '112007', '112008', '112009', '112010', '112011', '112012', '112013', '112014', '112015', '112016', '112017', '112018', '112019', '112020', '112021', '112022', '112023', '112024', '112025', '112026', '112027', '112028', '112029', '112030', '112031', '112032', '112033', '112034', '112035', '112036', '112037', '112038', '112039', '112040', '112041', '112042', '112043', '112044', '112045', '112046', '112047', '112048', '112049', '112050', '112051', '112052', '112053', '112054', '112055', '112056', '112057', '112058', '112059', '112060', '112061', '112062', '112063', '112064', '112065', '112066', '112067', '112068', '112069', '112070', '112071', '112072', '112073', '112074', '112075', '112076', '112077', '112078', '112079', '112080', '112081', '112082', '112083', '112084', '112085', '112086', '112087', '112088', '112089', '112090', '112091', '112092', '112093', '112094', '112095', '112096', '112097', '112098', '112099', '112100', '112101', '112102', '112103', '112104', '112105', '112106', '112107', '112108', '112109', '112110', '112111', '112112', '112113', '112114', '112115', '112116', '112117', '112118', '112119', '112120', '112121', '112122', '112123', '112124', '112125', '112126', '112127', '112128', '112129', '112130', '112131', '112132', '112133', '112134', '112135', '112136', '112137', '112138', '112139', '112140', '112141', '112142', '112143', '112144', '112145', '112146', '112147', '112148', '112149', '112150', '112151', '112152', '112153', '112154', '112155', '112156', '112157', '112158', '112159', '112160', '112161', '112162', '112163', '112164', '112165', '112166', '112167', '112168', '112169', '112170', '112171', '112172', '112173', '112174', '112175', '112176', '112177', '112178', '112179', '112180', '112181', '112182', '112183', '112184', '112185', '112186', '112187', '112188', '112189', '112191', '112192', '112193', '112194', '112195', '112196', '112197', '112198', '112199', '112200', '112201', '112220', '112222', '112224', '112225', '112226', '112227', '112228', '112229', '112232', '112233', '112238', '112240', '112241', '112242', '112243', '112244', '112248', '112249', '112300', '112301', '112302', '112303', '112304', '112305', '112306', '112307', '112308', '112309', '112310', '112311', '112312', '112313', '112314', '112315', '112316', '112317', '112318', '112319', '112320', '112321', '112325', '112340', '112341', '112342', '112343', '112344', '112345', '112346', '112347', '112348', '112350', '112351', '112352', '112353', '112354', '112355', '112356', '112357', '112358', '112359', '112360', '112361', '112362', '112363', '112364', '112365', '112366', '112367', '112368', '112369', '112370', '112371', '112372', '112373', '112374', '112375', '112376', '112377', '112378', '112379', '112380', '112381', '112700', '112701', '112702', '112703', '112704', '112705', '112706', '112707', '112708', '112709', '112710', '112711', '112712', '112713', '112714', '112715', '112716', '112717', '112718', '112719', '112720', '112721', '113000', '113001', '113002', '113003', '113004', '113005', '113006', '113007', '113008', '113009', '113010', '113011', '113012', '113013', '113014', '113015', '113016', '113017', '113018', '113020', '113021', '113026', '113030', '113031', '113032', '113033', '113034', '113035', '113036', '113037', '113038', '113039', '113040', '113041', '113042', '113043', '113044', '113045', '113046', '113047', '113048', '113049', '113050', '113051', '113052', '113053', '113054', '113055', '113056', '113057', '113058', '113059', '113060', '113061', '113062', '113063', '113064', '113065', '113066', '113067', '113068', '113069', '113070', '113071', '113072', '113073', '113074', '113075', '113076', '113077', '113078', '113079', '113080', '113081', '113082', '113083', '113085', '113086', '113087', '113088', '113089', '113090', '113091', '113092', '113093', '113094', '113095', '113096', '113097', '113100', '113101', '113102', '113103', '113104', '113105', '113106', '113107', '113108', '113109', '113110', '113111', '113500', '113502', '113503', '113505', '113506', '113507', '113508', '113509', '113510', '113511', '113512', '113513', '113514', '113516', '113517', '113518', '113520', '113521', '113522', '113523', '113526', '113527', '113528', '113529', '113530', '113540', '113541', '113542', '113543', '113550', '113551', '113552', '113560', '113561', '113562', '113563', '113568', '113570', '113571', '113572', '113573', '113574', '113575', '113576', '113577', '113601', '113602', '113603', '113605', '113606', '113607', '113608', '113609', '113611', '113612', '113613', '113620', '113621', '113622', '113630', '113631', '113650', '113651', '113652', '113653', '113661', '113662', '113663', '113664', '113665', '113666', '113669', '113670', '113671', '113680', '113681', '113682', '113683', '113684', '113685', '113686', '113687', '113688', '113689', '113690', '113691', '113692', '113701', '113702', '113704', '113705', '113706', '113710', '113711', '113720', '113721', '113722', '113723', '113724', '113725', '113726', '113727', '113728', '113729', '113730', '113731', '113732', '113733', '113734', '113735', '113736', '113737', '113738', '113739', '113740', '113742', '113743', '113744', '113745', '113748', '113750', '113751', '113752', '113753', '113754', '113755', '113756', '113757', '113758', '113759', '113760', '113761', '113763', '113764', '113766', '113767', '113768', '113769', '113770', '113771', '113772', '113773', '113780', '113788', '113789', '113790', '113791', '113792', '113793', '113794', '113795', '113800', '113801', '113802', '113803', '113804', '113805', '113806', '113807', '113808', '113809', '113810', '113811', '113812', '113813', '113814', '113815', '113816', '113817', '113818', '113819', '113820', '113821', '113822', '113823', '113824', '113825', '113826', '113827', '113828', '113829', '113830', '113831', '113832', '113833', '113834', '113835', '113836', '113837', '113838', '113839', '113840', '113841', '113842', '113845', '113846', '113847', '113850', '113851', '113852', '113853', '113854', '113855', '113856', '113857', '113858', '113859', '113860', '113861', '113862', '113863', '113864', '113865', '113866', '113867', '113868', '113870', '113871', '113872', '113873', '113874', '113875', '113876', '113877', '113878', '113879', '113880', '113890', '113893', '113895', '113896', '113897', '113898', '113899', '113900', '113901', '113902', '113903', '113904', '113905', '113906', '113907', '113908', '113909', '113910', '113911', '113912', '113913', '113914', '113921', '113922', '113923', '113930', '113931', '113932', '113933', '113934', '113935', '113936', '113937', '113940', '113941', '113942', '113943', '113944', '113945', '113946', '113947', '113948', '113949', '113950', '113951', '113952', '113953', '113954', '113955', '113956', '113957', '113958', '113959', '113961', '113962', '113963', '113970', '114000', '114001', '114002', '114003', '114004', '114005', '114006', '114007', '114008', '114009', '114010', '114011', '114201', '114202', '114203', '114204', '114205', '114206', '114207', '114208', '114209', '114210', '114211', '114213', '114215', '114216', '121001', '121002', '121003', '121004', '121005', '121006', '121007', '121008', '121009', '121010', '121011', '121012', '121013', '121014', '121015', '121016', '121017', '121018', '121019', '121020', '121021', '121022', '121023', '121024', '121025', '121026', '121027', '121028', '121029', '121030', '121031', '121032', '121033', '121034', '121035', '121036', '121037', '121038', '121039', '121040', '121041', '121042', '121043', '121044', '121045', '121046', '121047', '121048', '121049', '121050', '121051', '121052', '121053', '121054', '121055', '121056', '121057', '121058', '121059', '121060', '121062', '121064', '121065', '121066', '121068', '121069', '121070', '121071', '121072', '121073', '121074', '121075', '121076', '121077', '121078', '121079', '121080', '121081', '121082', '121083', '121084', '121085', '121086', '121087', '121088', '121089', '121090', '121091', '121092', '121093', '121094', '121095', '121096', '121097', '121098', '121099', '121100', '121101', '121102', '121103', '121104', '121105', '121106', '121109', '121110', '121111', '121112', '121113', '121114', '121115', '121116', '121117', '121118', '121120', '121121', '121122', '121123', '121124', '121125', '121126', '121127', '121128', '121130', '121131', '121132', '121133', '121135', '121136', '121137', '121138', '121139', '121140', '121141', '121142', '121143', '121144', '121145', '121146', '121147', '121148', '121149', '121150', '121151', '121152', '121153', '121154', '121155', '121156', '121157', '121158', '121160', '121161', '121162', '121163', '121165', '121166', '121167', '121168', '121169', '121171', '121172', '121173', '121174', '121180', '121181', '121190', '121191', '121192', '121193', '121194', '121195', '121196', '121197', '121198', '121200', '121201', '121202', '121206', '121207', '121208', '121210', '121211', '121213', '121214', '121216', '121217', '121218', '121219', '121220', '121221', '121222', '121230', '121231', '121232', '121233', '121242', '121243', '121244', '121290', '121291', '121301', '121302', '121303', '121304', '121305', '121306', '121307', '121311', '121312', '121313', '121314', '121315', '121316', '121317', '121318', '121320', '121321', '121322', '121323', '121324', '121325', '121326', '121327', '121328', '121329', '121330', '121331', '121332', '121333', '121334', '121335', '121338', '121339', '121340', '121341', '121342', '121346', '121347', '121348', '121349', '121350', '121351', '121352', '121353', '121354', '121358', '121360', '121361', '121362', '121363', '121370', '121371', '121372', '121380', '121381', '121382', '121383', '121401', '121402', '121403', '121404', '121405', '121406', '121407', '121408', '121410', '121411', '121412', '121414', '121415', '121416', '121417', '121420', '121421', '121422', '121423', '121424', '121425', '121427', '121428', '121430', '121431', '121432', '121433', '121434', '121435', '121436', '121437', '121438', '121439', '121701', '121702', '121703', '121704', '121705', '121706', '121707', '121708', '121709', '121710', '121711', '121712', '121713', '121714', '121715', '121716', '121717', '121718', '121719', '121720', '121721', '121722', '121723', '121724', '121725', '121726', '121727', '121728', '121729', '121730', '121731', '121732', '121733', '121734', '121740', '122001', '122002', '122003', '122004', '122005', '122006', '122007', '122008', '122009', '122010', '122011', '122012', '122020', '122021', '122022', '122023', '122024', '122025', '122026', '122027', '122028', '122029', '122030', '122031', '122032', '122033', '122034', '122035', '122036', '122037', '122038', '122039', '122041', '122042', '122043', '122044', '122045', '122046', '122047', '122048', '122049', '122052', '122053', '122054', '122055', '122056', '122057', '122058', '122059', '122060', '122061', '122062', '122072', '122073', '122075', '122076', '122077', '122078', '122079', '122081', '122082', '122083', '122084', '122085', '122086', '122087', '122088', '122089', '122090', '122091', '122092', '122093', '122094', '122095', '122096', '122097', '122098', '122099', '122101', '122102', '122103', '122104', '122105', '122106', '122107', '122108', '122109', '122110', '122111', '122112', '122113', '122114', '122120', '122121', '122122', '122123', '122124', '122125', '122126', '122127', '122128', '122129', '122130', '122131', '122132', '122133', '122134', '122138', '122139', '122140', '122141', '122142', '122143', '122144', '122145', '122146', '122147', '122148', '122149', '122150', '122151', '122152', '122153', '122154', '122157', '122158', '122159', '122160', '122161', '122162', '122163', '122164', '122165', '122166', '122167', '122170', '122171', '122172', '122173', '122175', '122176', '122177', '122178', '122179', '122180', '122181', '122182', '122183', '122185', '122187', '122188', '122189', '122190', '122191', '122192', '122193', '122194', '122195', '122196', '122197', '122198', '122199', '122201', '122202', '122203', '122204', '122205', '122206', '122207', '122208', '122209', '122210', '122211', '122212', '122213', '122214', '122215', '122216', '122217', '122218', '122219', '122220', '122221', '122222', '122223', '122224', '122225', '122227', '122228', '122229', '122230', '122231', '122232', '122233', '122234', '122235', '122236', '122237', '122238', '122239', '122240', '122241', '122242', '122243', '122244', '122245', '122246', '122247', '122248', '122249', '122250', '122251', '122252', '122253', '122254', '122255', '122256', '122257', '122258', '122259', '122260', '122261', '122262', '122263', '122265', '122266', '122267', '122268', '122269', '122270', '122271', '122272', '122273', '122274', '122275', '122276', '122277', '122278', '122279', '122281', '122282', '122283', '122288', '122291', '122292', '122301', '122302', '122303', '122304', '122305', '122306', '122307', '122308', '122309', '122310', '122311', '122312', '122313', '122319', '122320', '122321', '122322', '122325', '122330', '122331', '122332', '122333', '122334', '122335', '122336', '122337', '122339', '122340', '122341', '122343', '122344', '122345', '122346', '122347', '122348', '122350', '122351', '122352', '122354', '122355', '122356', '122357', '122360', '122361', '122363', '122364', '122367', '122368', '122369', '122370', '122371', '122372', '122374', '122375', '122376', '122380', '122381', '122382', '122383', '122384', '122385', '122386', '122387', '122388', '122389', '122390', '122391', '122393', '122394', '122395', '122398', '122399', '122400', '122401', '122402', '122403', '122404', '122405', '122406', '122407', '122408', '122410', '122411', '122417', '122421', '122422', '122423', '122428', '122429', '122430', '122431', '122432', '122433', '122434', '122435', '122438', '122445', '122446', '122447', '122448', '122449', '122450', '122451', '122452', '122453', '122459', '122461', '122464', '122465', '122466', '122467', '122468', '122469', '122470', '122471', '122472', '122473', '122474', '122475', '122476', '122477', '122480', '122481', '122482', '122485', '122486', '122487', '122488', '122489', '122490', '122491', '122493', '122495', '122496', '122497', '122498', '122499', '122501', '122502', '122503', '122505', '122507', '122508', '122509', '122510', '122511', '122516', '122517', '122528', '122529', '122542', '122544', '122545', '122546', '122547', '122548', '122549', '122550', '122551', '122554', '122555', '122558', '122559', '122560', '122562', '122563', '122564', '122565', '122566', '122572', '122574', '122575', '122582', '122600', '122601', '122602', '122603', '122604', '122605', '122606', '122607', '122608', '122609', '122611', '122612', '122616', '122617', '122618', '122619', '122620', '122621', '122624', '122627', '122628', '122631', '122633', '122634', '122635', '122636', '122637', '122638', '122639', '122640', '122642', '122643', '122645', '122650', '122651', '122652', '122655', '122656', '122657', '122658', '122659', '122660', '122661', '122664', '122665', '122666', '122667', '122668', '122670', '122675', '122680', '122683', '122684', '122685', '122686', '122687', '122698', '122699', '122700', '122701', '122702', '122703', '122704', '122705', '122706', '122707', '122708', '122709', '122710', '122711', '122712', '122713', '122715', '122716', '122717', '122718', '122720', '122721', '122726', '122727', '122728', '122729', '122730', '122731', '122732', '122733', '122734', '122735', '122739', '122740', '122741', '122742', '122743', '122744', '122745', '122748', '122750', '122751', '122752', '122753', '122755', '122756', '122757', '122758', '122759', '122760', '122762', '122764', '122768', '122769', '122770', '122771', '122772', '122773', '122775', '122776', '122781', '122782', '122783', '122784', '122785', '122791', '122792', '122793', '122795', '122796', '122797', '122799', '123001', '123003', '123004', '123005', '123006', '123007', '123009', '123010', '123011', '123012', '123014', '123015', '123016', '123019', '123101', '123102', '123103', '123104', '123105', '123106', '123107', '123108', '123109', '123110', '123111', '125000', '125001', '125002', '125003', '125004', '125005', '125006', '125007', '125008', '125009', '125010', '125011', '125012', '125013', '125015', '125016', '125021', '125022', '125023', '125024', '125025', '125030', '125031', '125032', '125033', '125034', '125035', '125036', '125037', '125038', '125040', '125041', '125100', '125101', '125102', '125105', '125106', '125107', '125195', '125196', '125197', '125200', '125201', '125202', '125203', '125204', '125205', '125206', '125207', '125208', '125209', '125210', '125211', '125212', '125213', '125214', '125215', '125216', '125217', '125218', '125219', '125220', '125221', '125222', '125223', '125224', '125225', '125226', '125227', '125228', '125230', '125231', '125233', '125234', '125235', '125236', '125237', '125238', '125239', '125240', '125241', '125242', '125251', '125252', '125253', '125254', '125255', '125256', '125257', '125258', '125259', '125261', '125262', '125263', '125264', '125265', '125270', '125271', '125272', '125273', '125901', '125902', '125903', '125904', '125905', '125906', '125907', '125908', '126000', '126001', '126002', '126003', '126010', '126011', '126020', '126021', '126022', '126030', '126031', '126032', '126033', '126034', '126035', '126036', '126037', '126038', '126039', '126040', '126050', '126051', '126052', '126060', '126061', '126062', '126063', '126064', '126065', '126066', '126067', '126070', '126071', '126072', '126073', '126074', '126075', '126080', '126081', '126100', '126200', '126201', '126202', '126203', '126220', '126300', '126301', '126302', '126303', '126310', '126311', '126312', '126313', '126314', '126320', '126321', '126322', '126330', '126331', '126340', '126341', '126342', '126343', '126344', '126350', '126351', '126352', '126353', '126360', '126361', '126362', '126363', '126364', '126370', '126371', '126372', '126373', '126374', '126375', '126376', '126377', '126380', '126390', '126391', '126392', '126393', '126394', '126400', '126401', '126402', '126403', '126404', '126410', '126411', '126412', '126413', '126500', '126501', '126502', '126503', '126510', '126511', '126512', '126513', '126514', '126515', '126516', '126517', '126518', '126519', '126520', '126600', '126601', '126602', '126603', '126604', '126605', '126606', '126700', '126701', '126702', '126703', '126704', '126705', '126706', '126707', '126708', '126709', '126710', '126711', '126712', '126713', '126714', '126715', '126716', '126801', '126802', '126803', '126804', '126805', '126806', '126807', '126808', '126809', '126810', '126811']}, 'type'=>'Coding', 'path'=>'Series.modality', 'min'=>1, 'max'=>1, 'binding'=>{'strength'=>'extensible', 'uri'=>'http://hl7.org/fhir/ValueSet/dicom-cid29'}},
          'description' => {'type'=>'string', 'path'=>'Series.description', 'min'=>0, 'max'=>1},
          'numberOfInstances' => {'type'=>'unsignedInt', 'path'=>'Series.numberOfInstances', 'min'=>0, 'max'=>1},
          'availability' => {'valid_codes'=>{'http://dicom.nema.org/resources/ontology/DCM'=>['ONLINE', 'OFFLINE', 'NEARLINE', 'UNAVAILABLE', 'ARCHIVE', 'AR', 'AS', 'AU', 'BDUS', 'BI', 'BMD', 'CAD', 'CAPTURE', 'CD', 'CF', 'COMP', 'CP', 'CR', 'CS', 'CT', 'DD', 'DF', 'DG', 'DM', 'DOCD', 'DS', 'DSS', 'DX', 'EC', 'ECG', 'EPS', 'ES', 'F', 'FA', 'FC', 'FILMD', 'FP', 'FS', 'GM', 'H', 'HC', 'HD', 'IO', 'IVOCT', 'IVUS', 'KER', 'KO', 'LEN', 'LOG', 'LP', 'LS', 'M', 'MA', 'MC', 'MCD', 'MEDIM', 'MG', 'MP', 'MR', 'MS', 'NM', 'OAM', 'OCT', 'OP', 'OPM', 'OPR', 'OPT', 'OPV', 'OSS', 'OT', 'PR', 'PRINT', 'PT', 'PX', 'REG', 'RF', 'RG', 'RT', 'RTDOSE', 'RTIMAGE', 'RTPLAN', 'RTRECORD', 'RTSTRUCT', 'SEG', 'SM', 'SMR', 'SR', 'SRF', 'ST', 'TG', 'U', 'US', 'VA', 'VF', 'VIDD', 'WSD', 'XA', 'XC', '109001', '109002', '109003', '109004', '109005', '109006', '109007', '109008', '109009', '109010', '109011', '109012', '109013', '109014', '109015', '109016', '109017', '109018', '109019', '109020', '109021', '109022', '109023', '109024', '109025', '109026', '109027', '109028', '109029', '109030', '109031', '109032', '109033', '109034', '109035', '109036', '109037', '109038', '109039', '109040', '109041', '109042', '109043', '109044', '109045', '109046', '109047', '109048', '109049', '109050', '109051', '109052', '109053', '109054', '109055', '109056', '109057', '109058', '109059', '109060', '109061', '109063', '109070', '109071', '109072', '109073', '109080', '109081', '109082', '109083', '109091', '109092', '109093', '109094', '109095', '109096', '109101', '109102', '109103', '109104', '109105', '109106', '109110', '109111', '109112', '109113', '109114', '109115', '109116', '109117', '109120', '109121', '109122', '109123', '109124', '109125', '109132', '109133', '109134', '109135', '109136', '109200', '109201', '109202', '109203', '109204', '109205', '109206', '109207', '109208', '109209', '109210', '109211', '109212', '109213', '109214', '109215', '109216', '109217', '109218', '109219', '109220', '109221', '109222', '109701', '109702', '109703', '109704', '109705', '109706', '109707', '109708', '109709', '109710', '109801', '109802', '109803', '109804', '109805', '109806', '109807', '109808', '109809', '109810', '109811', '109812', '109813', '109814', '109815', '109816', '109817', '109818', '109819', '109820', '109821', '109822', '109823', '109824', '109825', '109826', '109827', '109828', '109829', '109830', '109831', '109832', '109833', '109834', '109835', '109836', '109837', '109838', '109839', '109840', '109841', '109842', '109843', '109844', '109845', '109846', '109847', '109848', '109849', '109850', '109851', '109852', '109853', '109854', '109855', '109856', '109857', '109858', '109859', '109860', '109861', '109862', '109863', '109864', '109865', '109866', '109867', '109868', '109869', '109870', '109871', '109872', '109873', '109874', '109875', '109876', '109877', '109878', '109879', '109880', '109881', '109901', '109902', '109903', '109904', '109905', '109906', '109907', '109908', '109909', '109910', '109911', '109912', '109913', '109914', '109915', '109916', '109917', '109918', '109919', '109920', '109921', '109931', '109932', '109933', '109941', '109943', '109991', '109992', '109993', '109994', '109995', '109996', '109997', '109998', '109999', '110001', '110002', '110003', '110004', '110005', '110006', '110007', '110008', '110009', '110010', '110011', '110012', '110013', '110020', '110021', '110022', '110023', '110024', '110025', '110026', '110027', '110028', '110030', '110031', '110032', '110033', '110034', '110035', '110036', '110037', '110038', '110100', '110101', '110102', '110103', '110104', '110105', '110106', '110107', '110108', '110109', '110110', '110111', '110112', '110113', '110114', '110120', '110121', '110122', '110123', '110124', '110125', '110126', '110127', '110128', '110129', '110130', '110131', '110132', '110133', '110134', '110135', '110136', '110137', '110138', '110139', '110140', '110141', '110142', '110150', '110151', '110152', '110153', '110154', '110155', '110180', '110181', '110182', '110190', '110500', '110501', '110502', '110503', '110504', '110505', '110506', '110507', '110508', '110509', '110510', '110511', '110512', '110513', '110514', '110515', '110516', '110518', '110519', '110521', '110522', '110523', '110524', '110526', '110527', '110528', '110529', '110700', '110701', '110702', '110703', '110704', '110705', '110706', '110800', '110801', '110802', '110803', '110804', '110805', '110806', '110807', '110808', '110809', '110810', '110811', '110812', '110813', '110814', '110815', '110816', '110817', '110818', '110819', '110820', '110821', '110822', '110823', '110824', '110825', '110826', '110827', '110828', '110829', '110830', '110831', '110832', '110833', '110834', '110835', '110836', '110837', '110838', '110839', '110840', '110841', '110842', '110843', '110844', '110845', '110846', '110847', '110848', '110849', '110850', '110851', '110852', '110853', '110854', '110855', '110856', '110857', '110858', '110859', '110860', '110861', '110862', '110863', '110864', '110865', '110866', '110867', '110868', '110869', '110870', '110871', '110872', '110873', '110874', '110875', '110876', '110877', '110901', '110902', '110903', '110904', '110905', '110906', '110907', '110908', '110909', '110910', '110911', '111001', '111002', '111003', '111004', '111005', '111006', '111007', '111008', '111009', '111010', '111011', '111012', '111013', '111014', '111015', '111016', '111017', '111018', '111019', '111020', '111021', '111022', '111023', '111024', '111025', '111026', '111027', '111028', '111029', '111030', '111031', '111032', '111033', '111034', '111035', '111036', '111037', '111038', '111039', '111040', '111041', '111042', '111043', '111044', '111045', '111046', '111047', '111048', '111049', '111050', '111051', '111052', '111053', '111054', '111055', '111056', '111057', '111058', '111059', '111060', '111061', '111062', '111063', '111064', '111065', '111066', '111069', '111071', '111072', '111081', '111086', '111087', '111088', '111089', '111090', '111091', '111092', '111093', '111099', '111100', '111101', '111102', '111103', '111104', '111105', '111111', '111112', '111113', '111120', '111121', '111122', '111123', '111124', '111125', '111126', '111127', '111128', '111129', '111130', '111135', '111136', '111137', '111138', '111139', '111140', '111141', '111142', '111143', '111144', '111145', '111146', '111147', '111148', '111149', '111150', '111151', '111152', '111153', '111154', '111155', '111156', '111157', '111158', '111159', '111168', '111170', '111171', '111172', '111173', '111174', '111175', '111176', '111177', '111178', '111179', '111180', '111181', '111182', '111183', '111184', '111185', '111186', '111187', '111188', '111189', '111190', '111191', '111192', '111193', '111194', '111195', '111196', '111197', '111198', '111199', '111200', '111201', '111202', '111203', '111204', '111205', '111206', '111207', '111208', '111209', '111210', '111211', '111212', '111213', '111214', '111215', '111216', '111217', '111218', '111219', '111220', '111221', '111222', '111223', '111224', '111225', '111233', '111234', '111235', '111236', '111237', '111238', '111239', '111240', '111241', '111242', '111243', '111244', '111245', '111248', '111249', '111250', '111251', '111252', '111253', '111254', '111255', '111256', '111257', '111258', '111259', '111260', '111262', '111263', '111264', '111265', '111269', '111271', '111273', '111277', '111278', '111279', '111281', '111283', '111284', '111285', '111286', '111287', '111288', '111290', '111291', '111292', '111293', '111294', '111296', '111297', '111298', '111299', '111300', '111301', '111302', '111303', '111304', '111305', '111306', '111307', '111308', '111309', '111310', '111311', '111312', '111313', '111314', '111315', '111316', '111317', '111318', '111320', '111321', '111322', '111323', '111324', '111325', '111326', '111327', '111328', '111329', '111330', '111331', '111332', '111333', '111334', '111335', '111336', '111338', '111340', '111341', '111342', '111343', '111344', '111345', '111346', '111347', '111350', '111351', '111352', '111353', '111354', '111355', '111356', '111357', '111358', '111359', '111360', '111361', '111362', '111363', '111364', '111365', '111366', '111367', '111368', '111369', '111370', '111371', '111372', '111373', '111374', '111375', '111376', '111377', '111380', '111381', '111382', '111383', '111384', '111385', '111386', '111387', '111388', '111389', '111390', '111391', '111392', '111393', '111394', '111395', '111396', '111397', '111398', '111399', '111400', '111401', '111402', '111403', '111404', '111405', '111406', '111407', '111408', '111409', '111410', '111411', '111412', '111413', '111414', '111415', '111416', '111417', '111418', '111419', '111420', '111421', '111423', '111424', '111425', '111426', '111427', '111428', '111429', '111430', '111431', '111432', '111433', '111434', '111435', '111436', '111437', '111438', '111439', '111440', '111441', '111442', '111443', '111444', '111445', '111446', '111447', '111448', '111449', '111450', '111451', '111452', '111453', '111454', '111455', '111456', '111457', '111458', '111459', '111460', '111461', '111462', '111463', '111464', '111465', '111466', '111467', '111468', '111469', '111470', '111471', '111472', '111473', '111474', '111475', '111476', '111477', '111478', '111479', '111480', '111481', '111482', '111483', '111484', '111485', '111486', '111487', '111488', '111489', '111490', '111491', '111492', '111494', '111495', '111496', '111497', '111498', '111499', '111500', '111501', '111502', '111503', '111504', '111505', '111506', '111507', '111508', '111509', '111510', '111511', '111512', '111513', '111514', '111515', '111516', '111517', '111518', '111519', '111520', '111521', '111522', '111523', '111524', '111525', '111526', '111527', '111528', '111529', '111530', '111531', '111532', '111533', '111534', '111535', '111536', '111537', '111538', '111539', '111540', '111541', '111542', '111543', '111544', '111545', '111546', '111547', '111548', '111549', '111550', '111551', '111552', '111553', '111554', '111555', '111556', '111557', '111558', '111559', '111560', '111561', '111562', '111563', '111564', '111565', '111566', '111567', '111568', '111569', '111570', '111571', '111572', '111573', '111574', '111575', '111576', '111577', '111578', '111579', '111580', '111581', '111582', '111583', '111584', '111585', '111586', '111587', '111590', '111591', '111592', '111593', '111601', '111602', '111603', '111604', '111605', '111606', '111607', '111609', '111621', '111622', '111623', '111625', '111626', '111627', '111628', '111629', '111630', '111631', '111632', '111633', '111634', '111635', '111636', '111637', '111638', '111641', '111642', '111643', '111644', '111645', '111646', '111671', '111672', '111673', '111674', '111675', '111676', '111677', '111678', '111679', '111680', '111685', '111686', '111687', '111688', '111689', '111690', '111691', '111692', '111693', '111694', '111695', '111696', '111697', '111698', '111700', '111701', '111702', '111703', '111704', '111705', '111706', '111707', '111708', '111709', '111710', '111711', '111712', '111718', '111719', '111720', '111721', '111723', '111724', '111726', '111727', '111729', '111741', '111742', '111743', '111744', '111745', '111746', '111747', '111748', '111749', '111750', '111751', '111752', '111753', '111754', '111755', '111756', '111760', '111761', '111762', '111763', '111764', '111765', '111766', '111767', '111768', '111769', '111770', '111771', '111772', '111773', '111776', '111777', '111778', '111779', '111780', '111781', '111782', '111783', '111786', '111787', '111791', '111792', '111800', '111801', '111802', '111803', '111804', '111805', '111806', '111807', '111808', '111809', '111810', '111811', '111812', '111813', '111814', '111815', '111816', '111817', '111818', '111819', '111820', '111821', '111822', '111823', '111824', '111825', '111826', '111827', '111828', '111829', '111830', '111831', '111832', '111833', '111834', '111835', '111836', '111837', '111838', '111839', '111840', '111841', '111842', '111843', '111844', '111845', '111846', '111847', '111848', '111849', '111850', '111851', '111852', '111853', '111854', '111855', '111856', '111900', '111901', '111902', '111903', '111904', '111905', '111906', '111907', '111908', '111909', '111910', '111911', '111912', '111913', '111914', '111915', '111916', '111917', '111918', '111919', '111920', '111921', '111922', '111923', '111924', '111925', '111926', '111927', '111928', '111929', '111930', '111931', '111932', '111933', '111934', '111935', '111936', '111937', '111938', '111939', '111940', '111941', '111942', '111943', '111944', '111945', '111946', '111947', '112000', '112001', '112002', '112003', '112004', '112005', '112006', '112007', '112008', '112009', '112010', '112011', '112012', '112013', '112014', '112015', '112016', '112017', '112018', '112019', '112020', '112021', '112022', '112023', '112024', '112025', '112026', '112027', '112028', '112029', '112030', '112031', '112032', '112033', '112034', '112035', '112036', '112037', '112038', '112039', '112040', '112041', '112042', '112043', '112044', '112045', '112046', '112047', '112048', '112049', '112050', '112051', '112052', '112053', '112054', '112055', '112056', '112057', '112058', '112059', '112060', '112061', '112062', '112063', '112064', '112065', '112066', '112067', '112068', '112069', '112070', '112071', '112072', '112073', '112074', '112075', '112076', '112077', '112078', '112079', '112080', '112081', '112082', '112083', '112084', '112085', '112086', '112087', '112088', '112089', '112090', '112091', '112092', '112093', '112094', '112095', '112096', '112097', '112098', '112099', '112100', '112101', '112102', '112103', '112104', '112105', '112106', '112107', '112108', '112109', '112110', '112111', '112112', '112113', '112114', '112115', '112116', '112117', '112118', '112119', '112120', '112121', '112122', '112123', '112124', '112125', '112126', '112127', '112128', '112129', '112130', '112131', '112132', '112133', '112134', '112135', '112136', '112137', '112138', '112139', '112140', '112141', '112142', '112143', '112144', '112145', '112146', '112147', '112148', '112149', '112150', '112151', '112152', '112153', '112154', '112155', '112156', '112157', '112158', '112159', '112160', '112161', '112162', '112163', '112164', '112165', '112166', '112167', '112168', '112169', '112170', '112171', '112172', '112173', '112174', '112175', '112176', '112177', '112178', '112179', '112180', '112181', '112182', '112183', '112184', '112185', '112186', '112187', '112188', '112189', '112191', '112192', '112193', '112194', '112195', '112196', '112197', '112198', '112199', '112200', '112201', '112220', '112222', '112224', '112225', '112226', '112227', '112228', '112229', '112232', '112233', '112238', '112240', '112241', '112242', '112243', '112244', '112248', '112249', '112300', '112301', '112302', '112303', '112304', '112305', '112306', '112307', '112308', '112309', '112310', '112311', '112312', '112313', '112314', '112315', '112316', '112317', '112318', '112319', '112320', '112321', '112325', '112340', '112341', '112342', '112343', '112344', '112345', '112346', '112347', '112348', '112350', '112351', '112352', '112353', '112354', '112355', '112356', '112357', '112358', '112359', '112360', '112361', '112362', '112363', '112364', '112365', '112366', '112367', '112368', '112369', '112370', '112371', '112372', '112373', '112374', '112375', '112376', '112377', '112378', '112379', '112380', '112381', '112700', '112701', '112702', '112703', '112704', '112705', '112706', '112707', '112708', '112709', '112710', '112711', '112712', '112713', '112714', '112715', '112716', '112717', '112718', '112719', '112720', '112721', '113000', '113001', '113002', '113003', '113004', '113005', '113006', '113007', '113008', '113009', '113010', '113011', '113012', '113013', '113014', '113015', '113016', '113017', '113018', '113020', '113021', '113026', '113030', '113031', '113032', '113033', '113034', '113035', '113036', '113037', '113038', '113039', '113040', '113041', '113042', '113043', '113044', '113045', '113046', '113047', '113048', '113049', '113050', '113051', '113052', '113053', '113054', '113055', '113056', '113057', '113058', '113059', '113060', '113061', '113062', '113063', '113064', '113065', '113066', '113067', '113068', '113069', '113070', '113071', '113072', '113073', '113074', '113075', '113076', '113077', '113078', '113079', '113080', '113081', '113082', '113083', '113085', '113086', '113087', '113088', '113089', '113090', '113091', '113092', '113093', '113094', '113095', '113096', '113097', '113100', '113101', '113102', '113103', '113104', '113105', '113106', '113107', '113108', '113109', '113110', '113111', '113500', '113502', '113503', '113505', '113506', '113507', '113508', '113509', '113510', '113511', '113512', '113513', '113514', '113516', '113517', '113518', '113520', '113521', '113522', '113523', '113526', '113527', '113528', '113529', '113530', '113540', '113541', '113542', '113543', '113550', '113551', '113552', '113560', '113561', '113562', '113563', '113568', '113570', '113571', '113572', '113573', '113574', '113575', '113576', '113577', '113601', '113602', '113603', '113605', '113606', '113607', '113608', '113609', '113611', '113612', '113613', '113620', '113621', '113622', '113630', '113631', '113650', '113651', '113652', '113653', '113661', '113662', '113663', '113664', '113665', '113666', '113669', '113670', '113671', '113680', '113681', '113682', '113683', '113684', '113685', '113686', '113687', '113688', '113689', '113690', '113691', '113692', '113701', '113702', '113704', '113705', '113706', '113710', '113711', '113720', '113721', '113722', '113723', '113724', '113725', '113726', '113727', '113728', '113729', '113730', '113731', '113732', '113733', '113734', '113735', '113736', '113737', '113738', '113739', '113740', '113742', '113743', '113744', '113745', '113748', '113750', '113751', '113752', '113753', '113754', '113755', '113756', '113757', '113758', '113759', '113760', '113761', '113763', '113764', '113766', '113767', '113768', '113769', '113770', '113771', '113772', '113773', '113780', '113788', '113789', '113790', '113791', '113792', '113793', '113794', '113795', '113800', '113801', '113802', '113803', '113804', '113805', '113806', '113807', '113808', '113809', '113810', '113811', '113812', '113813', '113814', '113815', '113816', '113817', '113818', '113819', '113820', '113821', '113822', '113823', '113824', '113825', '113826', '113827', '113828', '113829', '113830', '113831', '113832', '113833', '113834', '113835', '113836', '113837', '113838', '113839', '113840', '113841', '113842', '113845', '113846', '113847', '113850', '113851', '113852', '113853', '113854', '113855', '113856', '113857', '113858', '113859', '113860', '113861', '113862', '113863', '113864', '113865', '113866', '113867', '113868', '113870', '113871', '113872', '113873', '113874', '113875', '113876', '113877', '113878', '113879', '113880', '113890', '113893', '113895', '113896', '113897', '113898', '113899', '113900', '113901', '113902', '113903', '113904', '113905', '113906', '113907', '113908', '113909', '113910', '113911', '113912', '113913', '113914', '113921', '113922', '113923', '113930', '113931', '113932', '113933', '113934', '113935', '113936', '113937', '113940', '113941', '113942', '113943', '113944', '113945', '113946', '113947', '113948', '113949', '113950', '113951', '113952', '113953', '113954', '113955', '113956', '113957', '113958', '113959', '113961', '113962', '113963', '113970', '114000', '114001', '114002', '114003', '114004', '114005', '114006', '114007', '114008', '114009', '114010', '114011', '114201', '114202', '114203', '114204', '114205', '114206', '114207', '114208', '114209', '114210', '114211', '114213', '114215', '114216', '121001', '121002', '121003', '121004', '121005', '121006', '121007', '121008', '121009', '121010', '121011', '121012', '121013', '121014', '121015', '121016', '121017', '121018', '121019', '121020', '121021', '121022', '121023', '121024', '121025', '121026', '121027', '121028', '121029', '121030', '121031', '121032', '121033', '121034', '121035', '121036', '121037', '121038', '121039', '121040', '121041', '121042', '121043', '121044', '121045', '121046', '121047', '121048', '121049', '121050', '121051', '121052', '121053', '121054', '121055', '121056', '121057', '121058', '121059', '121060', '121062', '121064', '121065', '121066', '121068', '121069', '121070', '121071', '121072', '121073', '121074', '121075', '121076', '121077', '121078', '121079', '121080', '121081', '121082', '121083', '121084', '121085', '121086', '121087', '121088', '121089', '121090', '121091', '121092', '121093', '121094', '121095', '121096', '121097', '121098', '121099', '121100', '121101', '121102', '121103', '121104', '121105', '121106', '121109', '121110', '121111', '121112', '121113', '121114', '121115', '121116', '121117', '121118', '121120', '121121', '121122', '121123', '121124', '121125', '121126', '121127', '121128', '121130', '121131', '121132', '121133', '121135', '121136', '121137', '121138', '121139', '121140', '121141', '121142', '121143', '121144', '121145', '121146', '121147', '121148', '121149', '121150', '121151', '121152', '121153', '121154', '121155', '121156', '121157', '121158', '121160', '121161', '121162', '121163', '121165', '121166', '121167', '121168', '121169', '121171', '121172', '121173', '121174', '121180', '121181', '121190', '121191', '121192', '121193', '121194', '121195', '121196', '121197', '121198', '121200', '121201', '121202', '121206', '121207', '121208', '121210', '121211', '121213', '121214', '121216', '121217', '121218', '121219', '121220', '121221', '121222', '121230', '121231', '121232', '121233', '121242', '121243', '121244', '121290', '121291', '121301', '121302', '121303', '121304', '121305', '121306', '121307', '121311', '121312', '121313', '121314', '121315', '121316', '121317', '121318', '121320', '121321', '121322', '121323', '121324', '121325', '121326', '121327', '121328', '121329', '121330', '121331', '121332', '121333', '121334', '121335', '121338', '121339', '121340', '121341', '121342', '121346', '121347', '121348', '121349', '121350', '121351', '121352', '121353', '121354', '121358', '121360', '121361', '121362', '121363', '121370', '121371', '121372', '121380', '121381', '121382', '121383', '121401', '121402', '121403', '121404', '121405', '121406', '121407', '121408', '121410', '121411', '121412', '121414', '121415', '121416', '121417', '121420', '121421', '121422', '121423', '121424', '121425', '121427', '121428', '121430', '121431', '121432', '121433', '121434', '121435', '121436', '121437', '121438', '121439', '121701', '121702', '121703', '121704', '121705', '121706', '121707', '121708', '121709', '121710', '121711', '121712', '121713', '121714', '121715', '121716', '121717', '121718', '121719', '121720', '121721', '121722', '121723', '121724', '121725', '121726', '121727', '121728', '121729', '121730', '121731', '121732', '121733', '121734', '121740', '122001', '122002', '122003', '122004', '122005', '122006', '122007', '122008', '122009', '122010', '122011', '122012', '122020', '122021', '122022', '122023', '122024', '122025', '122026', '122027', '122028', '122029', '122030', '122031', '122032', '122033', '122034', '122035', '122036', '122037', '122038', '122039', '122041', '122042', '122043', '122044', '122045', '122046', '122047', '122048', '122049', '122052', '122053', '122054', '122055', '122056', '122057', '122058', '122059', '122060', '122061', '122062', '122072', '122073', '122075', '122076', '122077', '122078', '122079', '122081', '122082', '122083', '122084', '122085', '122086', '122087', '122088', '122089', '122090', '122091', '122092', '122093', '122094', '122095', '122096', '122097', '122098', '122099', '122101', '122102', '122103', '122104', '122105', '122106', '122107', '122108', '122109', '122110', '122111', '122112', '122113', '122114', '122120', '122121', '122122', '122123', '122124', '122125', '122126', '122127', '122128', '122129', '122130', '122131', '122132', '122133', '122134', '122138', '122139', '122140', '122141', '122142', '122143', '122144', '122145', '122146', '122147', '122148', '122149', '122150', '122151', '122152', '122153', '122154', '122157', '122158', '122159', '122160', '122161', '122162', '122163', '122164', '122165', '122166', '122167', '122170', '122171', '122172', '122173', '122175', '122176', '122177', '122178', '122179', '122180', '122181', '122182', '122183', '122185', '122187', '122188', '122189', '122190', '122191', '122192', '122193', '122194', '122195', '122196', '122197', '122198', '122199', '122201', '122202', '122203', '122204', '122205', '122206', '122207', '122208', '122209', '122210', '122211', '122212', '122213', '122214', '122215', '122216', '122217', '122218', '122219', '122220', '122221', '122222', '122223', '122224', '122225', '122227', '122228', '122229', '122230', '122231', '122232', '122233', '122234', '122235', '122236', '122237', '122238', '122239', '122240', '122241', '122242', '122243', '122244', '122245', '122246', '122247', '122248', '122249', '122250', '122251', '122252', '122253', '122254', '122255', '122256', '122257', '122258', '122259', '122260', '122261', '122262', '122263', '122265', '122266', '122267', '122268', '122269', '122270', '122271', '122272', '122273', '122274', '122275', '122276', '122277', '122278', '122279', '122281', '122282', '122283', '122288', '122291', '122292', '122301', '122302', '122303', '122304', '122305', '122306', '122307', '122308', '122309', '122310', '122311', '122312', '122313', '122319', '122320', '122321', '122322', '122325', '122330', '122331', '122332', '122333', '122334', '122335', '122336', '122337', '122339', '122340', '122341', '122343', '122344', '122345', '122346', '122347', '122348', '122350', '122351', '122352', '122354', '122355', '122356', '122357', '122360', '122361', '122363', '122364', '122367', '122368', '122369', '122370', '122371', '122372', '122374', '122375', '122376', '122380', '122381', '122382', '122383', '122384', '122385', '122386', '122387', '122388', '122389', '122390', '122391', '122393', '122394', '122395', '122398', '122399', '122400', '122401', '122402', '122403', '122404', '122405', '122406', '122407', '122408', '122410', '122411', '122417', '122421', '122422', '122423', '122428', '122429', '122430', '122431', '122432', '122433', '122434', '122435', '122438', '122445', '122446', '122447', '122448', '122449', '122450', '122451', '122452', '122453', '122459', '122461', '122464', '122465', '122466', '122467', '122468', '122469', '122470', '122471', '122472', '122473', '122474', '122475', '122476', '122477', '122480', '122481', '122482', '122485', '122486', '122487', '122488', '122489', '122490', '122491', '122493', '122495', '122496', '122497', '122498', '122499', '122501', '122502', '122503', '122505', '122507', '122508', '122509', '122510', '122511', '122516', '122517', '122528', '122529', '122542', '122544', '122545', '122546', '122547', '122548', '122549', '122550', '122551', '122554', '122555', '122558', '122559', '122560', '122562', '122563', '122564', '122565', '122566', '122572', '122574', '122575', '122582', '122600', '122601', '122602', '122603', '122604', '122605', '122606', '122607', '122608', '122609', '122611', '122612', '122616', '122617', '122618', '122619', '122620', '122621', '122624', '122627', '122628', '122631', '122633', '122634', '122635', '122636', '122637', '122638', '122639', '122640', '122642', '122643', '122645', '122650', '122651', '122652', '122655', '122656', '122657', '122658', '122659', '122660', '122661', '122664', '122665', '122666', '122667', '122668', '122670', '122675', '122680', '122683', '122684', '122685', '122686', '122687', '122698', '122699', '122700', '122701', '122702', '122703', '122704', '122705', '122706', '122707', '122708', '122709', '122710', '122711', '122712', '122713', '122715', '122716', '122717', '122718', '122720', '122721', '122726', '122727', '122728', '122729', '122730', '122731', '122732', '122733', '122734', '122735', '122739', '122740', '122741', '122742', '122743', '122744', '122745', '122748', '122750', '122751', '122752', '122753', '122755', '122756', '122757', '122758', '122759', '122760', '122762', '122764', '122768', '122769', '122770', '122771', '122772', '122773', '122775', '122776', '122781', '122782', '122783', '122784', '122785', '122791', '122792', '122793', '122795', '122796', '122797', '122799', '123001', '123003', '123004', '123005', '123006', '123007', '123009', '123010', '123011', '123012', '123014', '123015', '123016', '123019', '123101', '123102', '123103', '123104', '123105', '123106', '123107', '123108', '123109', '123110', '123111', '125000', '125001', '125002', '125003', '125004', '125005', '125006', '125007', '125008', '125009', '125010', '125011', '125012', '125013', '125015', '125016', '125021', '125022', '125023', '125024', '125025', '125030', '125031', '125032', '125033', '125034', '125035', '125036', '125037', '125038', '125040', '125041', '125100', '125101', '125102', '125105', '125106', '125107', '125195', '125196', '125197', '125200', '125201', '125202', '125203', '125204', '125205', '125206', '125207', '125208', '125209', '125210', '125211', '125212', '125213', '125214', '125215', '125216', '125217', '125218', '125219', '125220', '125221', '125222', '125223', '125224', '125225', '125226', '125227', '125228', '125230', '125231', '125233', '125234', '125235', '125236', '125237', '125238', '125239', '125240', '125241', '125242', '125251', '125252', '125253', '125254', '125255', '125256', '125257', '125258', '125259', '125261', '125262', '125263', '125264', '125265', '125270', '125271', '125272', '125273', '125901', '125902', '125903', '125904', '125905', '125906', '125907', '125908', '126000', '126001', '126002', '126003', '126010', '126011', '126020', '126021', '126022', '126030', '126031', '126032', '126033', '126034', '126035', '126036', '126037', '126038', '126039', '126040', '126050', '126051', '126052', '126060', '126061', '126062', '126063', '126064', '126065', '126066', '126067', '126070', '126071', '126072', '126073', '126074', '126075', '126080', '126081', '126100', '126200', '126201', '126202', '126203', '126220', '126300', '126301', '126302', '126303', '126310', '126311', '126312', '126313', '126314', '126320', '126321', '126322', '126330', '126331', '126340', '126341', '126342', '126343', '126344', '126350', '126351', '126352', '126353', '126360', '126361', '126362', '126363', '126364', '126370', '126371', '126372', '126373', '126374', '126375', '126376', '126377', '126380', '126390', '126391', '126392', '126393', '126394', '126400', '126401', '126402', '126403', '126404', '126410', '126411', '126412', '126413', '126500', '126501', '126502', '126503', '126510', '126511', '126512', '126513', '126514', '126515', '126516', '126517', '126518', '126519', '126520', '126600', '126601', '126602', '126603', '126604', '126605', '126606', '126700', '126701', '126702', '126703', '126704', '126705', '126706', '126707', '126708', '126709', '126710', '126711', '126712', '126713', '126714', '126715', '126716', '126801', '126802', '126803', '126804', '126805', '126806', '126807', '126808', '126809', '126810', '126811']}, 'type'=>'code', 'path'=>'Series.availability', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'required', 'uri'=>'http://hl7.org/fhir/ValueSet/instance-availability'}},
          'endpoint' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Endpoint'], 'type'=>'Reference', 'path'=>'Series.endpoint', 'min'=>0, 'max'=>Float::INFINITY},
          'bodySite' => {'valid_codes'=>{'http://snomed.info/sct'=>['106004', '107008', '108003', '110001', '111002', '116007', '124002', '149003', '155008', '167005', '202009', '205006', '206007', '221001', '227002', '233006', '235004', '246001', '247005', '251007', '256002', '263002', '266005', '272005', '273000', '283001', '284007', '289002', '301000', '311007', '315003', '318001', '344001', '345000', '356000', '393006', '402006', '405008', '414003', '420002', '422005', '446003', '457008', '461002', '464005', '465006', '471000', '480000', '485005', '528006', '552004', '565008', '582005', '587004', '589001', '595000', '608002', '621009', '635006', '650002', '660006', '661005', '667009', '688000', '691000', '692007', '723004', '774007', '790007', '798000', '808000', '809008', '823005', '830004', '836005', '885000', '895007', '917004', '921006', '947002', '955009', '976004', '996007', '1005009', '1012000', '1015003', '1028005', '1030007', '1063000', '1075005', '1076006', '1086007', '1087003', '1092001', '1099005', '1101003', '1106008', '1110006', '1122009', '1136004', '1159005', '1172006', '1173001', '1174007', '1193009', '1216008', '1231004', '1236009', '1243003', '1246006', '1263005', '1277008', '1307006', '1311000', '1350001', '1353004', '1403006', '1425000', '1439000', '1441004', '1456008', '1467009', '1484003', '1490004', '1502004', '1511004', '1516009', '1527006', '1537001', '1541002', '1562001', '1569005', '1580005', '1581009', '1584001', '1600003', '1605008', '1610007', '1611006', '1617005', '1620002', '1626008', '1627004', '1630006', '1631005', '1650005', '1655000', '1659006', '1684009', '1706004', '1707008', '1711002', '1716007', '1721005', '1729007', '1732005', '1765002', '1780008', '1781007', '1797002', '1818002', '1825009', '1832000', '1840006', '1849007', '1853009', '1874005', '1893007', '1895000', '1902009', '1910005', '1918003', '1927002', '1992003', '1997009', '2010005', '2020000', '2031008', '2033006', '2044003', '2048000', '2049008', '2059009', '2071003', '2076008', '2083001', '2095001', '2123001', '2150006', '2156000', '2160002', '2175005', '2182009', '2192001', '2205003', '2209009', '2236006', '2246008', '2255006', '2285001', '2292006', '2302002', '2305000', '2306004', '2327009', '2330002', '2332005', '2334006', '2349003', '2372001', '2383005', '2389009', '2395005', '2397002', '2400006', '2402003', '2421006', '2433001', '2436009', '2453002', '2454008', '2484000', '2489005', '2499000', '2502001', '2504000', '2510000', '2539000', '2543001', '2550002', '2577006', '2579009', '2592007', '2600000', '2620004', '2639009', '2653009', '2666009', '2672009', '2675006', '2681003', '2682005', '2686008', '2687004', '2695000', '2703009', '2712006', '2718005', '2726002', '2730004', '2739003', '2741002', '2746007', '2748008', '2759004', '2771005', '2789006', '2792005', '2803000', '2810006', '2812003', '2824005', '2826007', '2830005', '2839006', '2841007', '2845003', '2848001', '2855004', '2861001', '2894003', '2905008', '2909002', '2920002', '2922005', '2923000', '2954001', '2969000', '2979003', '2986006', '2998001', '3003007', '3008003', '3028004', '3039001', '3042007', '3054007', '3055008', '3056009', '3057000', '3058005', '3062004', '3068000', '3081007', '3093003', '3100007', '3113001', '3117000', '3118005', '3120008', '3134008', '3138006', '3153003', '3156006', '3159004', '3169005', '3178004', '3194006', '3198009', '3215002', '3222005', '3227004', '3236000', '3243006', '3255000', '3262009', '3279003', '3295003', '3301002', '3302009', '3315000', '3332001', '3336003', '3341006', '3350008', '3362007', '3366005', '3370002', '3374006', '3377004', '3382006', '3383001', '3394002', '3395001', '3396000', '3400000', '3409004', '3417007', '3438001', '3444002', '3447009', '3460003', '3462006', '3471002', '3478008', '3481003', '3488009', '3490005', '3524005', '3538003', '3541007', '3553006', '3556003', '3563003', '3572006', '3578005', '3582007', '3584008', '3594003', '3608004', '3609007', '3646006', '3663005', '3665003', '3670005', '3711007', '3743007', '3761003', '3766008', '3785006', '3788008', '3789000', '3810000', '3838008', '3860006', '3865001', '3867009', '3876002', '3877006', '3910004', '3916005', '3924000', '3931001', '3935005', '3937002', '3954005', '3956007', '3959000', '3960005', '3964001', '3966004', '3977005', '3984002', '3989007', '4015004', '4019005', '4029003', '4061004', '4066009', '4072009', '4081003', '4093007', '4111006', '4117005', '4121003', '4146003', '4148002', '4150005', '4158003', '4159006', '4180000', '4193005', '4205002', '4212006', '4215008', '4247003', '4258007', '4268002', '4276000', '4281009', '4295007', '4303006', '4312008', '4317002', '4328003', '4335006', '4352005', '4358009', '4360006', '4369007', '4371007', '4375003', '4377006', '4394008', '4402002', '4419000', '4421005', '4430002', '4432005', '4442007', '4486002', '4524000', '4527007', '4537002', '4548009', '4549001', '4566004', '4573009', '4578000', '4583008', '4588004', '4596009', '4603002', '4606005', '4621004', '4624007', '4647008', '4651005', '4658004', '4677002', '4703008', '4717004', '4718009', '4743003', '4755009', '4759003', '4766002', '4768001', '4774001', '4775000', '4799000', '4810005', '4812002', '4828007', '4840007', '4843009', '4861000', '4866005', '4870002', '4871003', '4881004', '4888005', '4897009', '4905007', '4906008', '4924005', '4942000', '4954000', '4956003', '4958002', '5001007', '5023006', '5026003', '5046008', '5068003', '5069006', '5076001', '5115006', '5122003', '5128004', '5140004', '5192008', '5194009', '5195005', '5204005', '5213007', '5225005', '5228007', '5229004', '5261000', '5272005', '5279001', '5296000', '5324007', '5329002', '5336001', '5347008', '5362005', '5366008', '5379004', '5382009', '5394000', '5398002', '5403001', '5421003', '5427004', '5458003', '5459006', '5491007', '5493005', '5498001', '5501001', '5520004', '5538001', '5542003', '5544002', '5560003', '5564007', '5574005', '5580002', '5597008', '5611001', '5625000', '5627008', '5633004', '5643001', '5644007', '5653000', '5665001', '5668004', '5677006', '5682004', '5696005', '5697001', '5709001', '5713008', '5717009', '5718004', '5727003', '5742000', '5751008', '5769004', '5780004', '5798000', '5802004', '5814007', '5815008', '5816009', '5825003', '5828001', '5847003', '5854009', '5868002', '5872003', '5881009', '5882002', '5889006', '5890002', '5893000', '5898009', '5923009', '5926001', '5928000', '5942008', '5943003', '5944009', '5948007', '5951000', '5953002', '5976004', '5979006', '5996007', '6001004', '6004007', '6006009', '6009002', '6013009', '6014003', '6023000', '6032003', '6046003', '6050005', '6059006', '6062009', '6073002', '6074008', '6076005', '6104005', '6105006', '6110005', '6194002', '6216007', '6217003', '6229007', '6253001', '6268000', '6269008', '6279005', '6317000', '6325003', '6326002', '6335009', '6359004', '6371005', '6375001', '6392005', '6404004', '6413002', '6417001', '6423006', '6424000', '6445007', '6448009', '6450001', '6472004', '6504002', '6511003', '6530003', '6533001', '6538005', '6541001', '6544009', '6550004', '6551000', '6553002', '6564004', '6566002', '6572002', '6598008', '6606008', '6608009', '6620001', '6623004', '6633007', '6643005', '6646002', '6649009', '6651008', '6684008', '6685009', '6711001', '6720005', '6731002', '6739000', '6742006', '6750002', '6757004', '6787005', '6789008', '6799003', '6805009', '6820003', '6828005', '6829002', '6834003', '6841009', '6844001', '6850006', '6864006', '6866008', '6871001', '6894000', '6902008', '6905005', '6912001', '6914000', '6921000', '6930008', '6944002', '6969002', '6975006', '6981003', '6987004', '6989001', '6991009', '7035006', '7050002', '7067009', '7076002', '7083009', '7090004', '7091000', '7099003', '7117004', '7121006', '7148007', '7149004', '7154008', '7160008', '7167006', '7173007', '7188002', '7192009', '7227003', '7234001', '7242000', '7275008', '7295002', '7296001', '7311008', '7344002', '7345001', '7347009', '7362006', '7376007', '7378008', '7384006', '7404008', '7435002', '7471001', '7477002', '7480001', '7494000', '7498002', '7507003', '7524009', '7532001', '7554004', '7566005', '7569003', '7591005', '7597009', '7605000', '7610001', '7629007', '7651004', '7652006', '7657000', '7658005', '7697002', '7712004', '7726008', '7736000', '7742001', '7748002', '7755000', '7756004', '7764005', '7769000', '7783003', '7820009', '7829005', '7832008', '7835005', '7840002', '7841003', '7844006', '7851002', '7854005', '7872004', '7874003', '7880006', '7884002', '7885001', '7892006', '7896009', '7911004', '7925003', '7936005', '7944005', '7954009', '7967007', '7986004', '7991003', '7999001', '8001006', '8012006', '8017000', '8024004', '8039003', '8040001', '8045006', '8057002', '8059004', '8067007', '8068002', '8079007', '8091003', '8100009', '8111001', '8112008', '8119004', '8128003', '8133004', '8157004', '8158009', '8159001', '8160006', '8161005', '8165001', '8205005', '8225009', '8242003', '8251006', '8264007', '8265008', '8266009', '8279000', '8289001', '8292002', '8314003', '8334002', '8356004', '8361002', '8369000', '8373002', '8387002', '8389004', '8412003', '8415001', '8454000', '8464009', '8482007', '8483002', '8496001', '8523001', '8546004', '8556000', '8559007', '8560002', '8568009', '8580001', '8595004', '8598002', '8600008', '8603005', '8604004', '8608001', '8617001', '8623006', '8629005', '8640002', '8668003', '8671006', '8677005', '8688004', '8695008', '8710005', '8711009', '8714001', '8752000', '8770002', '8775007', '8784007', '8810002', '8814006', '8815007', '8820007', '8821006', '8827005', '8839002', '8845005', '8850004', '8854008', '8862000', '8873007', '8887007', '8892009', '8894005', '8897003', '8907008', '8910001', '8911002', '8928004', '8931003', '8935007', '8942007', '8965002', '8966001', '8983005', '8988001', '8993003', '9000002', '9003000', '9018004', '9040008', '9055004', '9073001', '9081000', '9086005', '9089003', '9108007', '9127001', '9156001', '9181003', '9185007', '9186008', '9188009', '9208002', '9212008', '9229006', '9231002', '9240003', '9242006', '9258009', '9261005', '9262003', '9284003', '9290004', '9305001', '9317004', '9320007', '9321006', '9325002', '9332006', '9348007', '9379006', '9380009', '9384000', '9390001', '9432007', '9438006', '9454009', '9455005', '9475001', '9481009', '9490002', '9498009', '9502002', '9512009', '9535007', '9558005', '9566001', '9568000', '9596006', '9609000', '9625005', '9642004', '9646001', '9654004', '9659009', '9662007', '9668006', '9677004', '9683001', '9684007', '9708001', '9732008', '9736006', '9743000', '9758008', '9770007', '9775002', '9779008', '9783008', '9791004', '9796009', '9813009', '9825007', '9837009', '9840009', '9841008', '9846003', '9847007', '9849005', '9870004', '9875009', '9878006', '9880000', '9881001', '9891007', '9898001', '9951005', '9968009', '9970000', '9976006', '9994000', '9999005', '10013000', '10024003', '10025002', '10026001', '10036009', '10042008', '10047002', '10052007', '10056005', '10062000', '10119003', '10124000']}, 'type'=>'Coding', 'path'=>'Series.bodySite', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/body-site'}},
          'laterality' => {'valid_codes'=>{'http://snomed.info/sct'=>['419161000', '419465000', '51440002']}, 'type'=>'Coding', 'path'=>'Series.laterality', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/bodysite-laterality'}},
          'started' => {'type'=>'dateTime', 'path'=>'Series.started', 'min'=>0, 'max'=>1},
          'performer' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Practitioner'], 'type'=>'Reference', 'path'=>'Series.performer', 'min'=>0, 'max'=>Float::INFINITY},
          'instance' => {'type'=>'ImagingStudy::Series::Instance', 'path'=>'Series.instance', 'min'=>0, 'max'=>Float::INFINITY}
        }

        class Instance < FHIR::STU3::Model
          include FHIR::STU3::Hashable
          include FHIR::STU3::Json
          include FHIR::STU3::Xml

          METADATA = {
            'id' => {'type'=>'string', 'path'=>'Instance.id', 'min'=>0, 'max'=>1},
            'extension' => {'type'=>'Extension', 'path'=>'Instance.extension', 'min'=>0, 'max'=>Float::INFINITY},
            'modifierExtension' => {'type'=>'Extension', 'path'=>'Instance.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
            'uid' => {'type'=>'oid', 'path'=>'Instance.uid', 'min'=>1, 'max'=>1},
            'number' => {'type'=>'unsignedInt', 'path'=>'Instance.number', 'min'=>0, 'max'=>1},
            'sopClass' => {'type'=>'oid', 'path'=>'Instance.sopClass', 'min'=>1, 'max'=>1},
            'title' => {'type'=>'string', 'path'=>'Instance.title', 'min'=>0, 'max'=>1}
          }

          attr_accessor :id                # 0-1 string
          attr_accessor :extension         # 0-* [ Extension ]
          attr_accessor :modifierExtension # 0-* [ Extension ]
          attr_accessor :uid               # 1-1 oid
          attr_accessor :number            # 0-1 unsignedInt
          attr_accessor :sopClass          # 1-1 oid
          attr_accessor :title             # 0-1 string
        end

        attr_accessor :id                # 0-1 string
        attr_accessor :extension         # 0-* [ Extension ]
        attr_accessor :modifierExtension # 0-* [ Extension ]
        attr_accessor :uid               # 1-1 oid
        attr_accessor :number            # 0-1 unsignedInt
        attr_accessor :modality          # 1-1 Coding
        attr_accessor :description       # 0-1 string
        attr_accessor :numberOfInstances # 0-1 unsignedInt
        attr_accessor :availability      # 0-1 code
        attr_accessor :endpoint          # 0-* [ Reference(Endpoint) ]
        attr_accessor :bodySite          # 0-1 Coding
        attr_accessor :laterality        # 0-1 Coding
        attr_accessor :started           # 0-1 dateTime
        attr_accessor :performer         # 0-* [ Reference(Practitioner) ]
        attr_accessor :instance          # 0-* [ ImagingStudy::Series::Instance ]
      end

      attr_accessor :id                 # 0-1 id
      attr_accessor :meta               # 0-1 Meta
      attr_accessor :implicitRules      # 0-1 uri
      attr_accessor :language           # 0-1 code
      attr_accessor :text               # 0-1 Narrative
      attr_accessor :contained          # 0-* [ Resource ]
      attr_accessor :extension          # 0-* [ Extension ]
      attr_accessor :modifierExtension  # 0-* [ Extension ]
      attr_accessor :uid                # 1-1 oid
      attr_accessor :accession          # 0-1 Identifier
      attr_accessor :identifier         # 0-* [ Identifier ]
      attr_accessor :availability       # 0-1 code
      attr_accessor :modalityList       # 0-* [ Coding ]
      attr_accessor :patient            # 1-1 Reference(Patient)
      attr_accessor :context            # 0-1 Reference(Encounter|EpisodeOfCare)
      attr_accessor :started            # 0-1 dateTime
      attr_accessor :basedOn            # 0-* [ Reference(ReferralRequest|CarePlan|ProcedureRequest) ]
      attr_accessor :referrer           # 0-1 Reference(Practitioner)
      attr_accessor :interpreter        # 0-* [ Reference(Practitioner) ]
      attr_accessor :endpoint           # 0-* [ Reference(Endpoint) ]
      attr_accessor :numberOfSeries     # 0-1 unsignedInt
      attr_accessor :numberOfInstances  # 0-1 unsignedInt
      attr_accessor :procedureReference # 0-* [ Reference(Procedure) ]
      attr_accessor :procedureCode      # 0-* [ CodeableConcept ]
      attr_accessor :reason             # 0-1 CodeableConcept
      attr_accessor :description        # 0-1 string
      attr_accessor :series             # 0-* [ ImagingStudy::Series ]

      def resourceType
        'ImagingStudy'
      end
    end
  end
end