module FHIR
  module STU3
    class Media < FHIR::STU3::Model
      include FHIR::STU3::Hashable
      include FHIR::STU3::Json
      include FHIR::STU3::Xml

      MULTIPLE_TYPES = {
        'occurrence' => ['dateTime', 'Period']
      }
      SEARCH_PARAMS = ['based-on', 'context', 'created', 'date', 'device', 'identifier', 'operator', 'patient', 'site', 'subject', 'subtype', 'type', 'view']
      METADATA = {
        'id' => {'type'=>'id', 'path'=>'Media.id', 'min'=>0, 'max'=>1},
        'meta' => {'type'=>'Meta', 'path'=>'Media.meta', 'min'=>0, 'max'=>1},
        'implicitRules' => {'type'=>'uri', 'path'=>'Media.implicitRules', 'min'=>0, 'max'=>1},
        'language' => {'valid_codes'=>{'urn:ietf:bcp:47'=>['ar', 'bn', 'cs', 'da', 'de', 'de-AT', 'de-CH', 'de-DE', 'el', 'en', 'en-AU', 'en-CA', 'en-GB', 'en-IN', 'en-NZ', 'en-SG', 'en-US', 'es', 'es-AR', 'es-ES', 'es-UY', 'fi', 'fr', 'fr-BE', 'fr-CH', 'fr-FR', 'fy', 'fy-NL', 'hi', 'hr', 'it', 'it-CH', 'it-IT', 'ja', 'ko', 'nl', 'nl-BE', 'nl-NL', 'no', 'no-NO', 'pa', 'pt', 'pt-BR', 'ru', 'ru-RU', 'sr', 'sr-SP', 'sv', 'sv-SE', 'te', 'zh', 'zh-CN', 'zh-HK', 'zh-SG', 'zh-TW']}, 'type'=>'code', 'path'=>'Media.language', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'extensible', 'uri'=>'http://hl7.org/fhir/ValueSet/languages'}},
        'text' => {'type'=>'Narrative', 'path'=>'Media.text', 'min'=>0, 'max'=>1},
        'contained' => {'type'=>'Resource', 'path'=>'Media.contained', 'min'=>0, 'max'=>Float::INFINITY},
        'extension' => {'type'=>'Extension', 'path'=>'Media.extension', 'min'=>0, 'max'=>Float::INFINITY},
        'modifierExtension' => {'type'=>'Extension', 'path'=>'Media.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
        'identifier' => {'type'=>'Identifier', 'path'=>'Media.identifier', 'min'=>0, 'max'=>Float::INFINITY},
        'basedOn' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/ProcedureRequest'], 'type'=>'Reference', 'path'=>'Media.basedOn', 'min'=>0, 'max'=>Float::INFINITY},
        'type' => {'valid_codes'=>{'http://hl7.org/fhir/digital-media-type'=>['photo', 'video', 'audio']}, 'type'=>'code', 'path'=>'Media.type', 'min'=>1, 'max'=>1, 'binding'=>{'strength'=>'required', 'uri'=>'http://hl7.org/fhir/ValueSet/digital-media-type'}},
        'subtype' => {'valid_codes'=>{'http://dicom.nema.org/resources/ontology/DCM'=>['AR', 'BMD', 'BDUS', 'EPS', 'CR', 'CT', 'DX', 'ECG', 'ES', 'XC', 'GM', 'HD', 'IO', 'IVOCT', 'IVUS', 'KER', 'LEN', 'MR', 'MG', 'NM', 'OAM', 'OCT', 'OPM', 'OP', 'OPR', 'OPT', 'OPV', 'OSS', 'PX', 'PT', 'RF', 'RG', 'SM', 'SRF', 'US', 'VA', 'XA'], 'http://snomed.info/sct'=>['306005', '334003', '435001', '642006', '762008', '951000', '1043007', '1044001', '1225002', '1292009', '1385001', '1414009', '1597004', '1787006', '2266004', '2508002', '2690005', '2696004', '2811005', '2847006', '2933008', '3047001', '3256004', '3258003', '3512003', '3620007', '3787003', '3799005', '3858009', '3991004', '3998005', '4008007', '4321009', '4438009', '4934001', '4970003', '5110001', '5131003', '5216004', '5433008', '5823005', '5846007', '6007000', '6127002', '6157006', '6238009', '6271008', '6480006', '6521006', '6650009', '6728003', '7174001', '7370001', '7421004', '7576008', '7656009', '7812007', '7993000', '7995007', '8031000', '8073008', '8151003', '8306009', '8358003', '8449009', '8503002', '8693001', '8994009', '9403009', '9518008', '9704004', '9988008', '10181005', '10374007', '10428007', '11269009', '11278003', '11295006', '11390003', '11582002', '11634002', '11760007', '11819005', '11892002', '11895000', '11971003', '12118001', '12124007', '12341000', '12356009', '12357000', '12389009', '12513003', '12749000', '13088001', '13167007', '13205008', '13256004', '13378009', '13450007', '13518004', '13578005', '13845008', '14211004', '14305004', '15282006', '15351005', '15364006', '15749009', '15757007', '16245009', '16278002', '16306001', '16310003', '16747000', '16910009', '17026004', '17375006', '17624002', '17711006', '17724006', '17745004', '17776005', '17984001', '18102001', '18370004', '18479002', '18499008', '18529002', '18640002', '18747005', '18848007', '18912009', '19086005', '19252005', '19490002', '19589009', '19671003', '19731001', '19961003', '20067007', '20350005', '20384009', '20603005', '20630000', '20740007', '20798004', '20836009', '21126008', '21339000', '21613005', '21623001', '21685006', '21970003', '22034001', '22059005', '22089003', '22289008', '22400007', '22446007', '22458007', '22530002', '22760005', '22761009', '22791004', '22873002', '22891007', '22901000', '22948003', '23225008', '23394003', '23461000', '23572007', '23738001', '23818008', '23846005', '23931002', '24058001', '24135002', '24267008', '24623002', '24646000', '24689001', '24715008', '24737001', '24848001', '24856003', '25306006', '25347009', '25411007', '25630002', '25759006', '25760001', '25850001', '26262000', '26308001', '26537001', '26648002', '26946001', '27300001', '27469002', '27483000', '27498003', '27821009', '27851003', '28033003', '28160007', '28303002', '28337005', '28339008', '28367004', '28514000', '28566009', '28686001', '28687005', '28806001', '28894006', '29117008', '29166005', '29357002', '29433003', '29559003', '29567006', '29592009', '29845000', '29967000', '30353000', '30439001', '30462004', '30536006', '30726001', '30788002', '30842004', '30918004', '30957007', '31157004', '31643000', '31683008', '31800006', '31911002', '31931003', '31962004', '31998007', '32012009', '32265006', '32289004', '32328007', '32345002', '32366005', '32535000', '32729002', '32962002', '33085008', '33148003', '33202000', '33357000', '33367005', '33450004', '33460008', '33527008', '33677003', '34227000', '34616009', '34885003', '34945008', '35198004', '35202002', '35249003', '35443000', '35492006', '35621002', '35757004', '36004004', '36624001', '36870006', '36960008', '37090007', '37307009', '37312005', '37348007', '37385004', '37403009', '37537004', '37541000', '37603004', '37707006', '37815002', '37859006', '38172006', '38336006', '38356007', '38366004', '38644000', '38769008', '38930009', '39305005', '39500001', '39714003', '39856007', '40008005', '40064005', '40228004', '40348008', '40357002', '40371005', '40372003', '40502003', '40538005', '40701008', '40892001', '41051004', '41209002', '41260001', '41333006', '41380003', '41385008', '41440006', '41466009', '41496004', '41500002', '41747008', '41785006', '41823007', '41842006', '41913002', '42003005', '42075002', '42539009', '42687005', '42705007', '42869005', '42957001', '42976004', '43129000', '43145003', '43204002', '43255009', '43294005', '43370007', '43704001', '43837006', '43947005', '44052005', '44260000', '44491008', '44545002', '44691001', '44884002', '45036003', '45315006', '45316007', '45554006', '45588000', '45689001', '45732007', '46108001', '46258004', '46291008', '46377000', '46424009', '46453005', '46471003', '46480003', '46597006', '46700000', '46798003', '46822003', '46854007', '46870009', '47079000', '47187002', '47293000', '47324001', '47616002', '47621004', '47859009', '47987001', '48138001', '48290004', '48380009', '48450000', '48526000', '48564003', '48633006', '48735005', '48816001', '48849005', '48858003', '48966008', '48986007', '48995004', '48996003', '49140003', '49276007', '49345004', '49459005', '49626003', '49673009', '49752000', '49856005', '50025001', '50251009', '50621006', '50759007', '50788008', '50867009', '50964001', '51006009', '51469006', '51619007', '51808006', '52221007', '52340003', '52432005', '52514008', '52566004', '52792009', '52823003', '52960000', '53054006', '53161007', '53457009', '53484005', '53495004', '53585008', '53683005', '53835005', '54042002', '54149009', '54321008', '54438008', '54640009', '54689004', '54780008', '54810009', '55052008', '55357008', '55447006', '55498000', '55501000', '55550006', '55596003', '55612007', '55761000', '55965002', '56058002', '56087001', '56216006', '56712007', '57093001', '57113004', '57235004', '57354002', '57417005', '57780004', '57902003', '58011003', '58082001', '58259007', '58316000', '58518000', '58713006', '58719005', '58746000', '58920005', '58951003', '59105009', '59413000', '59517002', '59608007', '59778004', '59800002', '59916001', '60006002', '60027007', '60228007', '60287000', '60443006', '60539009', '60619004', '60654006', '60668004', '61147008', '61361006', '61368000', '61518007', '61553000', '61593002', '61832002', '61982008', '62295005', '62434009', '62559003', '62581008', '62658002', '62756008', '63243008', '63469004', '63670007', '63713007', '64021002', '64152004', '64167000', '64318009', '64387007', '64432007', '64682006', '64707006', '65066001', '65083005', '65388005', '65416003', '65590007', '65749006', '65837003', '65839000', '65867009', '66088009', '66377006', '66596009', '66675005', '66769009', '66995002', '67022004', '67051000', '67071009', '67255001', '67357007', '67361001', '67499007', '67595003', '67632007', '67715004', '68083009', '68280004', '68306006', '68558001', '68796002', '68862002', '68965004', '69064006', '69143005', '69167002', '69477006', '69610007', '69657008', '69720006', '69772001', '70157001', '70268007', '70435002', '70780000', '71040008', '71093009', '71163001', '71233004', '71254006', '71503007', '71599004', '71651007', '71867003', '71894004', '71954002', '71977002', '72221006', '72383008', '72508000', '72716007', '72872009', '72911009', '73523002', '73771004', '74016001', '74017005', '74170002', '74193008', '74219000', '74546006', '74590001', '74710000', '74809003', '74834003', '74874009', '75014006', '75233009', '75385009', '75593005', '75675001', '75679007', '75691003', '75766009', '76285001', '76565001', '76573005', '76718005', '76913009', '76927004', '76930006', '76981001', '77343006', '77477000', '77532004', '77658008', '77660005', '77717008', '77973006', '78002002', '78013004', '78138006', '78176000', '78579002', '78669009', '78670005', '78711007', '78938007', '79073004', '79082005', '79092002', '79190008', '79237001', '79516005', '79563007', '79760008', '79777008', '79966006', '80218009', '80254008', '80302000', '80308001', '80372004', '80501006', '80648002', '80823002', '80865008', '81391006', '81451007', '81523000', '81618005', '81937003', '81941004', '82006003', '82066000', '82327001', '82420003', '82499005', '82588005', '82641000', '82831001', '82891004', '82899002', '82918005', '82921007', '83061004', '83093007', '83262001', '83429007', '83611007', '83641009', '83735008', '83788002', '83932002', '83949009', '84200003', '84311009', '84492002', '84881006', '85199006', '85339002', '85606007', '85815002', '85895003', '86086004', '86307000', '86354001', '86392000', '86410006', '86434001', '86543007', '86599005', '86811003', '86924002', '86950003', '87338009', '87411003', '87674005', '87751001', '87785000', '87932003', '88061002', '88365004', '88504002', '88628008', '88663003', '88745008', '88914000', '88935003', '89118008', '89240007', '89343007', '89846007', '90084008', '90223007', '90523008', '90686009', '90697009', '90711000', '90805008', '90992001', '91008002', '91119001', '91160008', '91186003', '91333005', '91360003', '91453008', '91583001', '91649003', '91672001', '103734008', '103745006', '105368002', '105369005', '105371005', '105372003', '105375001', '105376000', '105377009', '105378004', '108273007', '108274001', '108275000', '108276004', '108279006', '108280009', '108282001', '108283006', '108284000', '108285004', '108286003', '108287007', '108288002', '108294005', '108296007', '108300008', '113025000', '113090004', '113091000', '113094008', '113096005', '113099003', '113100006', '113103008', '113104002', '113105001', '113107009', '113109007', '113110002', '113113000', '113125002', '116152004', '129108007', '129118002', '129119005', '129120004', '133883001', '133884007', '133885008', '133886009', '133887000', '133888005', '133889002', '133890006', '164817009', '165095009', '168537006', '168558000', '168559008', '168560003', '168564007', '168565008', '168566009', '168573004', '168588009', '168594001', '168599006', '168600009', '168609005', '168619004', '168620005', '168623007', '168632009', '168633004', '168637003', '168654006', '168655007', '168663008', '168664002', '168665001', '168669007', '168681006', '168682004', '168702005', '168713008', '168716000', '168717009', '168719007', '168722009', '168723004', '168725006', '168729000', '168731009', '168736004', '168743005', '168744004', '168745003', '168746002', '168759005', '168760000', '168763003', '168764009', '168766006', '168767002', '168770003', '168772006', '168773001', '168775008', '168779002', '168780004', '168781000', '168783002', '168800007', '168803009', '168810003', '168811004', '168812006', '168814007', '168816009', '168817000', '168818005', '168821007', '168831000', '168836005', '168843004', '168844005', '168845006', '168846007', '168847003', '168854009', '168858007', '168859004', '168860009', '168861008', '168864000', '168870006', '168875001', '168881009', '168882002', '168884001', '168890002', '168892005', '168894006', '168896008', '168897004', '168899001', '168900006', '168902003', '168903008', '168904002', '168905001', '168906000', '168908004', '168917004', '168918009', '168919001', '168920007', '168922004', '168941001', '168968001', '168969009', '168970005', '168971009', '168973007', '168974001', '168975000', '168976004', '168977008', '168978003', '168979006', '168981008', '168982001', '168988002', '168989005', '168990001', '168996007', '168997003', '168998008', '168999000', '169000003', '169001004', '169002006', '169003001', '169004007', '169005008', '169006009', '169007000', '169008005', '169009002', '169010007', '169011006', '169012004', '169014003', '169015002', '169016001', '169017005', '169018000', '169019008', '169020002', '169021003', '169022005', '169023000', '169025007', '169026008', '169031005', '169032003', '169033008', '169034002', '169035001', '169037009', '169044000', '169045004', '169046003', '169047007', '169048002', '169049005', '169050005', '169055000', '169056004', '169057008', '169058003', '169061002', '169066007', '169067003', '169068008', '169069000', '169070004', '169071000', '169072007', '169074008', '169078006', '169086006', '169087002', '169088007', '169089004', '169090008', '169091007', '169092000', '169093005', '169094004', '169096002', '169097006', '169098001', '169099009', '169100001'], nil=>[], 'http://hl7.org/fhir/media-subtype'=>['diagram', 'fax', 'scan', 'retina', 'fingerprint', 'iris', 'palm', 'face']}, 'type'=>'CodeableConcept', 'path'=>'Media.subtype', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/digital-media-subtype'}},
        'view' => {'valid_codes'=>{'http://snomed.info/sct'=>['260421001', '260422008', '260424009', '260425005', '260426006', '260427002', '260428007', '260430009', '260431008', '260432001', '260434000', '260435004', '260436003', '260437007', '260438002', '260439005', '260440007', '260441006', '260442004', '260443009', '260444003', '260445002', '260446001', '260447005', '260450008', '260451007', '260452000', '260453005', '260454004', '260455003', '260458001', '260459009', '260460004', '260461000', '260463002', '260464008', '260465009', '260466005', '260467001', '260468006', '260469003', '260470002', '260471003', '260472005', '260473000', '260475007', '260476008', '260477004', '260478009', '260479001', '260481004', '260482006', '260483001', '260484007', '260485008', '260486009', '260487000', '260489002', '260490006', '260491005', '260492003', '260493008', '260494002', '260496000', '260497009', '260499007', '260500003', '260501004', '260502006', '260503001', '260504007', '260506009', '272455005', '272456006', '272457002', '272458007', '272459004', '272460009', '272461008', '272462001', '272464000', '272465004', '272466003', '272467007', '272468002', '272469005', '272470006', '272472003', '272473008', '272474002', '272475001', '272476000', '272478004', '272479007', '272480005', '272481009', '272482002', '272483007', '272484001', '278255003', '278267001', '278318001', '398996004', '399000008', '399001007', '399002000', '399003005', '399004004', '399005003', '399006002', '399011000', '399012007', '399013002', '399022001', '399024000', '399025004', '399026003', '399028002', '399033003', '399037002', '399038007', '399059000', '399061009', '399065000', '399067008', '399071006', '399073009', '399074003', '399075002', '399080006', '399082003', '399083008', '399089007', '399098005', '399099002', '399101009', '399103007', '399108003', '399110001', '399113004', '399118008', '399125001', '399127009', '399129007', '399130002', '399132005', '399135007', '399136008', '399138009', '399142007', '399146005', '399148006', '399152006', '399156009', '399157000', '399159002', '399160007', '399161006', '399162004', '399163009', '399168000', '399169008', '399171008', '399173006', '399179005', '399181007', '399182000', '399184004', '399188001', '399192008', '399196006', '399198007', '399199004', '399201002', '399206007', '399212002', '399215000', '399218003', '399225005', '399227002', '399234000', '399236003', '399237007', '399241006', '399242004', '399243009', '399245002', '399246001', '399247005', '399251007', '399255003', '399260004', '399263002', '399265009', '399268006', '399270002', '399272005', '399273000', '399277004', '399278009', '399280003', '399281004', '399284007', '399285008', '399288005', '399290006', '399292003', '399296000', '399297009', '399300004', '399303002', '399308006', '399311007', '399312000', '399313005', '399316002', '399318001', '399320003', '399321004', '399325008', '399327000', '399330007', '399332004', '399335002', '399341009', '399342002', '399344001', '399348003', '399349006', '399351005', '399352003', '399355001', '399356000', '399358004', '399360002', '399361003', '399362005', '399365007', '399368009', '399370000', '399372008', '408723005', '408724004', '408725003', '408726002', '422534007', '422568001', '422670003', '422795009', '422861003', '422954003', '422996004', '423091003', '423720000', '424086005', '424655003', '424811006', '424962005', '425030002', '425035007', '425042007', '425157002', '425188003', '441505008', '441555000', '441672003', '441753009', '442361004', '442441009', '442580003', '442581004', '442593008', '442594002', '442640004', '442653001', '442667005']}, 'type'=>'CodeableConcept', 'path'=>'Media.view', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/media-view'}},
        'subject' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Patient', 'http://hl7.org/fhir/StructureDefinition/Practitioner', 'http://hl7.org/fhir/StructureDefinition/Group', 'http://hl7.org/fhir/StructureDefinition/Device', 'http://hl7.org/fhir/StructureDefinition/Specimen'], 'type'=>'Reference', 'path'=>'Media.subject', 'min'=>0, 'max'=>1},
        'context' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Encounter', 'http://hl7.org/fhir/StructureDefinition/EpisodeOfCare'], 'type'=>'Reference', 'path'=>'Media.context', 'min'=>0, 'max'=>1},
        'occurrenceDateTime' => {'type'=>'dateTime', 'path'=>'Media.occurrence[x]', 'min'=>0, 'max'=>1},
        'occurrencePeriod' => {'type'=>'Period', 'path'=>'Media.occurrence[x]', 'min'=>0, 'max'=>1},
        'operator' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Practitioner'], 'type'=>'Reference', 'path'=>'Media.operator', 'min'=>0, 'max'=>1},
        'reasonCode' => {'valid_codes'=>{'http://snomed.info/sct'=>['109006', '122003', '127009', '129007', '134006', '140004', '144008', '147001', '150003', '151004', '162004', '165002', '168000', '171008', '172001', '175004', '177007', '179005', '181007', '183005', '184004', '188001', '192008', '193003', '195005', '198007', '199004', '208008', '216004', '219006', '222008', '223003', '228007', '241006', '242004', '253005', '257006', '258001', '264008', '276008', '279001', '281004', '282006', '290006', '292003', '297009', '299007', '303002', '308006', '310008', '313005', '317006', '320003', '324007', '330007', '335002', '341009', '349006', '355001', '357009', '358004', '359007', '360002', '364006', '366008', '368009', '369001', '378007', '382009', '383004', '385006', '387003', '398002', '407000', '408005', '409002', '426008', '431005', '437009', '440009', '442001', '443006', '447007', '450005', '452002', '460001', '467003', '470004', '479003', '486006', '488007', '490008', '496002', '504009', '517007', '518002', '520004', '527001', '536002', '539009', '547009', '548004', '554003', '555002', '563001', '568005', '586008', '590005', '596004', '599006', '600009', '602001', '607007', '610000', '613003', '615005', '616006', '626004', '631002', '634005', '640003', '643001', '646009', '649002', '651003', '652005', '655007', '658009', '663008', '664002', '666000', '675003', '682004', '685002', '701003', '703000', '714002', '715001', '718004', '733007', '734001', '736004', '750009', '755004', '756003', '758002', '775008', '776009', '781000', '786005', '787001', '788006', '792004', '799008', '801006', '805002', '811004', '813001', '815008', '816009', '818005', '825003', '827006', '832007', '834008', '841002', '842009', '843004', '844005', '845006', '849000', '857002', '862001', '865004', '871005', '874002', '875001', '888003', '890002', '899001', '903008', '904002', '908004', '919001', '928000', '931004', '932006', '934007', '943003', '954008', '961007', '962000', '964004', '965003', '975000', '978003', '981008', '984000', '987007', '991002', '998008', '1003002', '1020003', '1023001', '1027000', '1031006', '1033009', '1034003', '1038000', '1045000', '1046004', '1051005', '1055001', '1059007', '1070000', '1073003', '1074009', '1077002', '1079004', '1085006', '1089000', '1102005', '1107004', '1108009', '1111005', '1112003', '1116000', '1124005', '1125006', '1126007', '1131009', '1134001', '1135000', '1139006', '1140008', '1141007', '1145003', '1150009', '1151008', '1152001', '1155004', '1156003', '1168007', '1184008', '1192004', '1194003', '1196001', '1197005', '1201005', '1203008', '1207009', '1208004', '1212005', '1214006', '1230003', '1232006', '1239002', '1240000', '1259003', '1261007', '1264004', '1271009', '1280009', '1282001', '1283006', '1284000', '1286003', '1287007', '1297003', '1308001', '1310004', '1317001', '1318006', '1323006', '1332008', '1335005', '1343000', '1345007', '1351002', '1356007', '1361009', '1363007', '1367008', '1370007', '1372004', '1376001', '1378000', '1380006', '1383008', '1384002', '1386000', '1387009', '1388004', '1393001', '1395008', '1402001', '1412008', '1415005', '1418007', '1419004', '1426004', '1427008', '1430001', '1447000', '1469007', '1474004', '1475003', '1478001', '1479009', '1482004', '1486001', '1488000', '1489008', '1492007', '1493002', '1499003', '1512006', '1515008', '1518005', '1519002', '1521007', '1523005', '1525003', '1531000', '1532007', '1534008', '1538006', '1539003', '1542009', '1544005', '1551001', '1556006', '1563006', '1567007', '1588003', '1592005', '1593000', '1606009', '1608005', '1639007', '1647007', '1648002', '1654001', '1657008', '1658003', '1663004', '1667003', '1670004', '1671000', '1674008', '1679003', '1682008', '1685005', '1686006', '1694004', '1698001', '1703007', '1705000', '1708003', '1714005', '1717003', '1723008', '1724002', '1734006', '1735007', '1739001', '1742007', '1744008', '1748006', '1755008', '1761006', '1763009', '1767005', '1769008', '1771008', '1776003', '1777007', '1778002', '1779005', '1794009', '1816003', '1821000', '1822007', '1824008', '1826005', '1828006', '1829003', '1833005', '1835003', '1837006', '1845001', '1847009', '1848004', '1852004', '1855002', '1856001', '1857005', '1858000', '1860003', '1865008', '1869002', '1881003', '1892002', '1896004', '1897008', '1899006', '1903004', '1908008', '1909000', '1922008', '1926006', '1938002', '1939005', '1943009', '1953005', '1954004', '1955003', '1959009', '1961000', '1963002', '1965009', '1967001', '1973000', '1977004', '1979001', '1980003', '1981004', '1988005', '1989002', '2004005', '2012002', '2024009', '2028007', '2032001', '2036003', '2040007', '2041006', '2043009', '2053005', '2055003', '2058001', '2061000', '2065009', '2066005', '2070002', '2073000', '2087000', '2089002', '2091005', '2094002', '2102007', '2103002', '2107001', '2109003', '2114004', '2116002', '2120003', '2121004', '2128005', '2129002', '2132004', '2134003', '2136001', '2138000', '2145000', '2149006', '2158004', '2167004', '2169001', '2170000', '2176006', '2177002', '2186007', '2198002', '2202000', '2204004', '2213002', '2216005', '2217001', '2219003', '2224000', '2228002', '2229005', '2231001', '2237002', '2239004', '2241003', '2243000', '2245007', '2251002', '2256007', '2261009', '2268003', '2284002', '2295008', '2296009', '2298005', '2301009', '2303007', '2304001', '2307008', '2308003', '2312009', '2314005', '2326000', '2339001', '2341000', '2351004', '2355008', '2359002', '2365002', '2366001', '2367005', '2374000', '2385003', '2388001', '2390000', '2391001', '2396006', '2398007', '2403008', '2415007', '2418009', '2419001', '2420007', '2432006', '2435008', '2437000', '2438005', '2439002', '2443003', '2452007', '2463005', '2469009', '2470005', '2471009', '2472002', '2473007', '2477008', '2492009', '2495006', '2496007', '2506003', '2513003', '2518007', '2521009', '2523007', '2526004', '2528003', '2532009', '2534005', '2538008', '2541004', '2554006', '2556008', '2560006', '2562003', '2576002', '2581006', '2582004', '2583009', '2584003', '2585002', '2589008', '2591000', '2593002', '2602008', '2606006', '2615004', '2618002', '2622007', '2624008', '2625009', '2630008', '2634004', '2638001', '2640006', '2651006', '2655002', '2657005', '2663001', '2665008', '2683000', '2689001', '2694001', '2704003', '2707005', '2713001', '2724004', '2725003', '2733002', '2736005', '2740001', '2749000', '2751001', '2761008', '2764000', '2770006', '2772003', '2775001', '2776000', '2781009', '2782002', '2783007', '2786004', '2790002', '2805007', '2806008', '2807004', '2808009', '2815001', '2816000', '2818004', '2819007', '2825006', '2828008', '2829000', '2831009', '2835000', '2836004', '2838003', '2840008', '2850009', '2853006', '2856003', '2858002', '2884008', '2893009', '2897005', '2899008', '2900003', '2901004', '2902006', '2904007', '2910007', '2912004', '2917005', '2918000', '2919008', '2929001', '2935001', '2940009', '2946003', '2951009', '2955000', '2965006', '2967003', '2972007', '2973002', '2978006', '2981001', '2989004', '2990008', '2992000', '2994004', '2999009', '3002002', '3004001', '3006004', '3009006', '3013004', '3014005', '3018008', '3019000', '3021005', '3023008', '3032005', '3033000', '3038009', '3044008', '3053001', '3059002', '3067005', '3071008', '3072001', '3073006', '3084004', '3089009', '3094009', '3095005', '3097002', '3098007', '3105002', '3109008', '3110003', '3119002', '3129009', '3135009', '3140001', '3144005', '3158007', '3160009', '3163006', '3168002', '3185000', '3199001', '3200003', '3208005', '3214003', '3217005', '3218000', '3219008', '3228009', '3229001', '3230006', '3238004', '3239007', '3253007', '3254001', '3259006', '3261002', '3263004', '3272007', '3274008', '3275009', '3276005', '3277001', '3282008', '3283003', '3286006', '3289004', '3291007', '3298001', '3303004', '3304005', '3305006', '3308008', '3310005', '3321001', '3323003', '3327002', '3331008', '3344003', '3345002', '3355003', '3358001', '3368006', '3376008', '3381004', '3387000', '3391005', '3393008', '3398004', '3401001', '3415004', '3419005', '3421000', '3424008', '3426005', '3427001', '3434004', '3439009', '3441005', '3446000', '3449007', '3456001', '3458000', '3461004', '3464007', '3468005', '3469002', '3472009', '3474005', '3480002', '3482005', '3483000', '3487004', '3500002', '3502005', '3503000', '3505007', '3506008', '3507004', '3511005', '3514002', '3519007', '3528008', '3529000', '3530005', '3531009', '3533007', '3539006', '3542000', '3544004', '3545003', '3548001', '3549009', '3558002', '3560000', '3570003', '3571004', '3577000', '3585009', '3586005', '3589003', '3590007', '3591006', '3598000', '3611003', '3633001', '3634007', '3639002', '3640000', '3641001', '3642008', '3644009', '3649004', '3650004', '3652007', '3657001', '3660008', '3662000', '3677008', '3680009', '3681008', '3696007', '3699000', '3703002', '3704008', '3705009', '3712000', '3716002', '3720003', '3723001', '3733009', '3736001', '3738000', '3744001', '3745000', '3747008', '3750006', '3751005', '3752003', '3754002', '3755001', '3756000', '3759007', '3760002', '3762005', '3763000', '3783004', '3797007', '3798002', '3815005', '3820005', '3827008', '3830001', '3841004', '3845008', '3855007', '3859001', '3873005', '3885002', '3886001', '3899003', '3900008', '3902000', '3903005', '3908001', '3909009', '3913002', '3914008', '3928002', '3939004', '3944006', '3947004', '3950001', '3951002', '3972004', '3975002', '3978000', '3987009', '3993001', '3999002', '4003003', '4004009', '4006006', '4009004', '4016003', '4017007', '4022007', '4026005', '4030008', '4038001', '4039009', '4040006', '4041005', '4046000', '4062006', '4063001', '4069002', '4070001', '4075006', '4082005', '4088009', '4089001', '4092002', '4103001', '4106009', '4107000', '4113009', '4120002', '4124006', '4127004', '4129001', '4135001', '4136000', '4142001', '4152002', '4160001', '4168008', '4170004', '4174008', '4175009', '4178006', '4181001', '4183003', '4184009', '4191007', '4195003', '4197006', '4199009', '4208000', '4210003', '4223005', '4224004', '4225003', '4229009', '4232007', '4237001', '4240001', '4241002', '4242009', '4244005', '4248008', '4249000', '4251001', '4260009', '4262001', '4264000', '4269005', '4273008', '4275001', '4278004', '4283007', '4287008', '4294006', '4300009', '4301008', '4306003', '4307007', '4308002', '4310000', '4313003', '4316006', '4320005', '4324001', '4325000', '4332009', '4338008', '4340003', '4349002', '4354006', '4356008', '4359001', '4364002', '4367009', '4373005', '4374004', '4381006', '4386001', '4390004', '4397001', '4399003', '4403007', '4406004', '4409006', '4410001', '4412009', '4414005', '4416007', '4418008', '4426000', '4434006', '4439001', '4441000', '4445009', '4448006', '4451004', '4461006', '4463009', '4464003', '4465002', '4468000', '4470009', '4473006', '4477007', '4478002', '4481007', '4483005']}, 'type'=>'CodeableConcept', 'path'=>'Media.reasonCode', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/procedure-reason'}},
        'bodySite' => {'valid_codes'=>{'http://snomed.info/sct'=>['106004', '107008', '108003', '110001', '111002', '116007', '124002', '149003', '155008', '167005', '202009', '205006', '206007', '221001', '227002', '233006', '235004', '246001', '247005', '251007', '256002', '263002', '266005', '272005', '273000', '283001', '284007', '289002', '301000', '311007', '315003', '318001', '344001', '345000', '356000', '393006', '402006', '405008', '414003', '420002', '422005', '446003', '457008', '461002', '464005', '465006', '471000', '480000', '485005', '528006', '552004', '565008', '582005', '587004', '589001', '595000', '608002', '621009', '635006', '650002', '660006', '661005', '667009', '688000', '691000', '692007', '723004', '774007', '790007', '798000', '808000', '809008', '823005', '830004', '836005', '885000', '895007', '917004', '921006', '947002', '955009', '976004', '996007', '1005009', '1012000', '1015003', '1028005', '1030007', '1063000', '1075005', '1076006', '1086007', '1087003', '1092001', '1099005', '1101003', '1106008', '1110006', '1122009', '1136004', '1159005', '1172006', '1173001', '1174007', '1193009', '1216008', '1231004', '1236009', '1243003', '1246006', '1263005', '1277008', '1307006', '1311000', '1350001', '1353004', '1403006', '1425000', '1439000', '1441004', '1456008', '1467009', '1484003', '1490004', '1502004', '1511004', '1516009', '1527006', '1537001', '1541002', '1562001', '1569005', '1580005', '1581009', '1584001', '1600003', '1605008', '1610007', '1611006', '1617005', '1620002', '1626008', '1627004', '1630006', '1631005', '1650005', '1655000', '1659006', '1684009', '1706004', '1707008', '1711002', '1716007', '1721005', '1729007', '1732005', '1765002', '1780008', '1781007', '1797002', '1818002', '1825009', '1832000', '1840006', '1849007', '1853009', '1874005', '1893007', '1895000', '1902009', '1910005', '1918003', '1927002', '1992003', '1997009', '2010005', '2020000', '2031008', '2033006', '2044003', '2048000', '2049008', '2059009', '2071003', '2076008', '2083001', '2095001', '2123001', '2150006', '2156000', '2160002', '2175005', '2182009', '2192001', '2205003', '2209009', '2236006', '2246008', '2255006', '2285001', '2292006', '2302002', '2305000', '2306004', '2327009', '2330002', '2332005', '2334006', '2349003', '2372001', '2383005', '2389009', '2395005', '2397002', '2400006', '2402003', '2421006', '2433001', '2436009', '2453002', '2454008', '2484000', '2489005', '2499000', '2502001', '2504000', '2510000', '2539000', '2543001', '2550002', '2577006', '2579009', '2592007', '2600000', '2620004', '2639009', '2653009', '2666009', '2672009', '2675006', '2681003', '2682005', '2686008', '2687004', '2695000', '2703009', '2712006', '2718005', '2726002', '2730004', '2739003', '2741002', '2746007', '2748008', '2759004', '2771005', '2789006', '2792005', '2803000', '2810006', '2812003', '2824005', '2826007', '2830005', '2839006', '2841007', '2845003', '2848001', '2855004', '2861001', '2894003', '2905008', '2909002', '2920002', '2922005', '2923000', '2954001', '2969000', '2979003', '2986006', '2998001', '3003007', '3008003', '3028004', '3039001', '3042007', '3054007', '3055008', '3056009', '3057000', '3058005', '3062004', '3068000', '3081007', '3093003', '3100007', '3113001', '3117000', '3118005', '3120008', '3134008', '3138006', '3153003', '3156006', '3159004', '3169005', '3178004', '3194006', '3198009', '3215002', '3222005', '3227004', '3236000', '3243006', '3255000', '3262009', '3279003', '3295003', '3301002', '3302009', '3315000', '3332001', '3336003', '3341006', '3350008', '3362007', '3366005', '3370002', '3374006', '3377004', '3382006', '3383001', '3394002', '3395001', '3396000', '3400000', '3409004', '3417007', '3438001', '3444002', '3447009', '3460003', '3462006', '3471002', '3478008', '3481003', '3488009', '3490005', '3524005', '3538003', '3541007', '3553006', '3556003', '3563003', '3572006', '3578005', '3582007', '3584008', '3594003', '3608004', '3609007', '3646006', '3663005', '3665003', '3670005', '3711007', '3743007', '3761003', '3766008', '3785006', '3788008', '3789000', '3810000', '3838008', '3860006', '3865001', '3867009', '3876002', '3877006', '3910004', '3916005', '3924000', '3931001', '3935005', '3937002', '3954005', '3956007', '3959000', '3960005', '3964001', '3966004', '3977005', '3984002', '3989007', '4015004', '4019005', '4029003', '4061004', '4066009', '4072009', '4081003', '4093007', '4111006', '4117005', '4121003', '4146003', '4148002', '4150005', '4158003', '4159006', '4180000', '4193005', '4205002', '4212006', '4215008', '4247003', '4258007', '4268002', '4276000', '4281009', '4295007', '4303006', '4312008', '4317002', '4328003', '4335006', '4352005', '4358009', '4360006', '4369007', '4371007', '4375003', '4377006', '4394008', '4402002', '4419000', '4421005', '4430002', '4432005', '4442007', '4486002', '4524000', '4527007', '4537002', '4548009', '4549001', '4566004', '4573009', '4578000', '4583008', '4588004', '4596009', '4603002', '4606005', '4621004', '4624007', '4647008', '4651005', '4658004', '4677002', '4703008', '4717004', '4718009', '4743003', '4755009', '4759003', '4766002', '4768001', '4774001', '4775000', '4799000', '4810005', '4812002', '4828007', '4840007', '4843009', '4861000', '4866005', '4870002', '4871003', '4881004', '4888005', '4897009', '4905007', '4906008', '4924005', '4942000', '4954000', '4956003', '4958002', '5001007', '5023006', '5026003', '5046008', '5068003', '5069006', '5076001', '5115006', '5122003', '5128004', '5140004', '5192008', '5194009', '5195005', '5204005', '5213007', '5225005', '5228007', '5229004', '5261000', '5272005', '5279001', '5296000', '5324007', '5329002', '5336001', '5347008', '5362005', '5366008', '5379004', '5382009', '5394000', '5398002', '5403001', '5421003', '5427004', '5458003', '5459006', '5491007', '5493005', '5498001', '5501001', '5520004', '5538001', '5542003', '5544002', '5560003', '5564007', '5574005', '5580002', '5597008', '5611001', '5625000', '5627008', '5633004', '5643001', '5644007', '5653000', '5665001', '5668004', '5677006', '5682004', '5696005', '5697001', '5709001', '5713008', '5717009', '5718004', '5727003', '5742000', '5751008', '5769004', '5780004', '5798000', '5802004', '5814007', '5815008', '5816009', '5825003', '5828001', '5847003', '5854009', '5868002', '5872003', '5881009', '5882002', '5889006', '5890002', '5893000', '5898009', '5923009', '5926001', '5928000', '5942008', '5943003', '5944009', '5948007', '5951000', '5953002', '5976004', '5979006', '5996007', '6001004', '6004007', '6006009', '6009002', '6013009', '6014003', '6023000', '6032003', '6046003', '6050005', '6059006', '6062009', '6073002', '6074008', '6076005', '6104005', '6105006', '6110005', '6194002', '6216007', '6217003', '6229007', '6253001', '6268000', '6269008', '6279005', '6317000', '6325003', '6326002', '6335009', '6359004', '6371005', '6375001', '6392005', '6404004', '6413002', '6417001', '6423006', '6424000', '6445007', '6448009', '6450001', '6472004', '6504002', '6511003', '6530003', '6533001', '6538005', '6541001', '6544009', '6550004', '6551000', '6553002', '6564004', '6566002', '6572002', '6598008', '6606008', '6608009', '6620001', '6623004', '6633007', '6643005', '6646002', '6649009', '6651008', '6684008', '6685009', '6711001', '6720005', '6731002', '6739000', '6742006', '6750002', '6757004', '6787005', '6789008', '6799003', '6805009', '6820003', '6828005', '6829002', '6834003', '6841009', '6844001', '6850006', '6864006', '6866008', '6871001', '6894000', '6902008', '6905005', '6912001', '6914000', '6921000', '6930008', '6944002', '6969002', '6975006', '6981003', '6987004', '6989001', '6991009', '7035006', '7050002', '7067009', '7076002', '7083009', '7090004', '7091000', '7099003', '7117004', '7121006', '7148007', '7149004', '7154008', '7160008', '7167006', '7173007', '7188002', '7192009', '7227003', '7234001', '7242000', '7275008', '7295002', '7296001', '7311008', '7344002', '7345001', '7347009', '7362006', '7376007', '7378008', '7384006', '7404008', '7435002', '7471001', '7477002', '7480001', '7494000', '7498002', '7507003', '7524009', '7532001', '7554004', '7566005', '7569003', '7591005', '7597009', '7605000', '7610001', '7629007', '7651004', '7652006', '7657000', '7658005', '7697002', '7712004', '7726008', '7736000', '7742001', '7748002', '7755000', '7756004', '7764005', '7769000', '7783003', '7820009', '7829005', '7832008', '7835005', '7840002', '7841003', '7844006', '7851002', '7854005', '7872004', '7874003', '7880006', '7884002', '7885001', '7892006', '7896009', '7911004', '7925003', '7936005', '7944005', '7954009', '7967007', '7986004', '7991003', '7999001', '8001006', '8012006', '8017000', '8024004', '8039003', '8040001', '8045006', '8057002', '8059004', '8067007', '8068002', '8079007', '8091003', '8100009', '8111001', '8112008', '8119004', '8128003', '8133004', '8157004', '8158009', '8159001', '8160006', '8161005', '8165001', '8205005', '8225009', '8242003', '8251006', '8264007', '8265008', '8266009', '8279000', '8289001', '8292002', '8314003', '8334002', '8356004', '8361002', '8369000', '8373002', '8387002', '8389004', '8412003', '8415001', '8454000', '8464009', '8482007', '8483002', '8496001', '8523001', '8546004', '8556000', '8559007', '8560002', '8568009', '8580001', '8595004', '8598002', '8600008', '8603005', '8604004', '8608001', '8617001', '8623006', '8629005', '8640002', '8668003', '8671006', '8677005', '8688004', '8695008', '8710005', '8711009', '8714001', '8752000', '8770002', '8775007', '8784007', '8810002', '8814006', '8815007', '8820007', '8821006', '8827005', '8839002', '8845005', '8850004', '8854008', '8862000', '8873007', '8887007', '8892009', '8894005', '8897003', '8907008', '8910001', '8911002', '8928004', '8931003', '8935007', '8942007', '8965002', '8966001', '8983005', '8988001', '8993003', '9000002', '9003000', '9018004', '9040008', '9055004', '9073001', '9081000', '9086005', '9089003', '9108007', '9127001', '9156001', '9181003', '9185007', '9186008', '9188009', '9208002', '9212008', '9229006', '9231002', '9240003', '9242006', '9258009', '9261005', '9262003', '9284003', '9290004', '9305001', '9317004', '9320007', '9321006', '9325002', '9332006', '9348007', '9379006', '9380009', '9384000', '9390001', '9432007', '9438006', '9454009', '9455005', '9475001', '9481009', '9490002', '9498009', '9502002', '9512009', '9535007', '9558005', '9566001', '9568000', '9596006', '9609000', '9625005', '9642004', '9646001', '9654004', '9659009', '9662007', '9668006', '9677004', '9683001', '9684007', '9708001', '9732008', '9736006', '9743000', '9758008', '9770007', '9775002', '9779008', '9783008', '9791004', '9796009', '9813009', '9825007', '9837009', '9840009', '9841008', '9846003', '9847007', '9849005', '9870004', '9875009', '9878006', '9880000', '9881001', '9891007', '9898001', '9951005', '9968009', '9970000', '9976006', '9994000', '9999005', '10013000', '10024003', '10025002', '10026001', '10036009', '10042008', '10047002', '10052007', '10056005', '10062000', '10119003', '10124000']}, 'type'=>'CodeableConcept', 'path'=>'Media.bodySite', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/body-site'}},
        'device' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Device', 'http://hl7.org/fhir/StructureDefinition/DeviceMetric'], 'type'=>'Reference', 'path'=>'Media.device', 'min'=>0, 'max'=>1},
        'height' => {'type'=>'positiveInt', 'path'=>'Media.height', 'min'=>0, 'max'=>1},
        'width' => {'type'=>'positiveInt', 'path'=>'Media.width', 'min'=>0, 'max'=>1},
        'frames' => {'type'=>'positiveInt', 'path'=>'Media.frames', 'min'=>0, 'max'=>1},
        'duration' => {'type'=>'unsignedInt', 'path'=>'Media.duration', 'min'=>0, 'max'=>1},
        'content' => {'type'=>'Attachment', 'path'=>'Media.content', 'min'=>1, 'max'=>1},
        'note' => {'type'=>'Annotation', 'path'=>'Media.note', 'min'=>0, 'max'=>Float::INFINITY}
      }

      attr_accessor :id                 # 0-1 id
      attr_accessor :meta               # 0-1 Meta
      attr_accessor :implicitRules      # 0-1 uri
      attr_accessor :language           # 0-1 code
      attr_accessor :text               # 0-1 Narrative
      attr_accessor :contained          # 0-* [ Resource ]
      attr_accessor :extension          # 0-* [ Extension ]
      attr_accessor :modifierExtension  # 0-* [ Extension ]
      attr_accessor :identifier         # 0-* [ Identifier ]
      attr_accessor :basedOn            # 0-* [ Reference(ProcedureRequest) ]
      attr_accessor :type               # 1-1 code
      attr_accessor :subtype            # 0-1 CodeableConcept
      attr_accessor :view               # 0-1 CodeableConcept
      attr_accessor :subject            # 0-1 Reference(Patient|Practitioner|Group|Device|Specimen)
      attr_accessor :context            # 0-1 Reference(Encounter|EpisodeOfCare)
      attr_accessor :occurrenceDateTime # 0-1 dateTime
      attr_accessor :occurrencePeriod   # 0-1 Period
      attr_accessor :operator           # 0-1 Reference(Practitioner)
      attr_accessor :reasonCode         # 0-* [ CodeableConcept ]
      attr_accessor :bodySite           # 0-1 CodeableConcept
      attr_accessor :device             # 0-1 Reference(Device|DeviceMetric)
      attr_accessor :height             # 0-1 positiveInt
      attr_accessor :width              # 0-1 positiveInt
      attr_accessor :frames             # 0-1 positiveInt
      attr_accessor :duration           # 0-1 unsignedInt
      attr_accessor :content            # 1-1 Attachment
      attr_accessor :note               # 0-* [ Annotation ]

      def resourceType
        'Media'
      end
    end
  end
end