module FHIR
  module STU3
    class Observation < FHIR::STU3::Model
      include FHIR::STU3::Hashable
      include FHIR::STU3::Json
      include FHIR::STU3::Xml

      MULTIPLE_TYPES = {
        'effective' => ['dateTime', 'Period'],
        'value' => ['Quantity', 'CodeableConcept', 'string', 'boolean', 'Range', 'Ratio', 'SampledData', 'Attachment', 'time', 'dateTime', 'Period']
      }
      SEARCH_PARAMS = ['code', 'date', 'identifier', 'patient', 'encounter', 'based-on', 'category', 'combo-code', 'combo-data-absent-reason', 'combo-value-concept', 'combo-value-quantity', 'component-code', 'component-data-absent-reason', 'component-value-concept', 'component-value-quantity', 'context', 'data-absent-reason', 'device', 'method', 'performer', 'related-target', 'related-type', 'specimen', 'status', 'subject', 'value-concept', 'value-date', 'value-quantity', 'value-string']
      METADATA = {
        'id' => {'type'=>'id', 'path'=>'Observation.id', 'min'=>0, 'max'=>1},
        'meta' => {'type'=>'Meta', 'path'=>'Observation.meta', 'min'=>0, 'max'=>1},
        'implicitRules' => {'type'=>'uri', 'path'=>'Observation.implicitRules', 'min'=>0, 'max'=>1},
        'language' => {'valid_codes'=>{'urn:ietf:bcp:47'=>['ar', 'bn', 'cs', 'da', 'de', 'de-AT', 'de-CH', 'de-DE', 'el', 'en', 'en-AU', 'en-CA', 'en-GB', 'en-IN', 'en-NZ', 'en-SG', 'en-US', 'es', 'es-AR', 'es-ES', 'es-UY', 'fi', 'fr', 'fr-BE', 'fr-CH', 'fr-FR', 'fy', 'fy-NL', 'hi', 'hr', 'it', 'it-CH', 'it-IT', 'ja', 'ko', 'nl', 'nl-BE', 'nl-NL', 'no', 'no-NO', 'pa', 'pt', 'pt-BR', 'ru', 'ru-RU', 'sr', 'sr-SP', 'sv', 'sv-SE', 'te', 'zh', 'zh-CN', 'zh-HK', 'zh-SG', 'zh-TW']}, 'type'=>'code', 'path'=>'Observation.language', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'extensible', 'uri'=>'http://hl7.org/fhir/ValueSet/languages'}},
        'text' => {'type'=>'Narrative', 'path'=>'Observation.text', 'min'=>0, 'max'=>1},
        'contained' => {'type'=>'Resource', 'path'=>'Observation.contained', 'min'=>0, 'max'=>Float::INFINITY},
        'extension' => {'type'=>'Extension', 'path'=>'Observation.extension', 'min'=>0, 'max'=>Float::INFINITY},
        'modifierExtension' => {'type'=>'Extension', 'path'=>'Observation.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
        'identifier' => {'type'=>'Identifier', 'path'=>'Observation.identifier', 'min'=>0, 'max'=>Float::INFINITY},
        'basedOn' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/CarePlan', 'http://hl7.org/fhir/StructureDefinition/DeviceRequest', 'http://hl7.org/fhir/StructureDefinition/ImmunizationRecommendation', 'http://hl7.org/fhir/StructureDefinition/MedicationRequest', 'http://hl7.org/fhir/StructureDefinition/NutritionOrder', 'http://hl7.org/fhir/StructureDefinition/ProcedureRequest', 'http://hl7.org/fhir/StructureDefinition/ReferralRequest'], 'type'=>'Reference', 'path'=>'Observation.basedOn', 'min'=>0, 'max'=>Float::INFINITY},
        'status' => {'valid_codes'=>{'http://hl7.org/fhir/observation-status'=>['registered', 'preliminary', 'final', 'amended', 'corrected', 'cancelled', 'entered-in-error', 'unknown']}, 'type'=>'code', 'path'=>'Observation.status', 'min'=>1, 'max'=>1, 'binding'=>{'strength'=>'required', 'uri'=>'http://hl7.org/fhir/ValueSet/observation-status'}},
        'category' => {'valid_codes'=>{'http://hl7.org/fhir/observation-category'=>['social-history', 'vital-signs', 'imaging', 'laboratory', 'procedure', 'survey', 'exam', 'therapy']}, 'type'=>'CodeableConcept', 'path'=>'Observation.category', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'preferred', 'uri'=>'http://hl7.org/fhir/ValueSet/observation-category'}},
        'code' => {'valid_codes'=>{'http://loinc.org'=>['1-8', '10-9', '100-8', '1000-9', '10000-8', '10001-6', '10002-4', '10003-2', '10004-0', '10005-7', '10006-5', '10007-3', '10008-1', '10009-9', '1001-7', '10010-7', '10011-5', '10012-3', '10013-1', '10014-9', '10015-6', '10016-4', '10017-2', '10018-0', '10019-8', '1002-5', '10020-6', '10021-4', '10022-2', '10023-0', '10024-8', '10025-5', '10026-3', '10027-1', '10028-9', '10029-7', '1003-3', '10030-5', '10031-3', '10032-1', '10033-9', '10034-7', '10035-4', '10036-2', '10037-0', '10038-8', '10039-6', '1004-1', '10040-4', '10041-2', '10042-0', '10043-8', '10044-6', '10045-3', '10046-1', '10047-9', '10048-7', '10049-5', '1005-8', '10050-3', '10051-1', '10052-9', '10053-7', '10054-5', '10055-2', '10056-0', '10057-8', '10058-6', '10059-4', '1006-6', '10060-2', '10061-0', '10062-8', '10063-6', '10064-4', '10065-1', '10066-9', '10067-7', '10068-5', '10069-3', '1007-4', '10070-1', '10071-9', '10072-7', '10073-5', '10074-3', '10075-0', '10076-8', '10077-6', '10078-4', '10079-2', '1008-2', '10080-0', '10081-8', '10082-6', '10083-4', '10084-2', '10085-9', '10086-7', '10087-5', '10088-3', '10089-1', '1009-0', '10090-9', '10091-7', '10092-5', '10093-3', '10094-1', '10095-8', '10096-6', '10097-4', '10098-2', '10099-0', '101-6', '1010-8', '10100-6', '10101-4', '10102-2', '10103-0', '10104-8', '10105-5', '10106-3', '10107-1', '10108-9', '10109-7', '1011-6', '10110-5', '10111-3', '10112-1', '10113-9', '10114-7', '10115-4', '10116-2', '10117-0', '10118-8', '10119-6', '1012-4', '10120-4', '10121-2', '10122-0', '10123-8', '10124-6', '10125-3', '10126-1', '10127-9', '10128-7', '10129-5', '1013-2', '10130-3', '10131-1', '10132-9', '10133-7', '10134-5', '10135-2', '10136-0', '10137-8', '10138-6', '10139-4', '1014-0', '10140-2', '10141-0', '10142-8', '10143-6', '10144-4', '10145-1', '10146-9', '10147-7', '10148-5', '10149-3', '1015-7', '10150-1', '10151-9', '10152-7', '10153-5', '10154-3', '10155-0', '10156-8', '10157-6', '10158-4', '10159-2', '1016-5', '10160-0', '10161-8', '10162-6', '10163-4', '10164-2', '10165-9', '10166-7', '10167-5', '10168-3', '10169-1', '1017-3', '10170-9', '10171-7', '10172-5', '10173-3', '10174-1', '10175-8', '10176-6', '10177-4', '10178-2', '10179-0', '1018-1', '10180-8', '10181-6', '10182-4', '10183-2', '10184-0', '10185-7', '10186-5', '10187-3', '10188-1', '10189-9', '1019-9', '10190-7', '10191-5', '10192-3', '10193-1', '10194-9', '10195-6', '10196-4', '10197-2', '10198-0', '10199-8', '102-4', '1020-7', '10200-4', '10201-2', '10202-0', '10203-8', '10204-6', '10205-3', '10206-1', '10207-9', '10208-7', '10209-5', '1021-5', '10210-3', '10211-1', '10212-9', '10213-7', '10214-5', '10215-2', '10216-0', '10217-8', '10218-6', '10219-4', '1022-3', '10220-2', '10221-0', '10222-8', '10223-6', '10224-4', '10225-1', '10226-9', '10227-7', '10228-5', '10229-3', '1023-1', '10230-1', '10231-9', '10232-7', '10233-5', '10234-3', '10235-0', '10236-8', '10237-6', '10238-4', '10239-2', '1024-9', '10240-0', '10241-8', '10242-6', '10243-4', '10244-2', '10245-9', '10246-7', '10247-5', '10248-3', '10249-1', '1025-6', '10250-9', '10251-7', '10252-5', '10253-3', '10254-1', '10255-8', '10256-6', '10257-4', '10258-2', '10259-0', '1026-4', '10260-8', '10261-6', '10262-4', '10263-2', '10264-0', '10265-7', '10266-5', '10267-3', '10268-1', '10269-9', '1027-2', '10270-7', '10271-5', '10272-3', '10273-1', '10274-9', '10275-6', '10276-4', '10277-2', '10278-0', '10279-8', '1028-0', '10280-6', '10281-4', '10282-2', '10283-0', '10284-8', '10285-5', '10286-3', '10287-1', '10288-9', '10289-7', '1029-8', '10290-5', '10291-3', '10292-1', '10293-9', '10294-7', '10295-4', '10296-2', '10297-0', '10298-8', '10299-6', '103-2', '1030-6', '10300-2', '10301-0', '10302-8', '10303-6', '10304-4', '10305-1', '10306-9', '10307-7', '10308-5', '10309-3', '1031-4', '10310-1', '10311-9', '10312-7', '10313-5', '10314-3', '10315-0', '10316-8', '10317-6', '10318-4', '10319-2', '1032-2', '10320-0', '10321-8', '10322-6', '10323-4', '10324-2', '10325-9', '10326-7', '10327-5', '10328-3', '10329-1', '1033-0', '10330-9', '10331-7', '10332-5', '10333-3', '10334-1', '10335-8', '10336-6', '10337-4', '10338-2', '10339-0', '1034-8', '10340-8', '10341-6', '10342-4', '10343-2', '10344-0', '10345-7', '10346-5', '10347-3', '10348-1', '10349-9', '1035-5', '10350-7', '10351-5', '10352-3', '10353-1', '10354-9', '10355-6', '10356-4', '10357-2', '10358-0', '10359-8', '1036-3', '10360-6', '10361-4', '10362-2', '10363-0', '10364-8', '10365-5', '10366-3', '10367-1', '10368-9', '10369-7', '1037-1', '10370-5', '10371-3', '10372-1', '10373-9', '10374-7', '10375-4', '10376-2', '10377-0', '10378-8', '10379-6', '1038-9', '10380-4', '10381-2', '10382-0', '10383-8', '10384-6', '10385-3', '10386-1', '10387-9', '10388-7', '10389-5', '1039-7', '10390-3', '10391-1', '10392-9', '10393-7', '10394-5', '10395-2', '10396-0', '10397-8', '10398-6', '10399-4', '104-0', '1040-5', '10400-0', '10401-8', '10402-6', '10403-4', '10404-2', '10405-9', '10406-7', '10407-5', '10408-3', '10409-1', '1041-3', '10410-9', '10411-7', '10412-5', '10413-3', '10414-1', '10415-8', '10416-6', '10417-4', '10418-2', '10419-0', '1042-1', '10420-8', '10421-6', '10422-4', '10423-2', '10424-0', '10425-7', '10426-5', '10427-3', '10428-1', '10429-9', '1043-9', '10430-7', '10431-5', '10432-3', '10433-1', '10434-9', '10435-6', '10436-4', '10437-2', '10438-0', '10439-8', '1044-7', '10440-6', '10441-4', '10442-2', '10443-0', '10444-8', '10445-5', '10446-3', '10447-1', '10448-9', '10449-7', '1045-4', '10450-5', '10451-3', '10452-1', '10453-9', '10454-7', '10455-4', '10456-2', '10457-0', '10458-8', '10459-6', '1046-2', '10460-4', '10461-2', '10462-0', '10463-8', '10464-6', '10465-3', '10466-1', '10467-9', '10468-7', '10469-5', '1047-0', '10470-3', '10471-1', '10472-9', '10473-7', '10474-5', '10475-2', '10476-0', '10477-8', '10478-6', '10479-4', '1048-8', '10480-2', '10481-0', '10482-8', '10483-6', '10484-4', '10485-1', '10486-9', '10487-7', '10488-5', '10489-3', '1049-6', '10490-1', '10491-9', '10492-7', '10493-5', '10494-3', '10495-0', '10496-8', '10497-6', '10498-4', '10499-2', '105-7', '1050-4', '10500-7', '10501-5', '10502-3', '10503-1', '10504-9', '10505-6', '10506-4', '10507-2', '10508-0', '10509-8', '1051-2', '10510-6', '10511-4', '10512-2', '10513-0', '10514-8', '10515-5', '10516-3', '10517-1', '10518-9', '10519-7', '1052-0', '10520-5', '10521-3', '10522-1', '10523-9', '10524-7', '10525-4', '10526-2', '10527-0', '10528-8', '10529-6', '1053-8', '10530-4', '10531-2', '10532-0', '10533-8', '10534-6', '10535-3', '10536-1', '10537-9', '10538-7', '10539-5', '1054-6', '10540-3', '10541-1', '10542-9', '10543-7', '10544-5', '10545-2', '10546-0', '10547-8', '10548-6', '10549-4', '1055-3', '10550-2', '10551-0', '10552-8', '10553-6', '10554-4', '10555-1', '10556-9', '10557-7', '10558-5', '10559-3', '1056-1', '10560-1', '10561-9', '10562-7', '10563-5', '10564-3', '10565-0', '10566-8', '10567-6', '10568-4', '10569-2', '1057-9', '10570-0', '10571-8', '10572-6', '10573-4', '10574-2', '10575-9', '10576-7', '10577-5', '10578-3', '10579-1', '1058-7', '10580-9', '10581-7', '10582-5', '10583-3', '10584-1', '10585-8', '10586-6', '10587-4', '10588-2', '10589-0', '1059-5', '10590-8', '10591-6', '10592-4', '10593-2', '10594-0', '10595-7', '10596-5', '10597-3', '10598-1', '10599-9', '106-5', '1060-3', '10600-5', '10601-3', '10602-1', '10603-9', '10604-7', '10605-4', '10606-2', '10607-0', '10608-8', '10609-6', '1061-1', '10610-4', '10611-2', '10612-0', '10613-8', '10614-6', '10615-3', '10616-1', '10617-9', '10618-7', '10619-5', '1062-9', '10620-3', '10621-1', '10622-9', '10623-7', '10624-5', '10625-2', '10626-0', '10627-8', '10628-6', '10629-4', '1063-7', '10630-2', '10631-0', '10632-8', '10633-6', '10634-4', '10635-1', '10636-9', '10637-7', '10638-5', '10639-3', '1064-5', '10640-1', '10641-9', '10642-7', '10643-5', '10644-3', '10645-0', '10646-8', '10647-6', '10648-4', '10649-2', '1065-2', '10650-0', '10651-8', '10652-6', '10653-4', '10654-2', '10655-9', '10656-7', '10657-5', '10658-3', '10659-1', '1066-0', '10660-9', '10661-7', '10662-5', '10663-3', '10664-1', '10665-8', '10666-6', '10667-4', '10668-2', '10669-0', '1067-8', '10670-8', '10671-6', '10672-4', '10673-2', '10674-0', '10675-7', '10676-5', '10677-3', '10678-1', '10679-9', '1068-6', '10680-7', '10681-5', '10682-3', '10683-1', '10684-9', '10685-6', '10686-4', '10687-2', '10688-0', '10689-8', '1069-4', '10690-6', '10691-4', '10692-2', '10693-0', '10694-8', '10695-5', '10696-3', '10697-1', '10698-9', '10699-7', '107-3', '1070-2', '10700-3', '10701-1', '10702-9', '10703-7', '10704-5', '10705-2', '10706-0', '10707-8', '10708-6', '10709-4', '1071-0', '10710-2', '10711-0', '10712-8', '10713-6', '10714-4', '10715-1', '10716-9', '10717-7', '10718-5', '10719-3', '1072-8', '10720-1', '10721-9', '10722-7', '10723-5', '10724-3', '10725-0', '10726-8', '10727-6', '10728-4', '10729-2', '1073-6', '10730-0', '10731-8', '10732-6', '10733-4', '10734-2', '10735-9', '10736-7', '10737-5', '10738-3', '10739-1', '1074-4', '10740-9', '10741-7', '10742-5', '10743-3', '10744-1', '10745-8', '10746-6', '10747-4', '10748-2', '10749-0', '1075-1', '10750-8', '10751-6', '10752-4', '10753-2', '10754-0', '10755-7', '10756-5', '10757-3', '10758-1', '10759-9', '1076-9', '10760-7', '10761-5', '10762-3', '10763-1', '10764-9', '10765-6', '10766-4', '10767-2', '10768-0', '10769-8', '1077-7', '10770-6', '10771-4', '10772-2', '10773-0', '10774-8', '10775-5', '10776-3', '10777-1', '10778-9', '10779-7', '1078-5', '10780-5', '10781-3', '10782-1', '10783-9', '10784-7', '10785-4', '10786-2', '10787-0', '10788-8', '10789-6', '1079-3', '10790-4', '10791-2', '10792-0', '10793-8', '10794-6', '10795-3', '10796-1', '10797-9', '10798-7', '10799-5', '108-1', '1080-1', '10800-1', '10801-9', '10802-7', '10803-5', '10804-3', '10805-0', '10806-8', '10807-6', '10808-4', '10809-2', '1081-9', '10810-0', '10811-8', '10812-6', '10813-4', '10814-2', '10815-9', '10816-7', '10817-5', '10818-3', '10819-1', '1082-7', '10820-9', '10821-7', '10822-5', '10823-3', '10824-1', '10825-8', '10826-6', '10827-4', '10828-2', '10829-0', '1083-5', '10830-8', '10831-6', '10832-4', '10833-2', '10834-0', '10835-7', '10836-5', '10837-3', '10838-1', '10839-9', '1084-3', '10840-7', '10841-5', '10842-3', '10843-1', '10844-9', '10845-6', '10846-4', '10847-2', '10848-0', '10849-8', '1085-0', '10850-6', '10851-4', '10852-2', '10853-0', '10854-8', '10855-5', '10856-3', '10857-1', '10858-9', '10859-7', '1086-8', '10860-5', '10861-3', '10862-1', '10863-9', '10864-7', '10865-4', '10866-2', '10867-0', '10868-8', '10869-6', '1087-6', '10870-4', '10871-2', '10872-0', '10873-8', '10874-6', '10875-3', '10876-1', '10877-9', '10878-7', '10879-5', '1088-4', '10880-3', '10881-1', '10882-9', '10883-7', '10884-5', '10885-2', '10886-0', '10887-8', '10888-6', '10889-4', '1089-2', '10890-2', '10891-0', '10892-8', '10893-6', '10894-4', '10895-1', '10896-9', '10897-7', '10898-5']}, 'type'=>'CodeableConcept', 'path'=>'Observation.code', 'min'=>1, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/observation-codes'}},
        'subject' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Patient', 'http://hl7.org/fhir/StructureDefinition/Group', 'http://hl7.org/fhir/StructureDefinition/Device', 'http://hl7.org/fhir/StructureDefinition/Location'], 'type'=>'Reference', 'path'=>'Observation.subject', 'min'=>0, 'max'=>1},
        'context' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Encounter', 'http://hl7.org/fhir/StructureDefinition/EpisodeOfCare'], 'type'=>'Reference', 'path'=>'Observation.context', 'min'=>0, 'max'=>1},
        'effectiveDateTime' => {'type'=>'dateTime', 'path'=>'Observation.effective[x]', 'min'=>0, 'max'=>1},
        'effectivePeriod' => {'type'=>'Period', 'path'=>'Observation.effective[x]', 'min'=>0, 'max'=>1},
        'issued' => {'type'=>'instant', 'path'=>'Observation.issued', 'min'=>0, 'max'=>1},
        'performer' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Practitioner', 'http://hl7.org/fhir/StructureDefinition/Organization', 'http://hl7.org/fhir/StructureDefinition/Patient', 'http://hl7.org/fhir/StructureDefinition/RelatedPerson'], 'type'=>'Reference', 'path'=>'Observation.performer', 'min'=>0, 'max'=>Float::INFINITY},
        'valueQuantity' => {'type'=>'Quantity', 'path'=>'Observation.value[x]', 'min'=>0, 'max'=>1},
        'valueCodeableConcept' => {'type'=>'CodeableConcept', 'path'=>'Observation.value[x]', 'min'=>0, 'max'=>1},
        'valueString' => {'type'=>'string', 'path'=>'Observation.value[x]', 'min'=>0, 'max'=>1},
        'valueBoolean' => {'type'=>'boolean', 'path'=>'Observation.value[x]', 'min'=>0, 'max'=>1},
        'valueRange' => {'type'=>'Range', 'path'=>'Observation.value[x]', 'min'=>0, 'max'=>1},
        'valueRatio' => {'type'=>'Ratio', 'path'=>'Observation.value[x]', 'min'=>0, 'max'=>1},
        'valueSampledData' => {'type'=>'SampledData', 'path'=>'Observation.value[x]', 'min'=>0, 'max'=>1},
        'valueAttachment' => {'type'=>'Attachment', 'path'=>'Observation.value[x]', 'min'=>0, 'max'=>1},
        'valueTime' => {'type'=>'time', 'path'=>'Observation.value[x]', 'min'=>0, 'max'=>1},
        'valueDateTime' => {'type'=>'dateTime', 'path'=>'Observation.value[x]', 'min'=>0, 'max'=>1},
        'valuePeriod' => {'type'=>'Period', 'path'=>'Observation.value[x]', 'min'=>0, 'max'=>1},
        'dataAbsentReason' => {'valid_codes'=>{'http://hl7.org/fhir/data-absent-reason'=>['unknown', 'asked', 'temp', 'not-asked', 'masked', 'unsupported', 'astext', 'error', 'NaN', 'not-performed']}, 'type'=>'CodeableConcept', 'path'=>'Observation.dataAbsentReason', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'extensible', 'uri'=>'http://hl7.org/fhir/ValueSet/observation-valueabsentreason'}},
        'interpretation' => {'valid_codes'=>{'http://hl7.org/fhir/v2/0078'=>['<', '>', 'A', 'AA', 'AC', 'B', 'D', 'DET', 'H', 'HH', 'HM', 'HU', 'I', 'IE', 'IND', 'L', 'LL', 'LU', 'MS', 'N', 'ND', 'NEG', 'NR', 'NS', 'null', 'OBX', 'POS', 'QCF', 'R', 'RR', 'S', 'SDD', 'SYN-R', 'SYN-S', 'TOX', 'U', 'VS', 'W', 'WR']}, 'type'=>'CodeableConcept', 'path'=>'Observation.interpretation', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'extensible', 'uri'=>'http://hl7.org/fhir/ValueSet/observation-interpretation'}},
        'comment' => {'type'=>'string', 'path'=>'Observation.comment', 'min'=>0, 'max'=>1},
        'bodySite' => {'valid_codes'=>{'http://snomed.info/sct'=>['106004', '107008', '108003', '110001', '111002', '116007', '124002', '149003', '155008', '167005', '202009', '205006', '206007', '221001', '227002', '233006', '235004', '246001', '247005', '251007', '256002', '263002', '266005', '272005', '273000', '283001', '284007', '289002', '301000', '311007', '315003', '318001', '344001', '345000', '356000', '393006', '402006', '405008', '414003', '420002', '422005', '446003', '457008', '461002', '464005', '465006', '471000', '480000', '485005', '528006', '552004', '565008', '582005', '587004', '589001', '595000', '608002', '621009', '635006', '650002', '660006', '661005', '667009', '688000', '691000', '692007', '723004', '774007', '790007', '798000', '808000', '809008', '823005', '830004', '836005', '885000', '895007', '917004', '921006', '947002', '955009', '976004', '996007', '1005009', '1012000', '1015003', '1028005', '1030007', '1063000', '1075005', '1076006', '1086007', '1087003', '1092001', '1099005', '1101003', '1106008', '1110006', '1122009', '1136004', '1159005', '1172006', '1173001', '1174007', '1193009', '1216008', '1231004', '1236009', '1243003', '1246006', '1263005', '1277008', '1307006', '1311000', '1350001', '1353004', '1403006', '1425000', '1439000', '1441004', '1456008', '1467009', '1484003', '1490004', '1502004', '1511004', '1516009', '1527006', '1537001', '1541002', '1562001', '1569005', '1580005', '1581009', '1584001', '1600003', '1605008', '1610007', '1611006', '1617005', '1620002', '1626008', '1627004', '1630006', '1631005', '1650005', '1655000', '1659006', '1684009', '1706004', '1707008', '1711002', '1716007', '1721005', '1729007', '1732005', '1765002', '1780008', '1781007', '1797002', '1818002', '1825009', '1832000', '1840006', '1849007', '1853009', '1874005', '1893007', '1895000', '1902009', '1910005', '1918003', '1927002', '1992003', '1997009', '2010005', '2020000', '2031008', '2033006', '2044003', '2048000', '2049008', '2059009', '2071003', '2076008', '2083001', '2095001', '2123001', '2150006', '2156000', '2160002', '2175005', '2182009', '2192001', '2205003', '2209009', '2236006', '2246008', '2255006', '2285001', '2292006', '2302002', '2305000', '2306004', '2327009', '2330002', '2332005', '2334006', '2349003', '2372001', '2383005', '2389009', '2395005', '2397002', '2400006', '2402003', '2421006', '2433001', '2436009', '2453002', '2454008', '2484000', '2489005', '2499000', '2502001', '2504000', '2510000', '2539000', '2543001', '2550002', '2577006', '2579009', '2592007', '2600000', '2620004', '2639009', '2653009', '2666009', '2672009', '2675006', '2681003', '2682005', '2686008', '2687004', '2695000', '2703009', '2712006', '2718005', '2726002', '2730004', '2739003', '2741002', '2746007', '2748008', '2759004', '2771005', '2789006', '2792005', '2803000', '2810006', '2812003', '2824005', '2826007', '2830005', '2839006', '2841007', '2845003', '2848001', '2855004', '2861001', '2894003', '2905008', '2909002', '2920002', '2922005', '2923000', '2954001', '2969000', '2979003', '2986006', '2998001', '3003007', '3008003', '3028004', '3039001', '3042007', '3054007', '3055008', '3056009', '3057000', '3058005', '3062004', '3068000', '3081007', '3093003', '3100007', '3113001', '3117000', '3118005', '3120008', '3134008', '3138006', '3153003', '3156006', '3159004', '3169005', '3178004', '3194006', '3198009', '3215002', '3222005', '3227004', '3236000', '3243006', '3255000', '3262009', '3279003', '3295003', '3301002', '3302009', '3315000', '3332001', '3336003', '3341006', '3350008', '3362007', '3366005', '3370002', '3374006', '3377004', '3382006', '3383001', '3394002', '3395001', '3396000', '3400000', '3409004', '3417007', '3438001', '3444002', '3447009', '3460003', '3462006', '3471002', '3478008', '3481003', '3488009', '3490005', '3524005', '3538003', '3541007', '3553006', '3556003', '3563003', '3572006', '3578005', '3582007', '3584008', '3594003', '3608004', '3609007', '3646006', '3663005', '3665003', '3670005', '3711007', '3743007', '3761003', '3766008', '3785006', '3788008', '3789000', '3810000', '3838008', '3860006', '3865001', '3867009', '3876002', '3877006', '3910004', '3916005', '3924000', '3931001', '3935005', '3937002', '3954005', '3956007', '3959000', '3960005', '3964001', '3966004', '3977005', '3984002', '3989007', '4015004', '4019005', '4029003', '4061004', '4066009', '4072009', '4081003', '4093007', '4111006', '4117005', '4121003', '4146003', '4148002', '4150005', '4158003', '4159006', '4180000', '4193005', '4205002', '4212006', '4215008', '4247003', '4258007', '4268002', '4276000', '4281009', '4295007', '4303006', '4312008', '4317002', '4328003', '4335006', '4352005', '4358009', '4360006', '4369007', '4371007', '4375003', '4377006', '4394008', '4402002', '4419000', '4421005', '4430002', '4432005', '4442007', '4486002', '4524000', '4527007', '4537002', '4548009', '4549001', '4566004', '4573009', '4578000', '4583008', '4588004', '4596009', '4603002', '4606005', '4621004', '4624007', '4647008', '4651005', '4658004', '4677002', '4703008', '4717004', '4718009', '4743003', '4755009', '4759003', '4766002', '4768001', '4774001', '4775000', '4799000', '4810005', '4812002', '4828007', '4840007', '4843009', '4861000', '4866005', '4870002', '4871003', '4881004', '4888005', '4897009', '4905007', '4906008', '4924005', '4942000', '4954000', '4956003', '4958002', '5001007', '5023006', '5026003', '5046008', '5068003', '5069006', '5076001', '5115006', '5122003', '5128004', '5140004', '5192008', '5194009', '5195005', '5204005', '5213007', '5225005', '5228007', '5229004', '5261000', '5272005', '5279001', '5296000', '5324007', '5329002', '5336001', '5347008', '5362005', '5366008', '5379004', '5382009', '5394000', '5398002', '5403001', '5421003', '5427004', '5458003', '5459006', '5491007', '5493005', '5498001', '5501001', '5520004', '5538001', '5542003', '5544002', '5560003', '5564007', '5574005', '5580002', '5597008', '5611001', '5625000', '5627008', '5633004', '5643001', '5644007', '5653000', '5665001', '5668004', '5677006', '5682004', '5696005', '5697001', '5709001', '5713008', '5717009', '5718004', '5727003', '5742000', '5751008', '5769004', '5780004', '5798000', '5802004', '5814007', '5815008', '5816009', '5825003', '5828001', '5847003', '5854009', '5868002', '5872003', '5881009', '5882002', '5889006', '5890002', '5893000', '5898009', '5923009', '5926001', '5928000', '5942008', '5943003', '5944009', '5948007', '5951000', '5953002', '5976004', '5979006', '5996007', '6001004', '6004007', '6006009', '6009002', '6013009', '6014003', '6023000', '6032003', '6046003', '6050005', '6059006', '6062009', '6073002', '6074008', '6076005', '6104005', '6105006', '6110005', '6194002', '6216007', '6217003', '6229007', '6253001', '6268000', '6269008', '6279005', '6317000', '6325003', '6326002', '6335009', '6359004', '6371005', '6375001', '6392005', '6404004', '6413002', '6417001', '6423006', '6424000', '6445007', '6448009', '6450001', '6472004', '6504002', '6511003', '6530003', '6533001', '6538005', '6541001', '6544009', '6550004', '6551000', '6553002', '6564004', '6566002', '6572002', '6598008', '6606008', '6608009', '6620001', '6623004', '6633007', '6643005', '6646002', '6649009', '6651008', '6684008', '6685009', '6711001', '6720005', '6731002', '6739000', '6742006', '6750002', '6757004', '6787005', '6789008', '6799003', '6805009', '6820003', '6828005', '6829002', '6834003', '6841009', '6844001', '6850006', '6864006', '6866008', '6871001', '6894000', '6902008', '6905005', '6912001', '6914000', '6921000', '6930008', '6944002', '6969002', '6975006', '6981003', '6987004', '6989001', '6991009', '7035006', '7050002', '7067009', '7076002', '7083009', '7090004', '7091000', '7099003', '7117004', '7121006', '7148007', '7149004', '7154008', '7160008', '7167006', '7173007', '7188002', '7192009', '7227003', '7234001', '7242000', '7275008', '7295002', '7296001', '7311008', '7344002', '7345001', '7347009', '7362006', '7376007', '7378008', '7384006', '7404008', '7435002', '7471001', '7477002', '7480001', '7494000', '7498002', '7507003', '7524009', '7532001', '7554004', '7566005', '7569003', '7591005', '7597009', '7605000', '7610001', '7629007', '7651004', '7652006', '7657000', '7658005', '7697002', '7712004', '7726008', '7736000', '7742001', '7748002', '7755000', '7756004', '7764005', '7769000', '7783003', '7820009', '7829005', '7832008', '7835005', '7840002', '7841003', '7844006', '7851002', '7854005', '7872004', '7874003', '7880006', '7884002', '7885001', '7892006', '7896009', '7911004', '7925003', '7936005', '7944005', '7954009', '7967007', '7986004', '7991003', '7999001', '8001006', '8012006', '8017000', '8024004', '8039003', '8040001', '8045006', '8057002', '8059004', '8067007', '8068002', '8079007', '8091003', '8100009', '8111001', '8112008', '8119004', '8128003', '8133004', '8157004', '8158009', '8159001', '8160006', '8161005', '8165001', '8205005', '8225009', '8242003', '8251006', '8264007', '8265008', '8266009', '8279000', '8289001', '8292002', '8314003', '8334002', '8356004', '8361002', '8369000', '8373002', '8387002', '8389004', '8412003', '8415001', '8454000', '8464009', '8482007', '8483002', '8496001', '8523001', '8546004', '8556000', '8559007', '8560002', '8568009', '8580001', '8595004', '8598002', '8600008', '8603005', '8604004', '8608001', '8617001', '8623006', '8629005', '8640002', '8668003', '8671006', '8677005', '8688004', '8695008', '8710005', '8711009', '8714001', '8752000', '8770002', '8775007', '8784007', '8810002', '8814006', '8815007', '8820007', '8821006', '8827005', '8839002', '8845005', '8850004', '8854008', '8862000', '8873007', '8887007', '8892009', '8894005', '8897003', '8907008', '8910001', '8911002', '8928004', '8931003', '8935007', '8942007', '8965002', '8966001', '8983005', '8988001', '8993003', '9000002', '9003000', '9018004', '9040008', '9055004', '9073001', '9081000', '9086005', '9089003', '9108007', '9127001', '9156001', '9181003', '9185007', '9186008', '9188009', '9208002', '9212008', '9229006', '9231002', '9240003', '9242006', '9258009', '9261005', '9262003', '9284003', '9290004', '9305001', '9317004', '9320007', '9321006', '9325002', '9332006', '9348007', '9379006', '9380009', '9384000', '9390001', '9432007', '9438006', '9454009', '9455005', '9475001', '9481009', '9490002', '9498009', '9502002', '9512009', '9535007', '9558005', '9566001', '9568000', '9596006', '9609000', '9625005', '9642004', '9646001', '9654004', '9659009', '9662007', '9668006', '9677004', '9683001', '9684007', '9708001', '9732008', '9736006', '9743000', '9758008', '9770007', '9775002', '9779008', '9783008', '9791004', '9796009', '9813009', '9825007', '9837009', '9840009', '9841008', '9846003', '9847007', '9849005', '9870004', '9875009', '9878006', '9880000', '9881001', '9891007', '9898001', '9951005', '9968009', '9970000', '9976006', '9994000', '9999005', '10013000', '10024003', '10025002', '10026001', '10036009', '10042008', '10047002', '10052007', '10056005', '10062000', '10119003', '10124000']}, 'type'=>'CodeableConcept', 'path'=>'Observation.bodySite', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/body-site'}},
        'method' => {'local_name'=>'local_method', 'valid_codes'=>{'http://snomed.info/sct'=>['58207001', '115341008', '246363001', '246502009', '246503004', '246504005', '246505006', '246506007', '246507003', '255459008', '255463001', '255583002', '256233002', '257414001', '257425005', '257428007', '257452000', '257456002', '257460004', '257465009', '257740006', '257771002', '257772009', '257774005', '257775006', '257776007', '257827009', '257932009', '258005004', '258006003', '258009005', '258010000', '258011001', '258012008', '258013003', '258014009', '258017002', '258018007', '258019004', '258020005', '258021009', '258022002', '258025000', '258026004', '258027008', '258030001', '258031002', '258033004', '258034005', '258035006', '258036007', '258037003', '258038008', '258039000', '258041004', '258044007', '258045008', '258047000', '258048005', '258053000', '258054006', '258055007', '258056008', '258059001', '258060006', '258063008', '258065001', '258066000', '258067009', '258068004', '258069007', '258070008', '258071007', '258075003', '258076002', '258077006', '258078001', '258080007', '258081006', '258082004', '258083009', '258084003', '258086001', '258087005', '258094008', '258099003', '258100006', '258102003', '258109007', '258110002', '258112005', '258113000', '258114006', '258118009', '258119001', '258120007', '258121006', '258122004', '258123009', '258124003', '258125002', '258126001', '258128000', '258129008', '258131004', '258133001', '258144009', '258150004', '258159003', '258164004', '258169009', '258171009', '258173007', '258178003', '258179006', '258180009', '258181008', '258182001', '258183006', '260223001', '260227000', '260231006', '260710009', '260931002', '260982004', '261006005', '261009003', '261018001', '261032004', '261033009', '261039008', '261069001', '261070000', '261190007', '261192004', '261194003', '261196001', '261208004', '261209007', '261212005', '261213000', '261214006', '261215007', '261216008', '261271009', '261272002', '261338007', '261373009', '261504003', '261510003', '261548008', '261561008', '261567007', '261573008', '261671000', '261699009', '261700005', '261708003', '261710001', '261714005', '261732005', '261754007', '261787006', '261790000', '261793003', '261856001', '261909000', '261940007', '261943009', '261947005', '261958001', '261981004', '262041006', '262048000', '262062007', '262063002', '262064008', '262065009', '262069003', '262092003', '262095001', '262110008', '262136001', '262148003', '262162005', '262174009', '262180001', '262181002', '262201007', '262207006', '262265000', '262278000', '262293001', '262295008', '262296009', '262300005', '262305000', '262310001', '262313004', '262320006', '262323008', '263664004', '263696007', '263725008', '263746004', '263781002', '263809005', '263902000', '264220008', '264268002', '264269005', '264270006', '264271005', '264272003', '264273008', '264275001', '264276000', '264277009', '264279007', '264280005', '264281009', '264282002', '264283007', '264284001', '264355007', '264582003', '264583008', '264584002', '264590003', '264619009', '264773007', '264782001', '264788002', '264826006', '264828007', '264859009', '264863002', '264896000', '264903000', '264933007', '264934001', '264935000', '264946002', '272389005', '272390001', '272391002', '272392009', '272393004', '272395006', '276857005', '277337007', '277581000', '277620007', '277768009', '277769001', '277835006', '277853000', '277913002', '278283001', '278289002', '278300004', '278394000', '278395004', '278440009', '281408006', '281409003', '281410008', '281417006', '281418001', '281419009', '281420003', '284466007', '284467003', '286811001', '302554003', '304033004', '304364007', '304367000', '309796000', '309797009', '309798004', '312245009', '312246005', '312348008', '313115005', '313116006', '313201001', '313202008', '313281003', '362943005', '371871002', '371912002', '371913007', '371914001', '371916004', '371921001', '373098007', '373099004', '373100007', '373115008', '397801003', '397850009', '397884008', '397916001', '398037009', '398129004', '398317000', '404655007', '414378002', '414456005', '414611008', '415037003', '415741008', '416238005', '416423007', '417453009', '418449005', '418694008', '419125005', '419443000', '419913006', '420004004', '424457002', '445911007', '446402005', '446406008', '446947001', '447027002', '447056002', '447120003', '447692002', '447693007', '447826007', '447963004', '448076005', '449137004', '449225005', '702658000', '702659008', '702660003', '702661004', '702662006', '702663001', '702664007', '702665008', '702666009', '702667000', '702668005', '702669002', '702673004', '702674005', '702675006', '702872006', '702873001', '702940009', '702941008', '702942001', '702943006', '702944000', '702945004', '702946003', '702947007', '703436002', '703437006', '703438001', '703439009', '703440006', '703441005', '703442003', '703443008', '703444002', '703445001', '703446000', '703447009', '703448004', '703449007', '703450007', '703451006', '703452004', '703454003', '703455002', '703456001', '703457005', '703458000', '703459008', '703460003', '703461004', '703462006', '703463001', '703488009', '703490005', '703492002', '703497008', '703501003', '703505007', '703506008', '703507004', '703689005', '703690001', '703724007', '703725008', '703750006', '703751005', '703752003', '703753008', '703754002', '703856008', '703857004', '703858009', '703950001', '707682000', '707683005', '707684004', '707685003', '707687006', '707688001', '707689009', '707690000', '707691001', '707692008', '707693003', '707694009', '707695005', '707696006', '707698007', '707699004', '707700003', '707701004', '707702006', '708056006', '708058007', '708060009', '708061008', '708062001', '708063006', '708064000', '708065004', '708066003', '708067007', '708068002', '708069005', '708070006', '708071005', '708072003', '708073008', '708074002', '708075001', '708076000', '708077009', '708078004', '708097004', '708099001', '708104000', '708125000', '708128003', '708130001', '708131002', '708132009', '708133004', '708532004', '718496006', '129265001', '129266000', '129267009', '129268004', '129269007', '129271007', '129272000', '129273005', '129274004', '129275003', '129276002', '129277006', '129278001', '129279009', '129280007', '129283009', '129284003', '129286001', '129287005', '129288000', '129289008', '129291000', '129292007', '129293002', '129294008', '129295009', '129296005', '129297001', '129298006', '129299003', '129300006', '129301005', '129303008', '129304002', '129305001', '129306000', '129307009', '129308004', '129309007', '129310002', '129311003', '129312005', '129313000', '129314006', '129315007', '129316008', '129317004', '129318009', '129319001', '129321006', '129322004', '129323009', '129324003', '129325002', '129326001', '129327005', '129328000', '129330003', '129331004', '129332006', '129333001', '129334007', '129335008', '129337000', '129339002', '129340000', '129344009', '129345005', '129346006', '129347002', '129348007', '129349004', '129350004', '129351000', '129352007', '129353002', '129354008', '129355009', '129356005', '129357001', '129358006', '129360008', '129366002', '129368001', '129369009', '129371009', '129372002', '129373007', '129374001', '129376004', '129377008', '129378003', '129379006', '129380009', '129381008', '129382001', '129383006', '129384000', '129385004', '129386003', '129387007', '129388002', '129389005', '129390001', '129391002', '129392009', '129393004', '129394005', '129395006', '129396007', '129397003', '129398008', '129399000', '129400007', '129401006', '129402004', '129403009', '129404003', '129405002', '129406001', '129407005', '129408000', '129409008', '129410003', '129411004', '129412006', '129413001', '129414007', '129415008', '129416009', '129418005', '129419002', '129420008', '129421007', '129423005', '129424004', '129425003', '129426002', '129427006', '129430004', '129431000', '129433002', '129434008', '129435009', '129436005', '129437001', '129438006', '129441002', '129442009', '129443004', '129444005', '129445006', '129449000', '183648002', '245854003', '245855002', '255595002', '256644001', '257729003', '257730008', '257739009', '257741005', '257742003', '257743008', '257744002', '257745001', '257746000', '257747009', '257748004', '257749007', '257750007', '257751006', '257759008', '257768005', '257777003', '257778008', '257780002', '257781003', '257782005', '257783000', '257784006', '257785007', '257786008', '257788009', '257789001', '257791009', '257802002', '257803007', '257804001', '257805000', '257806004', '257808003', '257811002', '257817003', '257821005', '257822003', '257824002', '257825001', '257846005', '257850003', '257855008', '257857000', '257859002', '257863009', '257867005', '257878002', '257880008', '257884004', '257885003', '257886002', '257889009', '257890000', '257893003', '257894009', '257895005', '257897002', '257903006', '257905004', '257906003', '257907007', '257911001', '257912008', '257913003', '257914009', '257915005', '257916006', '257917002', '257918007', '257923007', '257926004', '257928003', '257933004', '257935006', '257937003', '257938008', '257940003', '258061005', '260222006', '261027000', '261191006', '261197005', '261198000', '261199008', '261391004', '261398005', '261498006', '261499003', '261518005', '261519002', '261520008', '261526002', '261545006', '261553003', '261569005', '261576000', '262143007', '263720003', '264592006', '264594007', '264730003', '264739002', '264947006', '272381008', '274392008', '276734006', '277261002', '277607009', '277763000', '277851003', '277852005', '278110001', '278292003', '278312000', '278313005', '278420002', '281609006', '281613004', '281615006', '281698007', '281767003', '281838007', '281839004', '282015008', '282089006', '282722008', '286553006', '286637000', '286792001', '287682008', '288324002', '288466002', '288468001', '289928003', '289930001', '289936007', '289938008', '290001001', '297179000', '297183000', '298053008', '298116000', '299712004', '299713009', '299893001', '302193003', '302196006', '302199004', '302204005', '302205006', '303893007', '303894001', '303955003', '303996000', '303998004', '304054006', '304904003', '312236008', '312250003', '312251004', '312254007', '312275004', '312336005', '312337001', '312421008', '312883004', '313029009', '360017003', '360018008', '360020006', '360021005', '360025001', '360027009', '360028004', '360029007', '360032005', '360037004', '360038009', '360051004', '360060007', '360082000', '360084004', '360087006', '360146007', '360147003', '360148008', '360149000', '360150000', '360152008', '360153003', '360154009', '360160009', '360161008', '360163006', '360165004', '360166003', '360220002', '360222005', '360223000', '360226008', '360231005', '360232003', '360239007', '360240009', '360270004', '360272007', '360273002', '360314001', '360315000', '360323003', '360324009', '360325005', '360393008', '362939006', '363659002', '363678002', '367529003', '367558000', '367559008', '367560003', '367642006', '367740008', '369242005', '386746003', '399009009', '399015009', '399035005', '399064001', '399155008', '410460000', '410461001', '410462008', '410463003', '410464009', '410465005', '410466006', '410467002', '410756002', '410757006', '410758001', '410759009', '410769003', '410814006', '410817004', '410820007', '415186003', '416677001', '419385000', '419652001', '419656003', '419988009', '424208002', '424832003', '424900004', '425362007', '425689005', '425704008', '425764006', '426413004', '426530000', '426865009', '428010000', '428381003', '430975009', '439054007', '439237009', '439315000', '439417007', '439513008', '440338007', '440647007', '441504007', '442837002', '445103003', '698788008', '698789000', '698790009', '698792001', '698793006', '698794000', '698796003', '698797007', '698798002', '702569007', '713295009', '128004', '135007', '153001', '170009', '197002', '306005', '334003', '352003', '353008', '389000', '435001', '468008', '489004', '493005', '540006', '574005', '628003', '642006', '673005', '674004', '687005', '697001', '759005', '762008', '767002', '814007', '831000', '853003', '870006', '879007', '893000', '910002', '941001', '951000', '969009', '1029002', '1035002', '1043007', '1044001', '1225002', '1292009', '1324000', '1358008', '1385001', '1399002', '1414009', '1494008', '1550000', '1559004', '1597004', '1616001', '1640009', '1677001', '1712009', '1757000', '1759002', '1784004', '1787006', '1820004', '1879000', '2054004', '2196003', '2214008', '2220009', '2225004', '2244006', '2266004', '2276001', '2278000', '2279008', '2290003', '2347001', '2373006', '2408004', '2425002', '2448007', '2461007', '2507007', '2508002', '2531002', '2629003', '2646000', '2690005', '2693007', '2696004', '2722000', '2731000', '2737001', '2743004', '2811005', '2842000', '2847006', '2885009', '2891006', '2898000']}, 'type'=>'CodeableConcept', 'path'=>'Observation.method', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/observation-methods'}},
        'specimen' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Specimen'], 'type'=>'Reference', 'path'=>'Observation.specimen', 'min'=>0, 'max'=>1},
        'device' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Device', 'http://hl7.org/fhir/StructureDefinition/DeviceMetric'], 'type'=>'Reference', 'path'=>'Observation.device', 'min'=>0, 'max'=>1},
        'referenceRange' => {'type'=>'Observation::ReferenceRange', 'path'=>'Observation.referenceRange', 'min'=>0, 'max'=>Float::INFINITY},
        'related' => {'type'=>'Observation::Related', 'path'=>'Observation.related', 'min'=>0, 'max'=>Float::INFINITY},
        'component' => {'type'=>'Observation::Component', 'path'=>'Observation.component', 'min'=>0, 'max'=>Float::INFINITY}
      }

      class ReferenceRange < FHIR::STU3::Model
        include FHIR::STU3::Hashable
        include FHIR::STU3::Json
        include FHIR::STU3::Xml

        METADATA = {
          'id' => {'type'=>'string', 'path'=>'ReferenceRange.id', 'min'=>0, 'max'=>1},
          'extension' => {'type'=>'Extension', 'path'=>'ReferenceRange.extension', 'min'=>0, 'max'=>Float::INFINITY},
          'modifierExtension' => {'type'=>'Extension', 'path'=>'ReferenceRange.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
          'low' => {'type'=>'Quantity', 'path'=>'ReferenceRange.low', 'min'=>0, 'max'=>1},
          'high' => {'type'=>'Quantity', 'path'=>'ReferenceRange.high', 'min'=>0, 'max'=>1},
          'type' => {'valid_codes'=>{'http://hl7.org/fhir/referencerange-meaning'=>['type', 'normal', 'recommended', 'treatment', 'therapeutic', 'pre', 'post', 'endocrine', 'pre-puberty', 'follicular', 'midcycle', 'luteal', 'postmeopausal']}, 'type'=>'CodeableConcept', 'path'=>'ReferenceRange.type', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'extensible', 'uri'=>'http://hl7.org/fhir/ValueSet/referencerange-meaning'}},
          'appliesTo' => {'valid_codes'=>{'http://hl7.org/fhir/v3/Race'=>['1002-5', '1004-1', '1006-6', '1008-2', '1010-8', '1011-6', '1012-4', '1013-2', '1014-0', '1015-7', '1016-5', '1017-3', '1018-1', '1019-9', '1021-5', '1022-3', '1023-1', '1024-9', '1026-4', '1028-0', '1030-6', '1031-4', '1033-0', '1035-5', '1037-1', '1039-7', '1041-3', '1042-1', '1044-7', '1045-4', '1046-2', '1047-0', '1048-8', '1049-6', '1050-4', '1051-2', '1053-8', '1054-6', '1055-3', '1056-1', '1057-9', '1058-7', '1059-5', '1060-3', '1061-1', '1062-9', '1063-7', '1064-5', '1065-2', '1066-0', '1068-6', '1069-4', '1070-2', '1071-0', '1072-8', '1073-6', '1074-4', '1076-9', '1741-8', '1742-6', '1743-4', '1744-2', '1745-9', '1746-7', '1747-5', '1748-3', '1749-1', '1750-9', '1751-7', '1752-5', '1753-3', '1754-1', '1755-8', '1756-6', '1757-4', '1758-2', '1759-0', '1760-8', '1761-6', '1762-4', '1763-2', '1764-0', '1765-7', '1766-5', '1767-3', '1768-1', '1769-9', '1770-7', '1771-5', '1772-3', '1773-1', '1774-9', '1775-6', '1776-4', '1777-2', '1778-0', '1779-8', '1780-6', '1781-4', '1782-2', '1783-0', '1784-8', '1785-5', '1786-3', '1787-1', '1788-9', '1789-7', '1790-5', '1791-3', '1792-1', '1793-9', '1794-7', '1795-4', '1796-2', '1797-0', '1798-8', '1799-6', '1800-2', '1801-0', '1802-8', '1803-6', '1804-4', '1805-1', '1806-9', '1807-7', '1808-5', '1809-3', '1078-5', '1080-1', '1082-7', '1083-5', '1084-3', '1086-8', '1088-4', '1089-2', '1090-0', '1091-8', '1092-6', '1093-4', '1094-2', '1095-9', '1096-7', '1097-5', '1098-3', '1100-7', '1102-3', '1103-1', '1104-9', '1106-4', '1108-0', '1109-8', '1110-6', '1112-2', '1114-8', '1115-5', '1116-3', '1117-1', '1118-9', '1119-7', '1120-5', '1121-3', '1123-9', '1124-7', '1125-4', '1126-2', '1127-0', '1128-8', '1129-6', '1130-4', '1131-2', '1132-0', '1133-8', '1134-6', '1135-3', '1136-1', '1137-9', '1138-7', '1139-5', '1140-3', '1141-1', '1142-9', '1143-7', '1144-5', '1145-2', '1146-0', '1147-8', '1148-6', '1150-2', '1151-0', '1153-6', '1155-1', '1156-9', '1157-7', '1158-5', '1159-3', '1160-1', '1162-7', '1163-5', '1165-0', '1167-6', '1169-2', '1171-8', '1173-4', '1175-9', '1176-7', '1178-3', '1180-9', '1182-5', '1184-1', '1186-6', '1187-4', '1189-0', '1191-6', '1193-2', '1194-0', '1195-7', '1196-5', '1197-3', '1198-1', '1199-9', '1200-5', '1201-3', '1202-1', '1203-9', '1204-7', '1205-4', '1207-0', '1209-6', '1211-2', '1212-0', '1214-6', '1215-3', '1216-1', '1217-9', '1218-7', '1219-5', '1220-3', '1222-9', '1223-7', '1224-5', '1225-2', '1226-0', '1227-8', '1228-6', '1229-4', '1230-2', '1231-0', '1233-6', '1234-4', '1235-1', '1236-9', '1237-7', '1238-5', '1239-3', '1240-1', '1241-9', '1242-7', '1243-5', '1244-3', '1245-0', '1246-8', '1247-6', '1248-4', '1250-0', '1252-6', '1254-2', '1256-7', '1258-3', '1260-9', '1262-5', '1264-1', '1265-8', '1267-4', '1269-0', '1271-6', '1272-4', '1273-2', '1275-7', '1277-3', '1279-9', '1281-5', '1282-3', '1283-1', '1285-6', '1286-4', '1287-2', '1288-0', '1289-8', '1290-6', '1291-4', '1292-2', '1293-0', '1294-8', '1295-5', '1297-1', '1299-7', '1301-1', '1303-7', '1305-2', '1306-0', '1307-8', '1309-4', '1310-2', '1312-8', '1313-6', '1314-4', '1315-1', '1317-7', '1319-3', '1321-9', '1323-5', '1325-0', '1326-8', '1327-6', '1328-4', '1329-2', '1331-8', '1332-6', '1333-4', '1334-2', '1335-9', '1336-7', '1337-5', '1338-3', '1340-9', '1342-5', '1344-1', '1345-8', '1346-6', '1348-2', '1350-8', '1352-4', '1354-0', '1356-5', '1358-1', '1359-9', '1360-7', '1361-5', '1363-1', '1365-6', '1366-4', '1368-0', '1370-6', '1372-2', '1374-8', '1376-3', '1378-9', '1380-5', '1382-1', '1383-9', '1384-7', '1385-4', '1387-0', '1389-6', '1391-2', '1392-0', '1393-8', '1394-6', '1395-3', '1396-1', '1397-9', '1398-7', '1399-5', '1400-1', '1401-9', '1403-5', '1405-0', '1407-6', '1409-2', '1411-8', '1412-6', '1413-4', '1414-2', '1416-7', '1417-5', '1418-3', '1419-1', '1420-9', '1421-7', '1422-5', '1423-3', '1424-1', '1425-8', '1426-6', '1427-4', '1428-2', '1429-0', '1430-8', '1431-6', '1432-4', '1433-2', '1434-0', '1435-7', '1436-5', '1437-3', '1439-9', '1441-5', '1442-3', '1443-1', '1445-6', '1446-4', '1448-0', '1450-6', '1451-4', '1453-0', '1454-8', '1456-3', '1457-1', '1458-9', '1460-5', '1462-1', '1464-7', '1465-4', '1466-2', '1467-0', '1468-8', '1469-6', '1470-4', '1471-2', '1472-0', '1474-6', '1475-3', '1476-1', '1478-7', '1479-5', '1480-3', '1481-1', '1482-9', '1483-7', '1484-5', '1485-2', '1487-8', '1489-4', '1490-2', '1491-0', '1492-8', '1493-6', '1494-4', '1495-1', '1496-9', '1497-7', '1498-5', '1499-3', '1500-8', '1501-6', '1502-4', '1503-2', '1504-0', '1505-7', '1506-5', '1507-3', '1508-1', '1509-9', '1510-7', '1511-5', '1512-3', '1513-1', '1514-9', '1515-6', '1516-4', '1518-0', '1519-8', '1520-6', '1521-4', '1522-2', '1523-0', '1524-8', '1525-5', '1526-3', '1527-1', '1528-9', '1529-7', '1530-5', '1531-3', '1532-1', '1533-9', '1534-7', '1535-4', '1536-2', '1537-0', '1538-8', '1539-6', '1541-2', '1543-8', '1545-3', '1547-9', '1549-5', '1551-1', '1552-9', '1553-7', '1554-5', '1556-0', '1558-6', '1560-2', '1562-8', '1564-4', '1566-9', '1567-7', '1568-5', '1569-3', '1570-1', '1571-9', '1573-5', '1574-3', '1576-8', '1578-4', '1579-2', '1580-0', '1582-6', '1584-2', '1586-7', '1587-5', '1588-3', '1589-1', '1590-9', '1591-7', '1592-5', '1593-3', '1594-1', '1595-8', '1596-6', '1597-4', '1598-2', '1599-0', '1600-6', '1602-2', '1603-0', '1604-8', '1605-5', '1607-1', '1609-7', '1610-5', '1611-3', '1612-1', '1613-9', '1614-7', '1615-4', '1616-2', '1617-0', '1618-8', '1619-6', '1620-4', '1621-2', '1622-0', '1623-8', '1624-6', '1625-3', '1626-1', '1627-9', '1628-7', '1629-5', '1630-3', '1631-1', '1632-9', '1633-7', '1634-5', '1635-2', '1636-0', '1637-8', '1638-6', '1639-4', '1640-2', '1641-0', '1643-6', '1645-1', '1647-7', '1649-3', '1651-9', '1653-5', '1654-3', '1655-0', '1656-8', '1657-6', '1659-2', '1661-8', '1663-4', '1665-9', '1667-5', '1668-3', '1670-9', '1671-7', '1672-5', '1673-3', '1675-8', '1677-4', '1679-0', '1680-8', '1681-6', '1683-2', '1685-7', '1687-3', '1688-1', '1689-9', '1690-7', '1692-3', '1694-9', '1696-4', '1697-2', '1698-0', '1700-4', '1702-0', '1704-6', '1705-3', '1707-9', '1709-5', '1711-1', '1712-9', '1713-7', '1715-2', '1717-8', '1718-6', '1719-4', '1720-2', '1722-8', '1724-4', '1725-1', '1726-9', '1727-7', '1728-5', '1729-3', '1730-1', '1731-9', '1732-7', '1733-5', '1735-0', '1737-6', '1739-2', '1740-0', '1811-9', '1813-5', '1814-3', '1815-0', '1816-8', '1817-6', '1818-4', '1819-2', '1820-0', '1821-8', '1822-6', '1823-4', '1824-2', '1825-9', '1826-7', '1827-5', '1828-3', '1829-1', '1830-9', '1831-7', '1832-5', '1833-3', '1834-1', '1835-8', '1837-4', '1838-2', '1840-8', '1842-4', '1844-0', '1845-7', '1846-5', '1847-3', '1848-1', '1849-9', '1850-7', '1851-5', '1852-3', '1853-1', '1854-9', '1855-6', '1856-4', '1857-2', '1858-0', '1859-8', '1860-6', '1861-4', '1862-2', '1863-0', '1864-8', '1865-5', '1866-3', '1867-1', '1868-9', '1869-7', '1870-5', '1871-3', '1872-1', '1873-9', '1874-7', '1875-4', '1876-2', '1877-0', '1878-8', '1879-6', '1880-4', '1881-2', '1882-0', '1883-8', '1884-6', '1885-3', '1886-1', '1887-9', '1888-7', '1889-5', '1891-1', '1892-9', '1893-7', '1894-5', '1896-0', '1897-8', '1898-6', '1899-4', '1900-0', '1901-8', '1902-6', '1903-4', '1904-2', '1905-9', '1906-7', '1907-5', '1908-3', '1909-1', '1910-9', '1911-7', '1912-5', '1913-3', '1914-1', '1915-8', '1916-6', '1917-4', '1918-2', '1919-0', '1920-8', '1921-6', '1922-4', '1923-2', '1924-0', '1925-7', '1926-5', '1927-3', '1928-1', '1929-9', '1930-7', '1931-5', '1932-3', '1933-1', '1934-9', '1935-6', '1936-4', '1937-2', '1938-0', '1939-8', '1940-6', '1941-4', '1942-2', '1943-0', '1944-8', '1945-5', '1946-3', '1947-1', '1948-9', '1949-7', '1950-5', '1951-3', '1952-1', '1953-9', '1954-7', '1955-4', '1956-2', '1957-0', '1958-8', '1959-6', '1960-4', '1961-2', '1962-0', '1963-8', '1964-6', '1966-1', '1968-7', '1969-5', '1970-3', '1972-9', '1973-7', '1974-5', '1975-2', '1976-0', '1977-8', '1978-6', '1979-4', '1980-2', '1981-0', '1982-8', '1984-4', '1985-1', '1986-9', '1987-7', '1988-5', '1990-1', '1992-7', '1993-5', '1994-3', '1995-0', '1996-8', '1997-6', '1998-4', '1999-2', '2000-8', '2002-4', '2004-0', '2006-5', '2007-3', '2008-1', '2009-9', '2010-7', '2011-5', '2012-3', '2013-1', '2014-9', '2015-6', '2016-4', '2017-2', '2018-0', '2019-8', '2020-6', '2021-4', '2022-2', '2023-0', '2024-8', '2025-5', '2026-3', '2028-9', '2029-7', '2030-5', '2031-3', '2032-1', '2033-9', '2034-7', '2035-4', '2036-2', '2037-0', '2038-8', '2039-6', '2040-4', '2041-2', '2042-0', '2043-8', '2044-6', '2045-3', '2046-1', '2047-9', '2048-7', '2049-5', '2050-3', '2051-1', '2052-9', '2054-5', '2056-0', '2058-6', '2060-2', '2061-0', '2062-8', '2063-6', '2064-4', '2065-1', '2066-9', '2067-7', '2068-5', '2069-3', '2070-1', '2071-9', '2072-7', '2073-5', '2074-3', '2075-0', '2076-8', '2078-4', '2079-2', '2080-0', '2081-8', '2082-6', '2083-4', '2085-9', '2086-7', '2087-5', '2088-3', '2089-1', '2090-9', '2091-7', '2092-5', '2093-3', '2094-1', '2095-8', '2096-6', '2097-4', '2098-2', '2100-6', '2101-4', '2102-2', '2103-0', '2104-8', '2500-7', '2106-3', '2108-9', '2109-7', '2110-5', '2111-3', '2112-1', '2113-9', '2114-7', '2115-4', '2116-2', '2118-8', '2119-6', '2120-4', '2121-2', '2122-0', '2123-8', '2124-6', '2125-3', '2126-1', '2127-9', '2129-5', '2131-1'], 'http://snomed.info/sct'=>['248153007', '248152002', '77386006'], nil=>[]}, 'type'=>'CodeableConcept', 'path'=>'ReferenceRange.appliesTo', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/referencerange-appliesto'}},
          'age' => {'type'=>'Range', 'path'=>'ReferenceRange.age', 'min'=>0, 'max'=>1},
          'text' => {'type'=>'string', 'path'=>'ReferenceRange.text', 'min'=>0, 'max'=>1}
        }

        attr_accessor :id                # 0-1 string
        attr_accessor :extension         # 0-* [ Extension ]
        attr_accessor :modifierExtension # 0-* [ Extension ]
        attr_accessor :low               # 0-1 Quantity
        attr_accessor :high              # 0-1 Quantity
        attr_accessor :type              # 0-1 CodeableConcept
        attr_accessor :appliesTo         # 0-* [ CodeableConcept ]
        attr_accessor :age               # 0-1 Range
        attr_accessor :text              # 0-1 string
      end

      class Related < FHIR::STU3::Model
        include FHIR::STU3::Hashable
        include FHIR::STU3::Json
        include FHIR::STU3::Xml

        METADATA = {
          'id' => {'type'=>'string', 'path'=>'Related.id', 'min'=>0, 'max'=>1},
          'extension' => {'type'=>'Extension', 'path'=>'Related.extension', 'min'=>0, 'max'=>Float::INFINITY},
          'modifierExtension' => {'type'=>'Extension', 'path'=>'Related.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
          'type' => {'valid_codes'=>{'http://hl7.org/fhir/observation-relationshiptypes'=>['has-member', 'derived-from', 'sequel-to', 'replaces', 'qualified-by', 'interfered-by']}, 'type'=>'code', 'path'=>'Related.type', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'required', 'uri'=>'http://hl7.org/fhir/ValueSet/observation-relationshiptypes'}},
          'target' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Observation', 'http://hl7.org/fhir/StructureDefinition/QuestionnaireResponse', 'http://hl7.org/fhir/StructureDefinition/Sequence'], 'type'=>'Reference', 'path'=>'Related.target', 'min'=>1, 'max'=>1}
        }

        attr_accessor :id                # 0-1 string
        attr_accessor :extension         # 0-* [ Extension ]
        attr_accessor :modifierExtension # 0-* [ Extension ]
        attr_accessor :type              # 0-1 code
        attr_accessor :target            # 1-1 Reference(Observation|QuestionnaireResponse|Sequence)
      end

      class Component < FHIR::STU3::Model
        include FHIR::STU3::Hashable
        include FHIR::STU3::Json
        include FHIR::STU3::Xml

        MULTIPLE_TYPES = {
          'value' => ['Quantity', 'CodeableConcept', 'string', 'Range', 'Ratio', 'SampledData', 'Attachment', 'time', 'dateTime', 'Period']
        }
        METADATA = {
          'id' => {'type'=>'string', 'path'=>'Component.id', 'min'=>0, 'max'=>1},
          'extension' => {'type'=>'Extension', 'path'=>'Component.extension', 'min'=>0, 'max'=>Float::INFINITY},
          'modifierExtension' => {'type'=>'Extension', 'path'=>'Component.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
          'code' => {'valid_codes'=>{'http://loinc.org'=>['1-8', '10-9', '100-8', '1000-9', '10000-8', '10001-6', '10002-4', '10003-2', '10004-0', '10005-7', '10006-5', '10007-3', '10008-1', '10009-9', '1001-7', '10010-7', '10011-5', '10012-3', '10013-1', '10014-9', '10015-6', '10016-4', '10017-2', '10018-0', '10019-8', '1002-5', '10020-6', '10021-4', '10022-2', '10023-0', '10024-8', '10025-5', '10026-3', '10027-1', '10028-9', '10029-7', '1003-3', '10030-5', '10031-3', '10032-1', '10033-9', '10034-7', '10035-4', '10036-2', '10037-0', '10038-8', '10039-6', '1004-1', '10040-4', '10041-2', '10042-0', '10043-8', '10044-6', '10045-3', '10046-1', '10047-9', '10048-7', '10049-5', '1005-8', '10050-3', '10051-1', '10052-9', '10053-7', '10054-5', '10055-2', '10056-0', '10057-8', '10058-6', '10059-4', '1006-6', '10060-2', '10061-0', '10062-8', '10063-6', '10064-4', '10065-1', '10066-9', '10067-7', '10068-5', '10069-3', '1007-4', '10070-1', '10071-9', '10072-7', '10073-5', '10074-3', '10075-0', '10076-8', '10077-6', '10078-4', '10079-2', '1008-2', '10080-0', '10081-8', '10082-6', '10083-4', '10084-2', '10085-9', '10086-7', '10087-5', '10088-3', '10089-1', '1009-0', '10090-9', '10091-7', '10092-5', '10093-3', '10094-1', '10095-8', '10096-6', '10097-4', '10098-2', '10099-0', '101-6', '1010-8', '10100-6', '10101-4', '10102-2', '10103-0', '10104-8', '10105-5', '10106-3', '10107-1', '10108-9', '10109-7', '1011-6', '10110-5', '10111-3', '10112-1', '10113-9', '10114-7', '10115-4', '10116-2', '10117-0', '10118-8', '10119-6', '1012-4', '10120-4', '10121-2', '10122-0', '10123-8', '10124-6', '10125-3', '10126-1', '10127-9', '10128-7', '10129-5', '1013-2', '10130-3', '10131-1', '10132-9', '10133-7', '10134-5', '10135-2', '10136-0', '10137-8', '10138-6', '10139-4', '1014-0', '10140-2', '10141-0', '10142-8', '10143-6', '10144-4', '10145-1', '10146-9', '10147-7', '10148-5', '10149-3', '1015-7', '10150-1', '10151-9', '10152-7', '10153-5', '10154-3', '10155-0', '10156-8', '10157-6', '10158-4', '10159-2', '1016-5', '10160-0', '10161-8', '10162-6', '10163-4', '10164-2', '10165-9', '10166-7', '10167-5', '10168-3', '10169-1', '1017-3', '10170-9', '10171-7', '10172-5', '10173-3', '10174-1', '10175-8', '10176-6', '10177-4', '10178-2', '10179-0', '1018-1', '10180-8', '10181-6', '10182-4', '10183-2', '10184-0', '10185-7', '10186-5', '10187-3', '10188-1', '10189-9', '1019-9', '10190-7', '10191-5', '10192-3', '10193-1', '10194-9', '10195-6', '10196-4', '10197-2', '10198-0', '10199-8', '102-4', '1020-7', '10200-4', '10201-2', '10202-0', '10203-8', '10204-6', '10205-3', '10206-1', '10207-9', '10208-7', '10209-5', '1021-5', '10210-3', '10211-1', '10212-9', '10213-7', '10214-5', '10215-2', '10216-0', '10217-8', '10218-6', '10219-4', '1022-3', '10220-2', '10221-0', '10222-8', '10223-6', '10224-4', '10225-1', '10226-9', '10227-7', '10228-5', '10229-3', '1023-1', '10230-1', '10231-9', '10232-7', '10233-5', '10234-3', '10235-0', '10236-8', '10237-6', '10238-4', '10239-2', '1024-9', '10240-0', '10241-8', '10242-6', '10243-4', '10244-2', '10245-9', '10246-7', '10247-5', '10248-3', '10249-1', '1025-6', '10250-9', '10251-7', '10252-5', '10253-3', '10254-1', '10255-8', '10256-6', '10257-4', '10258-2', '10259-0', '1026-4', '10260-8', '10261-6', '10262-4', '10263-2', '10264-0', '10265-7', '10266-5', '10267-3', '10268-1', '10269-9', '1027-2', '10270-7', '10271-5', '10272-3', '10273-1', '10274-9', '10275-6', '10276-4', '10277-2', '10278-0', '10279-8', '1028-0', '10280-6', '10281-4', '10282-2', '10283-0', '10284-8', '10285-5', '10286-3', '10287-1', '10288-9', '10289-7', '1029-8', '10290-5', '10291-3', '10292-1', '10293-9', '10294-7', '10295-4', '10296-2', '10297-0', '10298-8', '10299-6', '103-2', '1030-6', '10300-2', '10301-0', '10302-8', '10303-6', '10304-4', '10305-1', '10306-9', '10307-7', '10308-5', '10309-3', '1031-4', '10310-1', '10311-9', '10312-7', '10313-5', '10314-3', '10315-0', '10316-8', '10317-6', '10318-4', '10319-2', '1032-2', '10320-0', '10321-8', '10322-6', '10323-4', '10324-2', '10325-9', '10326-7', '10327-5', '10328-3', '10329-1', '1033-0', '10330-9', '10331-7', '10332-5', '10333-3', '10334-1', '10335-8', '10336-6', '10337-4', '10338-2', '10339-0', '1034-8', '10340-8', '10341-6', '10342-4', '10343-2', '10344-0', '10345-7', '10346-5', '10347-3', '10348-1', '10349-9', '1035-5', '10350-7', '10351-5', '10352-3', '10353-1', '10354-9', '10355-6', '10356-4', '10357-2', '10358-0', '10359-8', '1036-3', '10360-6', '10361-4', '10362-2', '10363-0', '10364-8', '10365-5', '10366-3', '10367-1', '10368-9', '10369-7', '1037-1', '10370-5', '10371-3', '10372-1', '10373-9', '10374-7', '10375-4', '10376-2', '10377-0', '10378-8', '10379-6', '1038-9', '10380-4', '10381-2', '10382-0', '10383-8', '10384-6', '10385-3', '10386-1', '10387-9', '10388-7', '10389-5', '1039-7', '10390-3', '10391-1', '10392-9', '10393-7', '10394-5', '10395-2', '10396-0', '10397-8', '10398-6', '10399-4', '104-0', '1040-5', '10400-0', '10401-8', '10402-6', '10403-4', '10404-2', '10405-9', '10406-7', '10407-5', '10408-3', '10409-1', '1041-3', '10410-9', '10411-7', '10412-5', '10413-3', '10414-1', '10415-8', '10416-6', '10417-4', '10418-2', '10419-0', '1042-1', '10420-8', '10421-6', '10422-4', '10423-2', '10424-0', '10425-7', '10426-5', '10427-3', '10428-1', '10429-9', '1043-9', '10430-7', '10431-5', '10432-3', '10433-1', '10434-9', '10435-6', '10436-4', '10437-2', '10438-0', '10439-8', '1044-7', '10440-6', '10441-4', '10442-2', '10443-0', '10444-8', '10445-5', '10446-3', '10447-1', '10448-9', '10449-7', '1045-4', '10450-5', '10451-3', '10452-1', '10453-9', '10454-7', '10455-4', '10456-2', '10457-0', '10458-8', '10459-6', '1046-2', '10460-4', '10461-2', '10462-0', '10463-8', '10464-6', '10465-3', '10466-1', '10467-9', '10468-7', '10469-5', '1047-0', '10470-3', '10471-1', '10472-9', '10473-7', '10474-5', '10475-2', '10476-0', '10477-8', '10478-6', '10479-4', '1048-8', '10480-2', '10481-0', '10482-8', '10483-6', '10484-4', '10485-1', '10486-9', '10487-7', '10488-5', '10489-3', '1049-6', '10490-1', '10491-9', '10492-7', '10493-5', '10494-3', '10495-0', '10496-8', '10497-6', '10498-4', '10499-2', '105-7', '1050-4', '10500-7', '10501-5', '10502-3', '10503-1', '10504-9', '10505-6', '10506-4', '10507-2', '10508-0', '10509-8', '1051-2', '10510-6', '10511-4', '10512-2', '10513-0', '10514-8', '10515-5', '10516-3', '10517-1', '10518-9', '10519-7', '1052-0', '10520-5', '10521-3', '10522-1', '10523-9', '10524-7', '10525-4', '10526-2', '10527-0', '10528-8', '10529-6', '1053-8', '10530-4', '10531-2', '10532-0', '10533-8', '10534-6', '10535-3', '10536-1', '10537-9', '10538-7', '10539-5', '1054-6', '10540-3', '10541-1', '10542-9', '10543-7', '10544-5', '10545-2', '10546-0', '10547-8', '10548-6', '10549-4', '1055-3', '10550-2', '10551-0', '10552-8', '10553-6', '10554-4', '10555-1', '10556-9', '10557-7', '10558-5', '10559-3', '1056-1', '10560-1', '10561-9', '10562-7', '10563-5', '10564-3', '10565-0', '10566-8', '10567-6', '10568-4', '10569-2', '1057-9', '10570-0', '10571-8', '10572-6', '10573-4', '10574-2', '10575-9', '10576-7', '10577-5', '10578-3', '10579-1', '1058-7', '10580-9', '10581-7', '10582-5', '10583-3', '10584-1', '10585-8', '10586-6', '10587-4', '10588-2', '10589-0', '1059-5', '10590-8', '10591-6', '10592-4', '10593-2', '10594-0', '10595-7', '10596-5', '10597-3', '10598-1', '10599-9', '106-5', '1060-3', '10600-5', '10601-3', '10602-1', '10603-9', '10604-7', '10605-4', '10606-2', '10607-0', '10608-8', '10609-6', '1061-1', '10610-4', '10611-2', '10612-0', '10613-8', '10614-6', '10615-3', '10616-1', '10617-9', '10618-7', '10619-5', '1062-9', '10620-3', '10621-1', '10622-9', '10623-7', '10624-5', '10625-2', '10626-0', '10627-8', '10628-6', '10629-4', '1063-7', '10630-2', '10631-0', '10632-8', '10633-6', '10634-4', '10635-1', '10636-9', '10637-7', '10638-5', '10639-3', '1064-5', '10640-1', '10641-9', '10642-7', '10643-5', '10644-3', '10645-0', '10646-8', '10647-6', '10648-4', '10649-2', '1065-2', '10650-0', '10651-8', '10652-6', '10653-4', '10654-2', '10655-9', '10656-7', '10657-5', '10658-3', '10659-1', '1066-0', '10660-9', '10661-7', '10662-5', '10663-3', '10664-1', '10665-8', '10666-6', '10667-4', '10668-2', '10669-0', '1067-8', '10670-8', '10671-6', '10672-4', '10673-2', '10674-0', '10675-7', '10676-5', '10677-3', '10678-1', '10679-9', '1068-6', '10680-7', '10681-5', '10682-3', '10683-1', '10684-9', '10685-6', '10686-4', '10687-2', '10688-0', '10689-8', '1069-4', '10690-6', '10691-4', '10692-2', '10693-0', '10694-8', '10695-5', '10696-3', '10697-1', '10698-9', '10699-7', '107-3', '1070-2', '10700-3', '10701-1', '10702-9', '10703-7', '10704-5', '10705-2', '10706-0', '10707-8', '10708-6', '10709-4', '1071-0', '10710-2', '10711-0', '10712-8', '10713-6', '10714-4', '10715-1', '10716-9', '10717-7', '10718-5', '10719-3', '1072-8', '10720-1', '10721-9', '10722-7', '10723-5', '10724-3', '10725-0', '10726-8', '10727-6', '10728-4', '10729-2', '1073-6', '10730-0', '10731-8', '10732-6', '10733-4', '10734-2', '10735-9', '10736-7', '10737-5', '10738-3', '10739-1', '1074-4', '10740-9', '10741-7', '10742-5', '10743-3', '10744-1', '10745-8', '10746-6', '10747-4', '10748-2', '10749-0', '1075-1', '10750-8', '10751-6', '10752-4', '10753-2', '10754-0', '10755-7', '10756-5', '10757-3', '10758-1', '10759-9', '1076-9', '10760-7', '10761-5', '10762-3', '10763-1', '10764-9', '10765-6', '10766-4', '10767-2', '10768-0', '10769-8', '1077-7', '10770-6', '10771-4', '10772-2', '10773-0', '10774-8', '10775-5', '10776-3', '10777-1', '10778-9', '10779-7', '1078-5', '10780-5', '10781-3', '10782-1', '10783-9', '10784-7', '10785-4', '10786-2', '10787-0', '10788-8', '10789-6', '1079-3', '10790-4', '10791-2', '10792-0', '10793-8', '10794-6', '10795-3', '10796-1', '10797-9', '10798-7', '10799-5', '108-1', '1080-1', '10800-1', '10801-9', '10802-7', '10803-5', '10804-3', '10805-0', '10806-8', '10807-6', '10808-4', '10809-2', '1081-9', '10810-0', '10811-8', '10812-6', '10813-4', '10814-2', '10815-9', '10816-7', '10817-5', '10818-3', '10819-1', '1082-7', '10820-9', '10821-7', '10822-5', '10823-3', '10824-1', '10825-8', '10826-6', '10827-4', '10828-2', '10829-0', '1083-5', '10830-8', '10831-6', '10832-4', '10833-2', '10834-0', '10835-7', '10836-5', '10837-3', '10838-1', '10839-9', '1084-3', '10840-7', '10841-5', '10842-3', '10843-1', '10844-9', '10845-6', '10846-4', '10847-2', '10848-0', '10849-8', '1085-0', '10850-6', '10851-4', '10852-2', '10853-0', '10854-8', '10855-5', '10856-3', '10857-1', '10858-9', '10859-7', '1086-8', '10860-5', '10861-3', '10862-1', '10863-9', '10864-7', '10865-4', '10866-2', '10867-0', '10868-8', '10869-6', '1087-6', '10870-4', '10871-2', '10872-0', '10873-8', '10874-6', '10875-3', '10876-1', '10877-9', '10878-7', '10879-5', '1088-4', '10880-3', '10881-1', '10882-9', '10883-7', '10884-5', '10885-2', '10886-0', '10887-8', '10888-6', '10889-4', '1089-2', '10890-2', '10891-0', '10892-8', '10893-6', '10894-4', '10895-1', '10896-9', '10897-7', '10898-5']}, 'type'=>'CodeableConcept', 'path'=>'Component.code', 'min'=>1, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/observation-codes'}},
          'valueQuantity' => {'type'=>'Quantity', 'path'=>'Component.value[x]', 'min'=>0, 'max'=>1},
          'valueCodeableConcept' => {'type'=>'CodeableConcept', 'path'=>'Component.value[x]', 'min'=>0, 'max'=>1},
          'valueString' => {'type'=>'string', 'path'=>'Component.value[x]', 'min'=>0, 'max'=>1},
          'valueRange' => {'type'=>'Range', 'path'=>'Component.value[x]', 'min'=>0, 'max'=>1},
          'valueRatio' => {'type'=>'Ratio', 'path'=>'Component.value[x]', 'min'=>0, 'max'=>1},
          'valueSampledData' => {'type'=>'SampledData', 'path'=>'Component.value[x]', 'min'=>0, 'max'=>1},
          'valueAttachment' => {'type'=>'Attachment', 'path'=>'Component.value[x]', 'min'=>0, 'max'=>1},
          'valueTime' => {'type'=>'time', 'path'=>'Component.value[x]', 'min'=>0, 'max'=>1},
          'valueDateTime' => {'type'=>'dateTime', 'path'=>'Component.value[x]', 'min'=>0, 'max'=>1},
          'valuePeriod' => {'type'=>'Period', 'path'=>'Component.value[x]', 'min'=>0, 'max'=>1},
          'dataAbsentReason' => {'valid_codes'=>{'http://hl7.org/fhir/data-absent-reason'=>['unknown', 'asked', 'temp', 'not-asked', 'masked', 'unsupported', 'astext', 'error', 'NaN', 'not-performed']}, 'type'=>'CodeableConcept', 'path'=>'Component.dataAbsentReason', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'extensible', 'uri'=>'http://hl7.org/fhir/ValueSet/observation-valueabsentreason'}},
          'interpretation' => {'valid_codes'=>{'http://hl7.org/fhir/v2/0078'=>['<', '>', 'A', 'AA', 'AC', 'B', 'D', 'DET', 'H', 'HH', 'HM', 'HU', 'I', 'IE', 'IND', 'L', 'LL', 'LU', 'MS', 'N', 'ND', 'NEG', 'NR', 'NS', 'null', 'OBX', 'POS', 'QCF', 'R', 'RR', 'S', 'SDD', 'SYN-R', 'SYN-S', 'TOX', 'U', 'VS', 'W', 'WR']}, 'type'=>'CodeableConcept', 'path'=>'Component.interpretation', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'extensible', 'uri'=>'http://hl7.org/fhir/ValueSet/observation-interpretation'}},
          'referenceRange' => {'type'=>'Observation::ReferenceRange', 'path'=>'Component.referenceRange', 'min'=>0, 'max'=>Float::INFINITY}
        }

        attr_accessor :id                   # 0-1 string
        attr_accessor :extension            # 0-* [ Extension ]
        attr_accessor :modifierExtension    # 0-* [ Extension ]
        attr_accessor :code                 # 1-1 CodeableConcept
        attr_accessor :valueQuantity        # 0-1 Quantity
        attr_accessor :valueCodeableConcept # 0-1 CodeableConcept
        attr_accessor :valueString          # 0-1 string
        attr_accessor :valueRange           # 0-1 Range
        attr_accessor :valueRatio           # 0-1 Ratio
        attr_accessor :valueSampledData     # 0-1 SampledData
        attr_accessor :valueAttachment      # 0-1 Attachment
        attr_accessor :valueTime            # 0-1 time
        attr_accessor :valueDateTime        # 0-1 dateTime
        attr_accessor :valuePeriod          # 0-1 Period
        attr_accessor :dataAbsentReason     # 0-1 CodeableConcept
        attr_accessor :interpretation       # 0-1 CodeableConcept
        attr_accessor :referenceRange       # 0-* [ Observation::ReferenceRange ]
      end

      attr_accessor :id                   # 0-1 id
      attr_accessor :meta                 # 0-1 Meta
      attr_accessor :implicitRules        # 0-1 uri
      attr_accessor :language             # 0-1 code
      attr_accessor :text                 # 0-1 Narrative
      attr_accessor :contained            # 0-* [ Resource ]
      attr_accessor :extension            # 0-* [ Extension ]
      attr_accessor :modifierExtension    # 0-* [ Extension ]
      attr_accessor :identifier           # 0-* [ Identifier ]
      attr_accessor :basedOn              # 0-* [ Reference(CarePlan|DeviceRequest|ImmunizationRecommendation|MedicationRequest|NutritionOrder|ProcedureRequest|ReferralRequest) ]
      attr_accessor :status               # 1-1 code
      attr_accessor :category             # 0-* [ CodeableConcept ]
      attr_accessor :code                 # 1-1 CodeableConcept
      attr_accessor :subject              # 0-1 Reference(Patient|Group|Device|Location)
      attr_accessor :context              # 0-1 Reference(Encounter|EpisodeOfCare)
      attr_accessor :effectiveDateTime    # 0-1 dateTime
      attr_accessor :effectivePeriod      # 0-1 Period
      attr_accessor :issued               # 0-1 instant
      attr_accessor :performer            # 0-* [ Reference(Practitioner|Organization|Patient|RelatedPerson) ]
      attr_accessor :valueQuantity        # 0-1 Quantity
      attr_accessor :valueCodeableConcept # 0-1 CodeableConcept
      attr_accessor :valueString          # 0-1 string
      attr_accessor :valueBoolean         # 0-1 boolean
      attr_accessor :valueRange           # 0-1 Range
      attr_accessor :valueRatio           # 0-1 Ratio
      attr_accessor :valueSampledData     # 0-1 SampledData
      attr_accessor :valueAttachment      # 0-1 Attachment
      attr_accessor :valueTime            # 0-1 time
      attr_accessor :valueDateTime        # 0-1 dateTime
      attr_accessor :valuePeriod          # 0-1 Period
      attr_accessor :dataAbsentReason     # 0-1 CodeableConcept
      attr_accessor :interpretation       # 0-1 CodeableConcept
      attr_accessor :comment              # 0-1 string
      attr_accessor :bodySite             # 0-1 CodeableConcept
      attr_accessor :local_method         # 0-1 CodeableConcept
      attr_accessor :specimen             # 0-1 Reference(Specimen)
      attr_accessor :device               # 0-1 Reference(Device|DeviceMetric)
      attr_accessor :referenceRange       # 0-* [ Observation::ReferenceRange ]
      attr_accessor :related              # 0-* [ Observation::Related ]
      attr_accessor :component            # 0-* [ Observation::Component ]

      def resourceType
        'Observation'
      end
    end
  end
end