module FHIR
  module STU3
    class Procedure < FHIR::STU3::Model
      include FHIR::STU3::Hashable
      include FHIR::STU3::Json
      include FHIR::STU3::Xml

      MULTIPLE_TYPES = {
        'performed' => ['dateTime', 'Period']
      }
      SEARCH_PARAMS = ['code', 'date', 'identifier', 'patient', 'encounter', 'based-on', 'category', 'context', 'definition', 'location', 'part-of', 'performer', 'status', 'subject']
      METADATA = {
        'id' => {'type'=>'id', 'path'=>'Procedure.id', 'min'=>0, 'max'=>1},
        'meta' => {'type'=>'Meta', 'path'=>'Procedure.meta', 'min'=>0, 'max'=>1},
        'implicitRules' => {'type'=>'uri', 'path'=>'Procedure.implicitRules', 'min'=>0, 'max'=>1},
        'language' => {'valid_codes'=>{'urn:ietf:bcp:47'=>['ar', 'bn', 'cs', 'da', 'de', 'de-AT', 'de-CH', 'de-DE', 'el', 'en', 'en-AU', 'en-CA', 'en-GB', 'en-IN', 'en-NZ', 'en-SG', 'en-US', 'es', 'es-AR', 'es-ES', 'es-UY', 'fi', 'fr', 'fr-BE', 'fr-CH', 'fr-FR', 'fy', 'fy-NL', 'hi', 'hr', 'it', 'it-CH', 'it-IT', 'ja', 'ko', 'nl', 'nl-BE', 'nl-NL', 'no', 'no-NO', 'pa', 'pt', 'pt-BR', 'ru', 'ru-RU', 'sr', 'sr-SP', 'sv', 'sv-SE', 'te', 'zh', 'zh-CN', 'zh-HK', 'zh-SG', 'zh-TW']}, 'type'=>'code', 'path'=>'Procedure.language', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'extensible', 'uri'=>'http://hl7.org/fhir/ValueSet/languages'}},
        'text' => {'type'=>'Narrative', 'path'=>'Procedure.text', 'min'=>0, 'max'=>1},
        'contained' => {'type'=>'Resource', 'path'=>'Procedure.contained', 'min'=>0, 'max'=>Float::INFINITY},
        'extension' => {'type'=>'Extension', 'path'=>'Procedure.extension', 'min'=>0, 'max'=>Float::INFINITY},
        'modifierExtension' => {'type'=>'Extension', 'path'=>'Procedure.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
        'identifier' => {'type'=>'Identifier', 'path'=>'Procedure.identifier', 'min'=>0, 'max'=>Float::INFINITY},
        'definition' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/PlanDefinition', 'http://hl7.org/fhir/StructureDefinition/ActivityDefinition', 'http://hl7.org/fhir/StructureDefinition/HealthcareService'], 'type'=>'Reference', 'path'=>'Procedure.definition', 'min'=>0, 'max'=>Float::INFINITY},
        'basedOn' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/CarePlan', 'http://hl7.org/fhir/StructureDefinition/ProcedureRequest', 'http://hl7.org/fhir/StructureDefinition/ReferralRequest'], 'type'=>'Reference', 'path'=>'Procedure.basedOn', 'min'=>0, 'max'=>Float::INFINITY},
        'partOf' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Procedure', 'http://hl7.org/fhir/StructureDefinition/Observation', 'http://hl7.org/fhir/StructureDefinition/MedicationAdministration'], 'type'=>'Reference', 'path'=>'Procedure.partOf', 'min'=>0, 'max'=>Float::INFINITY},
        'status' => {'valid_codes'=>{'http://hl7.org/fhir/event-status'=>['preparation', 'in-progress', 'suspended', 'aborted', 'completed', 'entered-in-error', 'unknown']}, 'type'=>'code', 'path'=>'Procedure.status', 'min'=>1, 'max'=>1, 'binding'=>{'strength'=>'required', 'uri'=>'http://hl7.org/fhir/ValueSet/event-status'}},
        'notDone' => {'type'=>'boolean', 'path'=>'Procedure.notDone', 'min'=>0, 'max'=>1},
        'notDoneReason' => {'valid_codes'=>{'http://snomed.info/sct'=>['135809002', '135811006', '135822005', '135823000', '169551000', '170954008', '171277005', '171284002', '183934000', '183936003', '266757004', '266758009', '268560002', '275935009', '275974002', '312451002', '315061006', '315062004', '315363002', '315364008', '315591006', '390795005', '390796006', '390910005', '394987009', '395174005', '395175006', '395675007', '407582002', '413558003', '414055003', '414159007', '414677003', '415571003', '415666001', '416091008', '416475003', '416704001', '416759002', '416996000', '417101006', '417128001', '438767006', '438833006', '698468005', '698521002', '699037006', '703997000', '703999002', '707298000', '715163003', '715166006', '170624001', '170688000', '170689008', '170919001', '170958006', '182840001', '182841002', '182842009', '182843004', '182844005', '182845006', '182846007', '274512008', '309841001', '394909009', '395006008', '395007004', '395008009', '395009001', '412782003', '425519007', '425921008', '426970003', '426999008', '427569000', '430279008', '438604008', '439516000', '710765004', '713246009', '713247000', '713248005', '162650008', '162675007', '162882008', '162980001', '163128002', '163348001', '163582008', '163628001', '163900009', '164176006', '164286000', '164321005', '164445005', '164503006', '164713001', '164725003', '164746007', '164766003', '164776000', '164786004', '164795007', '164808009', '164823004', '164831009', '164853006', '164964005', '164978006', '164985005', '164997006', '165008002', '165017002', '165026004', '165035006', '165074004', '165081006', '165104002', '165122004', '165139002', '165343008', '165377003', '165393007', '167219008', '167260001', '167272007', '167286006', '167296002', '167306007', '167317008', '167322008', '167594003', '167701000', '167728005', '168497006', '169607004', '169610006', '169611005', '169699008', '169704000', '169708002', '170100005', '170108003', '170117003', '170126000', '170135007', '170144008', '170153001', '170162004', '170171008', '170180008', '170257006', '170266005', '170275007', '170284007', '170293008', '170304008', '182849000', '183928007', '183929004', '183930009', '266756008', '266881002', '309846006', '310352003', '314374001', '371900001', '373147003', '373148008', '390848004', '391016008', '394965000', '396781004', '397004005', '397399004', '399538001', '401318002', '408504000', '408836004', '408837008', '416128008', '418014008', '418731009', '428348004', '439867009', '441989008', '443788002', '698569004', '698753008', '699231000', '703942005', '712751006', '712985002', '713207007', '715621003', '715622005', '4451000175106', '4461000175108', '4471000175100', '4501000175108', '4541000175105', '4551000175107', '4591000175100', '5991000175105', '6021000175100', '6031000175102', '6041000175108', '6051000175105', '134390006', '134391005', '134392003', '134394002', '135805008', '135806009', '135807000', '135808005', '183964008', '183965009', '183966005', '315214003', '407571005', '407572003', '407573008', '408339001', '408396006', '408397002', '408398007', '413167008', '413560001', '413812009', '415119001', '415570002', '415667005', '416664005', '416670004', '416678006', '416741000', '417013004', '417218000', '417434004', '699048004', '700384008', '703971006', '703996009', '704000000', '704033005', '704052004', '704096004', '707287001', '707853004', '709198003', '712740006', '146922001', '147022006', '148324002', '148477008', '169608009', '170115006', '170124002', '170133000', '170142007', '170151004', '170160007', '170169008', '170178002', '170255003', '170264008', '170273000', '170282006', '170291005', '170301000', '408506003', '444062004', '712790005', '712803007', '712812009', '712851004', '712852006', '712854007', '712869008', '712870009', '712872001', '712996005', '169609001', '169635000', '169649009', '169660000', '169687001', '169693009', '169795009', '169796005', '170116007', '170125001', '170134006', '170143002', '170152006', '170161006', '170170009', '170179005', '170256002', '170265009', '170274006', '170283001', '170292003', '170302007', '171034000', '171103002', '171152003', '184163005', '408505004', '105480006', '134385008', '134386009', '134396000', '134397009', '134398004', '135812004', '135814003', '135825007', '135826008', '165342003', '165376007', '168499009', '182895007', '182896008', '182897004', '182898009', '182899001', '182900006', '182901005', '182902003', '182903008', '183945002', '183946001', '183947005', '183948000', '183949008', '183956002', '183957006', '183958001', '183959009', '183960004', '183961000', '183962007', '185754009', '275936005', '315020006', '315021005', '315022003', '315023008', '315640000', '371138003', '390914001', '391015007', '395176007', '395703005', '401047000', '401084003', '401086001', '406149000', '407583007', '408548005', '408549002', '408551003', '408558009', '408559001', '408566000', '408567009', '408569007', '408572000', '408778004', '408791003', '408795007', '412713002', '412718006', '412725004', '412752009', '413122001', '413123006', '413310006', '413311005', '413312003', '413559006', '413756001', '415572005', '416126007', '416522000', '416888009', '417045009', '417114007', '417512003', '426544006', '428042006', '428073005', '428299008', '428650003', '428841003', '429284000', '429688007', '429726000', '429739001', '438370008', '438765003', '439495000', '440621003', '442324008', '442392002', '442444001', '444020006', '473149004', '698357006', '698451006', '698460003', '698473004', '698483000', '698484006', '698490005', '698758004', '698950001', '699034004', '699042003', '699053009', '699054003', '699128009', '699137009', '700359005', '700411009', '703427001', '703989007', '703991004', '703992006', '704046000', '704047009', '704049007', '704051006', '704097008', '705140004', '706890009', '707745004', '707746003', '708129006', '713068007', '713615000', '714747005', '715508000', '716048005', '591000119102', '921000119109', '116101000119100', '168533005', '170585007', '170588009', '170620005', '170621009', '170675003', '170687005', '170700002', '170712003', '170725006', '170800007', '170816009', '170826002', '170834008', '170843004', '170854009', '170863006', '170872003', '170882002', '170894006', '170904002', '170912005', '170929008', '180863000', '268521004', '288120003', '391021006', '397023003', '414120003', '698459008', '700110004', '708000007']}, 'type'=>'CodeableConcept', 'path'=>'Procedure.notDoneReason', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/procedure-not-performed-reason'}},
        'category' => {'valid_codes'=>{'http://snomed.info/sct'=>['24642003', '409063005', '409073007', '387713003', '103693007', '46947000']}, 'type'=>'CodeableConcept', 'path'=>'Procedure.category', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/procedure-category'}},
        'code' => {'valid_codes'=>{'http://snomed.info/sct'=>['104001', '115006', '119000', '121005', '128004', '133000', '135007', '142007', '146005', '153001', '160007', '166001', '170009', '174000', '176003', '189009', '197002', '230009', '243009', '245002', '262007', '267001', '285008', '294002', '295001', '306005', '316002', '334003', '342002', '346004', '348003', '351005', '352003', '353008', '374009', '388008', '389000', '401004', '406009', '417005', '435001', '445004', '456004', '459006', '463004', '468008', '474008', '489004', '493005', '494004', '497006', '503003', '531007', '533005', '535003', '540006', '543008', '545001', '549007', '550007', '559008', '570001', '574005', '603006', '617002', '618007', '625000', '628003', '629006', '633004', '637003', '642006', '645008', '647000', '657004', '665001', '670008', '671007', '673005', '674004', '676002', '680007', '687005', '695009', '697001', '710006', '712003', '721002', '722009', '726007', '730005', '741007', '746002', '753006', '754000', '759005', '762008', '764009', '767002', '789003', '791006', '807005', '814007', '817000', '831000', '851001', '853003', '867007', '870006', '879007', '881009', '893000', '897004', '910002', '911003', '913000', '926001', '935008', '941001', '945005', '948007', '951000', '956005', '967006', '969009', '971009', '1001000', '1008006', '1019009', '1021004', '1029002', '1032004', '1035002', '1036001', '1041009', '1042002', '1043007', '1044001', '1048003', '1054002', '1071001', '1084005', '1093006', '1103000', '1104006', '1115001', '1119007', '1121002', '1127003', '1133007', '1163003', '1176009', '1181000', '1186005', '1198000', '1209007', '1225002', '1227005', '1235008', '1237000', '1238005', '1251000', '1253002', '1258006', '1266002', '1267006', '1278003', '1279006', '1292009', '1299000', '1315009', '1316005', '1324000', '1327007', '1328002', '1329005', '1337002', '1339004', '1347004', '1352009', '1358008', '1366004', '1385001', '1390003', '1398005', '1399002', '1407007', '1410000', '1411001', '1413003', '1414009', '1417002', '1431002', '1440003', '1449002', '1453000', '1455007', '1457004', '1494008', '1500007', '1501006', '1505002', '1529009', '1533002', '1550000', '1555005', '1559004', '1576000', '1577009', '1578004', '1583007', '1585000', '1596008', '1597004', '1602006', '1614003', '1615002', '1616001', '1636000', '1638004', '1640009', '1645004', '1651009', '1653007', '1669000', '1677001', '1678006', '1680000', '1683003', '1689004', '1691007', '1699009', '1702002', '1704001', '1709006', '1712009', '1713004', '1730002', '1746005', '1747001', '1753001', '1757000', '1759002', '1770009', '1774000', '1775004', '1784004', '1787006', '1788001', '1801001', '1805005', '1811008', '1813006', '1820004', '1830008', '1836002', '1844002', '1854003', '1859008', '1861004', '1862006', '1866009', '1868005', '1870001', '1871002', '1872009', '1876007', '1879000', '1889001', '1906007', '1907003', '1917008', '1924009', '1950008', '1958001', '1966005', '1983001', '1995001', '1999007', '2002009', '2021001', '2051007', '2054004', '2067001', '2069003', '2078009', '2079001', '2080003', '2098004', '2115003', '2119009', '2127000', '2137005', '2153008', '2161003', '2164006', '2166008', '2171001', '2178007', '2181002', '2188008', '2193006', '2196003', '2199005', '2214008', '2220009', '2225004', '2234009', '2238007', '2242005', '2244006', '2250001', '2252009', '2266004', '2267008', '2270007', '2276001', '2278000', '2279008', '2290003', '2315006', '2318008', '2321005', '2322003', '2337004', '2344008', '2347001', '2364003', '2371008', '2373006', '2382000', '2386002', '2393003', '2406000', '2407009', '2408004', '2409007', '2425002', '2442008', '2448007', '2455009', '2457001', '2458006', '2459003', '2461007', '2474001', '2475000', '2480009', '2486003', '2488002', '2494005', '2498008', '2507007', '2508002', '2514009', '2517002', '2530001', '2531002', '2535006', '2536007', '2547000', '2552005', '2564002', '2566000', '2567009', '2580007', '2598006', '2601001', '2607002', '2613006', '2614000', '2616003', '2619005', '2629003', '2632000', '2642003', '2643008', '2644002', '2645001', '2646000', '2658000', '2659008', '2668005', '2670001', '2673004', '2677003', '2690005', '2693007', '2696004', '2697008', '2716009', '2722000', '2731000', '2732007', '2737001', '2742009', '2743004', '2745006', '2752008', '2780005', '2794006', '2802005', '2811005', '2813008', '2837008', '2842000', '2843005', '2847006', '2851008', '2854000', '2857007', '2866006', '2875008', '2876009', '2885009', '2891006', '2898000', '2903001', '2908005', '2914003', '2915002', '2933008', '2945004', '2947007', '2960001', '2968008', '2970004', '2971000', '2977001', '3001009', '3010001', '3016007', '3025001', '3026000', '3029007', '3041000', '3047001', '3060007', '3061006', '3063009', '3075004', '3078002', '3083005', '3088001', '3090000', '3112006', '3116009', '3130004', '3133002', '3137001', '3143004', '3162001', '3164000', '3165004', '3166003', '3177009', '3183007', '3186004', '3190002', '3204007', '3241008', '3249005', '3251009', '3256004', '3257008', '3258003', '3268008', '3270004', '3278006', '3287002', '3320000', '3324009', '3326006', '3328007', '3333006', '3338002', '3352000', '3357006', '3360004', '3390006', '3399007', '3407002', '3413006', '3418002', '3432000', '3443008', '3448004', '3450007', '3457005', '3479000', '3498003', '3499006', '3509001', '3512003', '3515001', '3517009', '3518004', '3527003', '3546002', '3559005', '3562008', '3564009', '3575008', '3580004', '3605001', '3607009', '3620007', '3625002', '3651000', '3654008', '3659003', '3664004', '3666002', '3669009', '3673007', '3683006', '3686003', '3688002', '3690001', '3691002', '3697003', '3700004', '3701000', '3713005', '3717006', '3734003', '3735002', '3740005', '3748003', '3749006', '3758004', '3770000', '3778007', '3780001', '3784005', '3786007', '3787003', '3794000', '3796003', '3799005', '3802001', '3819004', '3826004', '3828003', '3831002', '3843001', '3858009', '3861005', '3862003', '3864002', '3880007', '3881006', '3887005', '3889008', '3891000', '3895009', '3907006', '3911000', '3915009', '3917001', '3918006', '3926003', '3929005', '3936006', '3938007', '3942005', '3955006', '3957003', '3963007', '3967008', '3968003', '3969006', '3971006', '3980006', '3981005', '3985001', '3991004', '3998005', '4007002', '4008007', '4010009', '4027001', '4034004', '4035003', '4036002', '4037006', '4044002', '4045001', '4052004', '4064007', '4068005', '4083000', '4084006', '4090005', '4094001', '4101004', '4102006', '4114003', '4116001', '4119008', '4131005', '4134002', '4139007', '4143006', '4149005', '4154001', '4165006', '4176005', '4192000', '4213001', '4214007', '4226002', '4252008', '4263006', '4266003', '4285000', '4293000', '4304000', '4319004', '4321009', '4323007', '4331002', '4333004', '4336007', '4337003', '4339000', '4341004', '4344007', '4348005', '4350002', '4363008', '4365001', '4380007', '4387005', '4388000', '4407008', '4411002', '4420006', '4424002', '4436008', '4438009', '4443002', '4447001', '4449003', '4450003', '4455008', '4457000', '4466001', '4467005', '4475004', '4487006', '4489009', '4496006', '4503005', '4504004', '4505003', '4507006', '4511000', '4516005', '4520009', '4525004', '4533003', '4535005', '4539004', '4542005', '4544006', '4558008', '4563007', '4570007', '4579008', '4581005', '4585001', '4587009', '4589007', '4593001', '4594007', '4613005', '4625008', '4626009', '4636001', '4640005', '4642002', '4660002', '4670000', '4671001', '4672008', '4691008', '4692001', '4694000', '4699005', '4701005', '4707009', '4712005', '4713000', '4719001', '4727005', '4734007', '4737000', '4756005', '4758006', '4764004', '4765003', '4770005', '4772002', '4784000', '4804005', '4811009', '4815000', '4820000', '4827002', '4829004', '4847005', '4849008', '4862007', '4877004', '4891005', '4895001', '4902005', '4903000', '4904006', '4914002', '4929000', '4930005', '4934001', '4957007', '4966006', '4970003', '4974007', '4976009', '4987001', '4992004', '4993009', '5016005', '5019003', '5021008', '5022001', '5025004', '5032008', '5034009', '5048009', '5055006', '5057003', '5065000', '5091004', '5105000', '5110001', '5113004', '5119000', '5121005', '5123008', '5130002', '5131003', '5135007', '5147001', '5151004', '5154007', '5161006', '5162004', '5165002', '5176003', '5182000', '5184004', '5186002', '5190000', '5191001', '5212002', '5216004', '5233006', '5243009', '5245002', '5246001', '5264008', '5267001', '5270002', '5273000', '5282006', '5290006', '5298004', '5304008', '5316002', '5317006', '5326009', '5328005', '5337005', '5338000', '5342002', '5348003', '5357009', '5373003', '5384005', '5391008', '5393006', '5402006', '5407000', '5415002', '5419008', '5422005', '5429001', '5431005', '5433008', '5446003', '5447007', '5452002', '5456004', '5457008', '5460001', '5479003', '5482008', '5486006', '5489004', '5506006', '5517007', '5521000', '5536002', '5545001', '5551006', '5556001', '5570001', '5571002', '5572009', '5586008', '5608002', '5616006', '5621009', '5632009', '5636007', '5638008', '5648005', '5651003', '5663008', '5669007', '5671007', '5687005', '5690004', '5694008', '5721002', '5722009', '5726007', '5728008', '5731009', '5733007', '5738003', '5745003', '5760000', '5771004', '5777000', '5781000', '5785009', '5787001', '5789003', '5796001', '5806001', '5807005', '5809008', '5812006', '5818005', '5821007', '5823005', '5832007', '5845006', '5846007', '5857002', '5865004', '5870006', '5880005', '5892005', '5894006', '5897004', '5902003', '5925002', '5930003', '5947002', '5961007', '5966002', '5971009', '5983006', '5986003', '5992009', '5995006', '5997003', '5998008', '6005008', '6007000', '6019008', '6025007', '6026008', '6029001', '6035001', '6063004', '6069000', '6082008', '6092000', '6100001', '6108008', '6119006', '6125005', '6126006', '6127002', '6130009', '6133006', '6143009', '6146001', '6148000', '6157006', '6159009', '6161000', '6164008', '6166005', '6177004', '6187000', '6188005', '6189002', '6190006', '6195001', '6198004', '6200005', '6205000', '6213004', '6221005', '6225001', '6226000', '6227009', '6231003', '6238009', '6240004', '6255008', '6271008', '6274000', '6286002', '6289009', '6295005', '6307005', '6309008', '6319002', '6337001', '6339003', '6343004', '6353003', '6354009', '6355005', '6358007', '6361008', '6363006', '6370006', '6384001', '6385000', '6388003', '6396008', '6397004', '6399001', '6402000', '6403005', '6419003', '6429005', '6433003', '6434009', '6438007', '6439004', '6443000', '6444006', '6465000', '6466004', '6470007', '6473009', '6480006', '6486000', '6487009', '6491004', '6499002', '6502003', '6506000', '6519001', '6521006', '6527005', '6535008', '6536009', '6543003', '6547002', '6555009', '6556005', '6562000', '6563005', '6567006', '6568001', '6585004', '6589005', '6601003', '6614002', '6615001', '6622009', '6634001', '6639006', '6650009', '6656003', '6657007', '6658002', '6661001', '6665005', '6668007', '6670003']}, 'type'=>'CodeableConcept', 'path'=>'Procedure.code', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/procedure-code'}},
        'subject' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Patient', 'http://hl7.org/fhir/StructureDefinition/Group'], 'type'=>'Reference', 'path'=>'Procedure.subject', 'min'=>1, 'max'=>1},
        'context' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Encounter', 'http://hl7.org/fhir/StructureDefinition/EpisodeOfCare'], 'type'=>'Reference', 'path'=>'Procedure.context', 'min'=>0, 'max'=>1},
        'performedDateTime' => {'type'=>'dateTime', 'path'=>'Procedure.performed[x]', 'min'=>0, 'max'=>1},
        'performedPeriod' => {'type'=>'Period', 'path'=>'Procedure.performed[x]', 'min'=>0, 'max'=>1},
        'performer' => {'type'=>'Procedure::Performer', 'path'=>'Procedure.performer', 'min'=>0, 'max'=>Float::INFINITY},
        'location' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Location'], 'type'=>'Reference', 'path'=>'Procedure.location', 'min'=>0, 'max'=>1},
        'reasonCode' => {'valid_codes'=>{'http://snomed.info/sct'=>['109006', '122003', '127009', '129007', '134006', '140004', '144008', '147001', '150003', '151004', '162004', '165002', '168000', '171008', '172001', '175004', '177007', '179005', '181007', '183005', '184004', '188001', '192008', '193003', '195005', '198007', '199004', '208008', '216004', '219006', '222008', '223003', '228007', '241006', '242004', '253005', '257006', '258001', '264008', '276008', '279001', '281004', '282006', '290006', '292003', '297009', '299007', '303002', '308006', '310008', '313005', '317006', '320003', '324007', '330007', '335002', '341009', '349006', '355001', '357009', '358004', '359007', '360002', '364006', '366008', '368009', '369001', '378007', '382009', '383004', '385006', '387003', '398002', '407000', '408005', '409002', '426008', '431005', '437009', '440009', '442001', '443006', '447007', '450005', '452002', '460001', '467003', '470004', '479003', '486006', '488007', '490008', '496002', '504009', '517007', '518002', '520004', '527001', '536002', '539009', '547009', '548004', '554003', '555002', '563001', '568005', '586008', '590005', '596004', '599006', '600009', '602001', '607007', '610000', '613003', '615005', '616006', '626004', '631002', '634005', '640003', '643001', '646009', '649002', '651003', '652005', '655007', '658009', '663008', '664002', '666000', '675003', '682004', '685002', '701003', '703000', '714002', '715001', '718004', '733007', '734001', '736004', '750009', '755004', '756003', '758002', '775008', '776009', '781000', '786005', '787001', '788006', '792004', '799008', '801006', '805002', '811004', '813001', '815008', '816009', '818005', '825003', '827006', '832007', '834008', '841002', '842009', '843004', '844005', '845006', '849000', '857002', '862001', '865004', '871005', '874002', '875001', '888003', '890002', '899001', '903008', '904002', '908004', '919001', '928000', '931004', '932006', '934007', '943003', '954008', '961007', '962000', '964004', '965003', '975000', '978003', '981008', '984000', '987007', '991002', '998008', '1003002', '1020003', '1023001', '1027000', '1031006', '1033009', '1034003', '1038000', '1045000', '1046004', '1051005', '1055001', '1059007', '1070000', '1073003', '1074009', '1077002', '1079004', '1085006', '1089000', '1102005', '1107004', '1108009', '1111005', '1112003', '1116000', '1124005', '1125006', '1126007', '1131009', '1134001', '1135000', '1139006', '1140008', '1141007', '1145003', '1150009', '1151008', '1152001', '1155004', '1156003', '1168007', '1184008', '1192004', '1194003', '1196001', '1197005', '1201005', '1203008', '1207009', '1208004', '1212005', '1214006', '1230003', '1232006', '1239002', '1240000', '1259003', '1261007', '1264004', '1271009', '1280009', '1282001', '1283006', '1284000', '1286003', '1287007', '1297003', '1308001', '1310004', '1317001', '1318006', '1323006', '1332008', '1335005', '1343000', '1345007', '1351002', '1356007', '1361009', '1363007', '1367008', '1370007', '1372004', '1376001', '1378000', '1380006', '1383008', '1384002', '1386000', '1387009', '1388004', '1393001', '1395008', '1402001', '1412008', '1415005', '1418007', '1419004', '1426004', '1427008', '1430001', '1447000', '1469007', '1474004', '1475003', '1478001', '1479009', '1482004', '1486001', '1488000', '1489008', '1492007', '1493002', '1499003', '1512006', '1515008', '1518005', '1519002', '1521007', '1523005', '1525003', '1531000', '1532007', '1534008', '1538006', '1539003', '1542009', '1544005', '1551001', '1556006', '1563006', '1567007', '1588003', '1592005', '1593000', '1606009', '1608005', '1639007', '1647007', '1648002', '1654001', '1657008', '1658003', '1663004', '1667003', '1670004', '1671000', '1674008', '1679003', '1682008', '1685005', '1686006', '1694004', '1698001', '1703007', '1705000', '1708003', '1714005', '1717003', '1723008', '1724002', '1734006', '1735007', '1739001', '1742007', '1744008', '1748006', '1755008', '1761006', '1763009', '1767005', '1769008', '1771008', '1776003', '1777007', '1778002', '1779005', '1794009', '1816003', '1821000', '1822007', '1824008', '1826005', '1828006', '1829003', '1833005', '1835003', '1837006', '1845001', '1847009', '1848004', '1852004', '1855002', '1856001', '1857005', '1858000', '1860003', '1865008', '1869002', '1881003', '1892002', '1896004', '1897008', '1899006', '1903004', '1908008', '1909000', '1922008', '1926006', '1938002', '1939005', '1943009', '1953005', '1954004', '1955003', '1959009', '1961000', '1963002', '1965009', '1967001', '1973000', '1977004', '1979001', '1980003', '1981004', '1988005', '1989002', '2004005', '2012002', '2024009', '2028007', '2032001', '2036003', '2040007', '2041006', '2043009', '2053005', '2055003', '2058001', '2061000', '2065009', '2066005', '2070002', '2073000', '2087000', '2089002', '2091005', '2094002', '2102007', '2103002', '2107001', '2109003', '2114004', '2116002', '2120003', '2121004', '2128005', '2129002', '2132004', '2134003', '2136001', '2138000', '2145000', '2149006', '2158004', '2167004', '2169001', '2170000', '2176006', '2177002', '2186007', '2198002', '2202000', '2204004', '2213002', '2216005', '2217001', '2219003', '2224000', '2228002', '2229005', '2231001', '2237002', '2239004', '2241003', '2243000', '2245007', '2251002', '2256007', '2261009', '2268003', '2284002', '2295008', '2296009', '2298005', '2301009', '2303007', '2304001', '2307008', '2308003', '2312009', '2314005', '2326000', '2339001', '2341000', '2351004', '2355008', '2359002', '2365002', '2366001', '2367005', '2374000', '2385003', '2388001', '2390000', '2391001', '2396006', '2398007', '2403008', '2415007', '2418009', '2419001', '2420007', '2432006', '2435008', '2437000', '2438005', '2439002', '2443003', '2452007', '2463005', '2469009', '2470005', '2471009', '2472002', '2473007', '2477008', '2492009', '2495006', '2496007', '2506003', '2513003', '2518007', '2521009', '2523007', '2526004', '2528003', '2532009', '2534005', '2538008', '2541004', '2554006', '2556008', '2560006', '2562003', '2576002', '2581006', '2582004', '2583009', '2584003', '2585002', '2589008', '2591000', '2593002', '2602008', '2606006', '2615004', '2618002', '2622007', '2624008', '2625009', '2630008', '2634004', '2638001', '2640006', '2651006', '2655002', '2657005', '2663001', '2665008', '2683000', '2689001', '2694001', '2704003', '2707005', '2713001', '2724004', '2725003', '2733002', '2736005', '2740001', '2749000', '2751001', '2761008', '2764000', '2770006', '2772003', '2775001', '2776000', '2781009', '2782002', '2783007', '2786004', '2790002', '2805007', '2806008', '2807004', '2808009', '2815001', '2816000', '2818004', '2819007', '2825006', '2828008', '2829000', '2831009', '2835000', '2836004', '2838003', '2840008', '2850009', '2853006', '2856003', '2858002', '2884008', '2893009', '2897005', '2899008', '2900003', '2901004', '2902006', '2904007', '2910007', '2912004', '2917005', '2918000', '2919008', '2929001', '2935001', '2940009', '2946003', '2951009', '2955000', '2965006', '2967003', '2972007', '2973002', '2978006', '2981001', '2989004', '2990008', '2992000', '2994004', '2999009', '3002002', '3004001', '3006004', '3009006', '3013004', '3014005', '3018008', '3019000', '3021005', '3023008', '3032005', '3033000', '3038009', '3044008', '3053001', '3059002', '3067005', '3071008', '3072001', '3073006', '3084004', '3089009', '3094009', '3095005', '3097002', '3098007', '3105002', '3109008', '3110003', '3119002', '3129009', '3135009', '3140001', '3144005', '3158007', '3160009', '3163006', '3168002', '3185000', '3199001', '3200003', '3208005', '3214003', '3217005', '3218000', '3219008', '3228009', '3229001', '3230006', '3238004', '3239007', '3253007', '3254001', '3259006', '3261002', '3263004', '3272007', '3274008', '3275009', '3276005', '3277001', '3282008', '3283003', '3286006', '3289004', '3291007', '3298001', '3303004', '3304005', '3305006', '3308008', '3310005', '3321001', '3323003', '3327002', '3331008', '3344003', '3345002', '3355003', '3358001', '3368006', '3376008', '3381004', '3387000', '3391005', '3393008', '3398004', '3401001', '3415004', '3419005', '3421000', '3424008', '3426005', '3427001', '3434004', '3439009', '3441005', '3446000', '3449007', '3456001', '3458000', '3461004', '3464007', '3468005', '3469002', '3472009', '3474005', '3480002', '3482005', '3483000', '3487004', '3500002', '3502005', '3503000', '3505007', '3506008', '3507004', '3511005', '3514002', '3519007', '3528008', '3529000', '3530005', '3531009', '3533007', '3539006', '3542000', '3544004', '3545003', '3548001', '3549009', '3558002', '3560000', '3570003', '3571004', '3577000', '3585009', '3586005', '3589003', '3590007', '3591006', '3598000', '3611003', '3633001', '3634007', '3639002', '3640000', '3641001', '3642008', '3644009', '3649004', '3650004', '3652007', '3657001', '3660008', '3662000', '3677008', '3680009', '3681008', '3696007', '3699000', '3703002', '3704008', '3705009', '3712000', '3716002', '3720003', '3723001', '3733009', '3736001', '3738000', '3744001', '3745000', '3747008', '3750006', '3751005', '3752003', '3754002', '3755001', '3756000', '3759007', '3760002', '3762005', '3763000', '3783004', '3797007', '3798002', '3815005', '3820005', '3827008', '3830001', '3841004', '3845008', '3855007', '3859001', '3873005', '3885002', '3886001', '3899003', '3900008', '3902000', '3903005', '3908001', '3909009', '3913002', '3914008', '3928002', '3939004', '3944006', '3947004', '3950001', '3951002', '3972004', '3975002', '3978000', '3987009', '3993001', '3999002', '4003003', '4004009', '4006006', '4009004', '4016003', '4017007', '4022007', '4026005', '4030008', '4038001', '4039009', '4040006', '4041005', '4046000', '4062006', '4063001', '4069002', '4070001', '4075006', '4082005', '4088009', '4089001', '4092002', '4103001', '4106009', '4107000', '4113009', '4120002', '4124006', '4127004', '4129001', '4135001', '4136000', '4142001', '4152002', '4160001', '4168008', '4170004', '4174008', '4175009', '4178006', '4181001', '4183003', '4184009', '4191007', '4195003', '4197006', '4199009', '4208000', '4210003', '4223005', '4224004', '4225003', '4229009', '4232007', '4237001', '4240001', '4241002', '4242009', '4244005', '4248008', '4249000', '4251001', '4260009', '4262001', '4264000', '4269005', '4273008', '4275001', '4278004', '4283007', '4287008', '4294006', '4300009', '4301008', '4306003', '4307007', '4308002', '4310000', '4313003', '4316006', '4320005', '4324001', '4325000', '4332009', '4338008', '4340003', '4349002', '4354006', '4356008', '4359001', '4364002', '4367009', '4373005', '4374004', '4381006', '4386001', '4390004', '4397001', '4399003', '4403007', '4406004', '4409006', '4410001', '4412009', '4414005', '4416007', '4418008', '4426000', '4434006', '4439001', '4441000', '4445009', '4448006', '4451004', '4461006', '4463009', '4464003', '4465002', '4468000', '4470009', '4473006', '4477007', '4478002', '4481007', '4483005']}, 'type'=>'CodeableConcept', 'path'=>'Procedure.reasonCode', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/procedure-reason'}},
        'reasonReference' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Condition', 'http://hl7.org/fhir/StructureDefinition/Observation'], 'type'=>'Reference', 'path'=>'Procedure.reasonReference', 'min'=>0, 'max'=>Float::INFINITY},
        'bodySite' => {'valid_codes'=>{'http://snomed.info/sct'=>['106004', '107008', '108003', '110001', '111002', '116007', '124002', '149003', '155008', '167005', '202009', '205006', '206007', '221001', '227002', '233006', '235004', '246001', '247005', '251007', '256002', '263002', '266005', '272005', '273000', '283001', '284007', '289002', '301000', '311007', '315003', '318001', '344001', '345000', '356000', '393006', '402006', '405008', '414003', '420002', '422005', '446003', '457008', '461002', '464005', '465006', '471000', '480000', '485005', '528006', '552004', '565008', '582005', '587004', '589001', '595000', '608002', '621009', '635006', '650002', '660006', '661005', '667009', '688000', '691000', '692007', '723004', '774007', '790007', '798000', '808000', '809008', '823005', '830004', '836005', '885000', '895007', '917004', '921006', '947002', '955009', '976004', '996007', '1005009', '1012000', '1015003', '1028005', '1030007', '1063000', '1075005', '1076006', '1086007', '1087003', '1092001', '1099005', '1101003', '1106008', '1110006', '1122009', '1136004', '1159005', '1172006', '1173001', '1174007', '1193009', '1216008', '1231004', '1236009', '1243003', '1246006', '1263005', '1277008', '1307006', '1311000', '1350001', '1353004', '1403006', '1425000', '1439000', '1441004', '1456008', '1467009', '1484003', '1490004', '1502004', '1511004', '1516009', '1527006', '1537001', '1541002', '1562001', '1569005', '1580005', '1581009', '1584001', '1600003', '1605008', '1610007', '1611006', '1617005', '1620002', '1626008', '1627004', '1630006', '1631005', '1650005', '1655000', '1659006', '1684009', '1706004', '1707008', '1711002', '1716007', '1721005', '1729007', '1732005', '1765002', '1780008', '1781007', '1797002', '1818002', '1825009', '1832000', '1840006', '1849007', '1853009', '1874005', '1893007', '1895000', '1902009', '1910005', '1918003', '1927002', '1992003', '1997009', '2010005', '2020000', '2031008', '2033006', '2044003', '2048000', '2049008', '2059009', '2071003', '2076008', '2083001', '2095001', '2123001', '2150006', '2156000', '2160002', '2175005', '2182009', '2192001', '2205003', '2209009', '2236006', '2246008', '2255006', '2285001', '2292006', '2302002', '2305000', '2306004', '2327009', '2330002', '2332005', '2334006', '2349003', '2372001', '2383005', '2389009', '2395005', '2397002', '2400006', '2402003', '2421006', '2433001', '2436009', '2453002', '2454008', '2484000', '2489005', '2499000', '2502001', '2504000', '2510000', '2539000', '2543001', '2550002', '2577006', '2579009', '2592007', '2600000', '2620004', '2639009', '2653009', '2666009', '2672009', '2675006', '2681003', '2682005', '2686008', '2687004', '2695000', '2703009', '2712006', '2718005', '2726002', '2730004', '2739003', '2741002', '2746007', '2748008', '2759004', '2771005', '2789006', '2792005', '2803000', '2810006', '2812003', '2824005', '2826007', '2830005', '2839006', '2841007', '2845003', '2848001', '2855004', '2861001', '2894003', '2905008', '2909002', '2920002', '2922005', '2923000', '2954001', '2969000', '2979003', '2986006', '2998001', '3003007', '3008003', '3028004', '3039001', '3042007', '3054007', '3055008', '3056009', '3057000', '3058005', '3062004', '3068000', '3081007', '3093003', '3100007', '3113001', '3117000', '3118005', '3120008', '3134008', '3138006', '3153003', '3156006', '3159004', '3169005', '3178004', '3194006', '3198009', '3215002', '3222005', '3227004', '3236000', '3243006', '3255000', '3262009', '3279003', '3295003', '3301002', '3302009', '3315000', '3332001', '3336003', '3341006', '3350008', '3362007', '3366005', '3370002', '3374006', '3377004', '3382006', '3383001', '3394002', '3395001', '3396000', '3400000', '3409004', '3417007', '3438001', '3444002', '3447009', '3460003', '3462006', '3471002', '3478008', '3481003', '3488009', '3490005', '3524005', '3538003', '3541007', '3553006', '3556003', '3563003', '3572006', '3578005', '3582007', '3584008', '3594003', '3608004', '3609007', '3646006', '3663005', '3665003', '3670005', '3711007', '3743007', '3761003', '3766008', '3785006', '3788008', '3789000', '3810000', '3838008', '3860006', '3865001', '3867009', '3876002', '3877006', '3910004', '3916005', '3924000', '3931001', '3935005', '3937002', '3954005', '3956007', '3959000', '3960005', '3964001', '3966004', '3977005', '3984002', '3989007', '4015004', '4019005', '4029003', '4061004', '4066009', '4072009', '4081003', '4093007', '4111006', '4117005', '4121003', '4146003', '4148002', '4150005', '4158003', '4159006', '4180000', '4193005', '4205002', '4212006', '4215008', '4247003', '4258007', '4268002', '4276000', '4281009', '4295007', '4303006', '4312008', '4317002', '4328003', '4335006', '4352005', '4358009', '4360006', '4369007', '4371007', '4375003', '4377006', '4394008', '4402002', '4419000', '4421005', '4430002', '4432005', '4442007', '4486002', '4524000', '4527007', '4537002', '4548009', '4549001', '4566004', '4573009', '4578000', '4583008', '4588004', '4596009', '4603002', '4606005', '4621004', '4624007', '4647008', '4651005', '4658004', '4677002', '4703008', '4717004', '4718009', '4743003', '4755009', '4759003', '4766002', '4768001', '4774001', '4775000', '4799000', '4810005', '4812002', '4828007', '4840007', '4843009', '4861000', '4866005', '4870002', '4871003', '4881004', '4888005', '4897009', '4905007', '4906008', '4924005', '4942000', '4954000', '4956003', '4958002', '5001007', '5023006', '5026003', '5046008', '5068003', '5069006', '5076001', '5115006', '5122003', '5128004', '5140004', '5192008', '5194009', '5195005', '5204005', '5213007', '5225005', '5228007', '5229004', '5261000', '5272005', '5279001', '5296000', '5324007', '5329002', '5336001', '5347008', '5362005', '5366008', '5379004', '5382009', '5394000', '5398002', '5403001', '5421003', '5427004', '5458003', '5459006', '5491007', '5493005', '5498001', '5501001', '5520004', '5538001', '5542003', '5544002', '5560003', '5564007', '5574005', '5580002', '5597008', '5611001', '5625000', '5627008', '5633004', '5643001', '5644007', '5653000', '5665001', '5668004', '5677006', '5682004', '5696005', '5697001', '5709001', '5713008', '5717009', '5718004', '5727003', '5742000', '5751008', '5769004', '5780004', '5798000', '5802004', '5814007', '5815008', '5816009', '5825003', '5828001', '5847003', '5854009', '5868002', '5872003', '5881009', '5882002', '5889006', '5890002', '5893000', '5898009', '5923009', '5926001', '5928000', '5942008', '5943003', '5944009', '5948007', '5951000', '5953002', '5976004', '5979006', '5996007', '6001004', '6004007', '6006009', '6009002', '6013009', '6014003', '6023000', '6032003', '6046003', '6050005', '6059006', '6062009', '6073002', '6074008', '6076005', '6104005', '6105006', '6110005', '6194002', '6216007', '6217003', '6229007', '6253001', '6268000', '6269008', '6279005', '6317000', '6325003', '6326002', '6335009', '6359004', '6371005', '6375001', '6392005', '6404004', '6413002', '6417001', '6423006', '6424000', '6445007', '6448009', '6450001', '6472004', '6504002', '6511003', '6530003', '6533001', '6538005', '6541001', '6544009', '6550004', '6551000', '6553002', '6564004', '6566002', '6572002', '6598008', '6606008', '6608009', '6620001', '6623004', '6633007', '6643005', '6646002', '6649009', '6651008', '6684008', '6685009', '6711001', '6720005', '6731002', '6739000', '6742006', '6750002', '6757004', '6787005', '6789008', '6799003', '6805009', '6820003', '6828005', '6829002', '6834003', '6841009', '6844001', '6850006', '6864006', '6866008', '6871001', '6894000', '6902008', '6905005', '6912001', '6914000', '6921000', '6930008', '6944002', '6969002', '6975006', '6981003', '6987004', '6989001', '6991009', '7035006', '7050002', '7067009', '7076002', '7083009', '7090004', '7091000', '7099003', '7117004', '7121006', '7148007', '7149004', '7154008', '7160008', '7167006', '7173007', '7188002', '7192009', '7227003', '7234001', '7242000', '7275008', '7295002', '7296001', '7311008', '7344002', '7345001', '7347009', '7362006', '7376007', '7378008', '7384006', '7404008', '7435002', '7471001', '7477002', '7480001', '7494000', '7498002', '7507003', '7524009', '7532001', '7554004', '7566005', '7569003', '7591005', '7597009', '7605000', '7610001', '7629007', '7651004', '7652006', '7657000', '7658005', '7697002', '7712004', '7726008', '7736000', '7742001', '7748002', '7755000', '7756004', '7764005', '7769000', '7783003', '7820009', '7829005', '7832008', '7835005', '7840002', '7841003', '7844006', '7851002', '7854005', '7872004', '7874003', '7880006', '7884002', '7885001', '7892006', '7896009', '7911004', '7925003', '7936005', '7944005', '7954009', '7967007', '7986004', '7991003', '7999001', '8001006', '8012006', '8017000', '8024004', '8039003', '8040001', '8045006', '8057002', '8059004', '8067007', '8068002', '8079007', '8091003', '8100009', '8111001', '8112008', '8119004', '8128003', '8133004', '8157004', '8158009', '8159001', '8160006', '8161005', '8165001', '8205005', '8225009', '8242003', '8251006', '8264007', '8265008', '8266009', '8279000', '8289001', '8292002', '8314003', '8334002', '8356004', '8361002', '8369000', '8373002', '8387002', '8389004', '8412003', '8415001', '8454000', '8464009', '8482007', '8483002', '8496001', '8523001', '8546004', '8556000', '8559007', '8560002', '8568009', '8580001', '8595004', '8598002', '8600008', '8603005', '8604004', '8608001', '8617001', '8623006', '8629005', '8640002', '8668003', '8671006', '8677005', '8688004', '8695008', '8710005', '8711009', '8714001', '8752000', '8770002', '8775007', '8784007', '8810002', '8814006', '8815007', '8820007', '8821006', '8827005', '8839002', '8845005', '8850004', '8854008', '8862000', '8873007', '8887007', '8892009', '8894005', '8897003', '8907008', '8910001', '8911002', '8928004', '8931003', '8935007', '8942007', '8965002', '8966001', '8983005', '8988001', '8993003', '9000002', '9003000', '9018004', '9040008', '9055004', '9073001', '9081000', '9086005', '9089003', '9108007', '9127001', '9156001', '9181003', '9185007', '9186008', '9188009', '9208002', '9212008', '9229006', '9231002', '9240003', '9242006', '9258009', '9261005', '9262003', '9284003', '9290004', '9305001', '9317004', '9320007', '9321006', '9325002', '9332006', '9348007', '9379006', '9380009', '9384000', '9390001', '9432007', '9438006', '9454009', '9455005', '9475001', '9481009', '9490002', '9498009', '9502002', '9512009', '9535007', '9558005', '9566001', '9568000', '9596006', '9609000', '9625005', '9642004', '9646001', '9654004', '9659009', '9662007', '9668006', '9677004', '9683001', '9684007', '9708001', '9732008', '9736006', '9743000', '9758008', '9770007', '9775002', '9779008', '9783008', '9791004', '9796009', '9813009', '9825007', '9837009', '9840009', '9841008', '9846003', '9847007', '9849005', '9870004', '9875009', '9878006', '9880000', '9881001', '9891007', '9898001', '9951005', '9968009', '9970000', '9976006', '9994000', '9999005', '10013000', '10024003', '10025002', '10026001', '10036009', '10042008', '10047002', '10052007', '10056005', '10062000', '10119003', '10124000']}, 'type'=>'CodeableConcept', 'path'=>'Procedure.bodySite', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/body-site'}},
        'outcome' => {'valid_codes'=>{'http://snomed.info/sct'=>['385669000', '385671000', '385670004']}, 'type'=>'CodeableConcept', 'path'=>'Procedure.outcome', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/procedure-outcome'}},
        'report' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/DiagnosticReport'], 'type'=>'Reference', 'path'=>'Procedure.report', 'min'=>0, 'max'=>Float::INFINITY},
        'complication' => {'valid_codes'=>{'http://snomed.info/sct'=>['109006', '122003', '127009', '129007', '134006', '140004', '144008', '147001', '150003', '151004', '162004', '165002', '168000', '171008', '172001', '175004', '177007', '179005', '181007', '183005', '184004', '188001', '192008', '193003', '195005', '198007', '199004', '208008', '216004', '219006', '222008', '223003', '228007', '241006', '242004', '253005', '257006', '258001', '264008', '276008', '279001', '281004', '282006', '290006', '292003', '297009', '299007', '303002', '308006', '310008', '313005', '317006', '320003', '324007', '330007', '335002', '341009', '349006', '355001', '357009', '358004', '359007', '360002', '364006', '366008', '368009', '369001', '378007', '382009', '383004', '385006', '387003', '398002', '407000', '408005', '409002', '426008', '431005', '437009', '440009', '442001', '443006', '447007', '450005', '452002', '460001', '467003', '470004', '479003', '486006', '488007', '490008', '496002', '504009', '517007', '518002', '520004', '527001', '536002', '539009', '547009', '548004', '554003', '555002', '563001', '568005', '586008', '590005', '596004', '599006', '600009', '602001', '607007', '610000', '613003', '615005', '616006', '626004', '631002', '634005', '640003', '643001', '646009', '649002', '651003', '652005', '655007', '658009', '663008', '664002', '666000', '675003', '682004', '685002', '701003', '703000', '714002', '715001', '718004', '733007', '734001', '736004', '750009', '755004', '756003', '758002', '775008', '776009', '781000', '786005', '787001', '788006', '792004', '799008', '801006', '805002', '811004', '813001', '815008', '816009', '818005', '825003', '827006', '832007', '834008', '841002', '842009', '843004', '844005', '845006', '849000', '857002', '862001', '865004', '871005', '874002', '875001', '888003', '890002', '899001', '903008', '904002', '908004', '919001', '928000', '931004', '932006', '934007', '943003', '954008', '961007', '962000', '964004', '965003', '975000', '978003', '981008', '984000', '987007', '991002', '998008', '1003002', '1020003', '1023001', '1027000', '1031006', '1033009', '1034003', '1038000', '1045000', '1046004', '1051005', '1055001', '1059007', '1070000', '1073003', '1074009', '1077002', '1079004', '1085006', '1089000', '1102005', '1107004', '1108009', '1111005', '1112003', '1116000', '1124005', '1125006', '1126007', '1131009', '1134001', '1135000', '1139006', '1140008', '1141007', '1145003', '1150009', '1151008', '1152001', '1155004', '1156003', '1168007', '1184008', '1192004', '1194003', '1196001', '1197005', '1201005', '1203008', '1207009', '1208004', '1212005', '1214006', '1230003', '1232006', '1239002', '1240000', '1259003', '1261007', '1264004', '1271009', '1280009', '1282001', '1283006', '1284000', '1286003', '1287007', '1297003', '1308001', '1310004', '1317001', '1318006', '1323006', '1332008', '1335005', '1343000', '1345007', '1351002', '1356007', '1361009', '1363007', '1367008', '1370007', '1372004', '1376001', '1378000', '1380006', '1383008', '1384002', '1386000', '1387009', '1388004', '1393001', '1395008', '1402001', '1412008', '1415005', '1418007', '1419004', '1426004', '1427008', '1430001', '1447000', '1469007', '1474004', '1475003', '1478001', '1479009', '1482004', '1486001', '1488000', '1489008', '1492007', '1493002', '1499003', '1512006', '1515008', '1518005', '1519002', '1521007', '1523005', '1525003', '1531000', '1532007', '1534008', '1538006', '1539003', '1542009', '1544005', '1551001', '1556006', '1563006', '1567007', '1588003', '1592005', '1593000', '1606009', '1608005', '1639007', '1647007', '1648002', '1654001', '1657008', '1658003', '1663004', '1667003', '1670004', '1671000', '1674008', '1679003', '1682008', '1685005', '1686006', '1694004', '1698001', '1703007', '1705000', '1708003', '1714005', '1717003', '1723008', '1724002', '1734006', '1735007', '1739001', '1742007', '1744008', '1748006', '1755008', '1761006', '1763009', '1767005', '1769008', '1771008', '1776003', '1777007', '1778002', '1779005', '1794009', '1816003', '1821000', '1822007', '1824008', '1826005', '1828006', '1829003', '1833005', '1835003', '1837006', '1845001', '1847009', '1848004', '1852004', '1855002', '1856001', '1857005', '1858000', '1860003', '1865008', '1869002', '1881003', '1892002', '1896004', '1897008', '1899006', '1903004', '1908008', '1909000', '1922008', '1926006', '1938002', '1939005', '1943009', '1953005', '1954004', '1955003', '1959009', '1961000', '1963002', '1965009', '1967001', '1973000', '1977004', '1979001', '1980003', '1981004', '1988005', '1989002', '2004005', '2012002', '2024009', '2028007', '2032001', '2036003', '2040007', '2041006', '2043009', '2053005', '2055003', '2058001', '2061000', '2065009', '2066005', '2070002', '2073000', '2087000', '2089002', '2091005', '2094002', '2102007', '2103002', '2107001', '2109003', '2114004', '2116002', '2120003', '2121004', '2128005', '2129002', '2132004', '2134003', '2136001', '2138000', '2145000', '2149006', '2158004', '2167004', '2169001', '2170000', '2176006', '2177002', '2186007', '2198002', '2202000', '2204004', '2213002', '2216005', '2217001', '2219003', '2224000', '2228002', '2229005', '2231001', '2237002', '2239004', '2241003', '2243000', '2245007', '2251002', '2256007', '2261009', '2268003', '2284002', '2295008', '2296009', '2298005', '2301009', '2303007', '2304001', '2307008', '2308003', '2312009', '2314005', '2326000', '2339001', '2341000', '2351004', '2355008', '2359002', '2365002', '2366001', '2367005', '2374000', '2385003', '2388001', '2390000', '2391001', '2396006', '2398007', '2403008', '2415007', '2418009', '2419001', '2420007', '2432006', '2435008', '2437000', '2438005', '2439002', '2443003', '2452007', '2463005', '2469009', '2470005', '2471009', '2472002', '2473007', '2477008', '2492009', '2495006', '2496007', '2506003', '2513003', '2518007', '2521009', '2523007', '2526004', '2528003', '2532009', '2534005', '2538008', '2541004', '2554006', '2556008', '2560006', '2562003', '2576002', '2581006', '2582004', '2583009', '2584003', '2585002', '2589008', '2591000', '2593002', '2602008', '2606006', '2615004', '2618002', '2622007', '2624008', '2625009', '2630008', '2634004', '2638001', '2640006', '2651006', '2655002', '2657005', '2663001', '2665008', '2683000', '2689001', '2694001', '2704003', '2707005', '2713001', '2724004', '2725003', '2733002', '2736005', '2740001', '2749000', '2751001', '2761008', '2764000', '2770006', '2772003', '2775001', '2776000', '2781009', '2782002', '2783007', '2786004', '2790002', '2805007', '2806008', '2807004', '2808009', '2815001', '2816000', '2818004', '2819007', '2825006', '2828008', '2829000', '2831009', '2835000', '2836004', '2838003', '2840008', '2850009', '2853006', '2856003', '2858002', '2884008', '2893009', '2897005', '2899008', '2900003', '2901004', '2902006', '2904007', '2910007', '2912004', '2917005', '2918000', '2919008', '2929001', '2935001', '2940009', '2946003', '2951009', '2955000', '2965006', '2967003', '2972007', '2973002', '2978006', '2981001', '2989004', '2990008', '2992000', '2994004', '2999009', '3002002', '3004001', '3006004', '3009006', '3013004', '3014005', '3018008', '3019000', '3021005', '3023008', '3032005', '3033000', '3038009', '3044008', '3053001', '3059002', '3067005', '3071008', '3072001', '3073006', '3084004', '3089009', '3094009', '3095005', '3097002', '3098007', '3105002', '3109008', '3110003', '3119002', '3129009', '3135009', '3140001', '3144005', '3158007', '3160009', '3163006', '3168002', '3185000', '3199001', '3200003', '3208005', '3214003', '3217005', '3218000', '3219008', '3228009', '3229001', '3230006', '3238004', '3239007', '3253007', '3254001', '3259006', '3261002', '3263004', '3272007', '3274008', '3275009', '3276005', '3277001', '3282008', '3283003', '3286006', '3289004', '3291007', '3298001', '3303004', '3304005', '3305006', '3308008', '3310005', '3321001', '3323003', '3327002', '3331008', '3344003', '3345002', '3355003', '3358001', '3368006', '3376008', '3381004', '3387000', '3391005', '3393008', '3398004', '3401001', '3415004', '3419005', '3421000', '3424008', '3426005', '3427001', '3434004', '3439009', '3441005', '3446000', '3449007', '3456001', '3458000', '3461004', '3464007', '3468005', '3469002', '3472009', '3474005', '3480002', '3482005', '3483000', '3487004', '3500002', '3502005', '3503000', '3505007', '3506008', '3507004', '3511005', '3514002', '3519007', '3528008', '3529000', '3530005', '3531009', '3533007', '3539006', '3542000', '3544004', '3545003', '3548001', '3549009', '3558002', '3560000', '3570003', '3571004', '3577000', '3585009', '3586005', '3589003', '3590007', '3591006', '3598000', '3611003', '3633001', '3634007', '3639002', '3640000', '3641001', '3642008', '3644009', '3649004', '3650004', '3652007', '3657001', '3660008', '3662000', '3677008', '3680009', '3681008', '3696007', '3699000', '3703002', '3704008', '3705009', '3712000', '3716002', '3720003', '3723001', '3733009', '3736001', '3738000', '3744001', '3745000', '3747008', '3750006', '3751005', '3752003', '3754002', '3755001', '3756000', '3759007', '3760002', '3762005', '3763000', '3783004', '3797007', '3798002', '3815005', '3820005', '3827008', '3830001', '3841004', '3845008', '3855007', '3859001', '3873005', '3885002', '3886001', '3899003', '3900008', '3902000', '3903005', '3908001', '3909009', '3913002', '3914008', '3928002', '3939004', '3944006', '3947004', '3950001', '3951002', '3972004', '3975002', '3978000', '3987009', '3993001', '3999002', '4003003', '4004009', '4006006', '4009004', '4016003', '4017007', '4022007', '4026005', '4030008', '4038001', '4039009', '4040006', '4041005', '4046000', '4062006', '4063001', '4069002', '4070001', '4075006', '4082005', '4088009', '4089001', '4092002', '4103001', '4106009', '4107000', '4113009', '4120002', '4124006', '4127004', '4129001', '4135001', '4136000', '4142001', '4152002', '4160001', '4168008', '4170004', '4174008', '4175009', '4178006', '4181001', '4183003', '4184009', '4191007', '4195003', '4197006', '4199009', '4208000', '4210003', '4223005', '4224004', '4225003', '4229009', '4232007', '4237001', '4240001', '4241002', '4242009', '4244005', '4248008', '4249000', '4251001', '4260009', '4262001', '4264000', '4269005', '4273008', '4275001', '4278004', '4283007', '4287008', '4294006', '4300009', '4301008', '4306003', '4307007', '4308002', '4310000', '4313003', '4316006', '4320005', '4324001', '4325000', '4332009', '4338008', '4340003', '4349002', '4354006', '4356008', '4359001', '4364002', '4367009', '4373005', '4374004', '4381006', '4386001', '4390004', '4397001', '4399003', '4403007', '4406004', '4409006', '4410001', '4412009', '4414005', '4416007', '4418008', '4426000', '4434006', '4439001', '4441000', '4445009', '4448006', '4451004', '4461006', '4463009', '4464003', '4465002', '4468000', '4470009', '4473006', '4477007', '4478002', '4481007', '4483005', '160245001']}, 'type'=>'CodeableConcept', 'path'=>'Procedure.complication', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/condition-code'}},
        'complicationDetail' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Condition'], 'type'=>'Reference', 'path'=>'Procedure.complicationDetail', 'min'=>0, 'max'=>Float::INFINITY},
        'followUp' => {'valid_codes'=>{'http://snomed.info/sct'=>['18949003', '30549001', '241031001', '35963001', '225164002', '447346005', '229506003', '274441001', '394725008', '359825008']}, 'type'=>'CodeableConcept', 'path'=>'Procedure.followUp', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/procedure-followup'}},
        'note' => {'type'=>'Annotation', 'path'=>'Procedure.note', 'min'=>0, 'max'=>Float::INFINITY},
        'focalDevice' => {'type'=>'Procedure::FocalDevice', 'path'=>'Procedure.focalDevice', 'min'=>0, 'max'=>Float::INFINITY},
        'usedReference' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Device', 'http://hl7.org/fhir/StructureDefinition/Medication', 'http://hl7.org/fhir/StructureDefinition/Substance'], 'type'=>'Reference', 'path'=>'Procedure.usedReference', 'min'=>0, 'max'=>Float::INFINITY},
        'usedCode' => {'valid_codes'=>{'http://snomed.info/sct'=>['156009', '271003', '287000', '291005', '678001', '739006', '793009', '882002', '972002', '989005', '994005', '1211003', '1333003', '1422002', '1579007', '1766001', '1941006', '1962007', '2248009', '2282003', '2287009', '2468001', '2478003', '2491002', '3201004', '3319006', '4408003', '4632004', '4816004', '5041003', '5042005', '5159002', '5679009', '6012004', '6097006', '6822006', '6919005', '6972009', '7007007', '7402007', '7406005', '7704007', '7733008', '7968002', '7971005', '8060009', '8118007', '8170008', '8384009', '8407004', '8434001', '8451008', '8615009', '8643000', '8682003', '9017009', '9096001', '9129003', '9419002', '9458007', '9611009', '9883003', '10244001', '10371004', '10507000', '10826000', '10850003', '10906003', '11141007', '11158002', '11358008', '11987000', '12150006', '12183004', '12198002', '12953007', '13118005', '13219008', '13288007', '13459008', '13764006', '13855007', '13905003', '14106009', '14108005', '14116001', '14208000', '14288003', '14339000', '14364002', '14423008', '14519003', '14548009', '14762000', '14789005', '15000008', '15340005', '15447007', '15644007', '15869005', '15873008', '15922004', '16056004', '16349000', '16417001', '16470007', '16497000', '16524003', '16540000', '16650009', '17102003', '17107009', '17207004', '17306006', '17404008', '17472008', '18151003', '18153000', '18411005', '18666004', '19257004', '19328000', '19443004', '19627002', '19762002', '19817005', '19892000', '19923001', '20195009', '20235003', '20273004', '20359006', '20406008', '20428008', '20513005', '20568009', '20613002', '20861007', '20867006', '20873007', '20997002', '21079000', '21546008', '21870002', '21944004', '22251003', '22283009', '22566001', '22662007', '22679001', '22744006', '22852002', '23228005', '23366006', '23699001', '23785007', '23973005', '24073000', '24110008', '24174009', '24230000', '24290003', '24402003', '24470005', '24513003', '24697008', '24767007', '25005004', '25062003', '25152007', '25510005', '25632005', '25680008', '25742001', '25937001', '26128008', '26239002', '26334009', '26397000', '26412008', '26579007', '26719000', '26882005', '27042007', '27065002', '27091001', '27126002', '27229001', '27606000', '27785006', '27812008', '27976001', '27991004', '28026003', '29292008', '29319002', '29396008', '30012001', '30070001', '30115002', '30176005', '30234008', '30610008', '30661003', '30929000', '30968007', '31030004', '31031000', '31174004', '31791005', '31878003', '32033000', '32356002', '32504006', '32634007', '32667006', '32711007', '32712000', '32871007', '33194000', '33352006', '33388001', '33482001', '33686008', '33690005', '33802005', '33894003', '33918000', '34164001', '34188004', '34234003', '34263000', '34362008', '34759008', '35398009', '35593004', '35870000', '36365007', '36370000', '36645008', '36761001', '36965003', '36977008', '37189001', '37270008', '37284003', '37311003', '37347002', '37360008', '37503007', '37759000', '37874008', '37953008', '38126007', '38141007', '38277008', '38806006', '38862006', '38871002', '39590006', '39690000', '39768008', '39790008', '39802000', '39821008', '39849001', '39869006', '40388003', '40519001', '41157002', '41323003', '41525006', '41684000', '42152006', '42305009', '42380001', '42451009', '42716000', '42882002', '43001000', '43192004', '43252007', '43725001', '43734006', '43770009', '43983001', '44056008', '44396004', '44492001', '44668000', '44738004', '44806002', '44845007', '44907005', '44959004', '45633005', '45901004', '46181005', '46265007', '46299005', '46364009', '46440007', '46625003', '46666003', '46949002', '47162009', '47326004', '47424002', '47528002', '47731004', '47734007', '47776004', '47942000', '48066006', '48096001', '48240003', '48246009', '48295009', '48473008', '48822005', '48990009', '49448001', '49890001', '50121007', '50457005', '50483000', '50851003', '51016001', '51086006', '51324004', '51685009', '51791000', '51832004', '51883004', '52124006', '52161002', '52291003', '52520009', '52537002', '52624007', '52773007', '52809000', '52893008', '53167006', '53177008', '53217009', '53350007', '53535004', '53639001', '53671008', '53996008', '54234007', '54638004', '54953005', '55091003', '55206006', '55216003', '55337009', '55567004', '55658008', '55986002', '56144002', '56353002', '56547001', '56896002', '56961003', '57118008', '57134006', '57368009', '57395004', '57730005', '58153004', '58253008', '58514003', '58878002', '58938008', '59102007', '59127000', '59153008', '59160002', '59181002', '59432006', '59746007', '59772003', '59782002', '59833007', '60054005', '60110001', '60150003', '60161006', '60185003', '60311007', '60773001', '60806001', '60957001', '61330002', '61512008', '61835000', '61968008', '61979003', '62336005', '62495008', '62614002', '62980002', '63112008', '63173005', '63289001', '63336000', '63548003', '63562005', '63619003', '63653004', '63797009', '63839002', '63995005', '64174005', '64255007', '64565002', '64571008', '64883003', '64973003', '64989000', '65053001', '65105002', '65268008', '65473004', '65577000', '65818007', '66222000', '66415006', '66435007', '66494009', '67270000', '67387001', '67670006', '67777003', '67829007', '67920005', '67966000', '68080007', '68181008', '68183006', '68276009', '68325009', '68597009', '68685003', '68842005', '69670004', '69805005', '69922008', '70080007', '70300000', '70303003', '70453008', '70665002', '70793005', '70872004', '71384000', '71483007', '71545009', '71601002', '71667001', '71948003', '72070000', '72188006', '72302000', '72506001', '72742007', '73027007', '73534004', '73562006', '73571002', '73618007', '73878004', '73985004', '74094004', '74108008', '74300007', '74444006', '74566002', '74884005', '75075000', '75187009', '75192006', '75751006', '75780002', '75963008', '76091005', '76123001', '76428000', '76433001', '76664007', '76705002', '76825006', '76937009', '77444004', '77541009', '77720000', '77755003', '77777004', '78279003', '78498003', '78641001', '78886001', '79051006', '79068005', '79218005', '79287008', '79401009', '79438009', '79481007', '79593001', '79618001', '79811009', '79834000', '79952001', '80278003', '80404000', '80617005', '80664005', '80853009', '80950008', '81293006', '81317009', '81320001', '81826000', '81892008', '82379000', '82449006', '82657000', '82830000', '82879008', '83059008', '83315005', '83320005', '83369007', '83517001', '83903000', '84023008', '84330009', '84444002', '84546002', '84599008', '84610002', '84683006', '84756000', '85106006', '85329008', '85455005', '85684007', '86056006', '86174004', '86184003', '86407004', '86453006', '86572008', '86768006', '86816008', '86967005', '87088005', '87140005', '87405001', '87710003', '87717000', '87851008', '88063004', '88168006', '88208003', '88765001', '88959008', '89149003', '89236003', '89509004', '90003000', '90035000', '90082007', '90134004', '90412006', '90504001', '90913005', '90948003', '91294003', '91318002', '91535004', '91537007', '102303004', '102304005', '102305006', '102306007', '102307003', '102308008', '102309000', '102310005', '102311009', '102312002', '102313007', '102314001', '102315000', '102316004', '102317008', '102318003', '102319006', '102320000', '102321001', '102322008', '102323003', '102324009', '102325005', '102326006', '102327002', '102328007', '102384007', '102385008', '102386009', '102387000', '102388005', '102402008', '102403003', '105784003', '105785002', '105787005', '105788000', '105789008', '105790004', '105791000', '105792007', '105793002', '105794008', '105809003', '108874005', '109184000', '109226007', '109227003', '109228008', '111041008', '111042001', '111043006', '111044000', '111045004', '111047007', '111048002', '111052002', '111060001', '111062009', '115961006', '115962004', '116146000', '116204000', '116205004', '116206003', '116250002', '116251003', '118294000', '118295004', '118296003', '118297007', '118298002', '118299005', '118301003', '118302005', '118303000', '118304006', '118305007', '118306008', '118307004', '118308009', '118309001', '118310006', '118311005', '118312003', '118313008', '118314002', '118315001', '118316000', '118317009', '118318004', '118319007', '118320001', '118321002', '118322009', '118323004', '118324005', '118325006', '118326007', '118327003', '118328008', '118329000', '118330005', '118331009', '118332002', '118333007', '118334001', '118335000', '118336004', '118337008', '118338003', '118342000', '118343005', '118346002', '118347006', '118348001', '118349009', '118350009', '118351008', '118354000', '118355004', '118356003', '118357007', '118371004', '118372006', '118373001', '118374007', '118375008', '118376009', '118377000', '118378005', '118379002', '118380004', '118381000', '118382007', '118383002', '118384008', '118385009', '118386005', '118387001', '118388006', '118389003', '118390007', '118391006', '118392004', '118393009', '118394003', '118396001', '118397005', '118398000', '118399008', '118400001', '118401002', '118402009', '118403004', '118404005', '118405006', '118406007', '118407003', '118408008', '118409000', '118410005', '118411009', '118412002', '118413007', '118414001', '118415000', '118416004', '118418003', '118419006', '118420000', '118421001', '118422008', '118423003', '118424009', '118425005', '118426006', '118427002', '118428007', '118429004', '118643004', '122456005', '123636009', '126064005', '126065006', '128981007', '129113006', '129121000', '129247000', '129248005', '129460009', '129462001', '129463006', '129464000', '129465004', '129466003', '129467007', '134823007', '134963007', '170615005', '182562006', '182563001', '182564007', '182565008', '182566009', '182567000', '182568005', '182569002', '182570001', '182571002', '182572009', '182573004', '182574005', '182576007', '182577003', '182578008', '182579000', '182580002', '182581003', '182587004', '182588009', '182589001', '182590005', '182591009', '182592002', '182839003', '183116000', '183125006', '183135000', '183141007', '183143005', '183144004', '183146002', '183147006', '183148001', '183149009', '183150009', '183152001', '183153006', '183154000', '183155004', '183156003', '183157007', '183158002', '183159005', '183160000', '183161001', '183162008', '183164009', '183165005', '183166006', '183170003', '183171004', '183172006', '183173001', '183174007', '183175008', '183176009', '183177000', '183183002', '183184008', '183185009', '183187001', '183188006', '183189003', '183190007', '183192004', '183193009', '183194003', '183195002', '183196001', '183197005', '183198000', '183199008', '183200006', '183202003', '183204002', '183235008', '183236009', '183240000', '183241001', '183248007', '183249004', '183250004', '183251000', '201706006', '223394001', '224684009', '224685005', '224686006', '224823002', '224824008', '224825009', '224826005', '224827001', '224828006', '224898003', '224899006', '224900001', '228167008', '228235002', '228236001', '228237005', '228239008', '228240005', '228241009', '228242002', '228243007', '228259007', '228260002', '228261003', '228262005', '228264006', '228265007', '228266008', '228267004', '228268009', '228270000', '228271001', '228731007', '228732000', '228733005', '228734004', '228735003', '228736002', '228737006', '228738001', '228739009', '228740006', '228741005', '228742003', '228743008', '228744002', '228745001', '228746000', '228747009', '228748004', '228749007', '228750007', '228751006', '228752004', '228753009', '228754003', '228755002', '228756001', '228757005', '228759008', '228760003', '228761004', '228762006', '228763001', '228765008', '228766009', '228767000', '228768005', '228770001', '228771002', '228772009', '228773004', '228774005', '228775006', '228776007', '228777003', '228778008', '228869008', '229772003', '229839006', '229840008', '229841007', '229842000', '229843005', '243135003', '243719003', '243720009', '243722001', '243723006', '255296002', '255712000', '255716002', '256245006', '256246007', '256247003', '256562002', '256563007', '256564001', '256589007', '256590003', '256593001', '256641009', '256642002', '256643007', '257192006', '257193001', '257194007', '257211007', '257212000', '257213005', '257214004', '257215003', '257216002', '257217006', '257218001', '257219009', '257220003', '257221004', '257222006', '257223001', '257224007', '257225008', '257226009', '257227000', '257228005', '257229002', '257230007', '257231006']}, 'type'=>'CodeableConcept', 'path'=>'Procedure.usedCode', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/device-kind'}}
      }

      class Performer < FHIR::STU3::Model
        include FHIR::STU3::Hashable
        include FHIR::STU3::Json
        include FHIR::STU3::Xml

        METADATA = {
          'id' => {'type'=>'string', 'path'=>'Performer.id', 'min'=>0, 'max'=>1},
          'extension' => {'type'=>'Extension', 'path'=>'Performer.extension', 'min'=>0, 'max'=>Float::INFINITY},
          'modifierExtension' => {'type'=>'Extension', 'path'=>'Performer.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
          'role' => {'valid_codes'=>{'http://snomed.info/sct'=>['1421009', '3430008', '3842006', '4162009', '5275007', '6816002', '6868009', '8724009', '11661002', '11911009', '11935004', '13580004', '14698002', '17561000', '18803008', '18850004', '19244007', '20145008', '21365001', '21450003', '22515006', '22731001', '22983004', '23278007', '24430003', '24590004', '25961008', '26042002', '26369006', '28229004', '28411006', '28544002', '36682004', '37154003', '37504001', '39677007', '40127002', '40204001', '40570005', '41672002', '41904004', '43702002', '44652006', '45419001', '45440000', '45544007', '45956004', '46255001', '48740002', '49203003', '49993003', '50149000', '54503009', '56397003', '56466003', '56542007', '56545009', '57654006', '59058001', '59169001', '59944000', '60008001', '61207006', '61246008', '61345009', '61894003', '62247001', '63098009', '66476003', '66862007', '68867008', '68950000', '69280009', '71838004', '73265009', '75271001', '76166008', '76231001', '76899008', '78703002', '78729002', '79898004', '80409005', '80546007', '80584001', '80933006', '81464008', '82296001', '83189004', '83273008', '83685006', '85733003', '88189002', '88475002', '90201008', '90655003', '106289002', '106291005', '106292003', '106293008', '106294002', '106296000', '106330007', '112247003', '158965000', '158966004', '158967008', '158968003', '158969006', '158970007', '158971006', '158972004', '158973009', '158974003', '158975002', '158977005', '158978000', '158979008', '158980006', '158983008', '158984002', '158985001', '158986000', '158987009', '158988004', '158989007', '158990003', '158992006', '158993001', '158994007', '158995008', '158996009', '158997000', '158998005', '158999002', '159001001', '159002008', '159003003', '159004009', '159005005', '159006006', '159007002', '159010009', '159011008', '159012001', '159013006', '159014000', '159016003', '159017007', '159018002', '159019005', '159021000', '159022007', '159025009', '159026005', '159027001', '159028006', '159033005', '159034004', '159035003', '159036002', '159037006', '159038001', '159039009', '159040006', '159041005', '159141008', '159972006', '160008000', '224529009', '224530004', '224531000', '224532007', '224533002', '224534008', '224535009', '224536005', '224537001', '224538006', '224540001', '224541002', '224542009', '224543004', '224544005', '224545006', '224546007', '224547003', '224548008', '224549000', '224550000', '224551001', '224552008', '224553003', '224554009', '224555005', '224556006', '224557002', '224558007', '224559004', '224560009', '224561008', '224562001', '224563006', '224564000', '224565004', '224566003', '224567007', '224569005', '224570006', '224571005', '224572003', '224573008', '224574002', '224575001', '224576000', '224577009', '224578004', '224579007', '224580005', '224581009', '224583007', '224584001', '224585000', '224586004', '224587008', '224588003', '224589006', '224590002', '224591003', '224592005', '224593000', '224594006', '224595007', '224596008', '224597004', '224598009', '224599001', '224600003', '224601004', '224602006', '224603001', '224604007', '224605008', '224606009', '224607000', '224608005', '224609002', '224610007', '224614003', '224615002', '224620002', '224621003', '224622005', '224623000', '224624006', '224625007', '224626008', '224936003', '225726006', '225727002', '265937000', '265939002', '283875005', '302211009', '303124005', '303129000', '303133007', '303134001', '304291006', '304292004', '307988006', '308002005', '309294001', '309295000', '309296004', '309322005', '309323000', '309324006', '309326008', '309327004', '309328009', '309329001', '309330006', '309331005', '309332003', '309333008', '309334002', '309335001', '309336000', '309337009', '309338004', '309339007', '309340009', '309341008', '309342001', '309343006', '309345004', '309346003', '309347007', '309348002', '309349005', '309350005', '309351009', '309352002', '309353007', '309354001', '309355000', '309356004', '309357008', '309358003', '309359006', '309360001', '309361002', '309362009', '309363004', '309364005', '309365006', '309366007', '309367003', '309368008', '309369000', '309371000', '309372007', '309373002', '309374008', '309375009', '309376005', '309377001', '309378006', '309379003', '309380000', '309381001', '309382008', '309383003', '309384009', '309385005', '309386006', '309388007', '309389004', '309390008', '309391007', '309392000', '309393005', '309394004', '309395003', '309396002', '309397006', '309398001', '309399009', '309400002', '309401003', '309402005', '309403000', '309404006', '309409001', '309410006', '309411005', '309412003', '309413008', '309414002', '309415001', '309416000', '309417009', '309418004', '309419007', '309420001', '309421002', '309422009', '309423004', '309427003', '309428008', '309429000', '309434001', '309435000', '309436004', '309437008', '309439006', '309440008', '309441007', '309442000', '309443005', '309444004', '309445003', '309446002', '309450009', '309452001', '309453006', '309454000', '309455004', '309459005', '309460000', '310170009', '310171008', '310172001', '310173006', '310174000', '310175004', '310176003', '310177007', '310178002', '310179005', '310180008', '310181007', '310182000', '310183005', '310184004', '310185003', '310186002', '310187006', '310188001', '310189009', '310190000', '310191001', '310192008', '310193003', '310194009', '310512001', '311441001', '312485001', '372102007', '387619007', '394572006', '394618009', '397824005', '397897005', '397903001', '397908005', '398130009', '398238009', '404940000', '405277009', '405278004', '405279007', '405623001', '405684005', '405685006', '408798009', '408799001', '409974004', '409975003', '413854007', '415075003', '415506007', '416160000', '420409002', '420678001', '421841007', '422140007', '422234006', '432100008', '442867008', '443090005', '444912007', '445313000', '445451001', '446050000', '446701002', '449161006', '471302004', '3981000175106']}, 'type'=>'CodeableConcept', 'path'=>'Performer.role', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/performer-role'}},
          'actor' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Practitioner', 'http://hl7.org/fhir/StructureDefinition/Organization', 'http://hl7.org/fhir/StructureDefinition/Patient', 'http://hl7.org/fhir/StructureDefinition/RelatedPerson', 'http://hl7.org/fhir/StructureDefinition/Device'], 'type'=>'Reference', 'path'=>'Performer.actor', 'min'=>1, 'max'=>1},
          'onBehalfOf' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Organization'], 'type'=>'Reference', 'path'=>'Performer.onBehalfOf', 'min'=>0, 'max'=>1}
        }

        attr_accessor :id                # 0-1 string
        attr_accessor :extension         # 0-* [ Extension ]
        attr_accessor :modifierExtension # 0-* [ Extension ]
        attr_accessor :role              # 0-1 CodeableConcept
        attr_accessor :actor             # 1-1 Reference(Practitioner|Organization|Patient|RelatedPerson|Device)
        attr_accessor :onBehalfOf        # 0-1 Reference(Organization)
      end

      class FocalDevice < FHIR::STU3::Model
        include FHIR::STU3::Hashable
        include FHIR::STU3::Json
        include FHIR::STU3::Xml

        METADATA = {
          'id' => {'type'=>'string', 'path'=>'FocalDevice.id', 'min'=>0, 'max'=>1},
          'extension' => {'type'=>'Extension', 'path'=>'FocalDevice.extension', 'min'=>0, 'max'=>Float::INFINITY},
          'modifierExtension' => {'type'=>'Extension', 'path'=>'FocalDevice.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
          'action' => {'valid_codes'=>{'http://snomed.info/sct'=>['129265001', '129266000', '129267009', '129268004', '129269007', '129271007', '129272000', '129273005', '129274004', '129275003', '129276002', '129277006', '129278001', '129279009', '129280007', '129283009', '129284003', '129286001', '129287005', '129288000', '129289008', '129291000', '129292007', '129293002', '129294008', '129295009', '129296005', '129297001', '129298006', '129299003', '129300006', '129301005', '129303008', '129304002', '129305001', '129306000', '129307009', '129308004', '129309007', '129310002', '129311003', '129312005', '129313000', '129314006', '129315007', '129316008', '129317004', '129318009', '129319001', '129321006', '129322004', '129323009', '129324003', '129325002', '129326001', '129327005', '129328000', '129330003', '129331004', '129332006', '129333001', '129334007', '129335008', '129337000', '129339002', '129340000', '129344009', '129345005', '129346006', '129347002', '129348007', '129349004', '129350004', '129351000', '129352007', '129353002', '129354008', '129355009', '129356005', '129357001', '129358006', '129360008', '129366002', '129368001', '129369009', '129371009', '129372002', '129373007', '129374001', '129376004', '129377008', '129378003', '129379006', '129380009', '129381008', '129382001', '129383006', '129384000', '129385004', '129386003', '129387007', '129388002', '129389005', '129390001', '129391002', '129392009', '129393004', '129394005', '129395006', '129396007', '129397003', '129398008', '129399000', '129400007', '129401006', '129402004', '129403009', '129404003', '129405002', '129406001', '129407005', '129408000', '129409008', '129410003', '129411004', '129412006', '129413001', '129414007', '129415008', '129416009', '129418005', '129419002', '129420008', '129421007', '129423005', '129424004', '129425003', '129426002', '129427006', '129430004', '129431000', '129433002', '129434008', '129435009', '129436005', '129437001', '129438006', '129441002', '129442009', '129443004', '129444005', '129445006', '129449000', '183648002', '245854003', '245855002', '255595002', '256644001', '257729003', '257730008', '257739009', '257741005', '257742003', '257743008', '257744002', '257745001', '257746000', '257747009', '257748004', '257749007', '257750007', '257751006', '257759008', '257768005', '257777003', '257778008', '257780002', '257781003', '257782005', '257783000', '257784006', '257785007', '257786008', '257788009', '257789001', '257791009', '257802002', '257803007', '257804001', '257805000', '257806004', '257808003', '257811002', '257817003', '257821005', '257822003', '257824002', '257825001', '257846005', '257850003', '257855008', '257857000', '257859002', '257863009', '257867005', '257878002', '257880008', '257884004', '257885003', '257886002', '257889009', '257890000', '257893003', '257894009', '257895005', '257897002', '257903006', '257905004', '257906003', '257907007', '257911001', '257912008', '257913003', '257914009', '257915005', '257916006', '257917002', '257918007', '257923007', '257926004', '257928003', '257933004', '257935006', '257937003', '257938008', '257940003', '258061005', '260222006', '261027000', '261191006', '261197005', '261198000', '261199008', '261391004', '261398005', '261498006', '261499003', '261518005', '261519002', '261520008', '261526002', '261545006', '261553003', '261569005', '261576000', '262143007', '263720003', '264592006', '264594007', '264730003', '264739002', '264947006', '272381008', '274392008', '276734006', '277261002', '277607009', '277763000', '277851003', '277852005', '278110001', '278292003', '278312000', '278313005', '278420002', '281609006', '281613004', '281615006', '281698007', '281767003', '281838007', '281839004', '282015008', '282089006', '282722008', '286553006', '286637000', '286792001', '287682008', '288324002', '288466002', '288468001', '289928003', '289930001', '289936007', '289938008', '290001001', '297179000', '297183000', '298053008', '298116000', '299712004', '299713009', '299893001', '302193003', '302196006', '302199004', '302204005', '302205006', '303893007', '303894001', '303955003', '303996000', '303998004', '304054006', '304904003', '312236008', '312250003', '312251004', '312254007', '312275004', '312336005', '312337001', '312421008', '312883004', '313029009', '360017003', '360018008', '360020006', '360021005', '360025001', '360027009', '360028004', '360029007', '360032005', '360037004', '360038009', '360051004', '360060007', '360082000', '360084004', '360087006', '360146007', '360147003', '360148008', '360149000', '360150000', '360152008', '360153003', '360154009', '360160009', '360161008', '360163006', '360165004', '360166003', '360220002', '360222005', '360223000', '360226008', '360231005', '360232003', '360239007', '360240009', '360270004', '360272007', '360273002', '360314001', '360315000', '360323003', '360324009', '360325005', '360393008', '362939006', '363659002', '363678002', '367529003', '367558000', '367559008', '367560003', '367642006', '367740008', '369242005', '386746003', '399009009', '399015009', '399035005', '399064001', '399155008', '410460000', '410461001', '410462008', '410463003', '410464009', '410465005', '410466006', '410467002', '410756002', '410757006', '410758001', '410759009', '410769003', '410814006', '410817004', '410820007', '415186003', '416677001', '419385000', '419652001', '419656003', '419988009', '424208002', '424832003', '424900004', '425362007', '425689005', '425704008', '425764006', '426413004', '426530000', '426865009', '428010000', '428381003', '430975009', '439054007', '439237009', '439315000', '439417007', '439513008', '440338007', '440647007', '441504007', '442837002', '445103003', '698788008', '698789000', '698790009', '698792001', '698793006', '698794000', '698796003', '698797007', '698798002', '702569007', '713295009']}, 'type'=>'CodeableConcept', 'path'=>'FocalDevice.action', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'preferred', 'uri'=>'http://hl7.org/fhir/ValueSet/device-action'}},
          'manipulated' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Device'], 'type'=>'Reference', 'path'=>'FocalDevice.manipulated', 'min'=>1, 'max'=>1}
        }

        attr_accessor :id                # 0-1 string
        attr_accessor :extension         # 0-* [ Extension ]
        attr_accessor :modifierExtension # 0-* [ Extension ]
        attr_accessor :action            # 0-1 CodeableConcept
        attr_accessor :manipulated       # 1-1 Reference(Device)
      end

      attr_accessor :id                 # 0-1 id
      attr_accessor :meta               # 0-1 Meta
      attr_accessor :implicitRules      # 0-1 uri
      attr_accessor :language           # 0-1 code
      attr_accessor :text               # 0-1 Narrative
      attr_accessor :contained          # 0-* [ Resource ]
      attr_accessor :extension          # 0-* [ Extension ]
      attr_accessor :modifierExtension  # 0-* [ Extension ]
      attr_accessor :identifier         # 0-* [ Identifier ]
      attr_accessor :definition         # 0-* [ Reference(PlanDefinition|ActivityDefinition|HealthcareService) ]
      attr_accessor :basedOn            # 0-* [ Reference(CarePlan|ProcedureRequest|ReferralRequest) ]
      attr_accessor :partOf             # 0-* [ Reference(Procedure|Observation|MedicationAdministration) ]
      attr_accessor :status             # 1-1 code
      attr_accessor :notDone            # 0-1 boolean
      attr_accessor :notDoneReason      # 0-1 CodeableConcept
      attr_accessor :category           # 0-1 CodeableConcept
      attr_accessor :code               # 0-1 CodeableConcept
      attr_accessor :subject            # 1-1 Reference(Patient|Group)
      attr_accessor :context            # 0-1 Reference(Encounter|EpisodeOfCare)
      attr_accessor :performedDateTime  # 0-1 dateTime
      attr_accessor :performedPeriod    # 0-1 Period
      attr_accessor :performer          # 0-* [ Procedure::Performer ]
      attr_accessor :location           # 0-1 Reference(Location)
      attr_accessor :reasonCode         # 0-* [ CodeableConcept ]
      attr_accessor :reasonReference    # 0-* [ Reference(Condition|Observation) ]
      attr_accessor :bodySite           # 0-* [ CodeableConcept ]
      attr_accessor :outcome            # 0-1 CodeableConcept
      attr_accessor :report             # 0-* [ Reference(DiagnosticReport) ]
      attr_accessor :complication       # 0-* [ CodeableConcept ]
      attr_accessor :complicationDetail # 0-* [ Reference(Condition) ]
      attr_accessor :followUp           # 0-* [ CodeableConcept ]
      attr_accessor :note               # 0-* [ Annotation ]
      attr_accessor :focalDevice        # 0-* [ Procedure::FocalDevice ]
      attr_accessor :usedReference      # 0-* [ Reference(Device|Medication|Substance) ]
      attr_accessor :usedCode           # 0-* [ CodeableConcept ]

      def resourceType
        'Procedure'
      end
    end
  end
end