module FHIR
  module STU3
    class ReferralRequest < FHIR::STU3::Model
      include FHIR::STU3::Hashable
      include FHIR::STU3::Json
      include FHIR::STU3::Xml

      MULTIPLE_TYPES = {
        'occurrence' => ['dateTime', 'Period']
      }
      SEARCH_PARAMS = ['patient', 'type', 'authored-on', 'based-on', 'context', 'definition', 'encounter', 'group-identifier', 'identifier', 'intent', 'occurrence-date', 'priority', 'recipient', 'replaces', 'requester', 'service', 'specialty', 'status', 'subject']
      METADATA = {
        'id' => {'type'=>'id', 'path'=>'ReferralRequest.id', 'min'=>0, 'max'=>1},
        'meta' => {'type'=>'Meta', 'path'=>'ReferralRequest.meta', 'min'=>0, 'max'=>1},
        'implicitRules' => {'type'=>'uri', 'path'=>'ReferralRequest.implicitRules', 'min'=>0, 'max'=>1},
        'language' => {'valid_codes'=>{'urn:ietf:bcp:47'=>['ar', 'bn', 'cs', 'da', 'de', 'de-AT', 'de-CH', 'de-DE', 'el', 'en', 'en-AU', 'en-CA', 'en-GB', 'en-IN', 'en-NZ', 'en-SG', 'en-US', 'es', 'es-AR', 'es-ES', 'es-UY', 'fi', 'fr', 'fr-BE', 'fr-CH', 'fr-FR', 'fy', 'fy-NL', 'hi', 'hr', 'it', 'it-CH', 'it-IT', 'ja', 'ko', 'nl', 'nl-BE', 'nl-NL', 'no', 'no-NO', 'pa', 'pt', 'pt-BR', 'ru', 'ru-RU', 'sr', 'sr-SP', 'sv', 'sv-SE', 'te', 'zh', 'zh-CN', 'zh-HK', 'zh-SG', 'zh-TW']}, 'type'=>'code', 'path'=>'ReferralRequest.language', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'extensible', 'uri'=>'http://hl7.org/fhir/ValueSet/languages'}},
        'text' => {'type'=>'Narrative', 'path'=>'ReferralRequest.text', 'min'=>0, 'max'=>1},
        'contained' => {'type'=>'Resource', 'path'=>'ReferralRequest.contained', 'min'=>0, 'max'=>Float::INFINITY},
        'extension' => {'type'=>'Extension', 'path'=>'ReferralRequest.extension', 'min'=>0, 'max'=>Float::INFINITY},
        'modifierExtension' => {'type'=>'Extension', 'path'=>'ReferralRequest.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
        'identifier' => {'type'=>'Identifier', 'path'=>'ReferralRequest.identifier', 'min'=>0, 'max'=>Float::INFINITY},
        'definition' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/ActivityDefinition', 'http://hl7.org/fhir/StructureDefinition/PlanDefinition'], 'type'=>'Reference', 'path'=>'ReferralRequest.definition', 'min'=>0, 'max'=>Float::INFINITY},
        'basedOn' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/ReferralRequest', 'http://hl7.org/fhir/StructureDefinition/CarePlan', 'http://hl7.org/fhir/StructureDefinition/ProcedureRequest'], 'type'=>'Reference', 'path'=>'ReferralRequest.basedOn', 'min'=>0, 'max'=>Float::INFINITY},
        'replaces' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/ReferralRequest'], 'type'=>'Reference', 'path'=>'ReferralRequest.replaces', 'min'=>0, 'max'=>Float::INFINITY},
        'groupIdentifier' => {'type'=>'Identifier', 'path'=>'ReferralRequest.groupIdentifier', 'min'=>0, 'max'=>1},
        'status' => {'valid_codes'=>{'http://hl7.org/fhir/request-status'=>['draft', 'active', 'suspended', 'cancelled', 'completed', 'entered-in-error', 'unknown']}, 'type'=>'code', 'path'=>'ReferralRequest.status', 'min'=>1, 'max'=>1, 'binding'=>{'strength'=>'required', 'uri'=>'http://hl7.org/fhir/ValueSet/request-status'}},
        'intent' => {'valid_codes'=>{'http://hl7.org/fhir/request-intent'=>['proposal', 'plan', 'order', 'original-order', 'reflex-order', 'filler-order', 'instance-order', 'option']}, 'type'=>'code', 'path'=>'ReferralRequest.intent', 'min'=>1, 'max'=>1, 'binding'=>{'strength'=>'required', 'uri'=>'http://hl7.org/fhir/ValueSet/request-intent'}},
        'type' => {'valid_codes'=>{'http://snomed.info/sct'=>['4266003', '17294003', '18781004', '27217005', '28214001', '31751007', '38670004', '41920009', '44383000', '54395008', '55974000', '61801003', '62435005', '69377005', '78429003', '81294000', '86395003', '103696004', '103697008', '103698003', '103699006', '103700007', '103701006', '103702004', '103703009', '103704003', '105406002', '105407006', '134403003', '134440006', '170223003', '170224009', '170225005', '170229004', '170230009', '183444007', '183515008', '183516009', '183517000', '183518005', '183519002', '183520008', '183521007', '183522000', '183523005', '183524004', '183528001', '183529009', '183530004', '183532007', '183541002', '183542009', '183543004', '183544005', '183545006', '183546007', '183547003', '183548008', '183549000', '183555005', '183557002', '183561008', '183563006', '183564000', '183565004', '183567007', '183568002', '183569005', '183583007', '183584001', '183591003', '183595007', '183597004', '183598009', '183606009', '183608005', '183612004', '183659006', '183660001', '183661002', '183662009', '183664005', '183683003', '183684009', '183686006', '183687002', '183688007', '183689004', '183690008', '183691007', '183692000', '183693005', '183695003', '183696002', '183697006', '183699009', '183700005', '183701009', '183702002', '183703007', '183704001', '183705000', '183706004', '183819005', '183820004', '183821000', '183822007', '183823002', '183824008', '183825009', '183826005', '183827001', '183829003', '183830008', '183831007', '183832000', '183833005', '183834004', '183835003', '183838001', '183839009', '183840006', '183841005', '183842003', '183843008', '183844002', '183851006', '183852004', '183853009', '183854003', '183855002', '183856001', '183857005', '183858000', '183859008', '183860003', '183861004', '183862006', '183863001', '183864007', '183866009', '183867000', '183868005', '183874005', '183875006', '183876007', '183877003', '183878008', '183879000', '183880002', '183881003', '183882005', '183884006', '183885007', '183886008', '183887004', '183888009', '183889001', '183890005', '183891009', '183892002', '183893007', '183894001', '183895000', '183896004', '183897008', '183899006', '183900001', '183901002', '183902009', '183903004', '183904005', '183905006', '183906007', '183907003', '183908008', '183909000', '183910005', '183911009', '183912002', '183913007', '183914001', '183915000', '183916004', '183917008', '266747000', '266749002', '266752005', '266753000', '266754006', '266755007', '271363008', '274410002', '275640004', '275648006', '275821008', '276490004', '281097001', '281098006', '281099003', '281100006', '305912004', '305913009', '305914003', '305915002', '305916001', '305917005', '305918000', '305919008', '305920002', '305921003', '305922005', '305923000', '305924006', '305925007', '305926008', '305927004', '305929001', '305930006', '305931005', '305932003', '305933008', '305940009', '305941008', '305942001', '305943006', '305944000', '305945004', '305946003', '305947007', '305948002', '305949005', '305950005', '305951009', '305952002', '305953007', '305954001', '305955000', '305956004', '305957008', '305958003', '305959006', '305960001', '305961002', '305962009', '305963004', '305964005', '305965006', '305966007', '305967003', '305968008', '305970004', '305971000', '305972007', '305973002', '305974008', '305975009', '305976005', '305977001', '305978006', '305979003', '305980000', '305981001', '305983003', '305984009', '305985005', '305986006', '305987002', '305988007', '305989004', '305990008', '305991007', '305992000', '305993005', '305994004', '305995003', '305996002', '305997006', '305998001', '305999009', '306000006', '306001005', '306002003', '306003008', '306004002', '306005001', '306006000', '306007009', '306008004', '306009007', '306010002', '306011003', '306012005', '306013000', '306014006', '306015007', '306016008', '306017004', '306018009', '306019001', '306020007', '306021006', '306022004', '306023009', '306024003', '306025002', '306026001', '306027005', '306028000', '306029008', '306030003', '306031004', '306032006', '306033001', '306034007', '306035008', '306036009', '306037000', '306038005', '306039002', '306040000', '306041001', '306042008', '306043003', '306044009', '306045005', '306046006', '306047002', '306048007', '306050004', '306051000', '306052007', '306053002', '306054008', '306055009', '306056005', '306057001', '306059003', '306060008', '306061007', '306062000', '306063005', '306064004', '306065003', '306066002', '306067006', '306068001', '306069009', '306070005', '306071009', '306072002', '306073007', '306074001', '306076004', '306077008', '306078003', '306079006', '306080009', '306081008', '306082001', '306083006', '306085004', '306086003', '306087007', '306088002', '306089005', '306090001', '306091002', '306092009', '306093004', '306094005', '306095006', '306096007', '306097003', '306098008', '306099000', '306100008', '306101007', '306102000', '306103005', '306104004', '306105003', '306106002', '306107006', '306108001', '306109009', '306110004', '306111000', '306112007', '306113002', '306114008', '306115009', '306116005', '306117001', '306118006', '306119003', '306120009', '306121008', '306122001', '306123006', '306124000', '306125004', '306126003', '306127007', '306128002', '306129005', '306130000', '306131001', '306132008', '306133003', '306134009', '306135005', '306136006', '306137002', '306138007', '306139004', '306140002', '306141003', '306142005', '306143000', '306144006', '306145007', '306146008', '306147004', '306148009', '306149001', '306150001', '306151002', '306152009', '306153004', '306154005', '306156007', '306157003', '306158008', '306159000', '306160005', '306161009', '306162002', '306163007', '306164001', '306165000', '306166004', '306167008', '306168003', '306169006', '306170007', '306171006', '306172004', '306173009', '306174003', '306175002', '306176001', '306177005', '306178000', '306179008', '306180006', '306181005', '306182003', '306184002', '306185001', '306186000', '306187009', '306188004', '306189007', '306190003', '306191004', '306192006', '306193001', '306194007', '306195008', '306197000', '306198005', '306199002', '306200004', '306201000', '306202007', '306203002', '306204008', '306205009', '306206005', '306207001', '306208006', '306209003', '306210008', '306211007', '306212000', '306213005', '306214004', '306215003', '306216002', '306217006', '306218001', '306219009', '306220003', '306221004', '306222006', '306223001', '306224007', '306225008', '306226009', '306227000', '306228005', '306229002', '306230007', '306231006', '306232004', '306233009', '306234003', '306235002', '306236001', '306237005', '306238000', '306239008', '306240005', '306241009', '306242002', '306243007', '306244001', '306245000', '306246004', '306247008', '306248003', '306249006', '306250006', '306251005', '306252003', '306253008', '306254002', '306255001', '306256000', '306257009', '306258004', '306259007', '306260002', '306261003', '306262005', '306263000', '306264006', '306265007', '306266008', '306267004', '306268009', '306269001', '306270000', '306271001', '306272008', '306273003', '306274009', '306275005', '306276006', '306277002', '306278007', '306279004', '306280001', '306281002', '306282009', '306284005', '306285006', '306286007', '306287003', '306288008', '306289000', '306290009', '306291008', '306292001', '306293006', '306294000', '306295004', '306296003', '306297007', '306298002', '306299005', '306300002', '306301003', '306302005', '306303000', '306304006', '306305007', '306306008', '306307004', '306308009', '306309001', '306310006', '306311005', '306312003', '306313008', '306314002', '306315001', '306316000', '306317009', '306318004', '306319007', '306320001', '306321002', '306322009', '306323004', '306324005', '306325006', '306326007', '306327003', '306328008', '306329000', '306330005', '306331009', '306332002', '306333007', '306334001', '306335000', '306336004', '306337008', '306338003', '306339006', '306340008', '306341007', '306342000', '306343005', '306344004', '306345003', '306347006', '306348001', '306349009', '306350009', '306351008', '306352001', '306353006', '306354000', '306355004', '306356003', '306357007', '306358002', '306359005', '306360000', '306361001', '306362008', '306363003', '306364009', '306365005', '306366006', '306367002', '306368007', '306369004', '306370003', '306371004', '306722007', '306723002', '306724008', '306725009', '306726005', '306730008', '306734004', '306735003', '306736002', '306802002', '306929006', '306934005', '307061004', '307063001', '307373005', '307374004', '307375003', '307376002', '307377006', '307378001', '307379009', '307380007', '307777008', '307834000', '307835004', '307836003', '307837007', '308250002', '308435009', '308436005', '308439003', '308440001', '308447003', '308448008', '308449000', '308450000', '308451001', '308452008', '308453003', '308454009', '308455005', '308456006', '308457002', '308458007', '308459004', '308460009', '308461008', '308462001', '308463006', '308464000', '308465004', '308466003', '308468002', '308469005', '308470006', '308471005', '308472003', '308473008', '308474002', '308475001', '308476000', '308477009', '308478004', '308479007', '308480005', '308481009', '308482002', '308483007', '308484001', '308485000', '309046007', '309619003', '309620009', '309622001', '309623006', '309624000', '309625004', '309626003', '309627007', '309628002', '309629005', '309630000', '310353008', '310354002', '310355001', '310434002', '310449005', '310514000', '310515004', '310519005', '312047007', '312051009', '312487009', '312488004', '312856000', '313186001', '315015006', '315232003', '384711009', '384712002', '387624005', '387625006', '390791001', '390797002', '390807002', '390841005', '390857005', '390864007', '390866009', '390881003', '390882005', '390883000', '390890005', '390893007', '390983001', '390984007', '391033001', '391034007', '391104004', '395700008', '396104000', '396150002', '396151003', '396158009', '396159001', '396185002', '397593002', '397603003', '397654003', '397671002', '397684006', '397721007', '397722000', '398752005', '398852003', '398855001', '400973003', '400992001', '401266006', '406158007', '406159004', '408285001', '408286000', '408288004', '408289007', '408342007', '408383005', '408493004', '408494005', '408495006', '408496007', '412712007', '412717001', '412773009', '413082001', '413087007', '413125004', '413127007', '413159000', '413293006', '414230000', '415260000', '415261001', '415262008', '415263003', '415264009', '415265005', '415266006', '415267002', '415268007', '415269004', '415270003', '415271004', '415272006', '415273001', '415274007', '415275008', '415276009', '415277000', '415278005', '415279002', '416076006', '416116000', '416194003', '416291002', '416414009', '416422002', '416457004', '416492007', '416609002', '416790000', '416851006', '416977004', '416999007', '417033000', '417038009', '417073006', '417096006', '417105002', '417146007', '417153003', '417158007', '417213009', '417282008', '417291007', '417311009', '417421000', '417504006', '417511005', '417546002', '417577000', '417699000', '417708006', '417724007', '425971006', '428573000', '428574006', '429201005', '429365000', '429387009', '429709006', '429711002', '431183005', '431260004', '431340005', '431550007', '431551006', '431719007', '431883007', '433151006', '437950007', '438517001', '439163006', '439306007', '439310005', '442135008', '442305005', '444543005', '697982000', '698559005', '698560000', '698561001', '698562008', '698563003', '698564009', '698565005', '698599008', '698943000', '700125004', '700274009', '700275005', '700282009', '700432001', '702475000', '702540003', '702982008', '703155005', '703939004', '703944006', '703974003', '703975002', '703976001', '703978000', '704031007', '704048004', '704050007', '704095000', '704124006', '705146005', '710005006', '710908005', '710909002', '710910007', '710911006', '710912004', '710913009', '710914003', '710915002', '710916001', '711281004', '713109004', '713146000', '713400007', '713442009', '715159005', '715161001', '715189003', '715962007', '716634006']}, 'type'=>'CodeableConcept', 'path'=>'ReferralRequest.type', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/referral-type'}},
        'priority' => {'valid_codes'=>{'http://hl7.org/fhir/request-priority'=>['routine', 'urgent', 'asap', 'stat']}, 'type'=>'code', 'path'=>'ReferralRequest.priority', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'required', 'uri'=>'http://hl7.org/fhir/ValueSet/request-priority'}},
        'serviceRequested' => {'valid_codes'=>{'http://snomed.info/sct'=>['408467006', '394577000', '394578005', '421661004', '408462000', '394579002', '394804000', '394580004', '394803006', '408480009', '408454008', '394809005', '394592004', '394600006', '394601005', '394581000', '408478003', '394812008', '408444009', '394582007', '408475000', '410005002', '394583002', '419772000', '394584008', '408443003', '394802001', '394915009', '394814009', '394808002', '394811001', '408446006', '394586005', '394916005', '408472002', '394597005', '394598000', '394807007', '419192003', '408468001', '394593009', '394813003', '410001006', '394589003', '394591006', '394599008', '394649004', '408470005', '394585009', '394821009', '422191005', '394594003', '416304004', '418960008', '394882004', '394806003', '394588006', '408459003', '394607009', '419610006', '418058008', '420208008', '418652005', '418535003', '418862001', '419365004', '418002000', '419983000', '419170002', '419472004', '394539006', '420112009', '409968004', '394587001', '394913002', '408440000', '418112009', '419815003', '394914008', '408455009', '394602003', '408447002', '394810000', '408450004', '408476004', '408469009', '408466002', '408471009', '408464004', '408441001', '408465003', '394605001', '394608004', '408461007', '408460008', '394606000', '408449004', '418018006', '394604002', '394609007', '408474001', '394610002', '394611003', '408477008', '394801008', '408463005', '419321007', '394576009', '394590007', '409967009', '408448007', '419043006', '394612005', '394733009', '394732004']}, 'type'=>'CodeableConcept', 'path'=>'ReferralRequest.serviceRequested', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/c80-practice-codes'}},
        'subject' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Patient', 'http://hl7.org/fhir/StructureDefinition/Group'], 'type'=>'Reference', 'path'=>'ReferralRequest.subject', 'min'=>1, 'max'=>1},
        'context' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Encounter', 'http://hl7.org/fhir/StructureDefinition/EpisodeOfCare'], 'type'=>'Reference', 'path'=>'ReferralRequest.context', 'min'=>0, 'max'=>1},
        'occurrenceDateTime' => {'type'=>'dateTime', 'path'=>'ReferralRequest.occurrence[x]', 'min'=>0, 'max'=>1},
        'occurrencePeriod' => {'type'=>'Period', 'path'=>'ReferralRequest.occurrence[x]', 'min'=>0, 'max'=>1},
        'authoredOn' => {'type'=>'dateTime', 'path'=>'ReferralRequest.authoredOn', 'min'=>0, 'max'=>1},
        'requester' => {'type'=>'ReferralRequest::Requester', 'path'=>'ReferralRequest.requester', 'min'=>0, 'max'=>1},
        'specialty' => {'valid_codes'=>{'http://hl7.org/fhir/practitioner-specialty'=>['cardio', 'dent', 'dietary', 'midw', 'sysarch']}, 'type'=>'CodeableConcept', 'path'=>'ReferralRequest.specialty', 'min'=>0, 'max'=>1, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/practitioner-specialty'}},
        'recipient' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Practitioner', 'http://hl7.org/fhir/StructureDefinition/Organization', 'http://hl7.org/fhir/StructureDefinition/HealthcareService'], 'type'=>'Reference', 'path'=>'ReferralRequest.recipient', 'min'=>0, 'max'=>Float::INFINITY},
        'reasonCode' => {'valid_codes'=>{'http://snomed.info/sct'=>['109006', '122003', '127009', '129007', '134006', '140004', '144008', '147001', '150003', '151004', '162004', '165002', '168000', '171008', '172001', '175004', '177007', '179005', '181007', '183005', '184004', '188001', '192008', '193003', '195005', '198007', '199004', '208008', '216004', '219006', '222008', '223003', '228007', '241006', '242004', '253005', '257006', '258001', '264008', '276008', '279001', '281004', '282006', '290006', '292003', '297009', '299007', '303002', '308006', '310008', '313005', '317006', '320003', '324007', '330007', '335002', '341009', '349006', '355001', '357009', '358004', '359007', '360002', '364006', '366008', '368009', '369001', '378007', '382009', '383004', '385006', '387003', '398002', '407000', '408005', '409002', '426008', '431005', '437009', '440009', '442001', '443006', '447007', '450005', '452002', '460001', '467003', '470004', '479003', '486006', '488007', '490008', '496002', '504009', '517007', '518002', '520004', '527001', '536002', '539009', '547009', '548004', '554003', '555002', '563001', '568005', '586008', '590005', '596004', '599006', '600009', '602001', '607007', '610000', '613003', '615005', '616006', '626004', '631002', '634005', '640003', '643001', '646009', '649002', '651003', '652005', '655007', '658009', '663008', '664002', '666000', '675003', '682004', '685002', '701003', '703000', '714002', '715001', '718004', '733007', '734001', '736004', '750009', '755004', '756003', '758002', '775008', '776009', '781000', '786005', '787001', '788006', '792004', '799008', '801006', '805002', '811004', '813001', '815008', '816009', '818005', '825003', '827006', '832007', '834008', '841002', '842009', '843004', '844005', '845006', '849000', '857002', '862001', '865004', '871005', '874002', '875001', '888003', '890002', '899001', '903008', '904002', '908004', '919001', '928000', '931004', '932006', '934007', '943003', '954008', '961007', '962000', '964004', '965003', '975000', '978003', '981008', '984000', '987007', '991002', '998008', '1003002', '1020003', '1023001', '1027000', '1031006', '1033009', '1034003', '1038000', '1045000', '1046004', '1051005', '1055001', '1059007', '1070000', '1073003', '1074009', '1077002', '1079004', '1085006', '1089000', '1102005', '1107004', '1108009', '1111005', '1112003', '1116000', '1124005', '1125006', '1126007', '1131009', '1134001', '1135000', '1139006', '1140008', '1141007', '1145003', '1150009', '1151008', '1152001', '1155004', '1156003', '1168007', '1184008', '1192004', '1194003', '1196001', '1197005', '1201005', '1203008', '1207009', '1208004', '1212005', '1214006', '1230003', '1232006', '1239002', '1240000', '1259003', '1261007', '1264004', '1271009', '1280009', '1282001', '1283006', '1284000', '1286003', '1287007', '1297003', '1308001', '1310004', '1317001', '1318006', '1323006', '1332008', '1335005', '1343000', '1345007', '1351002', '1356007', '1361009', '1363007', '1367008', '1370007', '1372004', '1376001', '1378000', '1380006', '1383008', '1384002', '1386000', '1387009', '1388004', '1393001', '1395008', '1402001', '1412008', '1415005', '1418007', '1419004', '1426004', '1427008', '1430001', '1447000', '1469007', '1474004', '1475003', '1478001', '1479009', '1482004', '1486001', '1488000', '1489008', '1492007', '1493002', '1499003', '1512006', '1515008', '1518005', '1519002', '1521007', '1523005', '1525003', '1531000', '1532007', '1534008', '1538006', '1539003', '1542009', '1544005', '1551001', '1556006', '1563006', '1567007', '1588003', '1592005', '1593000', '1606009', '1608005', '1639007', '1647007', '1648002', '1654001', '1657008', '1658003', '1663004', '1667003', '1670004', '1671000', '1674008', '1679003', '1682008', '1685005', '1686006', '1694004', '1698001', '1703007', '1705000', '1708003', '1714005', '1717003', '1723008', '1724002', '1734006', '1735007', '1739001', '1742007', '1744008', '1748006', '1755008', '1761006', '1763009', '1767005', '1769008', '1771008', '1776003', '1777007', '1778002', '1779005', '1794009', '1816003', '1821000', '1822007', '1824008', '1826005', '1828006', '1829003', '1833005', '1835003', '1837006', '1845001', '1847009', '1848004', '1852004', '1855002', '1856001', '1857005', '1858000', '1860003', '1865008', '1869002', '1881003', '1892002', '1896004', '1897008', '1899006', '1903004', '1908008', '1909000', '1922008', '1926006', '1938002', '1939005', '1943009', '1953005', '1954004', '1955003', '1959009', '1961000', '1963002', '1965009', '1967001', '1973000', '1977004', '1979001', '1980003', '1981004', '1988005', '1989002', '2004005', '2012002', '2024009', '2028007', '2032001', '2036003', '2040007', '2041006', '2043009', '2053005', '2055003', '2058001', '2061000', '2065009', '2066005', '2070002', '2073000', '2087000', '2089002', '2091005', '2094002', '2102007', '2103002', '2107001', '2109003', '2114004', '2116002', '2120003', '2121004', '2128005', '2129002', '2132004', '2134003', '2136001', '2138000', '2145000', '2149006', '2158004', '2167004', '2169001', '2170000', '2176006', '2177002', '2186007', '2198002', '2202000', '2204004', '2213002', '2216005', '2217001', '2219003', '2224000', '2228002', '2229005', '2231001', '2237002', '2239004', '2241003', '2243000', '2245007', '2251002', '2256007', '2261009', '2268003', '2284002', '2295008', '2296009', '2298005', '2301009', '2303007', '2304001', '2307008', '2308003', '2312009', '2314005', '2326000', '2339001', '2341000', '2351004', '2355008', '2359002', '2365002', '2366001', '2367005', '2374000', '2385003', '2388001', '2390000', '2391001', '2396006', '2398007', '2403008', '2415007', '2418009', '2419001', '2420007', '2432006', '2435008', '2437000', '2438005', '2439002', '2443003', '2452007', '2463005', '2469009', '2470005', '2471009', '2472002', '2473007', '2477008', '2492009', '2495006', '2496007', '2506003', '2513003', '2518007', '2521009', '2523007', '2526004', '2528003', '2532009', '2534005', '2538008', '2541004', '2554006', '2556008', '2560006', '2562003', '2576002', '2581006', '2582004', '2583009', '2584003', '2585002', '2589008', '2591000', '2593002', '2602008', '2606006', '2615004', '2618002', '2622007', '2624008', '2625009', '2630008', '2634004', '2638001', '2640006', '2651006', '2655002', '2657005', '2663001', '2665008', '2683000', '2689001', '2694001', '2704003', '2707005', '2713001', '2724004', '2725003', '2733002', '2736005', '2740001', '2749000', '2751001', '2761008', '2764000', '2770006', '2772003', '2775001', '2776000', '2781009', '2782002', '2783007', '2786004', '2790002', '2805007', '2806008', '2807004', '2808009', '2815001', '2816000', '2818004', '2819007', '2825006', '2828008', '2829000', '2831009', '2835000', '2836004', '2838003', '2840008', '2850009', '2853006', '2856003', '2858002', '2884008', '2893009', '2897005', '2899008', '2900003', '2901004', '2902006', '2904007', '2910007', '2912004', '2917005', '2918000', '2919008', '2929001', '2935001', '2940009', '2946003', '2951009', '2955000', '2965006', '2967003', '2972007', '2973002', '2978006', '2981001', '2989004', '2990008', '2992000', '2994004', '2999009', '3002002', '3004001', '3006004', '3009006', '3013004', '3014005', '3018008', '3019000', '3021005', '3023008', '3032005', '3033000', '3038009', '3044008', '3053001', '3059002', '3067005', '3071008', '3072001', '3073006', '3084004', '3089009', '3094009', '3095005', '3097002', '3098007', '3105002', '3109008', '3110003', '3119002', '3129009', '3135009', '3140001', '3144005', '3158007', '3160009', '3163006', '3168002', '3185000', '3199001', '3200003', '3208005', '3214003', '3217005', '3218000', '3219008', '3228009', '3229001', '3230006', '3238004', '3239007', '3253007', '3254001', '3259006', '3261002', '3263004', '3272007', '3274008', '3275009', '3276005', '3277001', '3282008', '3283003', '3286006', '3289004', '3291007', '3298001', '3303004', '3304005', '3305006', '3308008', '3310005', '3321001', '3323003', '3327002', '3331008', '3344003', '3345002', '3355003', '3358001', '3368006', '3376008', '3381004', '3387000', '3391005', '3393008', '3398004', '3401001', '3415004', '3419005', '3421000', '3424008', '3426005', '3427001', '3434004', '3439009', '3441005', '3446000', '3449007', '3456001', '3458000', '3461004', '3464007', '3468005', '3469002', '3472009', '3474005', '3480002', '3482005', '3483000', '3487004', '3500002', '3502005', '3503000', '3505007', '3506008', '3507004', '3511005', '3514002', '3519007', '3528008', '3529000', '3530005', '3531009', '3533007', '3539006', '3542000', '3544004', '3545003', '3548001', '3549009', '3558002', '3560000', '3570003', '3571004', '3577000', '3585009', '3586005', '3589003', '3590007', '3591006', '3598000', '3611003', '3633001', '3634007', '3639002', '3640000', '3641001', '3642008', '3644009', '3649004', '3650004', '3652007', '3657001', '3660008', '3662000', '3677008', '3680009', '3681008', '3696007', '3699000', '3703002', '3704008', '3705009', '3712000', '3716002', '3720003', '3723001', '3733009', '3736001', '3738000', '3744001', '3745000', '3747008', '3750006', '3751005', '3752003', '3754002', '3755001', '3756000', '3759007', '3760002', '3762005', '3763000', '3783004', '3797007', '3798002', '3815005', '3820005', '3827008', '3830001', '3841004', '3845008', '3855007', '3859001', '3873005', '3885002', '3886001', '3899003', '3900008', '3902000', '3903005', '3908001', '3909009', '3913002', '3914008', '3928002', '3939004', '3944006', '3947004', '3950001', '3951002', '3972004', '3975002', '3978000', '3987009', '3993001', '3999002', '4003003', '4004009', '4006006', '4009004', '4016003', '4017007', '4022007', '4026005', '4030008', '4038001', '4039009', '4040006', '4041005', '4046000', '4062006', '4063001', '4069002', '4070001', '4075006', '4082005', '4088009', '4089001', '4092002', '4103001', '4106009', '4107000', '4113009', '4120002', '4124006', '4127004', '4129001', '4135001', '4136000', '4142001', '4152002', '4160001', '4168008', '4170004', '4174008', '4175009', '4178006', '4181001', '4183003', '4184009', '4191007', '4195003', '4197006', '4199009', '4208000', '4210003', '4223005', '4224004', '4225003', '4229009', '4232007', '4237001', '4240001', '4241002', '4242009', '4244005', '4248008', '4249000', '4251001', '4260009', '4262001', '4264000', '4269005', '4273008', '4275001', '4278004', '4283007', '4287008', '4294006', '4300009', '4301008', '4306003', '4307007', '4308002', '4310000', '4313003', '4316006', '4320005', '4324001', '4325000', '4332009', '4338008', '4340003', '4349002', '4354006', '4356008', '4359001', '4364002', '4367009', '4373005', '4374004', '4381006', '4386001', '4390004', '4397001', '4399003', '4403007', '4406004', '4409006', '4410001', '4412009', '4414005', '4416007', '4418008', '4426000', '4434006', '4439001', '4441000', '4445009', '4448006', '4451004', '4461006', '4463009', '4464003', '4465002', '4468000', '4470009', '4473006', '4477007', '4478002', '4481007', '4483005']}, 'type'=>'CodeableConcept', 'path'=>'ReferralRequest.reasonCode', 'min'=>0, 'max'=>Float::INFINITY, 'binding'=>{'strength'=>'example', 'uri'=>'http://hl7.org/fhir/ValueSet/clinical-findings'}},
        'reasonReference' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Condition', 'http://hl7.org/fhir/StructureDefinition/Observation'], 'type'=>'Reference', 'path'=>'ReferralRequest.reasonReference', 'min'=>0, 'max'=>Float::INFINITY},
        'description' => {'type'=>'string', 'path'=>'ReferralRequest.description', 'min'=>0, 'max'=>1},
        'supportingInfo' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Resource'], 'type'=>'Reference', 'path'=>'ReferralRequest.supportingInfo', 'min'=>0, 'max'=>Float::INFINITY},
        'note' => {'type'=>'Annotation', 'path'=>'ReferralRequest.note', 'min'=>0, 'max'=>Float::INFINITY},
        'relevantHistory' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Provenance'], 'type'=>'Reference', 'path'=>'ReferralRequest.relevantHistory', 'min'=>0, 'max'=>Float::INFINITY}
      }

      class Requester < FHIR::STU3::Model
        include FHIR::STU3::Hashable
        include FHIR::STU3::Json
        include FHIR::STU3::Xml

        METADATA = {
          'id' => {'type'=>'string', 'path'=>'Requester.id', 'min'=>0, 'max'=>1},
          'extension' => {'type'=>'Extension', 'path'=>'Requester.extension', 'min'=>0, 'max'=>Float::INFINITY},
          'modifierExtension' => {'type'=>'Extension', 'path'=>'Requester.modifierExtension', 'min'=>0, 'max'=>Float::INFINITY},
          'agent' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Practitioner', 'http://hl7.org/fhir/StructureDefinition/Organization', 'http://hl7.org/fhir/StructureDefinition/Patient', 'http://hl7.org/fhir/StructureDefinition/RelatedPerson', 'http://hl7.org/fhir/StructureDefinition/Device'], 'type'=>'Reference', 'path'=>'Requester.agent', 'min'=>1, 'max'=>1},
          'onBehalfOf' => {'type_profiles'=>['http://hl7.org/fhir/StructureDefinition/Organization'], 'type'=>'Reference', 'path'=>'Requester.onBehalfOf', 'min'=>0, 'max'=>1}
        }

        attr_accessor :id                # 0-1 string
        attr_accessor :extension         # 0-* [ Extension ]
        attr_accessor :modifierExtension # 0-* [ Extension ]
        attr_accessor :agent             # 1-1 Reference(Practitioner|Organization|Patient|RelatedPerson|Device)
        attr_accessor :onBehalfOf        # 0-1 Reference(Organization)
      end

      attr_accessor :id                 # 0-1 id
      attr_accessor :meta               # 0-1 Meta
      attr_accessor :implicitRules      # 0-1 uri
      attr_accessor :language           # 0-1 code
      attr_accessor :text               # 0-1 Narrative
      attr_accessor :contained          # 0-* [ Resource ]
      attr_accessor :extension          # 0-* [ Extension ]
      attr_accessor :modifierExtension  # 0-* [ Extension ]
      attr_accessor :identifier         # 0-* [ Identifier ]
      attr_accessor :definition         # 0-* [ Reference(ActivityDefinition|PlanDefinition) ]
      attr_accessor :basedOn            # 0-* [ Reference(ReferralRequest|CarePlan|ProcedureRequest) ]
      attr_accessor :replaces           # 0-* [ Reference(ReferralRequest) ]
      attr_accessor :groupIdentifier    # 0-1 Identifier
      attr_accessor :status             # 1-1 code
      attr_accessor :intent             # 1-1 code
      attr_accessor :type               # 0-1 CodeableConcept
      attr_accessor :priority           # 0-1 code
      attr_accessor :serviceRequested   # 0-* [ CodeableConcept ]
      attr_accessor :subject            # 1-1 Reference(Patient|Group)
      attr_accessor :context            # 0-1 Reference(Encounter|EpisodeOfCare)
      attr_accessor :occurrenceDateTime # 0-1 dateTime
      attr_accessor :occurrencePeriod   # 0-1 Period
      attr_accessor :authoredOn         # 0-1 dateTime
      attr_accessor :requester          # 0-1 ReferralRequest::Requester
      attr_accessor :specialty          # 0-1 CodeableConcept
      attr_accessor :recipient          # 0-* [ Reference(Practitioner|Organization|HealthcareService) ]
      attr_accessor :reasonCode         # 0-* [ CodeableConcept ]
      attr_accessor :reasonReference    # 0-* [ Reference(Condition|Observation) ]
      attr_accessor :description        # 0-1 string
      attr_accessor :supportingInfo     # 0-* [ Reference(Resource) ]
      attr_accessor :note               # 0-* [ Annotation ]
      attr_accessor :relevantHistory    # 0-* [ Reference(Provenance) ]

      def resourceType
        'ReferralRequest'
      end
    end
  end
end